<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class epress_Elementor_Widget_Tabs extends Widget_Base {

    public function get_name() {
        return 'epress-tab-addons';
    }
    
    public function get_title() {
        return __( 'Tabs', 'epresscore' );
    }

	public function get_icon() {
		return "eicon-tabs";
	}
    
	public function get_categories() {
		return [ 'epress-addons' ];
	}

    protected function register_controls() {
        $this->start_controls_section(
            'tab_content',
            [
                'label' => __( 'Tabs', 'epresscore' ),
            ]
        );
            $this->add_control(
                'tab_style',
                [
                    'label' => __( 'Menu Position', 'epresscore' ),
                    'type' => Controls_Manager::SELECT,
                    'default' => '1',
                    'options' => [
                        'top' => __( 'Top Menu', 'epresscore' ),
                        'left' => __( 'Left Menu', 'epresscore' ),
                        'right' => __( 'Right Menu', 'epresscore' ),
                        'bottom' => __( 'Bottom Menu', 'epresscore' ),
                    ],
                ]
            );
            $repeater = new Repeater();
            $repeater->start_controls_tabs('tab_content_item_area_tabs');

                $repeater->start_controls_tab(
                    'tab_content_item_area',
                    [
                        'label' => __( 'Content', 'epresscore' ),
                    ]
                );
                    
                    $repeater->add_control(
                        'tab_title',
                        [
                            'label'   => esc_html__( 'Title', 'epresscore' ),
                            'type'    => Controls_Manager::TEXT,
                            'default' => esc_html__( 'Tab #1', 'epresscore' ),
                        ]
                    );

                    $repeater->add_control(
                        'tab_icon',
                        [
                            'label'   => esc_html__( 'Icon', 'epresscore' ),
                            'type'    => Controls_Manager::ICON,
                        ]
                    );

                    $repeater->add_control(
                        'content_source',
                        [
                            'label'   => esc_html__( 'Select Content Source', 'epresscore' ),
                            'type'    => Controls_Manager::SELECT,
                            'default' => 'custom',
                            'options' => [
                                'custom'    => esc_html__( 'Content', 'epresscore' ),
                                "elementor" => esc_html__( 'Template', 'epresscore' ),
                            ],
                        ]
                    );

                     $repeater->add_control(
                        'template_id',
                        [
                            'label'       => __( 'Content', 'epresscore' ),
                            'type'        => Controls_Manager::SELECT,
                            'default'     => '0',
                            'options'     => epress_elementor_template(),
                            'condition'   => [
                                'content_source' => "elementor"
                            ],
                        ]
                    );

                     $repeater->add_control(
                        'custom_content',
                        [
                            'label' => __( 'Content', 'epresscore' ),
                            'type' => Controls_Manager::WYSIWYG,
                            'title' => __( 'Content', 'epresscore' ),
                            'show_label' => false,
                            'condition' => [
                                'content_source' =>'custom',
                            ],
                        ]
                    );

                $repeater->end_controls_tab();// Tab Content area end

                // Style area start
                $repeater->start_controls_tab(
                    'tab_item_style_area',
                    [
                        'label' => __( 'Style', 'epresscore' ),
                    ]
                );
                    
                    $repeater->add_control(
                        'tab_title_color',
                        [
                            'label'     => esc_html__( 'Title Color', 'epresscore' ),
                            'type'      => Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .epress-tab-nav a{{CURRENT_ITEM}}' => 'color: {{VALUE}}',
                            ],
                        ]
                    );
                    
                    $repeater->add_group_control(
                        Group_Control_Background::get_type(),
                        [
                            'name' => 'title_background',
                            'label' => __( 'Background', 'epresscore' ),
                            'types' => [ 'classic', 'gradient' ],
                            'selector' => '{{WRAPPER}} .epress-tab-nav a{{CURRENT_ITEM}}',
                        ]
                    );

                    $repeater->add_control(
                        'tab_title_active_color',
                        [
                            'label'     => esc_html__( 'Title Active Color', 'epresscore' ),
                            'type'      => Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .epress-tab-nav li.active a{{CURRENT_ITEM}}' => 'color: {{VALUE}}',
                            ],
                        ]
                    );

                    $repeater->add_group_control(
                        Group_Control_Background::get_type(),
                        [
                            'name' => 'title_active_background',
                            'label' => __( 'Background', 'epresscore' ),
                            'types' => [ 'classic', 'gradient' ],
                            'selector' => '{{WRAPPER}} .epress-tab-nav li.active a{{CURRENT_ITEM}}',
                        ]
                    );

                    $repeater->add_control(
                        'tab_icon_color',
                        [
                            'label'     => esc_html__( 'Icon Color', 'epresscore' ),
                            'type'      => Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .epress-tab-nav a{{CURRENT_ITEM}} i' => 'color: {{VALUE}}',
                            ],
                            'condition' => [
                                'tab_icon!' => '',
                            ],
                            'separator' => 'before',
                        ]
                    );

                    $repeater->add_control(
                        'tab_icon_size',
                        [
                            'label' => __( 'Icon Size', 'epresscore' ),
                            'type'  => Controls_Manager::SLIDER,
                            'range' => [
                                'px' => [
                                    'min' => 0,
                                    'max' => 100,
                                ],
                            ],
                            'default' => [
                                'size' => 14,
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .epress-tab-nav a{{CURRENT_ITEM}} i' => 'font-size: {{SIZE}}{{UNIT}};',
                            ],
                        ]
                    );

                    $repeater->add_control(
                        'tab_icon_active_color',
                        [
                            'label'     => esc_html__( 'Active Icon Color', 'epresscore' ),
                            'type'      => Controls_Manager::COLOR,
                            'selectors' => [
                                '{{WRAPPER}} .epress-tab-nav li.active a{{CURRENT_ITEM}} i' => 'color: {{VALUE}}',
                            ],
                            'condition' => [
                                'tab_icon!' => '',
                            ]
                        ]
                    );

                $repeater->end_controls_tab(); // Style area end

            $repeater->end_controls_tabs();

            $this->add_control(
                'epress_tabs_list',
                [
                    'type'    => Controls_Manager::REPEATER,
                    'fields'  => array_values( $repeater->get_controls() ),
                    'default' => [
                        [
                            'tab_title' => esc_html__( 'Title #1', 'epresscore' ),
                            'custom_content' => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolo magna aliqua. Ut enim ad minim veniam, quis nostrud exerci ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in repre in voluptate.','epresscore' ),
                        ],
                        [
                            'tab_title' => esc_html__( 'Title #2', 'epresscore' ),
                            'custom_content' => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolo magna aliqua. Ut enim ad minim veniam, quis nostrud exerci ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in repre in voluptate.','epresscore' ),
                        ],
                        [
                            'tab_title' => esc_html__( 'Title #3', 'epresscore' ),
                            'custom_content' => esc_html__( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolo magna aliqua. Ut enim ad minim veniam, quis nostrud exerci ullamco laboris nisi ut aliquip ex ea commodo consequat. Duis aute irure dolor in repre in voluptate.','epresscore' ),
                        ],
                    ],
                    'title_field' => '{{{ tab_title }}}',
                ]
            );
            
        $this->end_controls_section();

        
        
        // Style tab area tab section
        $this->start_controls_section(
            'epress_tab_style_full_area',
            [
                'label' => __( 'Full Area', 'epresscore' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
            
            $this->add_responsive_control(
                'epress_tab_full_margin',
                [
                    'label' => __( 'Margin', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-tabs' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'default' => [
                        'top' => '0',
                        'right' => '0',
                        'bottom' => '0',
                        'left' => '0',
                        'isLinked' => false
                    ],
                    'separator' =>'before',
                ]
            );

            $this->add_responsive_control(
                'epress_tab_full_padding',
                [
                    'label' => __( 'Padding', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'default' => [
                        'top' => '0',
                        'right' => '0',
                        'bottom' => '0',
                        'left' => '0',
                        'isLinked' => false
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-tabs' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );
        
            $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name' => 'epress_tab_full_bg',
                    'label' => __( 'Background', 'epresscore' ),
                    'types' => [ 'classic', 'gradient' ],
                    'selector' => '{{WRAPPER}} .epress-tabs',
                ]
            );
            $this->add_group_control(
                Group_Control_Border::get_type(),
                [
                    'name' => 'epress_tab_full_border',
                    'label' => __( 'Border', 'epresscore' ),
                    'selector' => '{{WRAPPER}} .epress-tabs',
                ]
            );
            $this->add_group_control(
                Group_Control_Box_Shadow::get_type(),
                [
                    'name' => 'epress_tab_full_shadow',
                    'label' => __( 'Box Shadow', 'epresscore' ),
                    'selector' => '{{WRAPPER}} .epress-tabs',
                ]
            );
            $this->add_responsive_control(
                'epress_tab_full_width',
                [
                    'label' => __( 'Width', 'epresscore' ),
                    'type' => Controls_Manager::SLIDER,
                    'size_units' => [ 'px', '%', 'vw' ],
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 9999,
                            'step' => 1,
                        ],
                        '%' => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-tabs' => 'width: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );
            $this->add_responsive_control(
                'epress_tab_full_height',
                [
                    'label' => __( 'Height', 'epresscore' ),
                    'type' => Controls_Manager::SLIDER,
                    'size_units' => [ 'px', '%' ],
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 9999,
                            'step' => 1,
                        ],
                        '%' => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-tabs' => 'height: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );
        
            $this->add_responsive_control(
                'epress_tab_full_border_radius',
                [
                    'label' => esc_html__( 'Border Radius', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'selectors' => [
                        '{{WRAPPER}} .epress-tabs' => 'border-radius: {{TOP}}px {{RIGHT}}px {{BOTTOM}}px {{LEFT}}px;',
                    ],
                ]
            );
            $this->add_responsive_control(
                'custom_full_area_css',
                [
                    'label' => __( 'Custom CSS', 'epresscore' ),
                    'type' => Controls_Manager::CODE,
                    'rows' => 20,
                    'language' => 'css',
                    'selectors' => [
                        '{{WRAPPER}} .epress-tabs' => '{{VALUE}};',
                    ],
                    'separator' =>'before',
                ]
            );

        $this->end_controls_section();
        
        // Style tab area tab section
        $this->start_controls_section(
            'epress_tab_style_area',
            [
                'label' => __( 'Tab Menu', 'epresscore' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
            
            $this->add_responsive_control(
                'epress_tab_section_margin',
                [
                    'label' => __( 'Margin', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-tab-nav' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'default' => [
                        'top' => '0',
                        'right' => '0',
                        'bottom' => '0',
                        'left' => '0',
                        'isLinked' => false
                    ],
                    'separator' =>'before',
                ]
            );

            $this->add_responsive_control(
                'epress_tab_section_padding',
                [
                    'label' => __( 'Padding', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'default' => [
                        'top' => '10',
                        'right' => '0',
                        'bottom' => '10',
                        'left' => '0',
                        'isLinked' => false
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-tab-nav' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );
        
            $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name' => 'epress_tab_section_bg',
                    'label' => __( 'Background', 'epresscore' ),
                    'types' => [ 'classic', 'gradient' ],
                    'selector' => '{{WRAPPER}} .epress-tab-nav',
                ]
            );
            $this->add_group_control(
                Group_Control_Border::get_type(),
                [
                    'name' => 'epress_tab_section_border',
                    'label' => __( 'Border', 'epresscore' ),
                    'selector' => '{{WRAPPER}} .epress-tab-nav',
                ]
            );
            $this->add_group_control(
                Group_Control_Box_Shadow::get_type(),
                [
                    'name' => 'epress_tab_section_shadow',
                    'label' => __( 'Box Shadow', 'epresscore' ),
                    'selector' => '{{WRAPPER}} .epress-tab-nav',
                ]
            );
            $this->add_responsive_control(
                'epress_tab_section_width',
                [
                    'label' => __( 'Width', 'epresscore' ),
                    'type' => Controls_Manager::SLIDER,
                    'size_units' => [ 'px', '%', 'vw' ],
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 9999,
                            'step' => 1,
                        ],
                        '%' => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-tab-nav' => 'width: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );
            $this->add_responsive_control(
                'epress_tab_section_height',
                [
                    'label' => __( 'Height', 'epresscore' ),
                    'type' => Controls_Manager::SLIDER,
                    'size_units' => [ 'px', '%' ],
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 9999,
                            'step' => 1,
                        ],
                        '%' => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-tab-nav' => 'height: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );
        
            $this->add_responsive_control(
                'epress_tab_section_border_radius',
                [
                    'label' => esc_html__( 'Border Radius', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'selectors' => [
                        '{{WRAPPER}} .epress-tab-nav' => 'border-radius: {{TOP}}px {{RIGHT}}px {{BOTTOM}}px {{LEFT}}px;',
                    ],
                ]
            );
            $this->add_responsive_control(
                'custom_buttons_css',
                [
                    'label' => __( 'Custom CSS', 'epresscore' ),
                    'type' => Controls_Manager::CODE,
                    'rows' => 20,
                    'language' => 'css',
                    'selectors' => [
                        '{{WRAPPER}} .epress-tab-nav' => '{{VALUE}};',
                    ],
                    'separator' =>'before',
                ]
            );

        $this->end_controls_section();
        
        
		$this->start_controls_section(
			'tab_button_style_section',
			[
				'label' => __( 'Tab Button', 'epresscore' ),
				'tab' => Controls_Manager::TAB_STYLE,
			]
		);
        $this->add_responsive_control(
            'menu_text_align',
            [
                'label' => __( 'Alignment', 'epresscore' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => __( 'Left', 'epresscore' ),
                        'icon' => 'fa fa-align-left',
                    ],
                    'center' => [
                        'title' => __( 'Center', 'epresscore' ),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => __( 'Right', 'epresscore' ),
                        'icon' => 'fa fa-align-right',
                    ]
                ],
                'selectors' => [
                    '{{WRAPPER}} .epress-tab-nav .tab-button' => 'text-align: {{VALUE}};',
                ],
                'separator' =>'before',
            ]
        );
		$this->add_group_control(
			Group_Control_Typography::get_type(),
			[
				'name' => 'tab_button_typography',
				'selector' => '{{WRAPPER}} .epress-tab-nav .tab-button',
			]
		);
		$this->start_controls_tabs( 'tabs_button_style' );

		$this->start_controls_tab(
			'tab_button_normal',
			[
				'label' => __( 'Normal', 'epresscore' ),
			]
		);

		$this->add_control(
			'tab_button__color',
			[
				'label' => __( 'Color', 'epresscore' ),
				'type' => Controls_Manager::COLOR,
				'default' => '#CACBD2',
				'selectors' => [
					'{{WRAPPER}} .epress-tab-nav .tab-button' => 'color: {{VALUE}};',
				],
			]
		);
        $this->add_control(
            'epress_tab_item_width',
            [
                'label' => __( 'Width', 'epresscore' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%', 'vw' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 9999,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .epress-tab-nav li' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        
        $this->add_group_control(
			Group_Control_Background::get_type(),
			[
				'name' => 'tab_button_background_color',
				'label' => __( 'Background', 'epresscore' ),
				'types' => [ 'classic', 'gradient' ],
				'selector' => '{{WRAPPER}} .epress-tab-nav .tab-button',
			]
		);
        
        $this->add_responsive_control(
            'tab_button_margin',
            [
                'label' => __( 'Margin', 'epresscore' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'default' => [
                    'top' => '0',
                    'right' => '0',
                    'bottom' => '0',
                    'left' => '0',
                    'isLinked' => false
                ],
                'selectors' => [
                    '{{WRAPPER}} .epress-tab-nav .tab-button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator' =>'before',
            ]
        );
        
        $this->add_responsive_control(
            'tab_button_padding',
            [
                'label' => __( 'Padding', 'epresscore' ),
                'type' => Controls_Manager::DIMENSIONS,
                'default' => [
                    'top' => '15',
                    'right' => '40',
                    'bottom' => '15',
                    'left' => '40',
                    'isLinked' => false
                ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .epress-tab-nav .tab-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator' =>'before',
            ]
        );   
        
        $this->add_group_control(
			Group_Control_Border::get_type(),
			[
				'name' => 'tab_button_border',
				'selector' => '{{WRAPPER}} .epress-tab-nav .tab-button',
			]
		);

        $this->add_control(
			'tab_button_radius',
			[
				'label' => __( 'Border Radius', 'epresscore' ),
				'type' => Controls_Manager::DIMENSIONS,
				'size_units' => [ 'px', '%' ],                
                'default' => [
                    'top' => '0',
                    'right' => '0',
                    'bottom' => '0',
                    'left' => '0',
                    'isLinked' => false
                ],
				'selectors' => [
					'{{WRAPPER}} .epress-tab-nav .tab-button' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
				],
			]
		);
        
        $this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'tab_button_box_shadow',
				'selector' => '{{WRAPPER}} .epress-tab-nav .tab-button',
			]
		);

        $this->add_responsive_control(
            'custom_item_css',
            [
                'label' => __( 'Custom CSS', 'epresscore' ),
                'type' => Controls_Manager::CODE,
                'rows' => 20,
                'language' => 'css',
                'selectors' => [
                    '{{WRAPPER}} .epress-tab-nav li' => '{{VALUE}};',
                ],
                'separator' =>'before',
            ]
        );

		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_hover',
			[
				'label' => __( 'Hover', 'epresscore' ),
			]
		);

		$this->add_control(
			'tab_button_hover_color',
			[
				'label' => __( 'Color', 'epresscore' ),
				'type' => Controls_Manager::COLOR,
                'default' => '#ffffff',
				'selectors' => [
					'{{WRAPPER}} .epress-tab-nav .tab-button:hover, {{WRAPPER}} .epress-tab-nav li.active .tab-button' => 'color: {{VALUE}};',
                    '{{WRAPPER}} .epress-tab-nav li:before' => 'background-color: {{VALUE}};',
				],
			]
		);

		$this->add_control(
			'tab_button_hover_background',
			[
				'label' => __( 'Background Color', 'epresscore' ),
				'type' => Controls_Manager::COLOR,
                'default' => '#ff5621',
				'selectors' => [
					'{{WRAPPER}} .epress-tab-nav .tab-button:hover, {{WRAPPER}} .epress-tab-nav li.active .tab-button' => 'background-color: {{VALUE}};',
				],
			]
		);
        
        $this->add_responsive_control(
            'epress_tab_button_active_font_size',
            [
                'label' => __( 'Font Size', 'epresscore' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%', 'vw' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 9999,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .epress-tab-nav li.active .tab-button' => 'font-size: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
		$this->add_control(
			'tab_button_hover_border_color',
			[
				'label' => __( 'Border Color', 'epresscore' ),
				'type' => Controls_Manager::COLOR,
				'selectors' => [
					'{{WRAPPER}} .epress-tab-nav .tab-button:hover, {{WRAPPER}} .epress-tab-nav li.active .tab-button' => 'border-color: {{VALUE}};',
				],
			]
		);
		$this->add_group_control(
			Group_Control_Box_Shadow::get_type(),
			[
				'name' => 'tab_button_hover_box_shadow',
				'selector' => '{{WRAPPER}} .epress-tab-nav .tab-button:hover, {{WRAPPER}} .epress-tab-nav li.active .tab-button',
			]
		);

		$this->end_controls_tab();

		$this->end_controls_tabs();
		
		$this->end_controls_section();
        
        $this->start_controls_section(
			'tab_button_icon_section',
			[
				'label' => __( 'Button Icon', 'epresscore' ),
				'tab' => Controls_Manager::TAB_STYLE
			]
		);
        
        
            $this->add_responsive_control(
                'button_icon_floting',
                [
                    'label' => __( 'Float', 'epresscore' ),
                    'type' => Controls_Manager::CHOOSE,
                    'options' => [
                        'left' => [
                            'title' => __( 'Left', 'epresscore' ),
                            'icon' => 'fa fa-align-left',
                        ],
                        'none' => [
                            'title' => __( 'Center', 'epresscore' ),
                            'icon' => 'fa fa-align-center',
                        ],
                        'right' => [
                            'title' => __( 'Right', 'epresscore' ),
                            'icon' => 'fa fa-align-right',
                        ]
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-tab-nav .tab-button i' => 'float: {{VALUE}};',
                    ],
                    'separator' =>'before',
                ]
            );
        

        $this->start_controls_tabs( 'tabs_button_icon_style' );

		$this->start_controls_tab(
			'tab_button_icon_normal',
			[
				'label' => __( 'Normal', 'epresscore' ),
			]
		);
            $this->add_responsive_control(
                'button_icon_margin',
                [
                    'label' => __( 'Margin', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-tab-nav .tab-button i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );
            $this->add_responsive_control(
                'button_icon_opacity',
                [
                    'label' => __( 'Opacity (%)', 'vcharitycore' ),
                    'type' => Controls_Manager::SLIDER,
                    'default' => [
                        'size' => 1,
                    ],
                    'range' => [
                        'px' => [
                            'max' => 1,
                            'step' => 0.01,
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-tab-nav .tab-button i' => 'opacity: {{SIZE}}',

                    ],
                ]
            );
        
		$this->end_controls_tab();

		$this->start_controls_tab(
			'tab_button_icon_hover',
			[
				'label' => __( 'Hover', 'epresscore' ),
			]
		);
            $this->add_responsive_control(
                'button_icon_margin_hover',
                [
                    'label' => __( 'Margin', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-tab-nav .tab-button:hover i,{{WRAPPER}} .epress-tab-nav .active .tab-button i' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );
            $this->add_responsive_control(
                'button_icon_opacity_hover',
                [
                    'label' => __( 'Opacity (%)', 'vcharitycore' ),
                    'type' => Controls_Manager::SLIDER,
                    'default' => [
                        'size' => 1,
                    ],
                    'range' => [
                        'px' => [
                            'max' => 1,
                            'step' => 0.01,
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-tab-nav .tab-button:hover i,{{WRAPPER}} .epress-tab-nav .active .tab-button i' => 'opacity: {{SIZE}}',

                    ],
                ]
            );        

		$this->end_controls_tab();
		$this->end_controls_tabs();
		$this->end_controls_section();
        
        
        // Style tab section
        $this->start_controls_section(
            'tab_style_content_section',
            [
                'label' => __( 'Content', 'epresscore' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
            
            $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name' => 'tab_content_background',
                    'label' => __( 'Background', 'epresscore' ),
                    'types' => [ 'classic', 'gradient' ],
                    'selector' => '{{WRAPPER}} .epress-single-tab',
                ]
            );

            $this->add_group_control(
                Group_Control_Border::get_type(),
                [
                    'name' => 'tab_content_border',
                    'label' => __( 'Border', 'epresscore' ),
                    'selector' => '{{WRAPPER}} .epress-single-tab',
                ]
            );

            $this->add_responsive_control(
                'tab_content_border_radius',
                [
                    'label' => esc_html__( 'Border Radius', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'selectors' => [
                        '{{WRAPPER}} .epress-single-tab' => 'border-radius: {{TOP}}px {{RIGHT}}px {{BOTTOM}}px {{LEFT}}px;',
                    ],
                ]
            );

            $this->add_responsive_control(
                'tab_content_padding',
                [
                    'label' => __( 'Padding', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-single-tab' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' => 'before',
                ]
            );

            $this->add_responsive_control(
                'tab_content_margin',
                [
                    'label' => __( 'Margin', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-single-tab' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                ]
            );

            $this->add_control(
                'epress_tab_content_width',
                [
                    'label' => __( 'Width', 'epresscore' ),
                    'type' => Controls_Manager::SLIDER,
                    'size_units' => [ 'px', '%', 'vw' ],
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 9999,
                            'step' => 1,
                        ],
                        '%' => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .tab-content' => 'width: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );

            $this->add_control(
                'epress_tab_content_height',
                [
                    'label' => __( 'Height', 'epresscore' ),
                    'type' => Controls_Manager::SLIDER,
                    'size_units' => [ 'px', '%', 'vw' ],
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 9999,
                            'step' => 1,
                        ],
                        '%' => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .tab-content' => 'height: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );

            $this->add_responsive_control(
                'custom_content_css',
                [
                    'label' => __( 'Custom CSS', 'epresscore' ),
                    'type' => Controls_Manager::CODE,
                    'rows' => 20,
                    'language' => 'css',
                    'selectors' => [
                        '{{WRAPPER}} .tab-content' => '{{VALUE}};',
                    ],
                    'separator' =>'before',
                ]
            );

        $this->end_controls_section();

    }

    protected function render( $instance = [] ) {
        $settings   = $this->get_settings_for_display();
        $this->add_render_attribute( 'epress_tab_attr', 'class', 'epress-tabs' );
        $this->add_render_attribute( 'epress_tab_attr', 'class', 'epress-tab-'.$settings['tab_style'] );
        $this->add_render_attribute( 'epress_tab_menu_attr', 'class', 'epress-tab-nav');
        $this->add_render_attribute( 'epress_tab_menu_attr', 'role', 'tablist');
        $this->add_render_attribute( 'epress_tab_menu_attr', 'class', 'epress-tab-nav-'.$settings['tab_style'] );
        $id = $this->get_id();       
        ?>
            <div <?php echo $this->get_render_attribute_string( 'epress_tab_attr' ); ?>>

                <ul <?php echo $this->get_render_attribute_string( 'epress_tab_menu_attr' ); ?>>
                    <?php
                        $i=0;
                        foreach ( $settings['epress_tabs_list'] as $item ) {
                            $i++;
                            $tabbuttontxt = $item['tab_title'];
                            if( $i == 1 ){ $active_tab = 'active'; } else{ $active_tab = ''; }
                            if( !empty( $item['tab_icon'] ) ){ $tabbuttontxt = $item['tab_title'].'<i class="'.$item['tab_icon'].'"></i>'; }
                            echo sprintf( '<li class="%1$s" ><a class="tab-button %4$s" href="#epresstab-%2$s" data-toggle="tab" role="tab">%3$s</a></li>',$active_tab, $id.$i, $tabbuttontxt, 'elementor-repeater-item-'.$item['_id']);
                        }
                    ?>
                </ul>
                <div class="epress-tab-content-area tab-content">
                    <?php
                        $i=0;
                        foreach ( $settings['epress_tabs_list'] as $item ) {
                            $i++;
                            if( $i == 1 ){ $active_tab = 'active in'; } else{ $active_tab = ''; }

                            if ( $item['content_source'] == 'custom' && !empty( $item['custom_content'] ) ) {
                                $tab_content =  wp_kses_post( $item['custom_content'] );
                            } elseif ( $item['content_source'] == "elementor" && !empty( $item['template_id'] )) {
                                $tab_content =  Plugin::instance()->frontend->get_builder_content_for_display( $item['template_id'] );
                            }
                            echo sprintf('<div class="epress-single-tab tab-pane fade %1$s %4$s" id="epresstab-%2$s" role="tabpanel"><div class="epress-tab-content">%3$s</div></div>', $active_tab, $id.$i, $tab_content,'elementor-repeater-item-'.$item['_id'] );
                        }
                    ?>
                </div>
            </div>
        <?php
    }
}
Plugin::instance()->widgets_manager->register_widget_type( new epress_Elementor_Widget_Tabs );