<?php
namespace Elementor;

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

class epress_Testimonial_Widget extends Widget_Base {

    public function get_name() {
        return 'epress-testimonial-addons';
    }
    
    public function get_title() {
        return __( 'Testimonial', 'epresscore' );
    }

    public function get_icon() {
        return 'eicon-testimonial-carousel';
    }

    public function get_categories() {
        return [ 'epress-addons' ];
    }

    public function get_script_depends() {
        return [
            'slick',
            'el-widget-active',
        ];
    }
    
    protected function register_controls() {

        $this->start_controls_section(
            'epress_testimonial_content_section',
            [
                'label' => __( 'Testimonial', 'epresscore' ),
            ]
        );

            $this->add_control(
                'slider_on',
                [
                    'label' => esc_html__( 'Slider', 'epresscore' ),
                    'type' => Controls_Manager::SWITCHER,
                    'return_value' => 'yes',
                    'default' => 'yes',
                    'separator'=>'before',
                ]
            );

            $this->add_control(
                'quote_image',
                [
                    'label' => __( 'Quote Image', 'epresscore' ),
                    'type' => Controls_Manager::MEDIA,
                ]
            );

            $this->add_group_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name' => 'quote_image_size',
                    'default' => 'large',
                    'separator' => 'none',
                ]
            );

        
            $repeater = new Repeater(); 
            $repeater->add_control(
                'feed_rating',
                [
                    'label' => __( 'Rating Star', 'epresscore' ),
                    'type' => Controls_Manager::NUMBER,
                    'min' => 0,
                    'max' => 5,
                    'step' => 1,
                    'default' => 4,
                ]
            );
            $repeater->add_control(
                'feedback_title',
                [
                    'label'   => __( 'Feedback Title', 'epresscore' ),
                    'type'    => Controls_Manager::TEXTAREA,
                    'default' => __('Support the treatment of a baby at risk','epresscore'),
                ]
            );
            $repeater->add_control(
                'client_say',
                [
                    'label'   => __( 'Client Say', 'epresscore' ),
                    'type'    => Controls_Manager::TEXTAREA,
                    'default' => __('Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.','epresscore'),
                ]
            );
        
            $repeater->add_control(
                'client_name',
                [
                    'label'   => __( 'Name', 'epresscore' ),
                    'type'    => Controls_Manager::TEXT,
                    'default' => __('Carolina Monntoya','epresscore'),
                ]
            );


            $repeater->add_control(
                'client_designation',
                [
                    'label'   => __( 'Designation', 'epresscore' ),
                    'type'    => Controls_Manager::TEXT,
                    'default' => __('Managing Director','epresscore'),
                ]
            );
            $repeater->add_control(
                'client_image',
                [
                    'label' => __( 'Image', 'epresscore' ),
                    'type' => Controls_Manager::MEDIA,
                ]
            );

            $repeater->add_group_control(
                Group_Control_Image_Size::get_type(),
                [
                    'name' => 'client_imagesize',
                    'default' => 'large',
                    'separator' => 'none',
                ]
            );

            $this->add_control(
                'epress_testimonial_list',
                [
                    'type'    => Controls_Manager::REPEATER,
                    'fields'  => array_values( $repeater->get_controls() ),
                    'default' => [

                        [
                            'feed_rating'           => 5,                            
                            'feedback_title'           => __('Support the treatment of a baby at risk','epresscore'),
                            'client_name'           => __('Carolina Monntoya','epresscore'),
                            'client_designation'    => __( 'founder, uithemes','epresscore' ),
                            'client_say'            => __( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.', 'epresscore' ),
                        ],

                        [
                            'feed_rating'           => 4,                            
                            'feedback_title'           => __('Support the treatment of a baby at risk','epresscore'),
                            'client_name'           => __('Peter Rose','epresscore'),
                            'client_designation'    => __( 'Manager','epresscore' ),
                            'client_say'            => __( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.', 'epresscore' ),
                        ],

                        [
                            'feed_rating'           => 3,                            
                            'feedback_title'           => __('Support the treatment of a baby at risk','epresscore'),
                            'client_name'           => __('Gerald Gilbert','epresscore'),
                            'client_designation'    => __( 'Developer','epresscore' ),
                            'client_say'            => __( 'Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.', 'epresscore' ),
                        ],
                    ],
                    'title_field' => '{{{ client_name }}}',
                ]
            );


        $this->end_controls_section();


        // Carousel setting
        $this->start_controls_section(
            'slider_option',
            [
                'label' => esc_html__( 'Carousel Option', 'epresscore' ),
                'condition' => [
                    'slider_on' => 'yes',
                ]
            ]
        );

            $this->add_control(
                'slitems',
                [
                    'label' => esc_html__( 'Slider Items', 'epresscore' ),
                    'type' => Controls_Manager::NUMBER,
                    'min' => 1,
                    'max' => 20,
                    'step' => 1,
                    'default' => 3,
                    'condition' => [
                        'slider_on' => 'yes',
                    ]
                ]
            );

            $this->add_control(
                'slarrows',
                [
                    'label' => esc_html__( 'Slider Arrow', 'epresscore' ),
                    'type' => Controls_Manager::SWITCHER,
                    'return_value' => 'yes',
                    'default' => 'yes',
                    'condition' => [
                        'slider_on' => 'yes',
                    ]
                ]
            );

            $this->add_control(
                'slprevicon',
                [
                    'label' => __( 'Previous icon', 'epresscore' ),
                    'type' => Controls_Manager::ICON,
                    'default' => 'fa fa-angle-left',
                    'condition' => [
                        'slider_on' => 'yes',
                        'slarrows' => 'yes',
                    ]
                ]
            );

            $this->add_control(
                'slnexticon',
                [
                    'label' => __( 'Next icon', 'epresscore' ),
                    'type' => Controls_Manager::ICON,
                    'default' => 'fa fa-angle-right',
                    'condition' => [
                        'slider_on' => 'yes',
                        'slarrows' => 'yes',
                    ]
                ]
            );

            $this->add_control(
                'sldots',
                [
                    'label' => esc_html__( 'Slider dots', 'epresscore' ),
                    'type' => Controls_Manager::SWITCHER,
                    'return_value' => 'yes',
                    'default' => 'no',
                    'condition' => [
                        'slider_on' => 'yes',
                    ]
                ]
            );

            $this->add_control(
                'slpause_on_hover',
                [
                    'type' => Controls_Manager::SWITCHER,
                    'label_off' => __('No', 'epresscore'),
                    'label_on' => __('Yes', 'epresscore'),
                    'return_value' => 'yes',
                    'default' => 'yes',
                    'label' => __('Pause on Hover?', 'epresscore'),
                    'condition' => [
                        'slider_on' => 'yes',
                    ]
                ]
            );
            $this->add_control(
                'slcentermode',
                [
                    'label' => esc_html__( 'Center Mode', 'epresscore' ),
                    'type' => Controls_Manager::SWITCHER,
                    'return_value' => 'yes',
                    'default' => 'no',
                    'condition' => [
                        'slider_on' => 'yes',
                    ]
                ]
            );

            $this->add_control(
                'slcenterpadding',
                [
                    'label' => esc_html__( 'Center padding', 'epresscore' ),
                    'type' => Controls_Manager::NUMBER,
                    'min' => 0,
                    'max' => 500,
                    'step' => 1,
                    'default' => 50,
                    'condition' => [
                        'slider_on' => 'yes',
                        'slcentermode' => 'yes',
                    ]
                ]
            );
                
            $this->add_control(
                'slverticalmode',
                [
                    'label' => __( 'Vertical Mode', 'epresscore' ),
                    'type' => Controls_Manager::SWITCHER,
                    'return_value' => 'yes',
                    'default' => 'no',
                    'condition' => [
                        'slider_on' => 'yes',
                    ]
                ]
            );

            $this->add_control(
                'slautolay',
                [
                    'label' => esc_html__( 'Slider auto play', 'epresscore' ),
                    'type' => Controls_Manager::SWITCHER,
                    'return_value' => 'yes',
                    'separator' => 'before',
                    'default' => 'no',
                    'condition' => [
                        'slider_on' => 'yes',
                    ]
                ]
            );

            $this->add_control(
                'slautoplay_speed',
                [
                    'label' => __('Autoplay speed', 'epresscore'),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 3000,
                    'condition' => [
                        'slider_on' => 'yes',
                    ]
                ]
            );


            $this->add_control(
                'slanimation_speed',
                [
                    'label' => __('Autoplay animation speed', 'epresscore'),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 300,
                    'condition' => [
                        'slider_on' => 'yes',
                    ]
                ]
            );

            $this->add_control(
                'slscroll_columns',
                [
                    'label' => __('Slider item to scroll', 'epresscore'),
                    'type' => Controls_Manager::NUMBER,
                    'min' => 1,
                    'max' => 10,
                    'step' => 1,
                    'default' => 1,
                    'condition' => [
                        'slider_on' => 'yes',
                    ]
                ]
            );

            $this->add_control(
                'heading_tablet',
                [
                    'label' => __( 'Tablet', 'epresscore' ),
                    'type' => Controls_Manager::HEADING,
                    'separator' => 'after',
                    'condition' => [
                        'slider_on' => 'yes',
                    ]
                ]
            );

            $this->add_control(
                'sltablet_display_columns',
                [
                    'label' => __('Slider Items', 'epresscore'),
                    'type' => Controls_Manager::NUMBER,
                    'min' => 1,
                    'max' => 8,
                    'step' => 1,
                    'default' => 1,
                    'condition' => [
                        'slider_on' => 'yes',
                    ]
                ]
            );

            $this->add_control(
                'sltablet_scroll_columns',
                [
                    'label' => __('Slider item to scroll', 'epresscore'),
                    'type' => Controls_Manager::NUMBER,
                    'min' => 1,
                    'max' => 8,
                    'step' => 1,
                    'default' => 1,
                    'condition' => [
                        'slider_on' => 'yes',
                    ]
                ]
            );

            $this->add_control(
                'sltablet_width',
                [
                    'label' => __('Tablet Resolution', 'epresscore'),
                    'description' => __('The resolution to tablet.', 'epresscore'),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 750,
                    'condition' => [
                        'slider_on' => 'yes',
                    ]
                ]
            );

            $this->add_control(
                'heading_mobile',
                [
                    'label' => __( 'Mobile Phone', 'epresscore' ),
                    'type' => Controls_Manager::HEADING,
                    'separator' => 'after',
                    'condition' => [
                        'slider_on' => 'yes',
                    ]
                ]
            );

            $this->add_control(
                'slmobile_display_columns',
                [
                    'label' => __('Slider Items', 'epresscore'),
                    'type' => Controls_Manager::NUMBER,
                    'min' => 1,
                    'max' => 4,
                    'step' => 1,
                    'default' => 1,
                    'condition' => [
                        'slider_on' => 'yes',
                    ]
                ]
            );

            $this->add_control(
                'slmobile_scroll_columns',
                [
                    'label' => __('Slider item to scroll', 'epresscore'),
                    'type' => Controls_Manager::NUMBER,
                    'min' => 1,
                    'max' => 4,
                    'step' => 1,
                    'default' => 1,
                    'condition' => [
                        'slider_on' => 'yes',
                    ]
                ]
            );

            $this->add_control(
                'slmobile_width',
                [
                    'label' => __('Mobile Resolution', 'epresscore'),
                    'description' => __('The resolution to mobile.', 'epresscore'),
                    'type' => Controls_Manager::NUMBER,
                    'default' => 480,
                    'condition' => [
                        'slider_on' => 'yes',
                    ]
                ]
            );

        $this->end_controls_section(); // Slider Option end
        
        // Style Testimonial area tab section
        $this->start_controls_section(
            'epress_testimonial_style_area',
            [
                'label' => __( 'Area Style', 'epresscore' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
            
            $this->add_responsive_control(
                'epress_testimonial_section_margin',
                [
                    'label' => __( 'Margin', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial-area' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );

            $this->add_responsive_control(
                'epress_testimonial_section_padding',
                [
                    'label' => __( 'Padding', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial-area' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );
        
            $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name' => 'epress_testimonial_section_bg',
                    'label' => __( 'Background', 'epresscore' ),
                    'default' => '#ffffff',
                    'types' => [ 'classic', 'gradient' ],
                    'selector' => '{{WRAPPER}} .epress-testimonial-area',
                ]
            );
            $this->add_group_control(
                Group_Control_Border::get_type(),
                [
                    'name' => 'epress_testimonial_section_border',
                    'label' => __( 'Border', 'epresscore' ),
                    'selector' => '{{WRAPPER}} .epress-testimonial-area',
                ]
            );
            $this->add_group_control(
                Group_Control_Box_Shadow::get_type(),
                [
                    'name' => 'epress_testimonial_section_shadow',
                    'label' => __( 'Box Shadow', 'epresscore' ),
                    'selector' => '{{WRAPPER}} .epress-testimonial-area',
                ]
            );
            $this->add_control(
                'epress_testimonial_section_width',
                [
                    'label' => __( 'Width', 'epresscore' ),
                    'type' => Controls_Manager::SLIDER,
                    'size_units' => [ 'px', '%', 'vw' ],
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 9999,
                            'step' => 1,
                        ],
                        '%' => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial-area' => 'width: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );
            $this->add_control(
                'epress_testimonial_section_height',
                [
                    'label' => __( 'Height', 'epresscore' ),
                    'type' => Controls_Manager::SLIDER,
                    'size_units' => [ 'px', '%' ],
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 9999,
                            'step' => 1,
                        ],
                        '%' => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial-area' => 'height: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );
        
            $this->add_responsive_control(
                'epress_testimonial_section_border_radius',
                [
                    'label' => esc_html__( 'Border Radius', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial-area' => 'border-radius: {{TOP}}px {{RIGHT}}px {{BOTTOM}}px {{LEFT}}px;',
                    ],
                ]
            );

        $this->end_controls_section();
        
        
        // Service Style tab section
        $this->start_controls_section(
            'testimonial_column_style_section',
            [
                'label' => __( 'Column Style', 'epresscore' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition' => [
                    'slider_on!' => 'yes',
                ]
            ]
        );
        $this->add_responsive_control(
            'testimonial_column_margin',
            [
                'label' => __( 'Margin', 'epresscore' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .epress-testimonial-area.testimonial-grid .testimonial-column' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator' =>'before',
            ]
        );        
        $this->add_responsive_control(
            'testimonial_column_padding',
            [
                'label' => __( 'Padding', 'epresscore' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .epress-testimonial-area.testimonial-grid .testimonial-column' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator' =>'before',
            ]
        );        
        $this->add_responsive_control(
            'testimonial_column_width',
            [
                'label' => __( 'Width', 'epresscore' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ]
                ],
                'default' => [
                    'unit' => '%',
                    'size' => 50,
                ],
                'selectors' => [
                    '{{WRAPPER}} .epress-testimonial-area.testimonial-grid .testimonial-column' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $this->end_controls_section();        
        
        // Style Testimonial area tab section
        $this->start_controls_section(
            'epress_testimonial_box_area',
            [
                'label' => __( 'Box Style', 'epresscore' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
            
            $this->add_responsive_control(
                'epress_testimonial_box_alignment',
                [
                    'label' => __( 'Alignment', 'epresscore' ),
                    'type' => Controls_Manager::CHOOSE,
                    'options' => [
                        'left' => [
                            'title' => __( 'Left', 'epresscore' ),
                            'icon' => 'fa fa-align-left',
                        ],
                        'center' => [
                            'title' => __( 'Center', 'epresscore' ),
                            'icon' => 'fa fa-align-center',
                        ],
                        'right' => [
                            'title' => __( 'Right', 'epresscore' ),
                            'icon' => 'fa fa-align-right',
                        ],
                        'justify' => [
                            'title' => __( 'Justified', 'epresscore' ),
                            'icon' => 'fa fa-align-justify',
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial' => 'text-align: {{VALUE}};'
                    ],
                    'default' => 'left',
                    'separator' =>'before',
                ]
            );
            $this->add_responsive_control(
                'epress_testimonial_box_margin',
                [
                    'label' => __( 'Margin', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'default' => [
                        'top' => '0',
                        'right' => '0',
                        'bottom' => '0',
                        'left' => '0',
                        'isLinked' => false
                    ],
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );  
            $this->add_responsive_control(
                'epress_testimonial_box_padding',
                [
                    'label' => __( 'Padding', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'default' => [
                        'top' => '60',
                        'right' => '60',
                        'bottom' => '60',
                        'left' => '60',
                        'isLinked' => false
                    ],
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );  
            $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name' => 'epress_testimonial_box_bg',
                    'label' => __( 'Background', 'epresscore' ),
                    'types' => [ 'classic', 'gradient' ],
                    'selector' => '{{WRAPPER}} .epress-testimonial',
                ]
            );
            $this->add_group_control(
                Group_Control_Border::get_type(),
                [
                    'name' => 'epress_testimonial_box_border',
                    'label' => __( 'Border', 'epresscore' ),
                    'selector' => '{{WRAPPER}} .epress-testimonial',
                ]
            );
            $this->add_group_control(
                Group_Control_Box_Shadow::get_type(),
                [
                    'name' => 'epress_testimonial_box_shadow',
                    'label' => __( 'Box Shadow', 'epresscore' ),
                    'selector' => '{{WRAPPER}} .epress-testimonial',
                ]
            );
            $this->add_responsive_control(
                'epress_testimonial_box_border_radius',
                [
                    'label' => esc_html__( 'Border Radius', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial' => 'border-radius: {{TOP}}px {{RIGHT}}px {{BOTTOM}}px {{LEFT}}px;',
                    ],
                ]
            );

        $this->end_controls_section();


        // Feature Style tab section
        $this->start_controls_section(
            'box_quote_section',
            [
                'label' => __( 'Quote', 'epresscore' ),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_responsive_control(
            'quote_width',
            [
                'label' => __( 'Width', 'epresscore' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .epress-testimonial .quote' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );        
        
        $this->add_responsive_control(
            'quote_height',
            [
                'label' => __( 'Height', 'epresscore' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .epress-testimonial .quote' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'quote_line_height',
            [
                'label' => __( 'Line Height', 'epresscore' ),
                'type' => Controls_Manager::SLIDER,
                'size_units' => [ 'px', '%' ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .epress-testimonial .quote' => 'line-height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Background::get_type(),
            [
                'name' => 'quote_background',
                'label' => __( 'Background', 'epresscore' ),
                'types' => [ 'classic', 'gradient' ],
                'selector' => '{{WRAPPER}} .epress-testimonial .quote',
            ]
        );
         $this->add_responsive_control(
            'quote_floting',
            [
                'label' => __( 'Float Icon', 'epresscore' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => __( 'Left', 'epresscore' ),
                        'icon' => 'fa fa-align-left',
                    ],
                    'none' => [
                        'title' => __( 'None', 'epresscore' ),
                        'icon' => 'fa fa-align-center',
                    ],
                    'right' => [
                        'title' => __( 'Right', 'epresscore' ),
                        'icon' => 'fa fa-align-right',
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .epress-testimonial .quote' => 'float: {{VALUE}};',
                ],
                'default' => 'none',
                'separator' =>'before',
            ]
        );
                
        $this->add_responsive_control(
            'quote_margin',
            [
                'label' => __( 'Margin', 'epresscore' ),
                'type' => Controls_Manager::DIMENSIONS,
                'default' => [
                    'top' => '0',
                    'right' => '0',
                    'bottom' => '15',
                    'left' => '0',
                    'isLinked' => false
                ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .epress-testimonial .quote' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator' =>'before',
            ]
        );
        
        $this->add_responsive_control(
            'quote_padding',
            [
                'label' => __( 'Padding', 'epresscore' ),
                'type' => Controls_Manager::DIMENSIONS,
                'default' => [
                    'top' => '0',
                    'right' => '0',
                    'bottom' => '0',
                    'left' => '0',
                    'isLinked' => false
                ],
                'size_units' => [ 'px', '%', 'em' ],
                'selectors' => [
                    '{{WRAPPER}} .epress-testimonial .quote' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
                'separator' =>'before',
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name' => 'quote_border',
                'label' => __( 'Border', 'epresscore' ),
                'selector' => '{{WRAPPER}} .epress-testimonial .quote',
            ]
        );
        $this->add_responsive_control(
            'quote_border_radius',
            [
                'label' => esc_html__( 'Border Radius', 'epresscore' ),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => [ 'px', '%', 'em' ],
                'default' => [
                    'top' => '100',
                    'right' => '100',
                    'bottom' => '100',
                    'left' => '100',
                    'isLinked' => false,
                    'unit' => '%',
                ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 1000,
                        'step' => 1,
                    ],
                    '%' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .epress-testimonial .quote' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ]
            ]
        );
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name' => 'quote_shadow',
                'label' => __( 'Box Shadow', 'epresscore' ),
                'selector' => '{{WRAPPER}} .epress-testimonial .quote',
            ]
        );
		$this->add_responsive_control(
			'quote_icon_css',
			[
				'label' => __( 'Custom CSS', 'epresscore' ),
				'type' => Controls_Manager::CODE,
				'rows' => 20,
				'language' => 'css',
				'selectors' => [
					'{{WRAPPER}} .epress-testimonial .quote' => '{{VALUE}};',
				],
				'separator' =>'before',
			]
		);
        $this->end_controls_section();
        
        // Style Testimonial name style start
        $this->start_controls_section(
            'epress_testimonial_title_style',
            [
                'label'     => __( 'Title', 'epresscore' ),
                'tab'       => Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_control(
                'epress_testimonial_title_color',
                [
                    'label' => __( 'Color', 'epresscore' ),
                    'type' => Controls_Manager::COLOR,
                    
                    'default' => '#070c24',
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial .feedback-title' => 'color: {{VALUE}};',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'epress_testimonial_title_typography',
                    'selector' => '{{WRAPPER}} .epress-testimonial .feedback-title',
                ]
            );

            $this->add_responsive_control(
                'epress_testimonial_title_margin',
                [
                    'label' => __( 'Margin', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'default' => [
                        'top' => '0',
                        'right' => '0',
                        'bottom' => '15',
                        'left' => '0',
                        'isLinked' => false
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial .feedback-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                    ],
                    'separator' =>'before',
                ]
            );

            $this->add_responsive_control(
                'epress_testimonial_title_padding',
                [
                    'label' => __( 'Padding', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial .feedback-title' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );

        $this->end_controls_section(); // Style Testimonial name style end
        
         // Style Testimonial designation style start
        $this->start_controls_section(
            'epress_testimonial_clientsay_style',
            [
                'label'     => __( 'Client say', 'epresscore' ),
                'tab'       => Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_control(
                'epress_testimonial_clientsay_color',
                [
                    'label' => __( 'Color', 'epresscore' ),
                    'type' => Controls_Manager::COLOR,
                   
                    'default' => '#001a40',
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial .content' => 'color: {{VALUE}};',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'epress_testimonial_clientsay_typography',
                    'selector' => '{{WRAPPER}} .epress-testimonial .content',
                ]
            );

            $this->add_responsive_control(
                'epress_testimonial_clientsay_margin',
                [
                    'label' => __( 'Margin', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial .content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'default' => [
                        'top' => '0',
                        'right' => '0',
                        'bottom' => '30',
                        'left' => '0',
                        'isLinked' => false
                    ],
                    'separator' =>'before',
                ]
            );

            $this->add_responsive_control(
                'epress_testimonial_clientsay_padding',
                [
                    'label' => __( 'Padding', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial .content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                    ],
                    'separator' =>'before',
                ]
            );

        $this->end_controls_section(); // Style Testimonial designation style end// Style Testimonial designation style start
       
        // Style Testimonial name style start
        $this->start_controls_section(
            'epress_testimonial_name_style',
            [
                'label'     => __( 'Name', 'epresscore' ),
                'tab'       => Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_control(
                'epress_testimonial_name_color',
                [
                    'label' => __( 'Color', 'epresscore' ),
                    'type' => Controls_Manager::COLOR,
                  
                    'default' => '#001a40',
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial .ft-content .name' => 'color: {{VALUE}};',
                    ],
                ]
            );

            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'epress_testimonial_name_typography',
                    'selector' => '{{WRAPPER}} .epress-testimonial .ft-content .name',
                ]
            );

            $this->add_responsive_control(
                'epress_testimonial_name_margin',
                [
                    'label' => __( 'Margin', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'default' => [
                        'top' => '18',
                        'right' => '0',
                        'bottom' => '5',
                        'left' => '0',
                        'isLinked' => false
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial .ft-content .name' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                    ],
                    'separator' =>'before',
                ]
            );

            $this->add_responsive_control(
                'epress_testimonial_name_padding',
                [
                    'label' => __( 'Padding', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial .ft-content .name' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );

        $this->end_controls_section(); // Style Testimonial name style end
        // Style Testimonial name style start
        $this->start_controls_section(
            'epress_testimonial_designation_style',
            [
                'label'     => __( 'Designation', 'epresscore' ),
                'tab'       => Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_control(
                'epress_testimonial_designation_color',
                [
                    'label' => __( 'Color', 'epresscore' ),
                    'type' => Controls_Manager::COLOR,
                  
                    'default' => '#98adc2',
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial .footer .designation' => 'color: {{VALUE}};',
                    ],
                ]
            );
        
            $this->add_group_control(
                Group_Control_Typography::get_type(),
                [
                    'name' => 'epress_testimonial_designation_typography',
                    'selector' => '{{WRAPPER}} .epress-testimonial .footer .designation',
                ]
            );

            $this->add_responsive_control(
                'epress_testimonial_designation_margin',
                [
                    'label' => __( 'Margin', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial .footer .designation' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                    ],
                    'separator' =>'before',
                ]
            );

            $this->add_responsive_control(
                'epress_testimonial_designation_padding',
                [
                    'label' => __( 'Padding', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial .footer .designation' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );

        $this->end_controls_section(); 
        // Style Testimonial name style end   


        // Style Testimonial name style start
        $this->start_controls_section(
            'star_style_section',
            [
                'label'     => __( 'Star', 'epresscore' ),
                'tab'       => Controls_Manager::TAB_STYLE,
            ]
        );

            $this->add_control(
                'star_d_color',
                [
                    'label' => __( 'Color', 'epresscore' ),
                    'type' => Controls_Manager::COLOR,
                   
                    'default' => '#ededed',
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial .feed_rating span' => 'color: {{VALUE}};',
                    ],
                ]
            );
            $this->add_control(
                'star_a_color',
                [
                    'label' => __( 'Active Color', 'epresscore' ),
                    'type' => Controls_Manager::COLOR,
                   
                    'default' => '#e4ff00',
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial .feed_rating.star5 span:nth-child(-n+5),
                        {{WRAPPER}} .epress-testimonial .feed_rating.star4 span:nth-child(-n+4),
                        {{WRAPPER}} .epress-testimonial .feed_rating.star3 span:nth-child(-n+3),
                        {{WRAPPER}} .epress-testimonial .feed_rating.star2 span:nth-child(-n+2),
                        {{WRAPPER}} .epress-testimonial .feed_rating.star1 span:nth-child(-n+1)' => 'color: {{VALUE}};',
                    ],
                ]
            );
        
            $this->add_responsive_control(
                'star_margin',
                [
                    'label' => __( 'Margin', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial .feed_rating span' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};'
                    ],
                    'separator' =>'before',
                ]
            );

            $this->add_responsive_control(
                'star_padding',
                [
                    'label' => __( 'Padding', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial .feed_rating span' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );

        $this->end_controls_section(); 
        // Style Testimonial name style end   

        // Style Testimonial image style start
        $this->start_controls_section(
            'epress_testimonial_image_style',
            [
                'label'     => __( 'Image', 'epresscore' ),
                'tab'       => Controls_Manager::TAB_STYLE,
            ]
        );
             $this->add_responsive_control(
                'image_floting',
                [
                    'label' => __( 'Float Icon', 'epresscore' ),
                    'type' => Controls_Manager::CHOOSE,
                    'options' => [
                        'left' => [
                            'title' => __( 'Left', 'epresscore' ),
                            'icon' => 'fa fa-align-left',
                        ],
                        'none' => [
                            'title' => __( 'None', 'epresscore' ),
                            'icon' => 'fa fa-align-center',
                        ],
                        'right' => [
                            'title' => __( 'Right', 'epresscore' ),
                            'icon' => 'fa fa-align-right',
                        ],
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial .footer .photo' => 'float: {{VALUE}};',
                    ],
                    'default' => 'left',
                    'separator' =>'before',
                ]
            );
           $this->add_responsive_control(
                'epress_testimonial_image_margin',
                [
                    'label' => __( 'Margin', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'default' => [
                        'top' => '0',
                        'right' => '15',
                        'bottom' => '0',
                        'left' => '0',
                        'isLinked' => false
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial .footer .photo' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );

            $this->add_responsive_control(
                'epress_testimonial_image_padding',
                [
                    'label' => __( 'Padding', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'size_units' => [ 'px', '%', 'em' ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial .footer .photo' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                    ],
                    'separator' =>'before',
                ]
            );
        
            $this->add_group_control(
                Group_Control_Background::get_type(),
                [
                    'name' => 'epress_testimonial_image_bg',
                    'label' => __( 'Background', 'epresscore' ),
                    'default' => '#ffffff',
                    'types' => [ 'classic', 'gradient' ],
                    'selector' => '{{WRAPPER}} .epress-testimonial .footer .photo',
                ]
            );
            $this->add_group_control(
                Group_Control_Box_Shadow::get_type(),
                [
                    'name' => 'epress_testimonial_image_shadow',
                    'label' => __( 'Box Shadow', 'epresscore' ),
                    'selector' => '{{WRAPPER}} .epress-testimonial .footer .photo',
                ]
            );
            $this->add_control(
                'epress_testimonial_image_width',
                [
                    'label' => __( 'Width', 'epresscore' ),
                    'type' => Controls_Manager::SLIDER,
                    'size_units' => [ 'px', '%' ],
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 500,
                            'step' => 1,
                        ],
                        '%' => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'default' => [
                        'unit' => 'px',
                        'size' => 100,
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial .footer .photo' => 'width: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );
            $this->add_control(
                'epress_testimonial_image_height',
                [
                    'label' => __( 'Height', 'epresscore' ),
                    'type' => Controls_Manager::SLIDER,
                    'size_units' => [ 'px', '%' ],
                    'range' => [
                        'px' => [
                            'min' => 0,
                            'max' => 500,
                            'step' => 1,
                        ],
                        '%' => [
                            'min' => 0,
                            'max' => 100,
                        ],
                    ],
                    'default' => [
                        'unit' => 'px',
                        'size' => 100,
                    ],
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial .footer .photo' => 'height: {{SIZE}}{{UNIT}};',
                    ],
                ]
            );
            $this->add_group_control(
                Group_Control_Border::get_type(),
                    [
                        'name' => 'epress_testimonial_image_border',
                        'label' => __( 'Border', 'epresscore' ),
                        'selector' => '{{WRAPPER}} .epress-testimonial .footer .photo',
                    ]
            );

            $this->add_responsive_control(
                'epress_testimonial_image_border_radius',
                [
                    'label' => esc_html__( 'Border Radius', 'epresscore' ),
                    'type' => Controls_Manager::DIMENSIONS,
                    'selectors' => [
                        '{{WRAPPER}} .epress-testimonial .footer .photo' => 'border-radius: {{TOP}}px {{RIGHT}}px {{BOTTOM}}px {{LEFT}}px;',
                    ],
                     'default' => [
                        'top' => '5',
                        'right' => '5',
                        'bottom' => '5',
                        'left' => '5',
                        'isLinked' => false,
                        'unit' => '%',
                    ],
                ]
            );        
        $this->end_controls_section(); // Style Testimonial image style end
        
        $this->start_controls_section(
            'slider_arrow_style',
            [
                'label'     => __( 'Arrow', 'epresscore' ),
                'tab'       => Controls_Manager::TAB_STYLE,
                'condition' =>[
                    'slider_on' => 'yes',
                    'slarrows'  => 'yes',
                ],
            ]
        );
        
            $this->start_controls_tabs( 'slider_arrow_style_tabs' );

                // Normal tab Start
                $this->start_controls_tab(
                    'slider_arrow_style_normal_tab',
                    [
                        'label' => __( 'Normal', 'epresscore' ),
                    ]
                );

                    $this->add_control(
                        'slider_arrow_color',
                        [
                            'label' => __( 'Color', 'epresscore' ),
                            'type' => Controls_Manager::COLOR,
                          
                            'default' => '#ff5621',
                            'selectors' => [
                                '{{WRAPPER}} .epresscore-carousel-activation .slick-arrow' => 'color: {{VALUE}};',
                            ],
                        ]
                    );

                    $this->add_responsive_control(
                        'slider_arrow_fontsize',
                        [
                            'label' => __( 'Font Size', 'epresscore' ),
                            'type' => Controls_Manager::SLIDER,
                            'size_units' => [ 'px', '%' ],
                            'range' => [
                                'px' => [
                                    'min' => 0,
                                    'max' => 100,
                                    'step' => 1,
                                ],
                                '%' => [
                                    'min' => 0,
                                    'max' => 100,
                                ],
                            ],
                            'default' => [
                                'unit' => 'px',
                                'size' => 16,
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .epresscore-carousel-activation .slick-arrow' => 'font-size: {{SIZE}}{{UNIT}};',
                            ],
                        ]
                    );

                    $this->add_group_control(
                        Group_Control_Background::get_type(),
                        [
                            'name' => 'slider_arrow_background',
                            'label' => __( 'Background', 'epresscore' ),
                            'types' => [ 'classic', 'gradient' ],
                            'selector' => '{{WRAPPER}} .epresscore-carousel-activation .slick-arrow',
                        ]
                    );

                    $this->add_responsive_control(
                        'slider_arrow_height',
                        [
                            'label' => __( 'Height', 'epresscore' ),
                            'type' => Controls_Manager::SLIDER,
                            'size_units' => [ 'px', '%' ],
                            'range' => [
                                'px' => [
                                    'min' => 0,
                                    'max' => 1000,
                                    'step' => 1,
                                ],
                                '%' => [
                                    'min' => 0,
                                    'max' => 100,
                                ],
                            ],
                            'default' => [
                                'unit' => 'px',
                                'size' => 60,
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .epresscore-carousel-activation .slick-arrow' => 'height: {{SIZE}}{{UNIT}};',
                            ],
                        ]
                    );
                    $this->add_responsive_control(
                        'slider_arrow_line_height',
                        [
                            'label' => __( 'Line Height', 'epresscore' ),
                            'type' => Controls_Manager::SLIDER,
                            'size_units' => [ 'px', '%' ],
                            'range' => [
                                'px' => [
                                    'min' => 0,
                                    'max' => 1000,
                                    'step' => 1,
                                ],
                                '%' => [
                                    'min' => 0,
                                    'max' => 100,
                                ],
                            ],
                            'default' => [
                                'unit' => 'px',
                                'size' => 60,
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .epresscore-carousel-activation .slick-arrow' => 'line-height: {{SIZE}}{{UNIT}};',
                            ],
                        ]
                    );
                    $this->add_responsive_control(
                        'slider_arrow_width',
                        [
                            'label' => __( 'Width', 'epresscore' ),
                            'type' => Controls_Manager::SLIDER,
                            'size_units' => [ 'px', '%' ],
                            'range' => [
                                'px' => [
                                    'min' => 0,
                                    'max' => 1000,
                                    'step' => 1,
                                ],
                                '%' => [
                                    'min' => 0,
                                    'max' => 100,
                                ],
                            ],
                            'default' => [
                                'unit' => 'px',
                                'size' => 60,
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .epresscore-carousel-activation .slick-arrow' => 'width: {{SIZE}}{{UNIT}};',
                            ],
                        ]
                    );

                    $this->add_responsive_control(
                        'slider_arrow_padding',
                        [
                            'label' => __( 'Padding', 'epresscore' ),
                            'type' => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors' => [
                                '{{WRAPPER}} .epresscore-carousel-activation .slick-arrow' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                            'separator' =>'before',
                        ]
                    );
        
                    $this->add_group_control(
                        Group_Control_Border::get_type(),
                        [
                            'name' => 'slider_arrow_border',
                            'label' => __( 'Border', 'epresscore' ),
                            'selector' => '{{WRAPPER}} .epresscore-carousel-activation .slick-arrow',
                        ]
                    );

                    $this->add_responsive_control(
                        'slider_arrow_border_radius',
                        [
                            'label' => esc_html__( 'Border Radius', 'epresscore' ),
                            'type' => Controls_Manager::DIMENSIONS,
                            'selectors' => [
                                '{{WRAPPER}} .epresscore-carousel-activation .slick-arrow' => 'border-radius: {{TOP}}px {{RIGHT}}px {{BOTTOM}}px {{LEFT}}px;',
                            ],
                        ]
                    );
                    $this->add_group_control(
                        Group_Control_Box_Shadow::get_type(),
                        [
                            'name' => 'slider_arrow_box_shadow',
                            'label' => __( 'Box Shadow', 'epresscore' ),
                            'selector' => '{{WRAPPER}} .epresscore-carousel-activation .slick-arrow',
                        ]
                    );
        

                $this->end_controls_tab(); // Normal tab end

                // Hover tab Start
                $this->start_controls_tab(
                    'slider_arrow_style_hover_tab',
                    [
                        'label' => __( 'Hover', 'epresscore' ),
                    ]
                );

                    $this->add_control(
                        'slider_arrow_hover_color',
                        [
                            'label' => __( 'Color', 'epresscore' ),
                            'type' => Controls_Manager::COLOR,
                           
                            'default' => '#ffffff',
                            'selectors' => [
                                '{{WRAPPER}} .epresscore-carousel-activation .slick-arrow:hover' => 'color: {{VALUE}};',
                            ],
                        ]
                    );

                    $this->add_group_control(
                        Group_Control_Background::get_type(),
                        [
                            'name' => 'slider_arrow_hover_background',
                            'label' => __( 'Background', 'epresscore' ),
                            'types' => [ 'classic', 'gradient' ],
                            'default' => '#ff5621',
                            'selector' => '{{WRAPPER}} .epresscore-carousel-activation .slick-arrow:before',
                        ]
                    );

                    $this->add_group_control(
                        Group_Control_Border::get_type(),
                        [
                            'name' => 'slider_arrow_hover_border',
                            'label' => __( 'Border', 'epresscore' ),
                            'selector' => '{{WRAPPER}} .epresscore-carousel-activation .slick-arrow:hover',
                        ]
                    );

                    $this->add_responsive_control(
                        'slider_arrow_hover_border_radius',
                        [
                            'label' => esc_html__( 'Border Radius', 'epresscore' ),
                            'type' => Controls_Manager::DIMENSIONS,
                            'selectors' => [
                                '{{WRAPPER}} .epresscore-carousel-activation .slick-arrow:hover' => 'border-radius: {{TOP}}px {{RIGHT}}px {{BOTTOM}}px {{LEFT}}px;',
                            ],
                        ]
                    );
        
                    $this->add_group_control(
                        Group_Control_Box_Shadow::get_type(),
                        [
                            'name' => 'slider_arrow_box_shadow_hover',
                            'label' => __( 'Box Shadow', 'epresscore' ),
                            'selector' => '{{WRAPPER}} .epresscore-carousel-activation .slick-arrow:hover',
                        ]
                    );
        

                $this->end_controls_tab(); // Hover tab end

            $this->end_controls_tabs();
        
             $this->add_control(
                'slider_arrow_position_title',
                [
                    'label'     => __( 'Arrow Position', 'epresscore' ),
                    'type'      => Controls_Manager::HEADING,
                    'separator' => 'before',
                ]
            );
        
            $this->start_controls_tabs( 'slider_arrow_position_tabs' );

                // Normal tab Start
                $this->start_controls_tab(
                    'slider_arrow_prev_tab',
                    [
                        'label' => __( 'Prev', 'epresscore' ),
                    ]
                );
        
                $this->add_responsive_control(
                    'slider_arrow_prev_gap_x',
                    [
                        'label' => __( 'Position X', 'epresscore' ),
                        'type' => Controls_Manager::SLIDER,
                        'size_units' => [ 'px', '%', 'vw' ],
                        'range' => [
                            'px' => [
                                'min' => -9999,
                                'max' => 9999,
                                'step' => 1,
                            ],
                            '%' => [
                                'min' => -100,
                                'max' => 100,
                                'step' => 1,
                            ],
                            'vh' => [
                                'min' => -100,
                                'max' => 100,
                                'step' => 1,
                            ],
                        ],
                        'default' => [
                            'unit' => 'px',
                            'size' => 30,
                        ],
                        'selectors' => [
                            '{{WRAPPER}} .epresscore-carousel-activation .slick-arrow.slick-prev' => 'position: absolute; left: {{SIZE}}{{UNIT}};'
                        ],
                    ]
                );
                $this->add_responsive_control(
                    'slider_arrow_prev_gap_y',
                    [
                        'label' => __( 'Position Y', 'epresscore' ),
                        'type' => Controls_Manager::SLIDER,
                        'size_units' => [ 'px', '%', 'vh' ],
                        'range' => [
                            'px' => [
                                'min' => -9999,
                                'max' => 9999,
                                'step' => 1,
                            ],
                            '%' => [
                                'min' => -100,
                                'max' => 100,
                                'step' => 1,
                            ],
                            'vh' => [
                                'min' => -100,
                                'max' => 100,
                                'step' => 1,
                            ],
                        ],
                        'default' => [
                            'unit' => '%',
                            'size' => 45,
                        ],
                        'selectors' => [
                            '{{WRAPPER}} .epresscore-carousel-activation .slick-arrow.slick-prev' => 'position: absolute; top: {{SIZE}}{{UNIT}};'
                        ],
                    ]
                );
        
        
                 $this->end_controls_tab(); // Left Arrow tab end

                // Hover tab Start
                $this->start_controls_tab(
                    'slider_arrow_next_tab',
                    [
                        'label' => __( 'Next', 'epresscore' ),
                    ]
                );
        
                   $this->add_responsive_control(
                    'slider_arrow_next_gap_x',
                    [
                        'label' => __( 'Position X', 'epresscore' ),
                        'type' => Controls_Manager::SLIDER,
                        'size_units' => [ 'px', '%', 'vw' ],
                        'range' => [
                            'px' => [
                                'min' => -9999,
                                'max' => 9999,
                                'step' => 1,
                            ],
                            '%' => [
                                'min' => -100,
                                'max' => 100,
                                'step' => 1,
                            ],
                            'vh' => [
                                'min' => -100,
                                'max' => 100,
                                'step' => 1,
                            ],
                        ],
                        'default' => [
                            'unit' => 'px',
                            'size' => 30,
                        ],
                        'selectors' => [
                            '{{WRAPPER}} .epresscore-carousel-activation .slick-arrow.slick-next' => 'position: absolute; right: {{SIZE}}{{UNIT}};'
                        ],
                    ]
                );
                $this->add_responsive_control(
                    'slider_arrow_next_gap_y',
                    [
                        'label' => __( 'Position Y', 'epresscore' ),
                        'type' => Controls_Manager::SLIDER,
                        'size_units' => [ 'px', '%', 'vh' ],
                        'range' => [
                            'px' => [
                                'min' => -9999,
                                'max' => 9999,
                                'step' => 1,
                            ],
                            '%' => [
                                'min' => -100,
                                'max' => 100,
                                'step' => 1,
                            ],
                            'vh' => [
                                'min' => -100,
                                'max' => 100,
                                'step' => 1,
                            ],
                        ],
                        'default' => [
                            'unit' => '%',
                            'size' => 46,
                        ],
                        'selectors' => [
                            '{{WRAPPER}} .epresscore-carousel-activation .slick-arrow.slick-next' => 'position: absolute; top: {{SIZE}}{{UNIT}};'
                        ],
                    ]
                );
        
                $this->end_controls_tab(); // Right Arrow tab end
            $this->end_controls_tabs();
        $this->end_controls_section(); // Style Slider arrow style end

        // Style Pagination button tab section
        $this->start_controls_section(
            'product_slider_pagination_style_section',
            [
                'label' => __( 'Pagination', 'epresscore' ),
                'tab' => Controls_Manager::TAB_STYLE,
                'condition'=>[
                    'slider_on' => 'yes',
                    'sldots'=>'yes'
                ]
            ]
        );
            
            $this->start_controls_tabs('pagination_style_tabs');

                $this->start_controls_tab(
                    'pagination_style_normal_tab',
                    [
                        'label' => __( 'Normal', 'epresscore' ),
                    ]
                );

                    $this->add_responsive_control(
                        'slider_pagination_height',
                        [
                            'label' => __( 'Height', 'epresscore' ),
                            'type' => Controls_Manager::SLIDER,
                            'size_units' => [ 'px', '%' ],
                            'range' => [
                                'px' => [
                                    'min' => 0,
                                    'max' => 1000,
                                    'step' => 1,
                                ],
                                '%' => [
                                    'min' => 0,
                                    'max' => 100,
                                ],
                            ],
                            'default' => [
                                'unit' => 'px',
                                'size' => 8,
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .epresscore-carousel-activation .slick-dots li button' => 'height: {{SIZE}}{{UNIT}};',
                            ],
                        ]
                    );

                    $this->add_responsive_control(
                        'slider_pagination_width',
                        [
                            'label' => __( 'Width', 'epresscore' ),
                            'type' => Controls_Manager::SLIDER,
                            'size_units' => [ 'px', '%' ],
                            'range' => [
                                'px' => [
                                    'min' => 0,
                                    'max' => 1000,
                                    'step' => 1,
                                ],
                                '%' => [
                                    'min' => 0,
                                    'max' => 100,
                                ],
                            ],
                            'default' => [
                                'unit' => 'px',
                                'size' => 8,
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .epresscore-carousel-activation .slick-dots li button' => 'width: {{SIZE}}{{UNIT}};',
                            ],
                        ]
                    );

                    $this->add_group_control(
                        Group_Control_Background::get_type(),
                        [
                            'name' => 'pagination_background',
                            'label' => __( 'Background', 'epresscore' ),
                            'types' => [ 'classic', 'gradient' ],
                            'selector' => '{{WRAPPER}} .epresscore-carousel-activation .slick-dots li button',
                        ]
                    );

                    $this->add_responsive_control(
                        'pagination_margin',
                        [
                            'label' => __( 'Margin', 'epresscore' ),
                            'type' => Controls_Manager::DIMENSIONS,
                            'size_units' => [ 'px', '%', 'em' ],
                            'selectors' => [
                                '{{WRAPPER}} .epresscore-carousel-activation .slick-dots li button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                            ],
                        ]
                    );

                    $this->add_group_control(
                        Group_Control_Border::get_type(),
                        [
                            'name' => 'pagination_border',
                            'label' => __( 'Border', 'epresscore' ),
                            'selector' => '{{WRAPPER}} .epresscore-carousel-activation .slick-dots li button',
                        ]
                    );

                    $this->add_responsive_control(
                        'pagination_border_radius',
                        [
                            'label' => esc_html__( 'Border Radius', 'epresscore' ),
                            'type' => Controls_Manager::DIMENSIONS,
                            'selectors' => [
                                '{{WRAPPER}} .epresscore-carousel-activation .slick-dots li button' => 'border-radius: {{TOP}}px {{RIGHT}}px {{BOTTOM}}px {{LEFT}}px;',
                            ],
                        ]
                    );
                    $this->add_responsive_control(
                        'slider_dot_opacity',
                        [
                            'label' => __( 'Opacity (%)', 'epresscore' ),
                            'type' => Controls_Manager::SLIDER,
                            'default' => [
                                'size' => 0.5,
                            ],
                            'range' => [
                                'px' => [
                                    'max' => 1,
                                    'step' => 0.01,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .epresscore-carousel-activation .slick-dots li button' => 'opacity: {{SIZE}}',
                                
                            ],
                        ]
                    );
                    
                $this->end_controls_tab(); // Normal Tab end

                $this->start_controls_tab(
                    'pagination_style_active_tab',
                    [
                        'label' => __( 'Active', 'epresscore' ),
                    ]
                );
                
                    $this->add_responsive_control(
                        'slider_pagination_active_height',
                        [
                            'label' => __( 'Height', 'epresscore' ),
                            'type' => Controls_Manager::SLIDER,
                            'size_units' => [ 'px', '%' ],
                            'range' => [
                                'px' => [
                                    'min' => 0,
                                    'max' => 1000,
                                    'step' => 1,
                                ],
                                '%' => [
                                    'min' => 0,
                                    'max' => 100,
                                ],
                            ],
                            'default' => [
                                'unit' => 'px',
                                'size' => 8,
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .epresscore-carousel-activation .slick-dots li.slick-active button' => 'height: {{SIZE}}{{UNIT}};',
                            ],
                        ]
                    );

                    $this->add_responsive_control(
                        'slider_pagination_active_width',
                        [
                            'label' => __( 'Width', 'epresscore' ),
                            'type' => Controls_Manager::SLIDER,
                            'size_units' => [ 'px', '%' ],
                            'range' => [
                                'px' => [
                                    'min' => 0,
                                    'max' => 1000,
                                    'step' => 1,
                                ],
                                '%' => [
                                    'min' => 0,
                                    'max' => 100,
                                ],
                            ],
                            'default' => [
                                'unit' => 'px',
                                'size' => 32,
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .epresscore-carousel-activation .slick-dots li.slick-active button' => 'width: {{SIZE}}{{UNIT}};',
                            ],
                        ]
                    );

                    $this->add_group_control(
                        Group_Control_Border::get_type(),
                        [
                            'name' => 'pagination_hover_border',
                            'label' => __( 'Border', 'epresscore' ),
                            'selector' => '{{WRAPPER}} .epresscore-carousel-activation .slick-dots li:hover, {{WRAPPER}} .epresscore-carousel-activation .slick-dots li.slick-active button',
                        ]
                    );

                    $this->add_responsive_control(
                        'pagination_hover_border_radius',
                        [
                            'label' => esc_html__( 'Border Radius', 'epresscore' ),
                            'type' => Controls_Manager::DIMENSIONS,
                            'selectors' => [
                                '{{WRAPPER}} .epresscore-carousel-activation .slick-dots li.slick-active' => 'border-radius: {{TOP}}px {{RIGHT}}px {{BOTTOM}}px {{LEFT}}px;',
                                '{{WRAPPER}} .epresscore-carousel-activation .slick-dots li:hover button' => 'border-radius: {{TOP}}px {{RIGHT}}px {{BOTTOM}}px {{LEFT}}px;',
                            ],
                        ]
                    );

                    $this->add_responsive_control(
                        'slider_dot_active_opacity',
                        [
                            'label' => __( 'Opacity (%)', 'epresscore' ),
                            'type' => Controls_Manager::SLIDER,
                            'default' => [
                                'size' => 1,
                            ],
                            'range' => [
                                'px' => [
                                    'max' => 1,
                                    'step' => 0.01,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .epresscore-carousel-activation .slick-dots li.slick-active button,{{WRAPPER}} .epresscore-carousel-activation .slick-dots li:hover button,{{WRAPPER}} .epresscore-carousel-activation .slick-dots li:focus button' => 'opacity: {{SIZE}}',
                                
                            ],
                        ]
                    );

                $this->end_controls_tab(); // Hover Tab end

            $this->end_controls_tabs();

        $this->end_controls_section();

    }
    protected function render( $instance = [] ) {
        $settings   = $this->get_settings_for_display();
       
        $this->add_render_attribute( 'testimonial_area_attr', 'class', 'epress-testimonial-area' );

        if( $settings['slider_on'] == 'yes'){
            $slider_settings = [
                'arrows' => ('yes' === $settings['slarrows']),
                'arrow_prev_txt' => $settings['slprevicon'],
                'arrow_next_txt' => $settings['slnexticon'],
                'dots' => ('yes' === $settings['sldots']),
                'autoplay' => ('yes' === $settings['slautolay']),
                'autoplay_speed' => absint($settings['slautoplay_speed']),
                'animation_speed' => absint($settings['slanimation_speed']),
                'pause_on_hover' => ('yes' === $settings['slpause_on_hover']),
                'center_mode' => ( 'yes' === $settings['slcentermode']),
                'vertical_mode' => ( 'yes' === $settings['slverticalmode']),
                'center_padding' => absint($settings['slcenterpadding']),
            ];
            $slider_responsive_settings = [
                'display_columns' => $settings['slitems'],
                'scroll_columns' => $settings['slscroll_columns'],
                'tablet_width' => $settings['sltablet_width'],
                'tablet_display_columns' => $settings['sltablet_display_columns'],
                'tablet_scroll_columns' => $settings['sltablet_scroll_columns'],
                'mobile_width' => $settings['slmobile_width'],
                'mobile_display_columns' => $settings['slmobile_display_columns'],
                'mobile_scroll_columns' => $settings['slmobile_scroll_columns'],
            ];
            $slider_settings = array_merge( $slider_settings, $slider_responsive_settings );
            $this->add_render_attribute( 'testimonial_area_attr', 'class', 'epresscore-carousel-activation' );   
            $this->add_render_attribute( 'testimonial_area_attr', 'data-settings', wp_json_encode( $slider_settings ) );   
        }else {            
            $this->add_render_attribute( 'testimonial_area_attr', 'class', 'testimonial-grid' );
        }
        
        if( $settings['epress_testimonial_list'] ):
        
        ?>
        <div <?php echo $this->get_render_attribute_string( 'testimonial_area_attr' ); ?> >
           <?php foreach( $settings['epress_testimonial_list'] as $items ):            
            $client_image = Group_Control_Image_Size::get_attachment_image_html( $items, 'client_imagesize', 'client_image' );         
            $quote_image = Group_Control_Image_Size::get_attachment_image_html( $settings, 'quote_image_size', 'quote_image' );
            ?>
            <div class="testimonial-column">
                <div class="epress-testimonial">                                   
                    <?php if( !empty($quote_image) ): ?>
                    <div class="quote">
                        <?php echo $quote_image; ?>
                    </div>
                    <?php endif; ?>
                   <div class="top-info">
                   <div class="feed_rating star<?php echo $items['feed_rating']; ?>">
                       <span><i class="fas fa-star"></i></span>
                       <span><i class="fas fa-star"></i></span>
                       <span><i class="fas fa-star"></i></span>
                       <span><i class="fas fa-star"></i></span>
                       <span><i class="fas fa-star"></i></span>
                   </div>                   
                    <?php if( !empty($items['feedback_title']) ): ?>
                    <div class="feedback-title">
                        <?php echo wpautop(esc_html($items['feedback_title'])); ?>
                    </div>
                    <?php endif; ?>
                   </div>
                    <?php if( !empty($items['client_say']) ): ?>
                    <div class="content">
                        <?php echo wpautop(esc_html($items['client_say'])); ?>
                    </div>
                    <?php endif; ?>
                    <div class="footer">                   
                        <?php if( !empty($client_image) ): ?>
                        <div class="photo">
                            <?php echo $client_image; ?>
                        </div>
                        <?php endif; ?>
                        <div class="ft-content">                                           
                            <?php if( !empty($items['client_name']) ): ?>
                            <h4 class="name"><?php echo esc_html($items['client_name']); ?></h4>
                            <?php endif; ?>
                            <?php if( !empty($items['client_designation']) ): ?>
                            <div class="designation" ><?php echo esc_html($items['client_designation']); ?></div>
                            <?php endif; ?>
                        </div>
                    </div>
                </div>
            </div>
            <?php endforeach; ?>
        </div>
        <?php        
        endif;        
    }
}
Plugin::instance()->widgets_manager->register_widget_type( new epress_Testimonial_Widget );