<?php

function epress_breadcrumb( $home = 'Home', $separator = ' | ' ){
    // Set variables for later use
    $here_text        = __( 'You are currently here!' );
    $home_link        = home_url('/');
    $home_text        = '<span class="icon"><i class="flaticon-home"></i></span>'.wp_kses_post($home);
    $link_before      = '<span typeof="v:Breadcrumb">';
    $link_after       = '</span>';
    $link_attr        = ' rel="v:url" property="v:title"';
    $link             = $link_before . '<a' . $link_attr . ' href="%1$s">%2$s</a>' . $link_after;
    $delimiter        = '<span class="separator">'.wp_kses_post($separator).'</span>';             // Delimiter between crumbs
    $before           = '<span class="current">'; // Tag before the current crumb
    $after            = '</span>';                // Tag after the current crumb
    $page_addon       = '';                       // Adds the page number if the query is paged
    $breadcrumb_trail = '';
    $category_links   = '';
    /** 
     * Set our own $wp_the_query variable. Do not use the global variable version due to 
     * reliability
     */
    $wp_the_query   = $GLOBALS['wp_the_query'];
    $queried_object = $wp_the_query->get_queried_object();

    // Handle single post requests which includes single pages, posts and attatchments
    if ( is_singular() ) 
    {
        /** 
         * Set our own $post variable. Do not use the global variable version due to 
         * reliability. We will set $post_object variable to $GLOBALS['wp_the_query']
         */
        $post_object = sanitize_post( $queried_object );
        // Set variables 
        $title          = apply_filters( 'the_title', $post_object->post_title );
        $parent         = $post_object->post_parent;
        $post_type      = $post_object->post_type;
        $post_id        = $post_object->ID;
        $post_link      = $before . $title . $after;
        $parent_string  = '';
        $post_type_link = '';
        if ( 'post' === $post_type ) 
        {
            // Get the post categories
            $categories = get_the_category( $post_id );
            if ( $categories ) {
                // Lets grab the first category
                $category  = $categories[0];

                $category_links = get_category_parents( $category, true, $delimiter );
                $category_links = str_replace( '<a',   $link_before . '<a' . $link_attr, $category_links );
                $category_links = str_replace( '</a>', '</a>' . $link_after,             $category_links );
            }
        }
        if ( !in_array( $post_type, ['post', 'page', 'attachment'] ) )
        {
            $post_type_object = get_post_type_object( $post_type );
            $archive_link     = esc_url( get_post_type_archive_link( $post_type ) );

            $post_type_link   = sprintf( $link, $archive_link, $post_type_object->labels->singular_name );
        }
        // Get post parents if $parent !== 0
        if ( 0 !== $parent ) 
        {
            $parent_links = [];
            while ( $parent ) {
                $post_parent = get_post( $parent );
                $parent_links[] = sprintf( $link, esc_url( get_permalink( $post_parent->ID ) ), get_the_title( $post_parent->ID ) );
                $parent = $post_parent->post_parent;
            }
            $parent_links = array_reverse( $parent_links );
            $parent_string = implode( $delimiter, $parent_links );
        }
        // Lets build the breadcrumb trail
        if ( $parent_string ) {
            $breadcrumb_trail = $parent_string . $delimiter . $post_link;
        } else {
            $breadcrumb_trail = $post_link;
        }

        if ( $post_type_link )
            $breadcrumb_trail = $post_type_link . $delimiter . $breadcrumb_trail;

        if ( $category_links )
            $breadcrumb_trail = $category_links . $breadcrumb_trail;
    }
    // Handle archives which includes category-, tag-, taxonomy-, date-, custom post type archives and author archives
    if( is_archive() )
    {
        if (    is_category()
             || is_tag()
             || is_tax()
        ) {
            // Set the variables for this section
            $term_object        = get_term( $queried_object );
            $taxonomy           = $term_object->taxonomy;
            $term_id            = $term_object->term_id;
            $term_name          = $term_object->name;
            $term_parent        = $term_object->parent;
            $taxonomy_object    = get_taxonomy( $taxonomy );
            $current_term_link  = $before . $taxonomy_object->labels->singular_name . ': ' . $term_name . $after;
            $parent_term_string = '';
            if ( 0 !== $term_parent )
            {
                // Get all the current term ancestors
                $parent_term_links = [];
                while ( $term_parent ) {
                    $term = get_term( $term_parent, $taxonomy );

                    $parent_term_links[] = sprintf( $link, esc_url( get_term_link( $term ) ), $term->name );

                    $term_parent = $term->parent;
                }
                $parent_term_links  = array_reverse( $parent_term_links );
                $parent_term_string = implode( $delimiter, $parent_term_links );
            }
            if ( $parent_term_string ) {
                $breadcrumb_trail = $parent_term_string . $delimiter . $current_term_link;
            } else {
                $breadcrumb_trail = $current_term_link;
            }
        } elseif ( is_author() ) {
            $breadcrumb_trail = __( 'Author archive for ') .  $before . $queried_object->data->display_name . $after;
        } elseif ( is_date() ) {
            // Set default variables
            $year     = $wp_the_query->query_vars['year'];
            $monthnum = $wp_the_query->query_vars['monthnum'];
            $day      = $wp_the_query->query_vars['day'];

            // Get the month name if $monthnum has a value
            if ( $monthnum ) {
                $date_time  = DateTime::createFromFormat( '!m', $monthnum );
                $month_name = $date_time->format( 'F' );
            }

            if ( is_year() ) {

                $breadcrumb_trail = $before . $year . $after;

            } elseif( is_month() ) {

                $year_link        = sprintf( $link, esc_url( get_year_link( $year ) ), $year );

                $breadcrumb_trail = $year_link . $delimiter . $before . $month_name . $after;

            } elseif( is_day() ) {

                $year_link        = sprintf( $link, esc_url( get_year_link( $year ) ),             $year       );
                $month_link       = sprintf( $link, esc_url( get_month_link( $year, $monthnum ) ), $month_name );

                $breadcrumb_trail = $year_link . $delimiter . $month_link . $delimiter . $before . $day . $after;
            }
        } elseif ( is_post_type_archive() ) {
            $post_type        = $wp_the_query->query_vars['post_type'];
            $post_type_object = get_post_type_object( $post_type );
            $breadcrumb_trail = $before . $post_type_object->labels->singular_name . $after;
        }
    }
    // Handle the search page
    if ( is_search() ) {
        $breadcrumb_trail = __( 'Search query for: ' ) . $before . get_search_query() . $after;
    }
    // Handle 404's
    if ( is_404() ) {
        $breadcrumb_trail = $before . __( 'Error 404' ) . $after;
    }
    // Handle paged pages
    if ( is_paged() ) {
        $current_page = get_query_var( 'paged' ) ? get_query_var( 'paged' ) : get_query_var( 'page' );
        $page_addon   = $before . sprintf( __( ' ( Page %s )' ), number_format_i18n( $current_page ) ) . $after;
    }
    $breadcrumb_output_link  = '';
    $breadcrumb_output_link .= '<div class="bread sub-title">';
    if (is_home() or is_front_page() ) {
        // Do not show breadcrumbs on page one of home and frontpage
        if ( is_paged() ) {
            $breadcrumb_output_link .= '<a href="' . $home_link . '">' . $home_text . '</a>';
            $breadcrumb_output_link .= $page_addon;
        }else{
            $breadcrumb_output_link .= $home_text;
            $breadcrumb_output_link .= $page_addon;            
        }
    } else {
        $breadcrumb_output_link .= '<a href="' . $home_link . '" >' . $home_text . '</a>';
        $breadcrumb_output_link .= $delimiter;
        $breadcrumb_output_link .= $breadcrumb_trail;
        $breadcrumb_output_link .= $page_addon;
    }
    $breadcrumb_output_link .= '</div><!-- .breadcrumbs -->';

    return $breadcrumb_output_link;
}


/*
 * HTML Tag list
 * return array
 */
function epress_html_tag_lists() {
    $html_tag_list = [
        'h1'   => __( 'H1', 'eleven-addons' ),
        'h2'   => __( 'H2', 'eleven-addons' ),
        'h3'   => __( 'H3', 'eleven-addons' ),
        'h4'   => __( 'H4', 'eleven-addons' ),
        'h5'   => __( 'H5', 'eleven-addons' ),
        'h6'   => __( 'H6', 'eleven-addons' ),
        'p'    => __( 'p', 'eleven-addons' ),
        'div'  => __( 'div', 'eleven-addons' ),
        'span' => __( 'span', 'eleven-addons' ),
    ];
    return $html_tag_list;
}

if( !function_exists('campaign_single_cat') ){
    function campaign_single_cat( $separetor, $type = 'name' ){
        global $post;
        $related_taxs = wp_get_post_terms($post->ID, 'campaigncats' );
        $related_cats = array();
        foreach ( $related_taxs as $related_tax ) {
            $related_cats[] =   $related_tax->$type ;   
        } 
        return implode( $separetor , $related_cats);
    }
}


function epress_post_share_social(){
        global $post;
        /* Get current page URL */
        $crunchifyURL = get_permalink();
        $crunchifyImage = get_the_post_thumbnail('full');
        $crunchifyDesc = get_the_content();
        /* Get current page title*/
        $crunchifyTitle = str_replace( ' ', '%20', get_the_title());
        $twitterURL = 'https://twitter.com/intent/tweet?text='.$crunchifyTitle.'&amp;url='.$crunchifyURL.'&amp;via=Crunchify';
        $facebookURL = 'https://www.facebook.com/sharer/sharer.php?u='.$crunchifyURL;
        $linkedinURL = 'https://www.linkedin.com/shareArticle?mini=true&url='.$crunchifyURL;
        $pinterest = 'https://pinterest.com/pin/create/button/?url='.$crunchifyURL.'&media='.$crunchifyImage.'&description='.$crunchifyDesc;
        ?>
        <div class="social-share">
           <h3 class="share-title" >Social Share</h3>
            <ul>
                <li><a href="<?php echo esc_url($facebookURL); ?>"><i class="fab fa-facebook-f"></i></a></li>
                <li><a href="<?php echo esc_url($twitterURL); ?>"><i class="fab fa-twitter"></i></a></li>
                <li><a href="<?php echo esc_url($linkedinURL); ?>"><i class="fab fa-linkedin-in"></i></a></li>
                <li><a href="<?php echo esc_url($pinterest); ?>"><i class="fab fa-pinterest-p"></i></a></li>
            </ul>
        </div>
    <?php
}


function epress_set_post_views($postID) {
    $count_key = 'epress_post_views_count';
    $count = get_post_meta($postID, $count_key, true);
    if($count==''){
        $count = 0;
        delete_post_meta($postID, $count_key);
        add_post_meta($postID, $count_key, '0');
    }else{
        $count++;
        update_post_meta($postID, $count_key, $count);
    }
}



//To keep the count accurate, lets get rid of prefetching
remove_action( 'wp_head', 'adjacent_posts_rel_link_wp_head', 10, 0);

function epress_track_post_views ($post_id) {
    if ( !is_single() ) return;
    if ( empty ( $post_id) ) {
        global $post;
        $post_id = $post->ID;    
    }
    epress_set_post_views($post_id);
}
add_action( 'wp_head', 'epress_track_post_views');


/*
 * Get Taxonomy
 * return array
 */
function epress_get_taxonomies( $epress_texonomy = 'category' ){
    $terms = get_terms( array(
        'taxonomy' => $epress_texonomy,
        'hide_empty' => true,
    ));
    if ( ! empty( $terms ) && ! is_wp_error( $terms ) ){
        foreach ( $terms as $term ) {
            $options[ $term->slug ] = $term->name;
        }
        return $options;
    }
}




/*
 * Get Post Type
 * return array
 */
function epress_get_post_types( $args = [] ) {   
    $post_type_args = [
        'show_in_nav_menus' => true,
    ];
    if ( ! empty( $args['post_type'] ) ) {
        $post_type_args['name'] = $args['post_type'];
    }
    $_post_types = get_post_types( $post_type_args , 'objects' );
    $post_types  = [];
    foreach ( $_post_types as $post_type => $object ) {
        $post_types[ $post_type ] = $object->label;
    }
    return $post_types;
}


function flat_icon_list(){
    $new_add = array(
        "flaticon-up-arrow-angle" => "Flaticon up arrow angle",
        "flaticon-right-arrow-angle" => "Flaticon right arrow angle",
        "flaticon-down-arrow" => "Flaticon down arrow",
        "flaticon-like-heart-outline-symbol" => "Flaticon like heart outline symbol",
        "flaticon-share-social-interface-button" => "Flaticon share social interface button",
        "flaticon-chat-comment-oval-speech-bubble-with-text-lines" => "Flaticon chat comment oval speech bubble with text lines",
        "flaticon-login-square-arrow-button-outline" => "Flaticon login square arrow button outline",
        "flaticon-search-interface-symbol" => "Flaticon search interface symbol",
        "flaticon-recycling-bin" => "Flaticon recycling bin",
        "flaticon-chat-oval-speech-bubbles-symbol" => "Flaticon chat oval speech bubbles symbol",
        "flaticon-close-circular-button-symbol" => "Flaticon close circular button symbol",
        "flaticon-nine-oclock-on-circular-clock" => "Flaticon nine oclock on circular clock",
        "flaticon-weekly-calendar-outline-event-interface-symbol" => "Flaticon weekly calendar outline event interface symbol",
        "flaticon-copy-two-paper-sheets-interface-symbol" => "Flaticon copy two paper sheets interface symbol",
        "flaticon-video-camera-outline" => "Flaticon video camera outline",
        "flaticon-save-button-interface-symbol-of-outlined-diskette" => "Flaticon save button interface symbol of outlined diskette",
        "flaticon-big-map-placeholder-outlined-symbol-of-interface" => "Flaticon big map placeholder outlined symbol of interface",
        "flaticon-checkmark-verify-interface-symbol-button" => "Flaticon checkmark verify interface symbol button",
        "flaticon-download-circular-button" => "Flaticon download circular button",
        "flaticon-equalizer" => "Flaticon equalizer",
        "flaticon-play" => "Flaticon play",
        "flaticon-list" => "Flaticon list",
        "flaticon-image" => "Flaticon image",
        "flaticon-camera" => "Flaticon camera",
        "flaticon-menu" => "Flaticon menu",
        "flaticon-user" => "Flaticon user",
        "flaticon-profile" => "Flaticon profile",
        "flaticon-user-1" => "Flaticon user 1",
        "flaticon-users" => "Flaticon users",
        "flaticon-email-envelope-outline-shape-with-rounded-corners" => "Flaticon email envelope outline shape with rounded corners",
        "flaticon-email" => "Flaticon email",
        "flaticon-mail" => "Flaticon mail",
        "flaticon-message" => "Flaticon message",
        "flaticon-worldwide" => "Flaticon worldwide",
        "flaticon-location" => "Flaticon location",
        "flaticon-earth-globe" => "Flaticon earth globe",
        "flaticon-world" => "Flaticon world",
        "flaticon-earth" => "Flaticon earth",
        "flaticon-edit" => "Flaticon edit",
        "flaticon-edit-1" => "Flaticon edit 1",
        "flaticon-edit-2" => "Flaticon edit 2",
        "flaticon-edit-3" => "Flaticon edit 3",
        "flaticon-contract" => "Flaticon contract",
        "flaticon-graphic-design" => "Flaticon graphic design",
        "flaticon-clipboard" => "Flaticon clipboard",
        "flaticon-visa-logo" => "Flaticon visa logo",
        "flaticon-shopping-bag" => "Flaticon shopping bag",
        "flaticon-shopping-bag-1" => "Flaticon shopping bag 1",
        "flaticon-shopping-cart" => "Flaticon shopping cart",
        "flaticon-shopping-cart-1" => "Flaticon shopping cart 1",
        "flaticon-facebook" => "Flaticon facebook",
        "flaticon-twitter" => "Flaticon twitter",
        "flaticon-linkedin-social-outline-logotype" => "Flaticon linkedin social outline logotype",
        "flaticon-instagram" => "Flaticon instagram",
        "flaticon-pinterest" => "Flaticon pinterest",
        "flaticon-flickr-social-outlined-logo-in-a-circle" => "Flaticon flickr social outlined logo in a circle",
        "flaticon-youtube" => "Flaticon youtube",
        "flaticon-vimeo-letter-logo-outline" => "Flaticon vimeo letter logo outline",
        "flaticon-clock-circular-outline" => "Flaticon clock circular outline",
        "flaticon-clock" => "Flaticon clock",
        "flaticon-time" => "Flaticon time",
        "flaticon-alarm-clock" => "Flaticon alarm clock",
        "flaticon-comment" => "Flaticon comment",
        "flaticon-chat" => "Flaticon chat",
        "flaticon-comment-white-oval-bubble" => "Flaticon comment white oval bubble",
        "flaticon-bookmark-white" => "Flaticon bookmark white",
        "flaticon-tag" => "Flaticon tag",
        "flaticon-tags" => "Flaticon tags",
        "flaticon-search" => "Flaticon search",
        "flaticon-magnifying-glass" => "Flaticon magnifying glass",
        "flaticon-magnifying-glass-1" => "Flaticon magnifying glass 1",
        "flaticon-search-1" => "Flaticon search 1",
        "flaticon-call" => "Flaticon call",
        "flaticon-phone-call" => "Flaticon phone call",
        "flaticon-phone-call-1" => "Flaticon phone call 1",
        "flaticon-cancel" => "Flaticon cancel",
        "flaticon-delete-button" => "Flaticon delete button",
        "flaticon-social-care" => "Flaticon social care",
        "flaticon-solidarity" => "Flaticon solidarity",
        "flaticon-care" => "Flaticon care",
        "flaticon-heart" => "Flaticon heart",
        "flaticon-heart-1" => "Flaticon heart 1",
        "flaticon-hand" => "Flaticon hand",
        "flaticon-heart-box" => "Flaticon heart box",
        "flaticon-donation" => "Flaticon donation",
        "flaticon-charity" => "Flaticon charity",
        "flaticon-charity-1" => "Flaticon charity 1",
        "flaticon-donation-1" => "Flaticon donation 1",
        "flaticon-heart-2" => "Flaticon heart 2",
        "flaticon-care-1" => "Flaticon care 1",
        "flaticon-charity-2" => "Flaticon charity 2",
        "flaticon-charity-3" => "Flaticon charity 3",
        "flaticon-charity-4" => "Flaticon charity 4",
        "flaticon-gift-box" => "Flaticon gift box",
        "flaticon-health" => "Flaticon health",
        "flaticon-family" => "Flaticon family",
        "flaticon-muscle" => "Flaticon muscle",
        "flaticon-praying" => "Flaticon praying",
        "flaticon-business" => "Flaticon business",
        "flaticon-charity-5" => "Flaticon charity 5",
        "flaticon-money" => "Flaticon money",
        "flaticon-donation-2" => "Flaticon donation 2",
        "flaticon-support" => "Flaticon support",
        "flaticon-teamwork" => "Flaticon teamwork",
        "flaticon-dove" => "Flaticon dove",
        "flaticon-dove-1" => "Flaticon dove 1",
        "flaticon-growth" => "Flaticon growth",
        "flaticon-gift" => "Flaticon gift",
        "flaticon-hand-1" => "Flaticon hand 1",
        "flaticon-save-money" => "Flaticon save money",
        "flaticon-target" => "Flaticon target",
        "flaticon-team" => "Flaticon team",
        "flaticon-maternity" => "Flaticon maternity",
        "flaticon-team-1" => "Flaticon team 1",
        "flaticon-ribbon" => "Flaticon ribbon",
        "flaticon-olive-branches-award-symbol" => "Flaticon olive branches award symbol",
        "flaticon-olives" => "Flaticon olives",
        "flaticon-heart-3" => "Flaticon heart 3",
        "flaticon-goodwill" => "Flaticon goodwill",
        "flaticon-money-1" => "Flaticon money 1",
        "flaticon-hand-2" => "Flaticon hand 2",
        "flaticon-money-2" => "Flaticon money 2",
        "flaticon-heart-4" => "Flaticon heart 4",
        "flaticon-heart-5" => "Flaticon heart 5",
        "flaticon-help" => "Flaticon help",
        "flaticon-water" => "Flaticon water",
        "flaticon-ribbon-1" => "Flaticon ribbon 1",
        "flaticon-care-2" => "Flaticon care 2",
        "flaticon-sympathy" => "Flaticon sympathy",
        "flaticon-jar" => "Flaticon jar",
        "flaticon-heart-6" => "Flaticon heart 6",
        "flaticon-tray" => "Flaticon tray",
        "flaticon-food" => "Flaticon food",
        "flaticon-diet" => "Flaticon diet",
        "flaticon-fork" => "Flaticon fork",
        "flaticon-like" => "Flaticon like",
        "flaticon-heart-7" => "Flaticon heart 7",
        "flaticon-coin" => "Flaticon coin",
        "flaticon-dollar" => "Flaticon dollar",
        "flaticon-money-bag" => "Flaticon money bag",
        "flaticon-back" => "Flaticon back",
        "flaticon-down-arrow-1" => "Flaticon down arrow 1",
        "flaticon-right-arrow" => "Flaticon right arrow",
        "flaticon-next" => "Flaticon next",
        "flaticon-right-arrow-1" => "Flaticon right arrow 1",
        "flaticon-left-arrow" => "Flaticon left arrow",
        "flaticon-left-arrow-1" => "Flaticon left arrow 1",
        "flaticon-restart" => "Flaticon restart",
        "flaticon-coffee-cup" => "Flaticon coffee cup",
        "flaticon-hospital" => "Flaticon hospital",
        "flaticon-first-aid-kit" => "Flaticon first aid kit",
        "flaticon-medicine" => "Flaticon medicine",
        "flaticon-pills" => "Flaticon pills",
        "flaticon-water-1" => "Flaticon water 1",
        "flaticon-paper-plane" => "Flaticon paper plane",
        "flaticon-paper-plane-1" => "Flaticon paper plane 1",
        "flaticon-project-management" => "Flaticon project management",
        "flaticon-briefing" => "Flaticon briefing",
        "flaticon-motivation" => "Flaticon motivation",
        "flaticon-fist" => "Flaticon fist",
        "flaticon-handicap" => "Flaticon handicap",
        "flaticon-volunteer" => "Flaticon volunteer",
        "flaticon-placeholder" => "Flaticon placeholder",
        "flaticon-placeholder-1" => "Flaticon placeholder 1",
        "flaticon-placeholder-2" => "Flaticon placeholder 2",
        "flaticon-placeholder-3" => "Flaticon placeholder 3",
        "flaticon-map" => "Flaticon map",
        "flaticon-placeholder-4" => "Flaticon placeholder 4",
        "flaticon-flag" => "Flaticon flag",
        "flaticon-route" => "Flaticon route",
        "flaticon-customer-service" => "Flaticon customer service",
        "flaticon-support-1" => "Flaticon support 1",
        "flaticon-support-2" => "Flaticon support 2",
        "flaticon-home" => "Flaticon home",
        "flaticon-home-1" => "Flaticon home 1",
        "flaticon-home-2" => "Flaticon home 2",
        "flaticon-bookmark" => "Flaticon bookmark",
        "flaticon-bookmark-1" => "Flaticon bookmark 1",
        "flaticon-open-box" => "Flaticon open box",
        "flaticon-gift-1" => "Flaticon gift 1",
        "flaticon-gift-2" => "Flaticon gift 2",
        "flaticon-social-care-1" => "Flaticon social care 1",
        "flaticon-24-hours" => "Flaticon 24 hours",
        "flaticon-customer-service-1" => "Flaticon customer service 1",
        "flaticon-customer-service-2" => "Flaticon customer service 2",
        "flaticon-tent" => "Flaticon tent",
        "flaticon-boy-broad-smile" => "Flaticon boy broad smile",
        "flaticon-smile" => "Flaticon smile",
        "flaticon-laugh" => "Flaticon laugh",
        "flaticon-coffee" => "Flaticon coffee",
        "flaticon-cheers" => "Flaticon cheers",
        "flaticon-tent-1" => "Flaticon tent 1",
        "flaticon-right-quote" => "Flaticon right quote",
        "flaticon-quotation" => "Flaticon quotation",
        "fas fa-abacus" => "Solid Abacus", 
        "fas fa-acorn" => "Solid Acorn", 
        "fas fa-ad" => "Solid Ad", 
        "fas fa-address-book" => "Solid Address Book", 
        "fas fa-address-card" => "Solid Address Card", 
        "fas fa-adjust" => "Solid Adjust", 
        "fas fa-air-freshener" => "Solid Air Freshener", 
        "fas fa-alarm-clock" => "Solid Alarm Clock", 
        "fas fa-alicorn" => "Solid Alicorn", 
        "fas fa-align-center" => "Solid Align Center", 
        "fas fa-align-justify" => "Solid Align Justify", 
        "fas fa-align-left" => "Solid Align Left", 
        "fas fa-align-right" => "Solid Align Right", 
        "fas fa-allergies" => "Solid Allergies", 
        "fas fa-ambulance" => "Solid Ambulance", 
        "fas fa-american-sign-language-interpreting" => "Solid American Sign Language Interpreting", 
        "fas fa-analytics" => "Solid Analytics", 
        "fas fa-anchor" => "Solid Anchor", 
        "fas fa-angel" => "Solid Angel", 
        "fas fa-angle-double-down" => "Solid Angle Double Down", 
        "fas fa-angle-double-left" => "Solid Angle Double Left", 
        "fas fa-angle-double-right" => "Solid Angle Double Right", 
        "fas fa-angle-double-up" => "Solid Angle Double Up", 
        "fas fa-angle-down" => "Solid Angle Down", 
        "fas fa-angle-left" => "Solid Angle Left", 
        "fas fa-angle-right" => "Solid Angle Right", 
        "fas fa-angle-up" => "Solid Angle Up", 
        "fas fa-angry" => "Solid Angry", 
        "fas fa-ankh" => "Solid Ankh", 
        "fas fa-apple-alt" => "Solid Apple Alt", 
        "fas fa-apple-crate" => "Solid Apple Crate", 
        "fas fa-archive" => "Solid Archive", 
        "fas fa-archway" => "Solid Archway", 
        "fas fa-arrow-alt-circle-down" => "Solid Arrow Alt Circle Down", 
        "fas fa-arrow-alt-circle-left" => "Solid Arrow Alt Circle Left", 
        "fas fa-arrow-alt-circle-right" => "Solid Arrow Alt Circle Right", 
        "fas fa-arrow-alt-circle-up" => "Solid Arrow Alt Circle Up", 
        "fas fa-arrow-alt-down" => "Solid Arrow Alt Down", 
        "fas fa-arrow-alt-from-bottom" => "Solid Arrow Alt From Bottom", 
        "fas fa-arrow-alt-from-left" => "Solid Arrow Alt From Left", 
        "fas fa-arrow-alt-from-right" => "Solid Arrow Alt From Right", 
        "fas fa-arrow-alt-from-top" => "Solid Arrow Alt From Top", 
        "fas fa-arrow-alt-left" => "Solid Arrow Alt Left", 
        "fas fa-arrow-alt-right" => "Solid Arrow Alt Right", 
        "fas fa-arrow-alt-square-down" => "Solid Arrow Alt Square Down", 
        "fas fa-arrow-alt-square-left" => "Solid Arrow Alt Square Left", 
        "fas fa-arrow-alt-square-right" => "Solid Arrow Alt Square Right", 
        "fas fa-arrow-alt-square-up" => "Solid Arrow Alt Square Up", 
        "fas fa-arrow-alt-to-bottom" => "Solid Arrow Alt To Bottom", 
        "fas fa-arrow-alt-to-left" => "Solid Arrow Alt To Left", 
        "fas fa-arrow-alt-to-right" => "Solid Arrow Alt To Right", 
        "fas fa-arrow-alt-to-top" => "Solid Arrow Alt To Top", 
        "fas fa-arrow-alt-up" => "Solid Arrow Alt Up", 
        "fas fa-arrow-circle-down" => "Solid Arrow Circle Down", 
        "fas fa-arrow-circle-left" => "Solid Arrow Circle Left", 
        "fas fa-arrow-circle-right" => "Solid Arrow Circle Right", 
        "fas fa-arrow-circle-up" => "Solid Arrow Circle Up", 
        "fas fa-arrow-down" => "Solid Arrow Down", 
        "fas fa-arrow-from-bottom" => "Solid Arrow From Bottom", 
        "fas fa-arrow-from-left" => "Solid Arrow From Left", 
        "fas fa-arrow-from-right" => "Solid Arrow From Right", 
        "fas fa-arrow-from-top" => "Solid Arrow From Top", 
        "fas fa-arrow-left" => "Solid Arrow Left", 
        "fas fa-arrow-right" => "Solid Arrow Right", 
        "fas fa-arrow-square-down" => "Solid Arrow Square Down", 
        "fas fa-arrow-square-left" => "Solid Arrow Square Left", 
        "fas fa-arrow-square-right" => "Solid Arrow Square Right", 
        "fas fa-arrow-square-up" => "Solid Arrow Square Up", 
        "fas fa-arrow-to-bottom" => "Solid Arrow To Bottom", 
        "fas fa-arrow-to-left" => "Solid Arrow To Left", 
        "fas fa-arrow-to-right" => "Solid Arrow To Right", 
        "fas fa-arrow-to-top" => "Solid Arrow To Top", 
        "fas fa-arrow-up" => "Solid Arrow Up", 
        "fas fa-arrows" => "Solid Arrows", 
        "fas fa-arrows-alt" => "Solid Arrows Alt", 
        "fas fa-arrows-alt-h" => "Solid Arrows Alt H", 
        "fas fa-arrows-alt-v" => "Solid Arrows Alt V", 
        "fas fa-arrows-h" => "Solid Arrows H", 
        "fas fa-arrows-v" => "Solid Arrows V", 
        "fas fa-assistive-listening-systems" => "Solid Assistive Listening Systems", 
        "fas fa-asterisk" => "Solid Asterisk", 
        "fas fa-at" => "Solid At", 
        "fas fa-atlas" => "Solid Atlas", 
        "fas fa-atom" => "Solid Atom", 
        "fas fa-atom-alt" => "Solid Atom Alt", 
        "fas fa-audio-description" => "Solid Audio Description", 
        "fas fa-award" => "Solid Award", 
        "fas fa-axe" => "Solid Axe", 
        "fas fa-axe-battle" => "Solid Axe Battle", 
        "fas fa-baby" => "Solid Baby", 
        "fas fa-baby-carriage" => "Solid Baby Carriage", 
        "fas fa-backpack" => "Solid Backpack", 
        "fas fa-backspace" => "Solid Backspace", 
        "fas fa-backward" => "Solid Backward", 
        "fas fa-bacon" => "Solid Bacon", 
        "fas fa-badge" => "Solid Badge", 
        "fas fa-badge-check" => "Solid Badge Check", 
        "fas fa-badge-dollar" => "Solid Badge Dollar", 
        "fas fa-badge-percent" => "Solid Badge Percent", 
        "fas fa-badger-honey" => "Solid Badger Honey", 
        "fas fa-balance-scale" => "Solid Balance Scale", 
        "fas fa-balance-scale-left" => "Solid Balance Scale Left", 
        "fas fa-balance-scale-right" => "Solid Balance Scale Right", 
        "fas fa-ball-pile" => "Solid Ball Pile", 
        "fas fa-ballot" => "Solid Ballot", 
        "fas fa-ballot-check" => "Solid Ballot Check", 
        "fas fa-ban" => "Solid Ban", 
        "fas fa-band-aid" => "Solid Band Aid", 
        "fas fa-barcode" => "Solid Barcode", 
        "fas fa-barcode-alt" => "Solid Barcode Alt", 
        "fas fa-barcode-read" => "Solid Barcode Read", 
        "fas fa-barcode-scan" => "Solid Barcode Scan", 
        "fas fa-bars" => "Solid Bars", 
        "fas fa-baseball" => "Solid Baseball", 
        "fas fa-baseball-ball" => "Solid Baseball Ball", 
        "fas fa-basketball-ball" => "Solid Basketball Ball", 
        "fas fa-basketball-hoop" => "Solid Basketball Hoop", 
        "fas fa-bat" => "Solid Bat", 
        "fas fa-bath" => "Solid Bath", 
        "fas fa-battery-bolt" => "Solid Battery Bolt", 
        "fas fa-battery-empty" => "Solid Battery Empty", 
        "fas fa-battery-full" => "Solid Battery Full", 
        "fas fa-battery-half" => "Solid Battery Half", 
        "fas fa-battery-quarter" => "Solid Battery Quarter", 
        "fas fa-battery-slash" => "Solid Battery Slash", 
        "fas fa-battery-three-quarters" => "Solid Battery Three Quarters", 
        "fas fa-bed" => "Solid Bed", 
        "fas fa-beer" => "Solid Beer", 
        "fas fa-bell" => "Solid Bell", 
        "fas fa-bell-school" => "Solid Bell School", 
        "fas fa-bell-school-slash" => "Solid Bell School Slash", 
        "fas fa-bell-slash" => "Solid Bell Slash", 
        "fas fa-bells" => "Solid Bells", 
        "fas fa-bezier-curve" => "Solid Bezier Curve", 
        "fas fa-bible" => "Solid Bible", 
        "fas fa-bicycle" => "Solid Bicycle", 
        "fas fa-binoculars" => "Solid Binoculars", 
        "fas fa-biohazard" => "Solid Biohazard", 
        "fas fa-birthday-cake" => "Solid Birthday Cake", 
        "fas fa-blanket" => "Solid Blanket", 
        "fas fa-blender" => "Solid Blender", 
        "fas fa-blender-phone" => "Solid Blender Phone", 
        "fas fa-blind" => "Solid Blind", 
        "fas fa-blog" => "Solid Blog", 
        "fas fa-bold" => "Solid Bold", 
        "fas fa-bolt" => "Solid Bolt", 
        "fas fa-bomb" => "Solid Bomb", 
        "fas fa-bone" => "Solid Bone", 
        "fas fa-bone-break" => "Solid Bone Break", 
        "fas fa-bong" => "Solid Bong", 
        "fas fa-book" => "Solid Book", 
        "fas fa-book-alt" => "Solid Book Alt", 
        "fas fa-book-dead" => "Solid Book Dead", 
        "fas fa-book-heart" => "Solid Book Heart", 
        "fas fa-book-medical" => "Solid Book Medical", 
        "fas fa-book-open" => "Solid Book Open", 
        "fas fa-book-reader" => "Solid Book Reader", 
        "fas fa-book-spells" => "Solid Book Spells", 
        "fas fa-book-user" => "Solid Book User", 
        "fas fa-bookmark" => "Solid Bookmark", 
        "fas fa-books" => "Solid Books", 
        "fas fa-books-medical" => "Solid Books Medical", 
        "fas fa-boot" => "Solid Boot", 
        "fas fa-booth-curtain" => "Solid Booth Curtain", 
        "fas fa-bow-arrow" => "Solid Bow Arrow", 
        "fas fa-bowling-ball" => "Solid Bowling Ball", 
        "fas fa-bowling-pins" => "Solid Bowling Pins", 
        "fas fa-box" => "Solid Box", 
        "fas fa-box-alt" => "Solid Box Alt", 
        "fas fa-box-ballot" => "Solid Box Ballot", 
        "fas fa-box-check" => "Solid Box Check", 
        "fas fa-box-fragile" => "Solid Box Fragile", 
        "fas fa-box-full" => "Solid Box Full", 
        "fas fa-box-heart" => "Solid Box Heart", 
        "fas fa-box-open" => "Solid Box Open", 
        "fas fa-box-up" => "Solid Box Up", 
        "fas fa-box-usd" => "Solid Box Usd", 
        "fas fa-boxes" => "Solid Boxes", 
        "fas fa-boxes-alt" => "Solid Boxes Alt", 
        "fas fa-boxing-glove" => "Solid Boxing Glove", 
        "fas fa-brackets" => "Solid Brackets", 
        "fas fa-brackets-curly" => "Solid Brackets Curly", 
        "fas fa-braille" => "Solid Braille", 
        "fas fa-brain" => "Solid Brain", 
        "fas fa-bread-loaf" => "Solid Bread Loaf", 
        "fas fa-bread-slice" => "Solid Bread Slice", 
        "fas fa-briefcase" => "Solid Briefcase", 
        "fas fa-briefcase-medical" => "Solid Briefcase Medical", 
        "fas fa-broadcast-tower" => "Solid Broadcast Tower", 
        "fas fa-broom" => "Solid Broom", 
        "fas fa-browser" => "Solid Browser", 
        "fas fa-brush" => "Solid Brush", 
        "fas fa-bug" => "Solid Bug", 
        "fas fa-building" => "Solid Building", 
        "fas fa-bullhorn" => "Solid Bullhorn", 
        "fas fa-bullseye" => "Solid Bullseye", 
        "fas fa-bullseye-arrow" => "Solid Bullseye Arrow", 
        "fas fa-bullseye-pointer" => "Solid Bullseye Pointer", 
        "fas fa-burn" => "Solid Burn", 
        "fas fa-burrito" => "Solid Burrito", 
        "fas fa-bus" => "Solid Bus", 
        "fas fa-bus-alt" => "Solid Bus Alt", 
        "fas fa-bus-school" => "Solid Bus School", 
        "fas fa-business-time" => "Solid Business Time", 
        "fas fa-cabinet-filing" => "Solid Cabinet Filing", 
        "fas fa-calculator" => "Solid Calculator", 
        "fas fa-calculator-alt" => "Solid Calculator Alt", 
        "fas fa-calendar" => "Solid Calendar", 
        "fas fa-calendar-alt" => "Solid Calendar Alt", 
        "fas fa-calendar-check" => "Solid Calendar Check", 
        "fas fa-calendar-day" => "Solid Calendar Day", 
        "fas fa-calendar-edit" => "Solid Calendar Edit", 
        "fas fa-calendar-exclamation" => "Solid Calendar Exclamation", 
        "fas fa-calendar-minus" => "Solid Calendar Minus", 
        "fas fa-calendar-plus" => "Solid Calendar Plus", 
        "fas fa-calendar-star" => "Solid Calendar Star", 
        "fas fa-calendar-times" => "Solid Calendar Times", 
        "fas fa-calendar-week" => "Solid Calendar Week", 
        "fas fa-camera" => "Solid Camera", 
        "fas fa-camera-alt" => "Solid Camera Alt", 
        "fas fa-camera-retro" => "Solid Camera Retro", 
        "fas fa-campfire" => "Solid Campfire", 
        "fas fa-campground" => "Solid Campground", 
        "fas fa-candle-holder" => "Solid Candle Holder", 
        "fas fa-candy-cane" => "Solid Candy Cane", 
        "fas fa-candy-corn" => "Solid Candy Corn", 
        "fas fa-cannabis" => "Solid Cannabis", 
        "fas fa-capsules" => "Solid Capsules", 
        "fas fa-car" => "Solid Car", 
        "fas fa-car-alt" => "Solid Car Alt", 
        "fas fa-car-battery" => "Solid Car Battery", 
        "fas fa-car-bump" => "Solid Car Bump", 
        "fas fa-car-crash" => "Solid Car Crash", 
        "fas fa-car-garage" => "Solid Car Garage", 
        "fas fa-car-mechanic" => "Solid Car Mechanic", 
        "fas fa-car-side" => "Solid Car Side", 
        "fas fa-car-tilt" => "Solid Car Tilt", 
        "fas fa-car-wash" => "Solid Car Wash", 
        "fas fa-caret-circle-down" => "Solid Caret Circle Down", 
        "fas fa-caret-circle-left" => "Solid Caret Circle Left", 
        "fas fa-caret-circle-right" => "Solid Caret Circle Right", 
        "fas fa-caret-circle-up" => "Solid Caret Circle Up", 
        "fas fa-caret-down" => "Solid Caret Down", 
        "fas fa-caret-left" => "Solid Caret Left", 
        "fas fa-caret-right" => "Solid Caret Right", 
        "fas fa-caret-square-down" => "Solid Caret Square Down", 
        "fas fa-caret-square-left" => "Solid Caret Square Left", 
        "fas fa-caret-square-right" => "Solid Caret Square Right", 
        "fas fa-caret-square-up" => "Solid Caret Square Up", 
        "fas fa-caret-up" => "Solid Caret Up", 
        "fas fa-carrot" => "Solid Carrot", 
        "fas fa-cart-arrow-down" => "Solid Cart Arrow Down", 
        "fas fa-cart-plus" => "Solid Cart Plus", 
        "fas fa-cash-register" => "Solid Cash Register", 
        "fas fa-cat" => "Solid Cat", 
        "fas fa-cauldron" => "Solid Cauldron", 
        "fas fa-certificate" => "Solid Certificate", 
        "fas fa-chair" => "Solid Chair", 
        "fas fa-chair-office" => "Solid Chair Office", 
        "fas fa-chalkboard" => "Solid Chalkboard", 
        "fas fa-chalkboard-teacher" => "Solid Chalkboard Teacher", 
        "fas fa-charging-station" => "Solid Charging Station", 
        "fas fa-chart-area" => "Solid Chart Area", 
        "fas fa-chart-bar" => "Solid Chart Bar", 
        "fas fa-chart-line" => "Solid Chart Line", 
        "fas fa-chart-line-down" => "Solid Chart Line Down", 
        "fas fa-chart-network" => "Solid Chart Network", 
        "fas fa-chart-pie" => "Solid Chart Pie", 
        "fas fa-chart-pie-alt" => "Solid Chart Pie Alt", 
        "fas fa-chart-scatter" => "Solid Chart Scatter", 
        "fas fa-check" => "Solid Check", 
        "fas fa-check-circle" => "Solid Check Circle", 
        "fas fa-check-double" => "Solid Check Double", 
        "fas fa-check-square" => "Solid Check Square", 
        "fas fa-cheese" => "Solid Cheese", 
        "fas fa-cheese-swiss" => "Solid Cheese Swiss", 
        "fas fa-cheeseburger" => "Solid Cheeseburger", 
        "fas fa-chess" => "Solid Chess", 
        "fas fa-chess-bishop" => "Solid Chess Bishop", 
        "fas fa-chess-bishop-alt" => "Solid Chess Bishop Alt", 
        "fas fa-chess-board" => "Solid Chess Board", 
        "fas fa-chess-clock" => "Solid Chess Clock", 
        "fas fa-chess-clock-alt" => "Solid Chess Clock Alt", 
        "fas fa-chess-king" => "Solid Chess King", 
        "fas fa-chess-king-alt" => "Solid Chess King Alt", 
        "fas fa-chess-knight" => "Solid Chess Knight", 
        "fas fa-chess-knight-alt" => "Solid Chess Knight Alt", 
        "fas fa-chess-pawn" => "Solid Chess Pawn", 
        "fas fa-chess-pawn-alt" => "Solid Chess Pawn Alt", 
        "fas fa-chess-queen" => "Solid Chess Queen", 
        "fas fa-chess-queen-alt" => "Solid Chess Queen Alt", 
        "fas fa-chess-rook" => "Solid Chess Rook", 
        "fas fa-chess-rook-alt" => "Solid Chess Rook Alt", 
        "fas fa-chevron-circle-down" => "Solid Chevron Circle Down", 
        "fas fa-chevron-circle-left" => "Solid Chevron Circle Left", 
        "fas fa-chevron-circle-right" => "Solid Chevron Circle Right", 
        "fas fa-chevron-circle-up" => "Solid Chevron Circle Up", 
        "fas fa-chevron-double-down" => "Solid Chevron Double Down", 
        "fas fa-chevron-double-left" => "Solid Chevron Double Left", 
        "fas fa-chevron-double-right" => "Solid Chevron Double Right", 
        "fas fa-chevron-double-up" => "Solid Chevron Double Up", 
        "fas fa-chevron-down" => "Solid Chevron Down", 
        "fas fa-chevron-left" => "Solid Chevron Left", 
        "fas fa-chevron-right" => "Solid Chevron Right", 
        "fas fa-chevron-square-down" => "Solid Chevron Square Down", 
        "fas fa-chevron-square-left" => "Solid Chevron Square Left", 
        "fas fa-chevron-square-right" => "Solid Chevron Square Right", 
        "fas fa-chevron-square-up" => "Solid Chevron Square Up", 
        "fas fa-chevron-up" => "Solid Chevron Up", 
        "fas fa-child" => "Solid Child", 
        "fas fa-chimney" => "Solid Chimney", 
        "fas fa-church" => "Solid Church", 
        "fas fa-circle" => "Solid Circle", 
        "fas fa-circle-notch" => "Solid Circle Notch", 
        "fas fa-city" => "Solid City", 
        "fas fa-claw-marks" => "Solid Claw Marks", 
        "fas fa-clinic-medical" => "Solid Clinic Medical", 
        "fas fa-clipboard" => "Solid Clipboard", 
        "fas fa-clipboard-check" => "Solid Clipboard Check", 
        "fas fa-clipboard-list" => "Solid Clipboard List", 
        "fas fa-clipboard-list-check" => "Solid Clipboard List Check", 
        "fas fa-clipboard-prescription" => "Solid Clipboard Prescription", 
        "fas fa-clipboard-user" => "Solid Clipboard User", 
        "fas fa-clock" => "Solid Clock", 
        "fas fa-clone" => "Solid Clone", 
        "fas fa-closed-captioning" => "Solid Closed Captioning", 
        "fas fa-cloud" => "Solid Cloud", 
        "fas fa-cloud-download" => "Solid Cloud Download", 
        "fas fa-cloud-download-alt" => "Solid Cloud Download Alt", 
        "fas fa-cloud-drizzle" => "Solid Cloud Drizzle", 
        "fas fa-cloud-hail" => "Solid Cloud Hail", 
        "fas fa-cloud-hail-mixed" => "Solid Cloud Hail Mixed", 
        "fas fa-cloud-meatball" => "Solid Cloud Meatball", 
        "fas fa-cloud-moon" => "Solid Cloud Moon", 
        "fas fa-cloud-moon-rain" => "Solid Cloud Moon Rain", 
        "fas fa-cloud-rain" => "Solid Cloud Rain", 
        "fas fa-cloud-rainbow" => "Solid Cloud Rainbow", 
        "fas fa-cloud-showers" => "Solid Cloud Showers", 
        "fas fa-cloud-showers-heavy" => "Solid Cloud Showers Heavy", 
        "fas fa-cloud-sleet" => "Solid Cloud Sleet", 
        "fas fa-cloud-snow" => "Solid Cloud Snow", 
        "fas fa-cloud-sun" => "Solid Cloud Sun", 
        "fas fa-cloud-sun-rain" => "Solid Cloud Sun Rain", 
        "fas fa-cloud-upload" => "Solid Cloud Upload", 
        "fas fa-cloud-upload-alt" => "Solid Cloud Upload Alt", 
        "fas fa-clouds" => "Solid Clouds", 
        "fas fa-clouds-moon" => "Solid Clouds Moon", 
        "fas fa-clouds-sun" => "Solid Clouds Sun", 
        "fas fa-club" => "Solid Club", 
        "fas fa-cocktail" => "Solid Cocktail", 
        "fas fa-code" => "Solid Code", 
        "fas fa-code-branch" => "Solid Code Branch", 
        "fas fa-code-commit" => "Solid Code Commit", 
        "fas fa-code-merge" => "Solid Code Merge", 
        "fas fa-coffee" => "Solid Coffee", 
        "fas fa-coffee-togo" => "Solid Coffee Togo", 
        "fas fa-coffin" => "Solid Coffin", 
        "fas fa-cog" => "Solid Cog", 
        "fas fa-cogs" => "Solid Cogs", 
        "fas fa-coins" => "Solid Coins", 
        "fas fa-columns" => "Solid Columns", 
        "fas fa-comment" => "Solid Comment", 
        "fas fa-comment-alt" => "Solid Comment Alt", 
        "fas fa-comment-alt-check" => "Solid Comment Alt Check", 
        "fas fa-comment-alt-dollar" => "Solid Comment Alt Dollar", 
        "fas fa-comment-alt-dots" => "Solid Comment Alt Dots", 
        "fas fa-comment-alt-edit" => "Solid Comment Alt Edit", 
        "fas fa-comment-alt-exclamation" => "Solid Comment Alt Exclamation", 
        "fas fa-comment-alt-lines" => "Solid Comment Alt Lines", 
        "fas fa-comment-alt-medical" => "Solid Comment Alt Medical", 
        "fas fa-comment-alt-minus" => "Solid Comment Alt Minus", 
        "fas fa-comment-alt-plus" => "Solid Comment Alt Plus", 
        "fas fa-comment-alt-slash" => "Solid Comment Alt Slash", 
        "fas fa-comment-alt-smile" => "Solid Comment Alt Smile", 
        "fas fa-comment-alt-times" => "Solid Comment Alt Times", 
        "fas fa-comment-check" => "Solid Comment Check", 
        "fas fa-comment-dollar" => "Solid Comment Dollar", 
        "fas fa-comment-dots" => "Solid Comment Dots", 
        "fas fa-comment-edit" => "Solid Comment Edit", 
        "fas fa-comment-exclamation" => "Solid Comment Exclamation", 
        "fas fa-comment-lines" => "Solid Comment Lines", 
        "fas fa-comment-medical" => "Solid Comment Medical", 
        "fas fa-comment-minus" => "Solid Comment Minus", 
        "fas fa-comment-plus" => "Solid Comment Plus", 
        "fas fa-comment-slash" => "Solid Comment Slash", 
        "fas fa-comment-smile" => "Solid Comment Smile", 
        "fas fa-comment-times" => "Solid Comment Times", 
        "fas fa-comments" => "Solid Comments", 
        "fas fa-comments-alt" => "Solid Comments Alt", 
        "fas fa-comments-alt-dollar" => "Solid Comments Alt Dollar", 
        "fas fa-comments-dollar" => "Solid Comments Dollar", 
        "fas fa-compact-disc" => "Solid Compact Disc", 
        "fas fa-compass" => "Solid Compass", 
        "fas fa-compass-slash" => "Solid Compass Slash", 
        "fas fa-compress" => "Solid Compress", 
        "fas fa-compress-alt" => "Solid Compress Alt", 
        "fas fa-compress-arrows-alt" => "Solid Compress Arrows Alt", 
        "fas fa-compress-wide" => "Solid Compress Wide", 
        "fas fa-concierge-bell" => "Solid Concierge Bell", 
        "fas fa-container-storage" => "Solid Container Storage", 
        "fas fa-conveyor-belt" => "Solid Conveyor Belt", 
        "fas fa-conveyor-belt-alt" => "Solid Conveyor Belt Alt", 
        "fas fa-cookie" => "Solid Cookie", 
        "fas fa-cookie-bite" => "Solid Cookie Bite", 
        "fas fa-copy" => "Solid Copy", 
        "fas fa-copyright" => "Solid Copyright", 
        "fas fa-corn" => "Solid Corn", 
        "fas fa-couch" => "Solid Couch", 
        "fas fa-cow" => "Solid Cow", 
        "fas fa-credit-card" => "Solid Credit Card", 
        "fas fa-credit-card-blank" => "Solid Credit Card Blank", 
        "fas fa-credit-card-front" => "Solid Credit Card Front", 
        "fas fa-cricket" => "Solid Cricket", 
        "fas fa-croissant" => "Solid Croissant", 
        "fas fa-crop" => "Solid Crop", 
        "fas fa-crop-alt" => "Solid Crop Alt", 
        "fas fa-cross" => "Solid Cross", 
        "fas fa-crosshairs" => "Solid Crosshairs", 
        "fas fa-crow" => "Solid Crow", 
        "fas fa-crown" => "Solid Crown", 
        "fas fa-crutch" => "Solid Crutch", 
        "fas fa-crutches" => "Solid Crutches", 
        "fas fa-cube" => "Solid Cube", 
        "fas fa-cubes" => "Solid Cubes", 
        "fas fa-curling" => "Solid Curling", 
        "fas fa-cut" => "Solid Cut", 
        "fas fa-dagger" => "Solid Dagger", 
        "fas fa-database" => "Solid Database", 
        "fas fa-deaf" => "Solid Deaf", 
        "fas fa-debug" => "Solid Debug", 
        "fas fa-deer" => "Solid Deer", 
        "fas fa-deer-rudolph" => "Solid Deer Rudolph", 
        "fas fa-democrat" => "Solid Democrat", 
        "fas fa-desktop" => "Solid Desktop", 
        "fas fa-desktop-alt" => "Solid Desktop Alt", 
        "fas fa-dewpoint" => "Solid Dewpoint", 
        "fas fa-dharmachakra" => "Solid Dharmachakra", 
        "fas fa-diagnoses" => "Solid Diagnoses", 
        "fas fa-diamond" => "Solid Diamond", 
        "fas fa-dice" => "Solid Dice", 
        "fas fa-dice-d10" => "Solid Dice D10", 
        "fas fa-dice-d12" => "Solid Dice D12", 
        "fas fa-dice-d20" => "Solid Dice D20", 
        "fas fa-dice-d4" => "Solid Dice D4", 
        "fas fa-dice-d6" => "Solid Dice D6", 
        "fas fa-dice-d8" => "Solid Dice D8", 
        "fas fa-dice-five" => "Solid Dice Five", 
        "fas fa-dice-four" => "Solid Dice Four", 
        "fas fa-dice-one" => "Solid Dice One", 
        "fas fa-dice-six" => "Solid Dice Six", 
        "fas fa-dice-three" => "Solid Dice Three", 
        "fas fa-dice-two" => "Solid Dice Two", 
        "fas fa-digital-tachograph" => "Solid Digital Tachograph", 
        "fas fa-diploma" => "Solid Diploma", 
        "fas fa-directions" => "Solid Directions", 
        "fas fa-disease" => "Solid Disease", 
        "fas fa-divide" => "Solid Divide", 
        "fas fa-dizzy" => "Solid Dizzy", 
        "fas fa-dna" => "Solid Dna", 
        "fas fa-do-not-enter" => "Solid Do Not Enter", 
        "fas fa-dog" => "Solid Dog", 
        "fas fa-dog-leashed" => "Solid Dog Leashed", 
        "fas fa-dollar-sign" => "Solid Dollar Sign", 
        "fas fa-dolly" => "Solid Dolly", 
        "fas fa-dolly-empty" => "Solid Dolly Empty", 
        "fas fa-dolly-flatbed" => "Solid Dolly Flatbed", 
        "fas fa-dolly-flatbed-alt" => "Solid Dolly Flatbed Alt", 
        "fas fa-dolly-flatbed-empty" => "Solid Dolly Flatbed Empty", 
        "fas fa-donate" => "Solid Donate", 
        "fas fa-door-closed" => "Solid Door Closed", 
        "fas fa-door-open" => "Solid Door Open", 
        "fas fa-dot-circle" => "Solid Dot Circle", 
        "fas fa-dove" => "Solid Dove", 
        "fas fa-download" => "Solid Download", 
        "fas fa-drafting-compass" => "Solid Drafting Compass", 
        "fas fa-dragon" => "Solid Dragon", 
        "fas fa-draw-circle" => "Solid Draw Circle", 
        "fas fa-draw-polygon" => "Solid Draw Polygon", 
        "fas fa-draw-square" => "Solid Draw Square", 
        "fas fa-dreidel" => "Solid Dreidel", 
        "fas fa-drum" => "Solid Drum", 
        "fas fa-drum-steelpan" => "Solid Drum Steelpan", 
        "fas fa-drumstick" => "Solid Drumstick", 
        "fas fa-drumstick-bite" => "Solid Drumstick Bite", 
        "fas fa-duck" => "Solid Duck", 
        "fas fa-dumbbell" => "Solid Dumbbell", 
        "fas fa-dumpster" => "Solid Dumpster", 
        "fas fa-dumpster-fire" => "Solid Dumpster Fire", 
        "fas fa-dungeon" => "Solid Dungeon", 
        "fas fa-ear" => "Solid Ear", 
        "fas fa-ear-muffs" => "Solid Ear Muffs", 
        "fas fa-eclipse" => "Solid Eclipse", 
        "fas fa-eclipse-alt" => "Solid Eclipse Alt", 
        "fas fa-edit" => "Solid Edit", 
        "fas fa-egg" => "Solid Egg", 
        "fas fa-egg-fried" => "Solid Egg Fried", 
        "fas fa-eject" => "Solid Eject", 
        "fas fa-elephant" => "Solid Elephant", 
        "fas fa-ellipsis-h" => "Solid Ellipsis H", 
        "fas fa-ellipsis-h-alt" => "Solid Ellipsis H Alt", 
        "fas fa-ellipsis-v" => "Solid Ellipsis V", 
        "fas fa-ellipsis-v-alt" => "Solid Ellipsis V Alt", 
        "fas fa-empty-set" => "Solid Empty Set", 
        "fas fa-engine-warning" => "Solid Engine Warning", 
        "fas fa-envelope" => "Solid Envelope", 
        "fas fa-envelope-open" => "Solid Envelope Open", 
        "fas fa-envelope-open-dollar" => "Solid Envelope Open Dollar", 
        "fas fa-envelope-open-text" => "Solid Envelope Open Text", 
        "fas fa-envelope-square" => "Solid Envelope Square", 
        "fas fa-equals" => "Solid Equals", 
        "fas fa-eraser" => "Solid Eraser", 
        "fas fa-ethernet" => "Solid Ethernet", 
        "fas fa-euro-sign" => "Solid Euro Sign", 
        "fas fa-exchange" => "Solid Exchange", 
        "fas fa-exchange-alt" => "Solid Exchange Alt", 
        "fas fa-exclamation" => "Solid Exclamation", 
        "fas fa-exclamation-circle" => "Solid Exclamation Circle", 
        "fas fa-exclamation-square" => "Solid Exclamation Square", 
        "fas fa-exclamation-triangle" => "Solid Exclamation Triangle", 
        "fas fa-expand" => "Solid Expand", 
        "fas fa-expand-alt" => "Solid Expand Alt", 
        "fas fa-expand-arrows" => "Solid Expand Arrows", 
        "fas fa-expand-arrows-alt" => "Solid Expand Arrows Alt", 
        "fas fa-expand-wide" => "Solid Expand Wide", 
        "fas fa-external-link" => "Solid External Link", 
        "fas fa-external-link-alt" => "Solid External Link Alt", 
        "fas fa-external-link-square" => "Solid External Link Square", 
        "fas fa-external-link-square-alt" => "Solid External Link Square Alt", 
        "fas fa-eye" => "Solid Eye", 
        "fas fa-eye-dropper" => "Solid Eye Dropper", 
        "fas fa-eye-evil" => "Solid Eye Evil", 
        "fas fa-eye-slash" => "Solid Eye Slash", 
        "fas fa-fast-backward" => "Solid Fast Backward", 
        "fas fa-fast-forward" => "Solid Fast Forward", 
        "fas fa-fax" => "Solid Fax", 
        "fas fa-feather" => "Solid Feather", 
        "fas fa-feather-alt" => "Solid Feather Alt", 
        "fas fa-female" => "Solid Female", 
        "fas fa-field-hockey" => "Solid Field Hockey", 
        "fas fa-fighter-jet" => "Solid Fighter Jet", 
        "fas fa-file" => "Solid File", 
        "fas fa-file-alt" => "Solid File Alt", 
        "fas fa-file-archive" => "Solid File Archive", 
        "fas fa-file-audio" => "Solid File Audio", 
        "fas fa-file-certificate" => "Solid File Certificate", 
        "fas fa-file-chart-line" => "Solid File Chart Line", 
        "fas fa-file-chart-pie" => "Solid File Chart Pie", 
        "fas fa-file-check" => "Solid File Check", 
        "fas fa-file-code" => "Solid File Code", 
        "fas fa-file-contract" => "Solid File Contract", 
        "fas fa-file-csv" => "Solid File Csv", 
        "fas fa-file-download" => "Solid File Download", 
        "fas fa-file-edit" => "Solid File Edit", 
        "fas fa-file-excel" => "Solid File Excel", 
        "fas fa-file-exclamation" => "Solid File Exclamation", 
        "fas fa-file-export" => "Solid File Export", 
        "fas fa-file-image" => "Solid File Image", 
        "fas fa-file-import" => "Solid File Import", 
        "fas fa-file-invoice" => "Solid File Invoice", 
        "fas fa-file-invoice-dollar" => "Solid File Invoice Dollar", 
        "fas fa-file-medical" => "Solid File Medical", 
        "fas fa-file-medical-alt" => "Solid File Medical Alt", 
        "fas fa-file-minus" => "Solid File Minus", 
        "fas fa-file-pdf" => "Solid File Pdf", 
        "fas fa-file-plus" => "Solid File Plus", 
        "fas fa-file-powerpoint" => "Solid File Powerpoint", 
        "fas fa-file-prescription" => "Solid File Prescription", 
        "fas fa-file-signature" => "Solid File Signature", 
        "fas fa-file-spreadsheet" => "Solid File Spreadsheet", 
        "fas fa-file-times" => "Solid File Times", 
        "fas fa-file-upload" => "Solid File Upload", 
        "fas fa-file-user" => "Solid File User", 
        "fas fa-file-video" => "Solid File Video", 
        "fas fa-file-word" => "Solid File Word", 
        "fas fa-files-medical" => "Solid Files Medical", 
        "fas fa-fill" => "Solid Fill", 
        "fas fa-fill-drip" => "Solid Fill Drip", 
        "fas fa-film" => "Solid Film", 
        "fas fa-film-alt" => "Solid Film Alt", 
        "fas fa-filter" => "Solid Filter", 
        "fas fa-fingerprint" => "Solid Fingerprint", 
        "fas fa-fire" => "Solid Fire", 
        "fas fa-fire-alt" => "Solid Fire Alt", 
        "fas fa-fire-extinguisher" => "Solid Fire Extinguisher", 
        "fas fa-fire-smoke" => "Solid Fire Smoke", 
        "fas fa-fireplace" => "Solid Fireplace", 
        "fas fa-first-aid" => "Solid First Aid", 
        "fas fa-fish" => "Solid Fish", 
        "fas fa-fish-cooked" => "Solid Fish Cooked", 
        "fas fa-fist-raised" => "Solid Fist Raised", 
        "fas fa-flag" => "Solid Flag", 
        "fas fa-flag-alt" => "Solid Flag Alt", 
        "fas fa-flag-checkered" => "Solid Flag Checkered", 
        "fas fa-flag-usa" => "Solid Flag Usa", 
        "fas fa-flame" => "Solid Flame", 
        "fas fa-flask" => "Solid Flask", 
        "fas fa-flask-poison" => "Solid Flask Poison", 
        "fas fa-flask-potion" => "Solid Flask Potion", 
        "fas fa-flower" => "Solid Flower", 
        "fas fa-flower-daffodil" => "Solid Flower Daffodil", 
        "fas fa-flower-tulip" => "Solid Flower Tulip", 
        "fas fa-flushed" => "Solid Flushed", 
        "fas fa-fog" => "Solid Fog", 
        "fas fa-folder" => "Solid Folder", 
        "fas fa-folder-minus" => "Solid Folder Minus", 
        "fas fa-folder-open" => "Solid Folder Open", 
        "fas fa-folder-plus" => "Solid Folder Plus", 
        "fas fa-folder-times" => "Solid Folder Times", 
        "fas fa-folder-tree" => "Solid Folder Tree", 
        "fas fa-folders" => "Solid Folders", 
        "fas fa-font" => "Solid Font", 
        "fas fa-football-ball" => "Solid Football Ball", 
        "fas fa-football-helmet" => "Solid Football Helmet", 
        "fas fa-forklift" => "Solid Forklift", 
        "fas fa-forward" => "Solid Forward", 
        "fas fa-fragile" => "Solid Fragile", 
        "fas fa-french-fries" => "Solid French Fries", 
        "fas fa-frog" => "Solid Frog", 
        "fas fa-frosty-head" => "Solid Frosty Head", 
        "fas fa-frown" => "Solid Frown", 
        "fas fa-frown-open" => "Solid Frown Open", 
        "fas fa-function" => "Solid Function", 
        "fas fa-funnel-dollar" => "Solid Funnel Dollar", 
        "fas fa-futbol" => "Solid Futbol", 
        "fas fa-gamepad" => "Solid Gamepad", 
        "fas fa-gas-pump" => "Solid Gas Pump", 
        "fas fa-gas-pump-slash" => "Solid Gas Pump Slash", 
        "fas fa-gavel" => "Solid Gavel", 
        "fas fa-gem" => "Solid Gem", 
        "fas fa-genderless" => "Solid Genderless", 
        "fas fa-ghost" => "Solid Ghost", 
        "fas fa-gift" => "Solid Gift", 
        "fas fa-gift-card" => "Solid Gift Card", 
        "fas fa-gifts" => "Solid Gifts", 
        "fas fa-gingerbread-man" => "Solid Gingerbread Man", 
        "fas fa-glass" => "Solid Glass", 
        "fas fa-glass-champagne" => "Solid Glass Champagne", 
        "fas fa-glass-cheers" => "Solid Glass Cheers", 
        "fas fa-glass-martini" => "Solid Glass Martini", 
        "fas fa-glass-martini-alt" => "Solid Glass Martini Alt", 
        "fas fa-glass-whiskey" => "Solid Glass Whiskey", 
        "fas fa-glass-whiskey-rocks" => "Solid Glass Whiskey Rocks", 
        "fas fa-glasses" => "Solid Glasses", 
        "fas fa-glasses-alt" => "Solid Glasses Alt", 
        "fas fa-globe" => "Solid Globe", 
        "fas fa-globe-africa" => "Solid Globe Africa", 
        "fas fa-globe-americas" => "Solid Globe Americas", 
        "fas fa-globe-asia" => "Solid Globe Asia", 
        "fas fa-globe-europe" => "Solid Globe Europe", 
        "fas fa-globe-snow" => "Solid Globe Snow", 
        "fas fa-globe-stand" => "Solid Globe Stand", 
        "fas fa-golf-ball" => "Solid Golf Ball", 
        "fas fa-golf-club" => "Solid Golf Club", 
        "fas fa-gopuram" => "Solid Gopuram", 
        "fas fa-graduation-cap" => "Solid Graduation Cap", 
        "fas fa-greater-than" => "Solid Greater Than", 
        "fas fa-greater-than-equal" => "Solid Greater Than Equal", 
        "fas fa-grimace" => "Solid Grimace", 
        "fas fa-grin" => "Solid Grin", 
        "fas fa-grin-alt" => "Solid Grin Alt", 
        "fas fa-grin-beam" => "Solid Grin Beam", 
        "fas fa-grin-beam-sweat" => "Solid Grin Beam Sweat", 
        "fas fa-grin-hearts" => "Solid Grin Hearts", 
        "fas fa-grin-squint" => "Solid Grin Squint", 
        "fas fa-grin-squint-tears" => "Solid Grin Squint Tears", 
        "fas fa-grin-stars" => "Solid Grin Stars", 
        "fas fa-grin-tears" => "Solid Grin Tears", 
        "fas fa-grin-tongue" => "Solid Grin Tongue", 
        "fas fa-grin-tongue-squint" => "Solid Grin Tongue Squint", 
        "fas fa-grin-tongue-wink" => "Solid Grin Tongue Wink", 
        "fas fa-grin-wink" => "Solid Grin Wink", 
        "fas fa-grip-horizontal" => "Solid Grip Horizontal", 
        "fas fa-grip-lines" => "Solid Grip Lines", 
        "fas fa-grip-lines-vertical" => "Solid Grip Lines Vertical", 
        "fas fa-grip-vertical" => "Solid Grip Vertical", 
        "fas fa-guitar" => "Solid Guitar", 
        "fas fa-h-square" => "Solid H Square", 
        "fas fa-h1" => "Solid H1", 
        "fas fa-h2" => "Solid H2", 
        "fas fa-h3" => "Solid H3", 
        "fas fa-hamburger" => "Solid Hamburger", 
        "fas fa-hammer" => "Solid Hammer", 
        "fas fa-hammer-war" => "Solid Hammer War", 
        "fas fa-hamsa" => "Solid Hamsa", 
        "fas fa-hand-heart" => "Solid Hand Heart", 
        "fas fa-hand-holding" => "Solid Hand Holding", 
        "fas fa-hand-holding-box" => "Solid Hand Holding Box", 
        "fas fa-hand-holding-heart" => "Solid Hand Holding Heart", 
        "fas fa-hand-holding-magic" => "Solid Hand Holding Magic", 
        "fas fa-hand-holding-seedling" => "Solid Hand Holding Seedling", 
        "fas fa-hand-holding-usd" => "Solid Hand Holding Usd", 
        "fas fa-hand-holding-water" => "Solid Hand Holding Water", 
        "fas fa-hand-lizard" => "Solid Hand Lizard", 
        "fas fa-hand-middle-finger" => "Solid Hand Middle Finger", 
        "fas fa-hand-paper" => "Solid Hand Paper", 
        "fas fa-hand-peace" => "Solid Hand Peace", 
        "fas fa-hand-point-down" => "Solid Hand Point Down", 
        "fas fa-hand-point-left" => "Solid Hand Point Left", 
        "fas fa-hand-point-right" => "Solid Hand Point Right", 
        "fas fa-hand-point-up" => "Solid Hand Point Up", 
        "fas fa-hand-pointer" => "Solid Hand Pointer", 
        "fas fa-hand-receiving" => "Solid Hand Receiving", 
        "fas fa-hand-rock" => "Solid Hand Rock", 
        "fas fa-hand-scissors" => "Solid Hand Scissors", 
        "fas fa-hand-spock" => "Solid Hand Spock", 
        "fas fa-hands" => "Solid Hands", 
        "fas fa-hands-heart" => "Solid Hands Heart", 
        "fas fa-hands-helping" => "Solid Hands Helping", 
        "fas fa-hands-usd" => "Solid Hands Usd", 
        "fas fa-handshake" => "Solid Handshake", 
        "fas fa-handshake-alt" => "Solid Handshake Alt", 
        "fas fa-hanukiah" => "Solid Hanukiah", 
        "fas fa-hard-hat" => "Solid Hard Hat", 
        "fas fa-hashtag" => "Solid Hashtag", 
        "fas fa-hat-santa" => "Solid Hat Santa", 
        "fas fa-hat-winter" => "Solid Hat Winter", 
        "fas fa-hat-witch" => "Solid Hat Witch", 
        "fas fa-hat-wizard" => "Solid Hat Wizard", 
        "fas fa-haykal" => "Solid Haykal", 
        "fas fa-hdd" => "Solid Hdd", 
        "fas fa-head-side" => "Solid Head Side", 
        "fas fa-head-side-brain" => "Solid Head Side Brain", 
        "fas fa-head-side-medical" => "Solid Head Side Medical", 
        "fas fa-head-vr" => "Solid Head Vr", 
        "fas fa-heading" => "Solid Heading", 
        "fas fa-headphones" => "Solid Headphones", 
        "fas fa-headphones-alt" => "Solid Headphones Alt", 
        "fas fa-headset" => "Solid Headset", 
        "fas fa-heart" => "Solid Heart", 
        "fas fa-heart-broken" => "Solid Heart Broken", 
        "fas fa-heart-circle" => "Solid Heart Circle", 
        "fas fa-heart-rate" => "Solid Heart Rate", 
        "fas fa-heart-square" => "Solid Heart Square", 
        "fas fa-heartbeat" => "Solid Heartbeat", 
        "fas fa-helicopter" => "Solid Helicopter", 
        "fas fa-helmet-battle" => "Solid Helmet Battle", 
        "fas fa-hexagon" => "Solid Hexagon", 
        "fas fa-highlighter" => "Solid Highlighter", 
        "fas fa-hiking" => "Solid Hiking", 
        "fas fa-hippo" => "Solid Hippo", 
        "fas fa-history" => "Solid History", 
        "fas fa-hockey-mask" => "Solid Hockey Mask", 
        "fas fa-hockey-puck" => "Solid Hockey Puck", 
        "fas fa-hockey-sticks" => "Solid Hockey Sticks", 
        "fas fa-holly-berry" => "Solid Holly Berry", 
        "fas fa-home" => "Solid Home", 
        "fas fa-home-alt" => "Solid Home Alt", 
        "fas fa-home-heart" => "Solid Home Heart", 
        "fas fa-home-lg" => "Solid Home Lg", 
        "fas fa-home-lg-alt" => "Solid Home Lg Alt", 
        "fas fa-hood-cloak" => "Solid Hood Cloak", 
        "fas fa-horse" => "Solid Horse", 
        "fas fa-horse-head" => "Solid Horse Head", 
        "fas fa-hospital" => "Solid Hospital", 
        "fas fa-hospital-alt" => "Solid Hospital Alt", 
        "fas fa-hospital-symbol" => "Solid Hospital Symbol", 
        "fas fa-hospital-user" => "Solid Hospital User", 
        "fas fa-hospitals" => "Solid Hospitals", 
        "fas fa-hot-tub" => "Solid Hot Tub", 
        "fas fa-hotdog" => "Solid Hotdog", 
        "fas fa-hotel" => "Solid Hotel", 
        "fas fa-hourglass" => "Solid Hourglass", 
        "fas fa-hourglass-end" => "Solid Hourglass End", 
        "fas fa-hourglass-half" => "Solid Hourglass Half", 
        "fas fa-hourglass-start" => "Solid Hourglass Start", 
        "fas fa-house-damage" => "Solid House Damage", 
        "fas fa-house-flood" => "Solid House Flood", 
        "fas fa-hryvnia" => "Solid Hryvnia", 
        "fas fa-humidity" => "Solid Humidity", 
        "fas fa-hurricane" => "Solid Hurricane", 
        "fas fa-i-cursor" => "Solid I Cursor", 
        "fas fa-ice-cream" => "Solid Ice Cream", 
        "fas fa-ice-skate" => "Solid Ice Skate", 
        "fas fa-icicles" => "Solid Icicles", 
        "fas fa-id-badge" => "Solid Id Badge", 
        "fas fa-id-card" => "Solid Id Card", 
        "fas fa-id-card-alt" => "Solid Id Card Alt", 
        "fas fa-igloo" => "Solid Igloo", 
        "fas fa-image" => "Solid Image", 
        "fas fa-images" => "Solid Images", 
        "fas fa-inbox" => "Solid Inbox", 
        "fas fa-inbox-in" => "Solid Inbox In", 
        "fas fa-inbox-out" => "Solid Inbox Out", 
        "fas fa-indent" => "Solid Indent", 
        "fas fa-industry" => "Solid Industry", 
        "fas fa-industry-alt" => "Solid Industry Alt", 
        "fas fa-infinity" => "Solid Infinity", 
        "fas fa-info" => "Solid Info", 
        "fas fa-info-circle" => "Solid Info Circle", 
        "fas fa-info-square" => "Solid Info Square", 
        "fas fa-inhaler" => "Solid Inhaler", 
        "fas fa-integral" => "Solid Integral", 
        "fas fa-intersection" => "Solid Intersection", 
        "fas fa-inventory" => "Solid Inventory", 
        "fas fa-island-tropical" => "Solid Island Tropical", 
        "fas fa-italic" => "Solid Italic", 
        "fas fa-jack-o-lantern" => "Solid Jack O Lantern", 
        "fas fa-jedi" => "Solid Jedi", 
        "fas fa-joint" => "Solid Joint", 
        "fas fa-journal-whills" => "Solid Journal Whills", 
        "fas fa-kaaba" => "Solid Kaaba", 
        "fas fa-key" => "Solid Key", 
        "fas fa-key-skeleton" => "Solid Key Skeleton", 
        "fas fa-keyboard" => "Solid Keyboard", 
        "fas fa-keynote" => "Solid Keynote", 
        "fas fa-khanda" => "Solid Khanda", 
        "fas fa-kidneys" => "Solid Kidneys", 
        "fas fa-kiss" => "Solid Kiss", 
        "fas fa-kiss-beam" => "Solid Kiss Beam", 
        "fas fa-kiss-wink-heart" => "Solid Kiss Wink Heart", 
        "fas fa-kite" => "Solid Kite", 
        "fas fa-kiwi-bird" => "Solid Kiwi Bird", 
        "fas fa-knife-kitchen" => "Solid Knife Kitchen", 
        "fas fa-lambda" => "Solid Lambda", 
        "fas fa-lamp" => "Solid Lamp", 
        "fas fa-landmark" => "Solid Landmark", 
        "fas fa-landmark-alt" => "Solid Landmark Alt", 
        "fas fa-language" => "Solid Language", 
        "fas fa-laptop" => "Solid Laptop", 
        "fas fa-laptop-code" => "Solid Laptop Code", 
        "fas fa-laptop-medical" => "Solid Laptop Medical", 
        "fas fa-laugh" => "Solid Laugh", 
        "fas fa-laugh-beam" => "Solid Laugh Beam", 
        "fas fa-laugh-squint" => "Solid Laugh Squint", 
        "fas fa-laugh-wink" => "Solid Laugh Wink", 
        "fas fa-layer-group" => "Solid Layer Group", 
        "fas fa-layer-minus" => "Solid Layer Minus", 
        "fas fa-layer-plus" => "Solid Layer Plus", 
        "fas fa-leaf" => "Solid Leaf", 
        "fas fa-leaf-heart" => "Solid Leaf Heart", 
        "fas fa-leaf-maple" => "Solid Leaf Maple", 
        "fas fa-leaf-oak" => "Solid Leaf Oak", 
        "fas fa-lemon" => "Solid Lemon", 
        "fas fa-less-than" => "Solid Less Than", 
        "fas fa-less-than-equal" => "Solid Less Than Equal", 
        "fas fa-level-down" => "Solid Level Down", 
        "fas fa-level-down-alt" => "Solid Level Down Alt", 
        "fas fa-level-up" => "Solid Level Up", 
        "fas fa-level-up-alt" => "Solid Level Up Alt", 
        "fas fa-life-ring" => "Solid Life Ring", 
        "fas fa-lightbulb" => "Solid Lightbulb", 
        "fas fa-lightbulb-dollar" => "Solid Lightbulb Dollar", 
        "fas fa-lightbulb-exclamation" => "Solid Lightbulb Exclamation", 
        "fas fa-lightbulb-on" => "Solid Lightbulb On", 
        "fas fa-lightbulb-slash" => "Solid Lightbulb Slash", 
        "fas fa-lights-holiday" => "Solid Lights Holiday", 
        "fas fa-link" => "Solid Link", 
        "fas fa-lips" => "Solid Lips", 
        "fas fa-lira-sign" => "Solid Lira Sign", 
        "fas fa-list" => "Solid List", 
        "fas fa-list-alt" => "Solid List Alt", 
        "fas fa-list-ol" => "Solid List Ol", 
        "fas fa-list-ul" => "Solid List Ul", 
        "fas fa-location" => "Solid Location", 
        "fas fa-location-arrow" => "Solid Location Arrow", 
        "fas fa-location-circle" => "Solid Location Circle", 
        "fas fa-location-slash" => "Solid Location Slash", 
        "fas fa-lock" => "Solid Lock", 
        "fas fa-lock-alt" => "Solid Lock Alt", 
        "fas fa-lock-open" => "Solid Lock Open", 
        "fas fa-lock-open-alt" => "Solid Lock Open Alt", 
        "fas fa-long-arrow-alt-down" => "Solid Long Arrow Alt Down", 
        "fas fa-long-arrow-alt-left" => "Solid Long Arrow Alt Left", 
        "fas fa-long-arrow-alt-right" => "Solid Long Arrow Alt Right", 
        "fas fa-long-arrow-alt-up" => "Solid Long Arrow Alt Up", 
        "fas fa-long-arrow-down" => "Solid Long Arrow Down", 
        "fas fa-long-arrow-left" => "Solid Long Arrow Left", 
        "fas fa-long-arrow-right" => "Solid Long Arrow Right", 
        "fas fa-long-arrow-up" => "Solid Long Arrow Up", 
        "fas fa-loveseat" => "Solid Loveseat", 
        "fas fa-low-vision" => "Solid Low Vision", 
        "fas fa-luchador" => "Solid Luchador", 
        "fas fa-luggage-cart" => "Solid Luggage Cart", 
        "fas fa-lungs" => "Solid Lungs", 
        "fas fa-mace" => "Solid Mace", 
        "fas fa-magic" => "Solid Magic", 
        "fas fa-magnet" => "Solid Magnet", 
        "fas fa-mail-bulk" => "Solid Mail Bulk", 
        "fas fa-mailbox" => "Solid Mailbox", 
        "fas fa-male" => "Solid Male", 
        "fas fa-mandolin" => "Solid Mandolin", 
        "fas fa-map" => "Solid Map", 
        "fas fa-map-marked" => "Solid Map Marked", 
        "fas fa-map-marked-alt" => "Solid Map Marked Alt", 
        "fas fa-map-marker" => "Solid Map Marker", 
        "fas fa-map-marker-alt" => "Solid Map Marker Alt", 
        "fas fa-map-marker-alt-slash" => "Solid Map Marker Alt Slash", 
        "fas fa-map-marker-check" => "Solid Map Marker Check", 
        "fas fa-map-marker-edit" => "Solid Map Marker Edit", 
        "fas fa-map-marker-exclamation" => "Solid Map Marker Exclamation", 
        "fas fa-map-marker-minus" => "Solid Map Marker Minus", 
        "fas fa-map-marker-plus" => "Solid Map Marker Plus", 
        "fas fa-map-marker-question" => "Solid Map Marker Question", 
        "fas fa-map-marker-slash" => "Solid Map Marker Slash", 
        "fas fa-map-marker-smile" => "Solid Map Marker Smile", 
        "fas fa-map-marker-times" => "Solid Map Marker Times", 
        "fas fa-map-pin" => "Solid Map Pin", 
        "fas fa-map-signs" => "Solid Map Signs", 
        "fas fa-marker" => "Solid Marker", 
        "fas fa-mars" => "Solid Mars", 
        "fas fa-mars-double" => "Solid Mars Double", 
        "fas fa-mars-stroke" => "Solid Mars Stroke", 
        "fas fa-mars-stroke-h" => "Solid Mars Stroke H", 
        "fas fa-mars-stroke-v" => "Solid Mars Stroke V", 
        "fas fa-mask" => "Solid Mask", 
        "fas fa-meat" => "Solid Meat", 
        "fas fa-medal" => "Solid Medal", 
        "fas fa-medkit" => "Solid Medkit", 
        "fas fa-megaphone" => "Solid Megaphone", 
        "fas fa-meh" => "Solid Meh", 
        "fas fa-meh-blank" => "Solid Meh Blank", 
        "fas fa-meh-rolling-eyes" => "Solid Meh Rolling Eyes", 
        "fas fa-memory" => "Solid Memory", 
        "fas fa-menorah" => "Solid Menorah", 
        "fas fa-mercury" => "Solid Mercury", 
        "fas fa-meteor" => "Solid Meteor", 
        "fas fa-microchip" => "Solid Microchip", 
        "fas fa-microphone" => "Solid Microphone", 
        "fas fa-microphone-alt" => "Solid Microphone Alt", 
        "fas fa-microphone-alt-slash" => "Solid Microphone Alt Slash", 
        "fas fa-microphone-slash" => "Solid Microphone Slash", 
        "fas fa-microscope" => "Solid Microscope", 
        "fas fa-mind-share" => "Solid Mind Share", 
        "fas fa-minus" => "Solid Minus", 
        "fas fa-minus-circle" => "Solid Minus Circle", 
        "fas fa-minus-hexagon" => "Solid Minus Hexagon", 
        "fas fa-minus-octagon" => "Solid Minus Octagon", 
        "fas fa-minus-square" => "Solid Minus Square", 
        "fas fa-mistletoe" => "Solid Mistletoe", 
        "fas fa-mitten" => "Solid Mitten", 
        "fas fa-mobile" => "Solid Mobile", 
        "fas fa-mobile-alt" => "Solid Mobile Alt", 
        "fas fa-mobile-android" => "Solid Mobile Android", 
        "fas fa-mobile-android-alt" => "Solid Mobile Android Alt", 
        "fas fa-money-bill" => "Solid Money Bill", 
        "fas fa-money-bill-alt" => "Solid Money Bill Alt", 
        "fas fa-money-bill-wave" => "Solid Money Bill Wave", 
        "fas fa-money-bill-wave-alt" => "Solid Money Bill Wave Alt", 
        "fas fa-money-check" => "Solid Money Check", 
        "fas fa-money-check-alt" => "Solid Money Check Alt", 
        "fas fa-monitor-heart-rate" => "Solid Monitor Heart Rate", 
        "fas fa-monkey" => "Solid Monkey", 
        "fas fa-monument" => "Solid Monument", 
        "fas fa-moon" => "Solid Moon", 
        "fas fa-moon-cloud" => "Solid Moon Cloud", 
        "fas fa-moon-stars" => "Solid Moon Stars", 
        "fas fa-mortar-pestle" => "Solid Mortar Pestle", 
        "fas fa-mosque" => "Solid Mosque", 
        "fas fa-motorcycle" => "Solid Motorcycle", 
        "fas fa-mountain" => "Solid Mountain", 
        "fas fa-mountains" => "Solid Mountains", 
        "fas fa-mouse-pointer" => "Solid Mouse Pointer", 
        "fas fa-mug-hot" => "Solid Mug Hot", 
        "fas fa-mug-marshmallows" => "Solid Mug Marshmallows", 
        "fas fa-music" => "Solid Music", 
        "fas fa-narwhal" => "Solid Narwhal", 
        "fas fa-network-wired" => "Solid Network Wired", 
        "fas fa-neuter" => "Solid Neuter", 
        "fas fa-newspaper" => "Solid Newspaper", 
        "fas fa-not-equal" => "Solid Not Equal", 
        "fas fa-notes-medical" => "Solid Notes Medical", 
        "fas fa-object-group" => "Solid Object Group", 
        "fas fa-object-ungroup" => "Solid Object Ungroup", 
        "fas fa-octagon" => "Solid Octagon", 
        "fas fa-oil-can" => "Solid Oil Can", 
        "fas fa-oil-temp" => "Solid Oil Temp", 
        "fas fa-om" => "Solid Om", 
        "fas fa-omega" => "Solid Omega", 
        "fas fa-ornament" => "Solid Ornament", 
        "fas fa-otter" => "Solid Otter", 
        "fas fa-outdent" => "Solid Outdent", 
        "fas fa-pager" => "Solid Pager", 
        "fas fa-paint-brush" => "Solid Paint Brush", 
        "fas fa-paint-brush-alt" => "Solid Paint Brush Alt", 
        "fas fa-paint-roller" => "Solid Paint Roller", 
        "fas fa-palette" => "Solid Palette", 
        "fas fa-pallet" => "Solid Pallet", 
        "fas fa-pallet-alt" => "Solid Pallet Alt", 
        "fas fa-paper-plane" => "Solid Paper Plane", 
        "fas fa-paperclip" => "Solid Paperclip", 
        "fas fa-parachute-box" => "Solid Parachute Box", 
        "fas fa-paragraph" => "Solid Paragraph", 
        "fas fa-parking" => "Solid Parking", 
        "fas fa-parking-circle" => "Solid Parking Circle", 
        "fas fa-parking-circle-slash" => "Solid Parking Circle Slash", 
        "fas fa-parking-slash" => "Solid Parking Slash", 
        "fas fa-passport" => "Solid Passport", 
        "fas fa-pastafarianism" => "Solid Pastafarianism", 
        "fas fa-paste" => "Solid Paste", 
        "fas fa-pause" => "Solid Pause", 
        "fas fa-pause-circle" => "Solid Pause Circle", 
        "fas fa-paw" => "Solid Paw", 
        "fas fa-paw-alt" => "Solid Paw Alt", 
        "fas fa-paw-claws" => "Solid Paw Claws", 
        "fas fa-peace" => "Solid Peace", 
        "fas fa-pegasus" => "Solid Pegasus", 
        "fas fa-pen" => "Solid Pen", 
        "fas fa-pen-alt" => "Solid Pen Alt", 
        "fas fa-pen-fancy" => "Solid Pen Fancy", 
        "fas fa-pen-nib" => "Solid Pen Nib", 
        "fas fa-pen-square" => "Solid Pen Square", 
        "fas fa-pencil" => "Solid Pencil", 
        "fas fa-pencil-alt" => "Solid Pencil Alt", 
        "fas fa-pencil-paintbrush" => "Solid Pencil Paintbrush", 
        "fas fa-pencil-ruler" => "Solid Pencil Ruler", 
        "fas fa-pennant" => "Solid Pennant", 
        "fas fa-people-carry" => "Solid People Carry", 
        "fas fa-pepper-hot" => "Solid Pepper Hot", 
        "fas fa-percent" => "Solid Percent", 
        "fas fa-percentage" => "Solid Percentage", 
        "fas fa-person-booth" => "Solid Person Booth", 
        "fas fa-person-carry" => "Solid Person Carry", 
        "fas fa-person-dolly" => "Solid Person Dolly", 
        "fas fa-person-dolly-empty" => "Solid Person Dolly Empty", 
        "fas fa-person-sign" => "Solid Person Sign", 
        "fas fa-phone" => "Solid Phone", 
        "fas fa-phone-office" => "Solid Phone Office", 
        "fas fa-phone-plus" => "Solid Phone Plus", 
        "fas fa-phone-slash" => "Solid Phone Slash", 
        "fas fa-phone-square" => "Solid Phone Square", 
        "fas fa-phone-volume" => "Solid Phone Volume", 
        "fas fa-pi" => "Solid Pi", 
        "fas fa-pie" => "Solid Pie", 
        "fas fa-pig" => "Solid Pig", 
        "fas fa-piggy-bank" => "Solid Piggy Bank", 
        "fas fa-pills" => "Solid Pills", 
        "fas fa-pizza" => "Solid Pizza", 
        "fas fa-pizza-slice" => "Solid Pizza Slice", 
        "fas fa-place-of-worship" => "Solid Place Of Worship", 
        "fas fa-plane" => "Solid Plane", 
        "fas fa-plane-alt" => "Solid Plane Alt", 
        "fas fa-plane-arrival" => "Solid Plane Arrival", 
        "fas fa-plane-departure" => "Solid Plane Departure", 
        "fas fa-play" => "Solid Play", 
        "fas fa-play-circle" => "Solid Play Circle", 
        "fas fa-plug" => "Solid Plug", 
        "fas fa-plus" => "Solid Plus", 
        "fas fa-plus-circle" => "Solid Plus Circle", 
        "fas fa-plus-hexagon" => "Solid Plus Hexagon", 
        "fas fa-plus-octagon" => "Solid Plus Octagon", 
        "fas fa-plus-square" => "Solid Plus Square", 
        "fas fa-podcast" => "Solid Podcast", 
        "fas fa-podium" => "Solid Podium", 
        "fas fa-podium-star" => "Solid Podium Star", 
        "fas fa-poll" => "Solid Poll", 
        "fas fa-poll-h" => "Solid Poll H", 
        "fas fa-poll-people" => "Solid Poll People", 
        "fas fa-poo" => "Solid Poo", 
        "fas fa-poo-storm" => "Solid Poo Storm", 
        "fas fa-poop" => "Solid Poop", 
        "fas fa-popcorn" => "Solid Popcorn", 
        "fas fa-portrait" => "Solid Portrait", 
        "fas fa-pound-sign" => "Solid Pound Sign", 
        "fas fa-power-off" => "Solid Power Off", 
        "fas fa-pray" => "Solid Pray", 
        "fas fa-praying-hands" => "Solid Praying Hands", 
        "fas fa-prescription" => "Solid Prescription", 
        "fas fa-prescription-bottle" => "Solid Prescription Bottle", 
        "fas fa-prescription-bottle-alt" => "Solid Prescription Bottle Alt", 
        "fas fa-presentation" => "Solid Presentation", 
        "fas fa-print" => "Solid Print", 
        "fas fa-print-search" => "Solid Print Search", 
        "fas fa-print-slash" => "Solid Print Slash", 
        "fas fa-procedures" => "Solid Procedures", 
        "fas fa-project-diagram" => "Solid Project Diagram", 
        "fas fa-pumpkin" => "Solid Pumpkin", 
        "fas fa-puzzle-piece" => "Solid Puzzle Piece", 
        "fas fa-qrcode" => "Solid Qrcode", 
        "fas fa-question" => "Solid Question", 
        "fas fa-question-circle" => "Solid Question Circle", 
        "fas fa-question-square" => "Solid Question Square", 
        "fas fa-quidditch" => "Solid Quidditch", 
        "fas fa-quote-left" => "Solid Quote Left", 
        "fas fa-quote-right" => "Solid Quote Right", 
        "fas fa-quran" => "Solid Quran", 
        "fas fa-rabbit" => "Solid Rabbit", 
        "fas fa-rabbit-fast" => "Solid Rabbit Fast", 
        "fas fa-racquet" => "Solid Racquet", 
        "fas fa-radiation" => "Solid Radiation", 
        "fas fa-radiation-alt" => "Solid Radiation Alt", 
        "fas fa-rainbow" => "Solid Rainbow", 
        "fas fa-raindrops" => "Solid Raindrops", 
        "fas fa-ram" => "Solid Ram", 
        "fas fa-ramp-loading" => "Solid Ramp Loading", 
        "fas fa-random" => "Solid Random", 
        "fas fa-receipt" => "Solid Receipt", 
        "fas fa-rectangle-landscape" => "Solid Rectangle Landscape", 
        "fas fa-rectangle-portrait" => "Solid Rectangle Portrait", 
        "fas fa-rectangle-wide" => "Solid Rectangle Wide", 
        "fas fa-recycle" => "Solid Recycle", 
        "fas fa-redo" => "Solid Redo", 
        "fas fa-redo-alt" => "Solid Redo Alt", 
        "fas fa-registered" => "Solid Registered", 
        "fas fa-repeat" => "Solid Repeat", 
        "fas fa-repeat-1" => "Solid Repeat 1", 
        "fas fa-repeat-1-alt" => "Solid Repeat 1 Alt", 
        "fas fa-repeat-alt" => "Solid Repeat Alt", 
        "fas fa-reply" => "Solid Reply", 
        "fas fa-reply-all" => "Solid Reply All", 
        "fas fa-republican" => "Solid Republican", 
        "fas fa-restroom" => "Solid Restroom", 
        "fas fa-retweet" => "Solid Retweet", 
        "fas fa-retweet-alt" => "Solid Retweet Alt", 
        "fas fa-ribbon" => "Solid Ribbon", 
        "fas fa-ring" => "Solid Ring", 
        "fas fa-rings-wedding" => "Solid Rings Wedding", 
        "fas fa-road" => "Solid Road", 
        "fas fa-robot" => "Solid Robot", 
        "fas fa-rocket" => "Solid Rocket", 
        "fas fa-route" => "Solid Route", 
        "fas fa-route-highway" => "Solid Route Highway", 
        "fas fa-route-interstate" => "Solid Route Interstate", 
        "fas fa-rss" => "Solid Rss", 
        "fas fa-rss-square" => "Solid Rss Square", 
        "fas fa-ruble-sign" => "Solid Ruble Sign", 
        "fas fa-ruler" => "Solid Ruler", 
        "fas fa-ruler-combined" => "Solid Ruler Combined", 
        "fas fa-ruler-horizontal" => "Solid Ruler Horizontal", 
        "fas fa-ruler-triangle" => "Solid Ruler Triangle", 
        "fas fa-ruler-vertical" => "Solid Ruler Vertical", 
        "fas fa-running" => "Solid Running", 
        "fas fa-rupee-sign" => "Solid Rupee Sign", 
        "fas fa-rv" => "Solid Rv", 
        "fas fa-sack" => "Solid Sack", 
        "fas fa-sack-dollar" => "Solid Sack Dollar", 
        "fas fa-sad-cry" => "Solid Sad Cry", 
        "fas fa-sad-tear" => "Solid Sad Tear", 
        "fas fa-salad" => "Solid Salad", 
        "fas fa-sandwich" => "Solid Sandwich", 
        "fas fa-satellite" => "Solid Satellite", 
        "fas fa-satellite-dish" => "Solid Satellite Dish", 
        "fas fa-sausage" => "Solid Sausage", 
        "fas fa-save" => "Solid Save", 
        "fas fa-scalpel" => "Solid Scalpel", 
        "fas fa-scalpel-path" => "Solid Scalpel Path", 
        "fas fa-scanner" => "Solid Scanner", 
        "fas fa-scanner-keyboard" => "Solid Scanner Keyboard", 
        "fas fa-scanner-touchscreen" => "Solid Scanner Touchscreen", 
        "fas fa-scarecrow" => "Solid Scarecrow", 
        "fas fa-scarf" => "Solid Scarf", 
        "fas fa-school" => "Solid School", 
        "fas fa-screwdriver" => "Solid Screwdriver", 
        "fas fa-scroll" => "Solid Scroll", 
        "fas fa-scroll-old" => "Solid Scroll Old", 
        "fas fa-scrubber" => "Solid Scrubber", 
        "fas fa-scythe" => "Solid Scythe", 
        "fas fa-sd-card" => "Solid Sd Card", 
        "fas fa-search" => "Solid Search", 
        "fas fa-search-dollar" => "Solid Search Dollar", 
        "fas fa-search-location" => "Solid Search Location", 
        "fas fa-search-minus" => "Solid Search Minus", 
        "fas fa-search-plus" => "Solid Search Plus", 
        "fas fa-seedling" => "Solid Seedling", 
        "fas fa-server" => "Solid Server", 
        "fas fa-shapes" => "Solid Shapes", 
        "fas fa-share" => "Solid Share", 
        "fas fa-share-all" => "Solid Share All", 
        "fas fa-share-alt" => "Solid Share Alt", 
        "fas fa-share-alt-square" => "Solid Share Alt Square", 
        "fas fa-share-square" => "Solid Share Square", 
        "fas fa-sheep" => "Solid Sheep", 
        "fas fa-shekel-sign" => "Solid Shekel Sign", 
        "fas fa-shield" => "Solid Shield", 
        "fas fa-shield-alt" => "Solid Shield Alt", 
        "fas fa-shield-check" => "Solid Shield Check", 
        "fas fa-shield-cross" => "Solid Shield Cross", 
        "fas fa-ship" => "Solid Ship", 
        "fas fa-shipping-fast" => "Solid Shipping Fast", 
        "fas fa-shipping-timed" => "Solid Shipping Timed", 
        "fas fa-shish-kebab" => "Solid Shish Kebab", 
        "fas fa-shoe-prints" => "Solid Shoe Prints", 
        "fas fa-shopping-bag" => "Solid Shopping Bag", 
        "fas fa-shopping-basket" => "Solid Shopping Basket", 
        "fas fa-shopping-cart" => "Solid Shopping Cart", 
        "fas fa-shovel" => "Solid Shovel", 
        "fas fa-shovel-snow" => "Solid Shovel Snow", 
        "fas fa-shower" => "Solid Shower", 
        "fas fa-shredder" => "Solid Shredder", 
        "fas fa-shuttle-van" => "Solid Shuttle Van", 
        "fas fa-shuttlecock" => "Solid Shuttlecock", 
        "fas fa-sickle" => "Solid Sickle", 
        "fas fa-sigma" => "Solid Sigma", 
        "fas fa-sign" => "Solid Sign", 
        "fas fa-sign-in" => "Solid Sign In", 
        "fas fa-sign-in-alt" => "Solid Sign In Alt", 
        "fas fa-sign-language" => "Solid Sign Language", 
        "fas fa-sign-out" => "Solid Sign Out", 
        "fas fa-sign-out-alt" => "Solid Sign Out Alt", 
        "fas fa-signal" => "Solid Signal", 
        "fas fa-signal-1" => "Solid Signal 1", 
        "fas fa-signal-2" => "Solid Signal 2", 
        "fas fa-signal-3" => "Solid Signal 3", 
        "fas fa-signal-4" => "Solid Signal 4", 
        "fas fa-signal-alt" => "Solid Signal Alt", 
        "fas fa-signal-alt-1" => "Solid Signal Alt 1", 
        "fas fa-signal-alt-2" => "Solid Signal Alt 2", 
        "fas fa-signal-alt-3" => "Solid Signal Alt 3", 
        "fas fa-signal-alt-slash" => "Solid Signal Alt Slash", 
        "fas fa-signal-slash" => "Solid Signal Slash", 
        "fas fa-signature" => "Solid Signature", 
        "fas fa-sim-card" => "Solid Sim Card", 
        "fas fa-sitemap" => "Solid Sitemap", 
        "fas fa-skating" => "Solid Skating", 
        "fas fa-skeleton" => "Solid Skeleton", 
        "fas fa-ski-jump" => "Solid Ski Jump", 
        "fas fa-ski-lift" => "Solid Ski Lift", 
        "fas fa-skiing" => "Solid Skiing", 
        "fas fa-skiing-nordic" => "Solid Skiing Nordic", 
        "fas fa-skull" => "Solid Skull", 
        "fas fa-skull-crossbones" => "Solid Skull Crossbones", 
        "fas fa-slash" => "Solid Slash", 
        "fas fa-sledding" => "Solid Sledding", 
        "fas fa-sleigh" => "Solid Sleigh", 
        "fas fa-sliders-h" => "Solid Sliders H", 
        "fas fa-sliders-h-square" => "Solid Sliders H Square", 
        "fas fa-sliders-v" => "Solid Sliders V", 
        "fas fa-sliders-v-square" => "Solid Sliders V Square", 
        "fas fa-smile" => "Solid Smile", 
        "fas fa-smile-beam" => "Solid Smile Beam", 
        "fas fa-smile-plus" => "Solid Smile Plus", 
        "fas fa-smile-wink" => "Solid Smile Wink", 
        "fas fa-smog" => "Solid Smog", 
        "fas fa-smoke" => "Solid Smoke", 
        "fas fa-smoking" => "Solid Smoking", 
        "fas fa-smoking-ban" => "Solid Smoking Ban", 
        "fas fa-sms" => "Solid Sms", 
        "fas fa-snake" => "Solid Snake", 
        "fas fa-snow-blowing" => "Solid Snow Blowing", 
        "fas fa-snowboarding" => "Solid Snowboarding", 
        "fas fa-snowflake" => "Solid Snowflake", 
        "fas fa-snowflakes" => "Solid Snowflakes", 
        "fas fa-snowman" => "Solid Snowman", 
        "fas fa-snowmobile" => "Solid Snowmobile", 
        "fas fa-snowplow" => "Solid Snowplow", 
        "fas fa-socks" => "Solid Socks", 
        "fas fa-solar-panel" => "Solid Solar Panel", 
        "fas fa-sort" => "Solid Sort", 
        "fas fa-sort-alpha-down" => "Solid Sort Alpha Down", 
        "fas fa-sort-alpha-up" => "Solid Sort Alpha Up", 
        "fas fa-sort-amount-down" => "Solid Sort Amount Down", 
        "fas fa-sort-amount-up" => "Solid Sort Amount Up", 
        "fas fa-sort-down" => "Solid Sort Down", 
        "fas fa-sort-numeric-down" => "Solid Sort Numeric Down", 
        "fas fa-sort-numeric-up" => "Solid Sort Numeric Up", 
        "fas fa-sort-up" => "Solid Sort Up", 
        "fas fa-soup" => "Solid Soup", 
        "fas fa-spa" => "Solid Spa", 
        "fas fa-space-shuttle" => "Solid Space Shuttle", 
        "fas fa-spade" => "Solid Spade", 
        "fas fa-spider" => "Solid Spider", 
        "fas fa-spider-black-widow" => "Solid Spider Black Widow", 
        "fas fa-spider-web" => "Solid Spider Web", 
        "fas fa-spinner" => "Solid Spinner", 
        "fas fa-spinner-third" => "Solid Spinner Third", 
        "fas fa-splotch" => "Solid Splotch", 
        "fas fa-spray-can" => "Solid Spray Can", 
        "fas fa-square" => "Solid Square", 
        "fas fa-square-full" => "Solid Square Full", 
        "fas fa-square-root" => "Solid Square Root", 
        "fas fa-square-root-alt" => "Solid Square Root Alt", 
        "fas fa-squirrel" => "Solid Squirrel", 
        "fas fa-staff" => "Solid Staff", 
        "fas fa-stamp" => "Solid Stamp", 
        "fas fa-star" => "Solid Star", 
        "fas fa-star-and-crescent" => "Solid Star And Crescent", 
        "fas fa-star-christmas" => "Solid Star Christmas", 
        "fas fa-star-exclamation" => "Solid Star Exclamation", 
        "fas fa-star-half" => "Solid Star Half", 
        "fas fa-star-half-alt" => "Solid Star Half Alt", 
        "fas fa-star-of-david" => "Solid Star Of David", 
        "fas fa-star-of-life" => "Solid Star Of Life", 
        "fas fa-stars" => "Solid Stars", 
        "fas fa-steak" => "Solid Steak", 
        "fas fa-steering-wheel" => "Solid Steering Wheel", 
        "fas fa-step-backward" => "Solid Step Backward", 
        "fas fa-step-forward" => "Solid Step Forward", 
        "fas fa-stethoscope" => "Solid Stethoscope", 
        "fas fa-sticky-note" => "Solid Sticky Note", 
        "fas fa-stocking" => "Solid Stocking", 
        "fas fa-stomach" => "Solid Stomach", 
        "fas fa-stop" => "Solid Stop", 
        "fas fa-stop-circle" => "Solid Stop Circle", 
        "fas fa-stopwatch" => "Solid Stopwatch", 
        "fas fa-store" => "Solid Store", 
        "fas fa-store-alt" => "Solid Store Alt", 
        "fas fa-stream" => "Solid Stream", 
        "fas fa-street-view" => "Solid Street View", 
        "fas fa-stretcher" => "Solid Stretcher", 
        "fas fa-strikethrough" => "Solid Strikethrough", 
        "fas fa-stroopwafel" => "Solid Stroopwafel", 
        "fas fa-subscript" => "Solid Subscript", 
        "fas fa-subway" => "Solid Subway", 
        "fas fa-suitcase" => "Solid Suitcase", 
        "fas fa-suitcase-rolling" => "Solid Suitcase Rolling", 
        "fas fa-sun" => "Solid Sun", 
        "fas fa-sun-cloud" => "Solid Sun Cloud", 
        "fas fa-sun-dust" => "Solid Sun Dust", 
        "fas fa-sun-haze" => "Solid Sun Haze", 
        "fas fa-sunrise" => "Solid Sunrise", 
        "fas fa-sunset" => "Solid Sunset", 
        "fas fa-superscript" => "Solid Superscript", 
        "fas fa-surprise" => "Solid Surprise", 
        "fas fa-swatchbook" => "Solid Swatchbook", 
        "fas fa-swimmer" => "Solid Swimmer", 
        "fas fa-swimming-pool" => "Solid Swimming Pool", 
        "fas fa-sword" => "Solid Sword", 
        "fas fa-swords" => "Solid Swords", 
        "fas fa-synagogue" => "Solid Synagogue", 
        "fas fa-sync" => "Solid Sync", 
        "fas fa-sync-alt" => "Solid Sync Alt", 
        "fas fa-syringe" => "Solid Syringe", 
        "fas fa-table" => "Solid Table", 
        "fas fa-table-tennis" => "Solid Table Tennis", 
        "fas fa-tablet" => "Solid Tablet", 
        "fas fa-tablet-alt" => "Solid Tablet Alt", 
        "fas fa-tablet-android" => "Solid Tablet Android", 
        "fas fa-tablet-android-alt" => "Solid Tablet Android Alt", 
        "fas fa-tablet-rugged" => "Solid Tablet Rugged", 
        "fas fa-tablets" => "Solid Tablets", 
        "fas fa-tachometer" => "Solid Tachometer", 
        "fas fa-tachometer-alt" => "Solid Tachometer Alt", 
        "fas fa-tachometer-alt-average" => "Solid Tachometer Alt Average", 
        "fas fa-tachometer-alt-fast" => "Solid Tachometer Alt Fast", 
        "fas fa-tachometer-alt-fastest" => "Solid Tachometer Alt Fastest", 
        "fas fa-tachometer-alt-slow" => "Solid Tachometer Alt Slow", 
        "fas fa-tachometer-alt-slowest" => "Solid Tachometer Alt Slowest", 
        "fas fa-tachometer-average" => "Solid Tachometer Average", 
        "fas fa-tachometer-fast" => "Solid Tachometer Fast", 
        "fas fa-tachometer-fastest" => "Solid Tachometer Fastest", 
        "fas fa-tachometer-slow" => "Solid Tachometer Slow", 
        "fas fa-tachometer-slowest" => "Solid Tachometer Slowest", 
        "fas fa-taco" => "Solid Taco", 
        "fas fa-tag" => "Solid Tag", 
        "fas fa-tags" => "Solid Tags", 
        "fas fa-tally" => "Solid Tally", 
        "fas fa-tanakh" => "Solid Tanakh", 
        "fas fa-tape" => "Solid Tape", 
        "fas fa-tasks" => "Solid Tasks", 
        "fas fa-tasks-alt" => "Solid Tasks Alt", 
        "fas fa-taxi" => "Solid Taxi", 
        "fas fa-teeth" => "Solid Teeth", 
        "fas fa-teeth-open" => "Solid Teeth Open", 
        "fas fa-temperature-frigid" => "Solid Temperature Frigid", 
        "fas fa-temperature-high" => "Solid Temperature High", 
        "fas fa-temperature-hot" => "Solid Temperature Hot", 
        "fas fa-temperature-low" => "Solid Temperature Low", 
        "fas fa-tenge" => "Solid Tenge", 
        "fas fa-tennis-ball" => "Solid Tennis Ball", 
        "fas fa-terminal" => "Solid Terminal", 
        "fas fa-text-height" => "Solid Text Height", 
        "fas fa-text-width" => "Solid Text Width", 
        "fas fa-th" => "Solid Th", 
        "fas fa-th-large" => "Solid Th Large", 
        "fas fa-th-list" => "Solid Th List", 
        "fas fa-theater-masks" => "Solid Theater Masks", 
        "fas fa-thermometer" => "Solid Thermometer", 
        "fas fa-thermometer-empty" => "Solid Thermometer Empty", 
        "fas fa-thermometer-full" => "Solid Thermometer Full", 
        "fas fa-thermometer-half" => "Solid Thermometer Half", 
        "fas fa-thermometer-quarter" => "Solid Thermometer Quarter", 
        "fas fa-thermometer-three-quarters" => "Solid Thermometer Three Quarters", 
        "fas fa-theta" => "Solid Theta", 
        "fas fa-thumbs-down" => "Solid Thumbs Down", 
        "fas fa-thumbs-up" => "Solid Thumbs Up", 
        "fas fa-thumbtack" => "Solid Thumbtack", 
        "fas fa-thunderstorm" => "Solid Thunderstorm", 
        "fas fa-thunderstorm-moon" => "Solid Thunderstorm Moon", 
        "fas fa-thunderstorm-sun" => "Solid Thunderstorm Sun", 
        "fas fa-ticket" => "Solid Ticket", 
        "fas fa-ticket-alt" => "Solid Ticket Alt", 
        "fas fa-tilde" => "Solid Tilde", 
        "fas fa-times" => "Solid Times", 
        "fas fa-times-circle" => "Solid Times Circle", 
        "fas fa-times-hexagon" => "Solid Times Hexagon", 
        "fas fa-times-octagon" => "Solid Times Octagon", 
        "fas fa-times-square" => "Solid Times Square", 
        "fas fa-tint" => "Solid Tint", 
        "fas fa-tint-slash" => "Solid Tint Slash", 
        "fas fa-tire" => "Solid Tire", 
        "fas fa-tire-flat" => "Solid Tire Flat", 
        "fas fa-tire-pressure-warning" => "Solid Tire Pressure Warning", 
        "fas fa-tire-rugged" => "Solid Tire Rugged", 
        "fas fa-tired" => "Solid Tired", 
        "fas fa-toggle-off" => "Solid Toggle Off", 
        "fas fa-toggle-on" => "Solid Toggle On", 
        "fas fa-toilet" => "Solid Toilet", 
        "fas fa-toilet-paper" => "Solid Toilet Paper", 
        "fas fa-toilet-paper-alt" => "Solid Toilet Paper Alt", 
        "fas fa-tombstone" => "Solid Tombstone", 
        "fas fa-tombstone-alt" => "Solid Tombstone Alt", 
        "fas fa-toolbox" => "Solid Toolbox", 
        "fas fa-tools" => "Solid Tools", 
        "fas fa-tooth" => "Solid Tooth", 
        "fas fa-toothbrush" => "Solid Toothbrush", 
        "fas fa-torah" => "Solid Torah", 
        "fas fa-torii-gate" => "Solid Torii Gate", 
        "fas fa-tornado" => "Solid Tornado", 
        "fas fa-tractor" => "Solid Tractor", 
        "fas fa-trademark" => "Solid Trademark", 
        "fas fa-traffic-cone" => "Solid Traffic Cone", 
        "fas fa-traffic-light" => "Solid Traffic Light", 
        "fas fa-traffic-light-go" => "Solid Traffic Light Go", 
        "fas fa-traffic-light-slow" => "Solid Traffic Light Slow", 
        "fas fa-traffic-light-stop" => "Solid Traffic Light Stop", 
        "fas fa-train" => "Solid Train", 
        "fas fa-tram" => "Solid Tram", 
        "fas fa-transgender" => "Solid Transgender", 
        "fas fa-transgender-alt" => "Solid Transgender Alt", 
        "fas fa-trash" => "Solid Trash", 
        "fas fa-trash-alt" => "Solid Trash Alt", 
        "fas fa-trash-restore" => "Solid Trash Restore", 
        "fas fa-trash-restore-alt" => "Solid Trash Restore Alt", 
        "fas fa-treasure-chest" => "Solid Treasure Chest", 
        "fas fa-tree" => "Solid Tree", 
        "fas fa-tree-alt" => "Solid Tree Alt", 
        "fas fa-tree-christmas" => "Solid Tree Christmas", 
        "fas fa-tree-decorated" => "Solid Tree Decorated", 
        "fas fa-tree-large" => "Solid Tree Large", 
        "fas fa-tree-palm" => "Solid Tree Palm", 
        "fas fa-trees" => "Solid Trees", 
        "fas fa-triangle" => "Solid Triangle", 
        "fas fa-trophy" => "Solid Trophy", 
        "fas fa-trophy-alt" => "Solid Trophy Alt", 
        "fas fa-truck" => "Solid Truck", 
        "fas fa-truck-container" => "Solid Truck Container", 
        "fas fa-truck-couch" => "Solid Truck Couch", 
        "fas fa-truck-loading" => "Solid Truck Loading", 
        "fas fa-truck-monster" => "Solid Truck Monster", 
        "fas fa-truck-moving" => "Solid Truck Moving", 
        "fas fa-truck-pickup" => "Solid Truck Pickup", 
        "fas fa-truck-plow" => "Solid Truck Plow", 
        "fas fa-truck-ramp" => "Solid Truck Ramp", 
        "fas fa-tshirt" => "Solid Tshirt", 
        "fas fa-tty" => "Solid Tty", 
        "fas fa-turkey" => "Solid Turkey", 
        "fas fa-turtle" => "Solid Turtle", 
        "fas fa-tv" => "Solid Tv", 
        "fas fa-tv-retro" => "Solid Tv Retro", 
        "fas fa-umbrella" => "Solid Umbrella", 
        "fas fa-umbrella-beach" => "Solid Umbrella Beach", 
        "fas fa-underline" => "Solid Underline", 
        "fas fa-undo" => "Solid Undo", 
        "fas fa-undo-alt" => "Solid Undo Alt", 
        "fas fa-unicorn" => "Solid Unicorn", 
        "fas fa-union" => "Solid Union", 
        "fas fa-universal-access" => "Solid Universal Access", 
        "fas fa-university" => "Solid University", 
        "fas fa-unlink" => "Solid Unlink", 
        "fas fa-unlock" => "Solid Unlock", 
        "fas fa-unlock-alt" => "Solid Unlock Alt", 
        "fas fa-upload" => "Solid Upload", 
        "fas fa-usd-circle" => "Solid Usd Circle", 
        "fas fa-usd-square" => "Solid Usd Square", 
        "fas fa-user" => "Solid User", 
        "fas fa-user-alt" => "Solid User Alt", 
        "fas fa-user-alt-slash" => "Solid User Alt Slash", 
        "fas fa-user-astronaut" => "Solid User Astronaut", 
        "fas fa-user-chart" => "Solid User Chart", 
        "fas fa-user-check" => "Solid User Check", 
        "fas fa-user-circle" => "Solid User Circle", 
        "fas fa-user-clock" => "Solid User Clock", 
        "fas fa-user-cog" => "Solid User Cog", 
        "fas fa-user-crown" => "Solid User Crown", 
        "fas fa-user-edit" => "Solid User Edit", 
        "fas fa-user-friends" => "Solid User Friends", 
        "fas fa-user-graduate" => "Solid User Graduate", 
        "fas fa-user-hard-hat" => "Solid User Hard Hat", 
        "fas fa-user-headset" => "Solid User Headset", 
        "fas fa-user-injured" => "Solid User Injured", 
        "fas fa-user-lock" => "Solid User Lock", 
        "fas fa-user-md" => "Solid User Md", 
        "fas fa-user-md-chat" => "Solid User Md Chat", 
        "fas fa-user-minus" => "Solid User Minus", 
        "fas fa-user-ninja" => "Solid User Ninja", 
        "fas fa-user-nurse" => "Solid User Nurse", 
        "fas fa-user-plus" => "Solid User Plus", 
        "fas fa-user-secret" => "Solid User Secret", 
        "fas fa-user-shield" => "Solid User Shield", 
        "fas fa-user-slash" => "Solid User Slash", 
        "fas fa-user-tag" => "Solid User Tag", 
        "fas fa-user-tie" => "Solid User Tie", 
        "fas fa-user-times" => "Solid User Times", 
        "fas fa-users" => "Solid Users", 
        "fas fa-users-class" => "Solid Users Class", 
        "fas fa-users-cog" => "Solid Users Cog", 
        "fas fa-users-crown" => "Solid Users Crown", 
        "fas fa-users-medical" => "Solid Users Medical", 
        "fas fa-utensil-fork" => "Solid Utensil Fork", 
        "fas fa-utensil-knife" => "Solid Utensil Knife", 
        "fas fa-utensil-spoon" => "Solid Utensil Spoon", 
        "fas fa-utensils" => "Solid Utensils", 
        "fas fa-utensils-alt" => "Solid Utensils Alt", 
        "fas fa-value-absolute" => "Solid Value Absolute", 
        "fas fa-vector-square" => "Solid Vector Square", 
        "fas fa-venus" => "Solid Venus", 
        "fas fa-venus-double" => "Solid Venus Double", 
        "fas fa-venus-mars" => "Solid Venus Mars", 
        "fas fa-vial" => "Solid Vial", 
        "fas fa-vials" => "Solid Vials", 
        "fas fa-video" => "Solid Video", 
        "fas fa-video-plus" => "Solid Video Plus", 
        "fas fa-video-slash" => "Solid Video Slash", 
        "fas fa-vihara" => "Solid Vihara", 
        "fas fa-volcano" => "Solid Volcano", 
        "fas fa-volleyball-ball" => "Solid Volleyball Ball", 
        "fas fa-volume" => "Solid Volume", 
        "fas fa-volume-down" => "Solid Volume Down", 
        "fas fa-volume-mute" => "Solid Volume Mute", 
        "fas fa-volume-off" => "Solid Volume Off", 
        "fas fa-volume-slash" => "Solid Volume Slash", 
        "fas fa-volume-up" => "Solid Volume Up", 
        "fas fa-vote-nay" => "Solid Vote Nay", 
        "fas fa-vote-yea" => "Solid Vote Yea", 
        "fas fa-vr-cardboard" => "Solid Vr Cardboard", 
        "fas fa-walker" => "Solid Walker", 
        "fas fa-walking" => "Solid Walking", 
        "fas fa-wallet" => "Solid Wallet", 
        "fas fa-wand" => "Solid Wand", 
        "fas fa-wand-magic" => "Solid Wand Magic", 
        "fas fa-warehouse" => "Solid Warehouse", 
        "fas fa-warehouse-alt" => "Solid Warehouse Alt", 
        "fas fa-watch" => "Solid Watch", 
        "fas fa-watch-fitness" => "Solid Watch Fitness", 
        "fas fa-water" => "Solid Water", 
        "fas fa-water-lower" => "Solid Water Lower", 
        "fas fa-water-rise" => "Solid Water Rise", 
        "fas fa-wave-square" => "Solid Wave Square", 
        "fas fa-webcam" => "Solid Webcam", 
        "fas fa-webcam-slash" => "Solid Webcam Slash", 
        "fas fa-weight" => "Solid Weight", 
        "fas fa-weight-hanging" => "Solid Weight Hanging", 
        "fas fa-whale" => "Solid Whale", 
        "fas fa-wheat" => "Solid Wheat", 
        "fas fa-wheelchair" => "Solid Wheelchair", 
        "fas fa-whistle" => "Solid Whistle", 
        "fas fa-wifi" => "Solid Wifi", 
        "fas fa-wifi-1" => "Solid Wifi 1", 
        "fas fa-wifi-2" => "Solid Wifi 2", 
        "fas fa-wifi-slash" => "Solid Wifi Slash", 
        "fas fa-wind" => "Solid Wind", 
        "fas fa-wind-warning" => "Solid Wind Warning", 
        "fas fa-window" => "Solid Window", 
        "fas fa-window-alt" => "Solid Window Alt", 
        "fas fa-window-close" => "Solid Window Close", 
        "fas fa-window-maximize" => "Solid Window Maximize", 
        "fas fa-window-minimize" => "Solid Window Minimize", 
        "fas fa-window-restore" => "Solid Window Restore", 
        "fas fa-windsock" => "Solid Windsock", 
        "fas fa-wine-bottle" => "Solid Wine Bottle", 
        "fas fa-wine-glass" => "Solid Wine Glass", 
        "fas fa-wine-glass-alt" => "Solid Wine Glass Alt", 
        "fas fa-won-sign" => "Solid Won Sign", 
        "fas fa-wreath" => "Solid Wreath", 
        "fas fa-wrench" => "Solid Wrench", 
        "fas fa-x-ray" => "Solid X Ray", 
        "fas fa-yen-sign" => "Solid Yen Sign", 
        "fas fa-yin-yang" => "Solid Yin Yang",
        "far fa-abacus" => "Regular Abacus", 
        "far fa-acorn" => "Regular Acorn", 
        "far fa-ad" => "Regular Ad", 
        "far fa-address-book" => "Regular Address Book", 
        "far fa-address-card" => "Regular Address Card", 
        "far fa-adjust" => "Regular Adjust", 
        "far fa-air-freshener" => "Regular Air Freshener", 
        "far fa-alarm-clock" => "Regular Alarm Clock", 
        "far fa-alicorn" => "Regular Alicorn", 
        "far fa-align-center" => "Regular Align Center", 
        "far fa-align-justify" => "Regular Align Justify", 
        "far fa-align-left" => "Regular Align Left", 
        "far fa-align-right" => "Regular Align Right", 
        "far fa-allergies" => "Regular Allergies", 
        "far fa-ambulance" => "Regular Ambulance", 
        "far fa-american-sign-language-interpreting" => "Regular American Sign Language Interpreting", 
        "far fa-analytics" => "Regular Analytics", 
        "far fa-anchor" => "Regular Anchor", 
        "far fa-angel" => "Regular Angel", 
        "far fa-angle-double-down" => "Regular Angle Double Down", 
        "far fa-angle-double-left" => "Regular Angle Double Left", 
        "far fa-angle-double-right" => "Regular Angle Double Right", 
        "far fa-angle-double-up" => "Regular Angle Double Up", 
        "far fa-angle-down" => "Regular Angle Down", 
        "far fa-angle-left" => "Regular Angle Left", 
        "far fa-angle-right" => "Regular Angle Right", 
        "far fa-angle-up" => "Regular Angle Up", 
        "far fa-angry" => "Regular Angry", 
        "far fa-ankh" => "Regular Ankh", 
        "far fa-apple-alt" => "Regular Apple Alt", 
        "far fa-apple-crate" => "Regular Apple Crate", 
        "far fa-archive" => "Regular Archive", 
        "far fa-archway" => "Regular Archway", 
        "far fa-arrow-alt-circle-down" => "Regular Arrow Alt Circle Down", 
        "far fa-arrow-alt-circle-left" => "Regular Arrow Alt Circle Left", 
        "far fa-arrow-alt-circle-right" => "Regular Arrow Alt Circle Right", 
        "far fa-arrow-alt-circle-up" => "Regular Arrow Alt Circle Up", 
        "far fa-arrow-alt-down" => "Regular Arrow Alt Down", 
        "far fa-arrow-alt-from-bottom" => "Regular Arrow Alt From Bottom", 
        "far fa-arrow-alt-from-left" => "Regular Arrow Alt From Left", 
        "far fa-arrow-alt-from-right" => "Regular Arrow Alt From Right", 
        "far fa-arrow-alt-from-top" => "Regular Arrow Alt From Top", 
        "far fa-arrow-alt-left" => "Regular Arrow Alt Left", 
        "far fa-arrow-alt-right" => "Regular Arrow Alt Right", 
        "far fa-arrow-alt-square-down" => "Regular Arrow Alt Square Down", 
        "far fa-arrow-alt-square-left" => "Regular Arrow Alt Square Left", 
        "far fa-arrow-alt-square-right" => "Regular Arrow Alt Square Right", 
        "far fa-arrow-alt-square-up" => "Regular Arrow Alt Square Up", 
        "far fa-arrow-alt-to-bottom" => "Regular Arrow Alt To Bottom", 
        "far fa-arrow-alt-to-left" => "Regular Arrow Alt To Left", 
        "far fa-arrow-alt-to-right" => "Regular Arrow Alt To Right", 
        "far fa-arrow-alt-to-top" => "Regular Arrow Alt To Top", 
        "far fa-arrow-alt-up" => "Regular Arrow Alt Up", 
        "far fa-arrow-circle-down" => "Regular Arrow Circle Down", 
        "far fa-arrow-circle-left" => "Regular Arrow Circle Left", 
        "far fa-arrow-circle-right" => "Regular Arrow Circle Right", 
        "far fa-arrow-circle-up" => "Regular Arrow Circle Up", 
        "far fa-arrow-down" => "Regular Arrow Down", 
        "far fa-arrow-from-bottom" => "Regular Arrow From Bottom", 
        "far fa-arrow-from-left" => "Regular Arrow From Left", 
        "far fa-arrow-from-right" => "Regular Arrow From Right", 
        "far fa-arrow-from-top" => "Regular Arrow From Top", 
        "far fa-arrow-left" => "Regular Arrow Left", 
        "far fa-arrow-right" => "Regular Arrow Right", 
        "far fa-arrow-square-down" => "Regular Arrow Square Down", 
        "far fa-arrow-square-left" => "Regular Arrow Square Left", 
        "far fa-arrow-square-right" => "Regular Arrow Square Right", 
        "far fa-arrow-square-up" => "Regular Arrow Square Up", 
        "far fa-arrow-to-bottom" => "Regular Arrow To Bottom", 
        "far fa-arrow-to-left" => "Regular Arrow To Left", 
        "far fa-arrow-to-right" => "Regular Arrow To Right", 
        "far fa-arrow-to-top" => "Regular Arrow To Top", 
        "far fa-arrow-up" => "Regular Arrow Up", 
        "far fa-arrows" => "Regular Arrows", 
        "far fa-arrows-alt" => "Regular Arrows Alt", 
        "far fa-arrows-alt-h" => "Regular Arrows Alt H", 
        "far fa-arrows-alt-v" => "Regular Arrows Alt V", 
        "far fa-arrows-h" => "Regular Arrows H", 
        "far fa-arrows-v" => "Regular Arrows V", 
        "far fa-assistive-listening-systems" => "Regular Assistive Listening Systems", 
        "far fa-asterisk" => "Regular Asterisk", 
        "far fa-at" => "Regular At", 
        "far fa-atlas" => "Regular Atlas", 
        "far fa-atom" => "Regular Atom", 
        "far fa-atom-alt" => "Regular Atom Alt", 
        "far fa-audio-description" => "Regular Audio Description", 
        "far fa-award" => "Regular Award", 
        "far fa-axe" => "Regular Axe", 
        "far fa-axe-battle" => "Regular Axe Battle", 
        "far fa-baby" => "Regular Baby", 
        "far fa-baby-carriage" => "Regular Baby Carriage", 
        "far fa-backpack" => "Regular Backpack", 
        "far fa-backspace" => "Regular Backspace", 
        "far fa-backward" => "Regular Backward", 
        "far fa-bacon" => "Regular Bacon", 
        "far fa-badge" => "Regular Badge", 
        "far fa-badge-check" => "Regular Badge Check", 
        "far fa-badge-dollar" => "Regular Badge Dollar", 
        "far fa-badge-percent" => "Regular Badge Percent", 
        "far fa-badger-honey" => "Regular Badger Honey", 
        "far fa-balance-scale" => "Regular Balance Scale", 
        "far fa-balance-scale-left" => "Regular Balance Scale Left", 
        "far fa-balance-scale-right" => "Regular Balance Scale Right", 
        "far fa-ball-pile" => "Regular Ball Pile", 
        "far fa-ballot" => "Regular Ballot", 
        "far fa-ballot-check" => "Regular Ballot Check", 
        "far fa-ban" => "Regular Ban", 
        "far fa-band-aid" => "Regular Band Aid", 
        "far fa-barcode" => "Regular Barcode", 
        "far fa-barcode-alt" => "Regular Barcode Alt", 
        "far fa-barcode-read" => "Regular Barcode Read", 
        "far fa-barcode-scan" => "Regular Barcode Scan", 
        "far fa-bars" => "Regular Bars", 
        "far fa-baseball" => "Regular Baseball", 
        "far fa-baseball-ball" => "Regular Baseball Ball", 
        "far fa-basketball-ball" => "Regular Basketball Ball", 
        "far fa-basketball-hoop" => "Regular Basketball Hoop", 
        "far fa-bat" => "Regular Bat", 
        "far fa-bath" => "Regular Bath", 
        "far fa-battery-bolt" => "Regular Battery Bolt", 
        "far fa-battery-empty" => "Regular Battery Empty", 
        "far fa-battery-full" => "Regular Battery Full", 
        "far fa-battery-half" => "Regular Battery Half", 
        "far fa-battery-quarter" => "Regular Battery Quarter", 
        "far fa-battery-slash" => "Regular Battery Slash", 
        "far fa-battery-three-quarters" => "Regular Battery Three Quarters", 
        "far fa-bed" => "Regular Bed", 
        "far fa-beer" => "Regular Beer", 
        "far fa-bell" => "Regular Bell", 
        "far fa-bell-school" => "Regular Bell School", 
        "far fa-bell-school-slash" => "Regular Bell School Slash", 
        "far fa-bell-slash" => "Regular Bell Slash", 
        "far fa-bells" => "Regular Bells", 
        "far fa-bezier-curve" => "Regular Bezier Curve", 
        "far fa-bible" => "Regular Bible", 
        "far fa-bicycle" => "Regular Bicycle", 
        "far fa-binoculars" => "Regular Binoculars", 
        "far fa-biohazard" => "Regular Biohazard", 
        "far fa-birthday-cake" => "Regular Birthday Cake", 
        "far fa-blanket" => "Regular Blanket", 
        "far fa-blender" => "Regular Blender", 
        "far fa-blender-phone" => "Regular Blender Phone", 
        "far fa-blind" => "Regular Blind", 
        "far fa-blog" => "Regular Blog", 
        "far fa-bold" => "Regular Bold", 
        "far fa-bolt" => "Regular Bolt", 
        "far fa-bomb" => "Regular Bomb", 
        "far fa-bone" => "Regular Bone", 
        "far fa-bone-break" => "Regular Bone Break", 
        "far fa-bong" => "Regular Bong", 
        "far fa-book" => "Regular Book", 
        "far fa-book-alt" => "Regular Book Alt", 
        "far fa-book-dead" => "Regular Book Dead", 
        "far fa-book-heart" => "Regular Book Heart", 
        "far fa-book-medical" => "Regular Book Medical", 
        "far fa-book-open" => "Regular Book Open", 
        "far fa-book-reader" => "Regular Book Reader", 
        "far fa-book-spells" => "Regular Book Spells", 
        "far fa-book-user" => "Regular Book User", 
        "far fa-bookmark" => "Regular Bookmark", 
        "far fa-books" => "Regular Books", 
        "far fa-books-medical" => "Regular Books Medical", 
        "far fa-boot" => "Regular Boot", 
        "far fa-booth-curtain" => "Regular Booth Curtain", 
        "far fa-bow-arrow" => "Regular Bow Arrow", 
        "far fa-bowling-ball" => "Regular Bowling Ball", 
        "far fa-bowling-pins" => "Regular Bowling Pins", 
        "far fa-box" => "Regular Box", 
        "far fa-box-alt" => "Regular Box Alt", 
        "far fa-box-ballot" => "Regular Box Ballot", 
        "far fa-box-check" => "Regular Box Check", 
        "far fa-box-fragile" => "Regular Box Fragile", 
        "far fa-box-full" => "Regular Box Full", 
        "far fa-box-heart" => "Regular Box Heart", 
        "far fa-box-open" => "Regular Box Open", 
        "far fa-box-up" => "Regular Box Up", 
        "far fa-box-usd" => "Regular Box Usd", 
        "far fa-boxes" => "Regular Boxes", 
        "far fa-boxes-alt" => "Regular Boxes Alt", 
        "far fa-boxing-glove" => "Regular Boxing Glove", 
        "far fa-brackets" => "Regular Brackets", 
        "far fa-brackets-curly" => "Regular Brackets Curly", 
        "far fa-braille" => "Regular Braille", 
        "far fa-brain" => "Regular Brain", 
        "far fa-bread-loaf" => "Regular Bread Loaf", 
        "far fa-bread-slice" => "Regular Bread Slice", 
        "far fa-briefcase" => "Regular Briefcase", 
        "far fa-briefcase-medical" => "Regular Briefcase Medical", 
        "far fa-broadcast-tower" => "Regular Broadcast Tower", 
        "far fa-broom" => "Regular Broom", 
        "far fa-browser" => "Regular Browser", 
        "far fa-brush" => "Regular Brush", 
        "far fa-bug" => "Regular Bug", 
        "far fa-building" => "Regular Building", 
        "far fa-bullhorn" => "Regular Bullhorn", 
        "far fa-bullseye" => "Regular Bullseye", 
        "far fa-bullseye-arrow" => "Regular Bullseye Arrow", 
        "far fa-bullseye-pointer" => "Regular Bullseye Pointer", 
        "far fa-burn" => "Regular Burn", 
        "far fa-burrito" => "Regular Burrito", 
        "far fa-bus" => "Regular Bus", 
        "far fa-bus-alt" => "Regular Bus Alt", 
        "far fa-bus-school" => "Regular Bus School", 
        "far fa-business-time" => "Regular Business Time", 
        "far fa-cabinet-filing" => "Regular Cabinet Filing", 
        "far fa-calculator" => "Regular Calculator", 
        "far fa-calculator-alt" => "Regular Calculator Alt", 
        "far fa-calendar" => "Regular Calendar", 
        "far fa-calendar-alt" => "Regular Calendar Alt", 
        "far fa-calendar-check" => "Regular Calendar Check", 
        "far fa-calendar-day" => "Regular Calendar Day", 
        "far fa-calendar-edit" => "Regular Calendar Edit", 
        "far fa-calendar-exclamation" => "Regular Calendar Exclamation", 
        "far fa-calendar-minus" => "Regular Calendar Minus", 
        "far fa-calendar-plus" => "Regular Calendar Plus", 
        "far fa-calendar-star" => "Regular Calendar Star", 
        "far fa-calendar-times" => "Regular Calendar Times", 
        "far fa-calendar-week" => "Regular Calendar Week", 
        "far fa-camera" => "Regular Camera", 
        "far fa-camera-alt" => "Regular Camera Alt", 
        "far fa-camera-retro" => "Regular Camera Retro", 
        "far fa-campfire" => "Regular Campfire", 
        "far fa-campground" => "Regular Campground", 
        "far fa-candle-holder" => "Regular Candle Holder", 
        "far fa-candy-cane" => "Regular Candy Cane", 
        "far fa-candy-corn" => "Regular Candy Corn", 
        "far fa-cannabis" => "Regular Cannabis", 
        "far fa-capsules" => "Regular Capsules", 
        "far fa-car" => "Regular Car", 
        "far fa-car-alt" => "Regular Car Alt", 
        "far fa-car-battery" => "Regular Car Battery", 
        "far fa-car-bump" => "Regular Car Bump", 
        "far fa-car-crash" => "Regular Car Crash", 
        "far fa-car-garage" => "Regular Car Garage", 
        "far fa-car-mechanic" => "Regular Car Mechanic", 
        "far fa-car-side" => "Regular Car Side", 
        "far fa-car-tilt" => "Regular Car Tilt", 
        "far fa-car-wash" => "Regular Car Wash", 
        "far fa-caret-circle-down" => "Regular Caret Circle Down", 
        "far fa-caret-circle-left" => "Regular Caret Circle Left", 
        "far fa-caret-circle-right" => "Regular Caret Circle Right", 
        "far fa-caret-circle-up" => "Regular Caret Circle Up", 
        "far fa-caret-down" => "Regular Caret Down", 
        "far fa-caret-left" => "Regular Caret Left", 
        "far fa-caret-right" => "Regular Caret Right", 
        "far fa-caret-square-down" => "Regular Caret Square Down", 
        "far fa-caret-square-left" => "Regular Caret Square Left", 
        "far fa-caret-square-right" => "Regular Caret Square Right", 
        "far fa-caret-square-up" => "Regular Caret Square Up", 
        "far fa-caret-up" => "Regular Caret Up", 
        "far fa-carrot" => "Regular Carrot", 
        "far fa-cart-arrow-down" => "Regular Cart Arrow Down", 
        "far fa-cart-plus" => "Regular Cart Plus", 
        "far fa-cash-register" => "Regular Cash Register", 
        "far fa-cat" => "Regular Cat", 
        "far fa-cauldron" => "Regular Cauldron", 
        "far fa-certificate" => "Regular Certificate", 
        "far fa-chair" => "Regular Chair", 
        "far fa-chair-office" => "Regular Chair Office", 
        "far fa-chalkboard" => "Regular Chalkboard", 
        "far fa-chalkboard-teacher" => "Regular Chalkboard Teacher", 
        "far fa-charging-station" => "Regular Charging Station", 
        "far fa-chart-area" => "Regular Chart Area", 
        "far fa-chart-bar" => "Regular Chart Bar", 
        "far fa-chart-line" => "Regular Chart Line", 
        "far fa-chart-line-down" => "Regular Chart Line Down", 
        "far fa-chart-network" => "Regular Chart Network", 
        "far fa-chart-pie" => "Regular Chart Pie", 
        "far fa-chart-pie-alt" => "Regular Chart Pie Alt", 
        "far fa-chart-scatter" => "Regular Chart Scatter", 
        "far fa-check" => "Regular Check", 
        "far fa-check-circle" => "Regular Check Circle", 
        "far fa-check-double" => "Regular Check Double", 
        "far fa-check-square" => "Regular Check Square", 
        "far fa-cheese" => "Regular Cheese", 
        "far fa-cheese-swiss" => "Regular Cheese Swiss", 
        "far fa-cheeseburger" => "Regular Cheeseburger", 
        "far fa-chess" => "Regular Chess", 
        "far fa-chess-bishop" => "Regular Chess Bishop", 
        "far fa-chess-bishop-alt" => "Regular Chess Bishop Alt", 
        "far fa-chess-board" => "Regular Chess Board", 
        "far fa-chess-clock" => "Regular Chess Clock", 
        "far fa-chess-clock-alt" => "Regular Chess Clock Alt", 
        "far fa-chess-king" => "Regular Chess King", 
        "far fa-chess-king-alt" => "Regular Chess King Alt", 
        "far fa-chess-knight" => "Regular Chess Knight", 
        "far fa-chess-knight-alt" => "Regular Chess Knight Alt", 
        "far fa-chess-pawn" => "Regular Chess Pawn", 
        "far fa-chess-pawn-alt" => "Regular Chess Pawn Alt", 
        "far fa-chess-queen" => "Regular Chess Queen", 
        "far fa-chess-queen-alt" => "Regular Chess Queen Alt", 
        "far fa-chess-rook" => "Regular Chess Rook", 
        "far fa-chess-rook-alt" => "Regular Chess Rook Alt", 
        "far fa-chevron-circle-down" => "Regular Chevron Circle Down", 
        "far fa-chevron-circle-left" => "Regular Chevron Circle Left", 
        "far fa-chevron-circle-right" => "Regular Chevron Circle Right", 
        "far fa-chevron-circle-up" => "Regular Chevron Circle Up", 
        "far fa-chevron-double-down" => "Regular Chevron Double Down", 
        "far fa-chevron-double-left" => "Regular Chevron Double Left", 
        "far fa-chevron-double-right" => "Regular Chevron Double Right", 
        "far fa-chevron-double-up" => "Regular Chevron Double Up", 
        "far fa-chevron-down" => "Regular Chevron Down", 
        "far fa-chevron-left" => "Regular Chevron Left", 
        "far fa-chevron-right" => "Regular Chevron Right", 
        "far fa-chevron-square-down" => "Regular Chevron Square Down", 
        "far fa-chevron-square-left" => "Regular Chevron Square Left", 
        "far fa-chevron-square-right" => "Regular Chevron Square Right", 
        "far fa-chevron-square-up" => "Regular Chevron Square Up", 
        "far fa-chevron-up" => "Regular Chevron Up", 
        "far fa-child" => "Regular Child", 
        "far fa-chimney" => "Regular Chimney", 
        "far fa-church" => "Regular Church", 
        "far fa-circle" => "Regular Circle", 
        "far fa-circle-notch" => "Regular Circle Notch", 
        "far fa-city" => "Regular City", 
        "far fa-claw-marks" => "Regular Claw Marks", 
        "far fa-clinic-medical" => "Regular Clinic Medical", 
        "far fa-clipboard" => "Regular Clipboard", 
        "far fa-clipboard-check" => "Regular Clipboard Check", 
        "far fa-clipboard-list" => "Regular Clipboard List", 
        "far fa-clipboard-list-check" => "Regular Clipboard List Check", 
        "far fa-clipboard-prescription" => "Regular Clipboard Prescription", 
        "far fa-clipboard-user" => "Regular Clipboard User", 
        "far fa-clock" => "Regular Clock", 
        "far fa-clone" => "Regular Clone", 
        "far fa-closed-captioning" => "Regular Closed Captioning", 
        "far fa-cloud" => "Regular Cloud", 
        "far fa-cloud-download" => "Regular Cloud Download", 
        "far fa-cloud-download-alt" => "Regular Cloud Download Alt", 
        "far fa-cloud-drizzle" => "Regular Cloud Drizzle", 
        "far fa-cloud-hail" => "Regular Cloud Hail", 
        "far fa-cloud-hail-mixed" => "Regular Cloud Hail Mixed", 
        "far fa-cloud-meatball" => "Regular Cloud Meatball", 
        "far fa-cloud-moon" => "Regular Cloud Moon", 
        "far fa-cloud-moon-rain" => "Regular Cloud Moon Rain", 
        "far fa-cloud-rain" => "Regular Cloud Rain", 
        "far fa-cloud-rainbow" => "Regular Cloud Rainbow", 
        "far fa-cloud-showers" => "Regular Cloud Showers", 
        "far fa-cloud-showers-heavy" => "Regular Cloud Showers Heavy", 
        "far fa-cloud-sleet" => "Regular Cloud Sleet", 
        "far fa-cloud-snow" => "Regular Cloud Snow", 
        "far fa-cloud-sun" => "Regular Cloud Sun", 
        "far fa-cloud-sun-rain" => "Regular Cloud Sun Rain", 
        "far fa-cloud-upload" => "Regular Cloud Upload", 
        "far fa-cloud-upload-alt" => "Regular Cloud Upload Alt", 
        "far fa-clouds" => "Regular Clouds", 
        "far fa-clouds-moon" => "Regular Clouds Moon", 
        "far fa-clouds-sun" => "Regular Clouds Sun", 
        "far fa-club" => "Regular Club", 
        "far fa-cocktail" => "Regular Cocktail", 
        "far fa-code" => "Regular Code", 
        "far fa-code-branch" => "Regular Code Branch", 
        "far fa-code-commit" => "Regular Code Commit", 
        "far fa-code-merge" => "Regular Code Merge", 
        "far fa-coffee" => "Regular Coffee", 
        "far fa-coffee-togo" => "Regular Coffee Togo", 
        "far fa-coffin" => "Regular Coffin", 
        "far fa-cog" => "Regular Cog", 
        "far fa-cogs" => "Regular Cogs", 
        "far fa-coins" => "Regular Coins", 
        "far fa-columns" => "Regular Columns", 
        "far fa-comment" => "Regular Comment", 
        "far fa-comment-alt" => "Regular Comment Alt", 
        "far fa-comment-alt-check" => "Regular Comment Alt Check", 
        "far fa-comment-alt-dollar" => "Regular Comment Alt Dollar", 
        "far fa-comment-alt-dots" => "Regular Comment Alt Dots", 
        "far fa-comment-alt-edit" => "Regular Comment Alt Edit", 
        "far fa-comment-alt-exclamation" => "Regular Comment Alt Exclamation", 
        "far fa-comment-alt-lines" => "Regular Comment Alt Lines", 
        "far fa-comment-alt-medical" => "Regular Comment Alt Medical", 
        "far fa-comment-alt-minus" => "Regular Comment Alt Minus", 
        "far fa-comment-alt-plus" => "Regular Comment Alt Plus", 
        "far fa-comment-alt-slash" => "Regular Comment Alt Slash", 
        "far fa-comment-alt-smile" => "Regular Comment Alt Smile", 
        "far fa-comment-alt-times" => "Regular Comment Alt Times", 
        "far fa-comment-check" => "Regular Comment Check", 
        "far fa-comment-dollar" => "Regular Comment Dollar", 
        "far fa-comment-dots" => "Regular Comment Dots", 
        "far fa-comment-edit" => "Regular Comment Edit", 
        "far fa-comment-exclamation" => "Regular Comment Exclamation", 
        "far fa-comment-lines" => "Regular Comment Lines", 
        "far fa-comment-medical" => "Regular Comment Medical", 
        "far fa-comment-minus" => "Regular Comment Minus", 
        "far fa-comment-plus" => "Regular Comment Plus", 
        "far fa-comment-slash" => "Regular Comment Slash", 
        "far fa-comment-smile" => "Regular Comment Smile", 
        "far fa-comment-times" => "Regular Comment Times", 
        "far fa-comments" => "Regular Comments", 
        "far fa-comments-alt" => "Regular Comments Alt", 
        "far fa-comments-alt-dollar" => "Regular Comments Alt Dollar", 
        "far fa-comments-dollar" => "Regular Comments Dollar", 
        "far fa-compact-disc" => "Regular Compact Disc", 
        "far fa-compass" => "Regular Compass", 
        "far fa-compass-slash" => "Regular Compass Slash", 
        "far fa-compress" => "Regular Compress", 
        "far fa-compress-alt" => "Regular Compress Alt", 
        "far fa-compress-arrows-alt" => "Regular Compress Arrows Alt", 
        "far fa-compress-wide" => "Regular Compress Wide", 
        "far fa-concierge-bell" => "Regular Concierge Bell", 
        "far fa-container-storage" => "Regular Container Storage", 
        "far fa-conveyor-belt" => "Regular Conveyor Belt", 
        "far fa-conveyor-belt-alt" => "Regular Conveyor Belt Alt", 
        "far fa-cookie" => "Regular Cookie", 
        "far fa-cookie-bite" => "Regular Cookie Bite", 
        "far fa-copy" => "Regular Copy", 
        "far fa-copyright" => "Regular Copyright", 
        "far fa-corn" => "Regular Corn", 
        "far fa-couch" => "Regular Couch", 
        "far fa-cow" => "Regular Cow", 
        "far fa-credit-card" => "Regular Credit Card", 
        "far fa-credit-card-blank" => "Regular Credit Card Blank", 
        "far fa-credit-card-front" => "Regular Credit Card Front", 
        "far fa-cricket" => "Regular Cricket", 
        "far fa-croissant" => "Regular Croissant", 
        "far fa-crop" => "Regular Crop", 
        "far fa-crop-alt" => "Regular Crop Alt", 
        "far fa-cross" => "Regular Cross", 
        "far fa-crosshairs" => "Regular Crosshairs", 
        "far fa-crow" => "Regular Crow", 
        "far fa-crown" => "Regular Crown", 
        "far fa-crutch" => "Regular Crutch", 
        "far fa-crutches" => "Regular Crutches", 
        "far fa-cube" => "Regular Cube", 
        "far fa-cubes" => "Regular Cubes", 
        "far fa-curling" => "Regular Curling", 
        "far fa-cut" => "Regular Cut", 
        "far fa-dagger" => "Regular Dagger", 
        "far fa-database" => "Regular Database", 
        "far fa-deaf" => "Regular Deaf", 
        "far fa-debug" => "Regular Debug", 
        "far fa-deer" => "Regular Deer", 
        "far fa-deer-rudolph" => "Regular Deer Rudolph", 
        "far fa-democrat" => "Regular Democrat", 
        "far fa-desktop" => "Regular Desktop", 
        "far fa-desktop-alt" => "Regular Desktop Alt", 
        "far fa-dewpoint" => "Regular Dewpoint", 
        "far fa-dharmachakra" => "Regular Dharmachakra", 
        "far fa-diagnoses" => "Regular Diagnoses", 
        "far fa-diamond" => "Regular Diamond", 
        "far fa-dice" => "Regular Dice", 
        "far fa-dice-d10" => "Regular Dice D10", 
        "far fa-dice-d12" => "Regular Dice D12", 
        "far fa-dice-d20" => "Regular Dice D20", 
        "far fa-dice-d4" => "Regular Dice D4", 
        "far fa-dice-d6" => "Regular Dice D6", 
        "far fa-dice-d8" => "Regular Dice D8", 
        "far fa-dice-five" => "Regular Dice Five", 
        "far fa-dice-four" => "Regular Dice Four", 
        "far fa-dice-one" => "Regular Dice One", 
        "far fa-dice-six" => "Regular Dice Six", 
        "far fa-dice-three" => "Regular Dice Three", 
        "far fa-dice-two" => "Regular Dice Two", 
        "far fa-digital-tachograph" => "Regular Digital Tachograph", 
        "far fa-diploma" => "Regular Diploma", 
        "far fa-directions" => "Regular Directions", 
        "far fa-disease" => "Regular Disease", 
        "far fa-divide" => "Regular Divide", 
        "far fa-dizzy" => "Regular Dizzy", 
        "far fa-dna" => "Regular Dna", 
        "far fa-do-not-enter" => "Regular Do Not Enter", 
        "far fa-dog" => "Regular Dog", 
        "far fa-dog-leashed" => "Regular Dog Leashed", 
        "far fa-dollar-sign" => "Regular Dollar Sign", 
        "far fa-dolly" => "Regular Dolly", 
        "far fa-dolly-empty" => "Regular Dolly Empty", 
        "far fa-dolly-flatbed" => "Regular Dolly Flatbed", 
        "far fa-dolly-flatbed-alt" => "Regular Dolly Flatbed Alt", 
        "far fa-dolly-flatbed-empty" => "Regular Dolly Flatbed Empty", 
        "far fa-donate" => "Regular Donate", 
        "far fa-door-closed" => "Regular Door Closed", 
        "far fa-door-open" => "Regular Door Open", 
        "far fa-dot-circle" => "Regular Dot Circle", 
        "far fa-dove" => "Regular Dove", 
        "far fa-download" => "Regular Download", 
        "far fa-drafting-compass" => "Regular Drafting Compass", 
        "far fa-dragon" => "Regular Dragon", 
        "far fa-draw-circle" => "Regular Draw Circle", 
        "far fa-draw-polygon" => "Regular Draw Polygon", 
        "far fa-draw-square" => "Regular Draw Square", 
        "far fa-dreidel" => "Regular Dreidel", 
        "far fa-drum" => "Regular Drum", 
        "far fa-drum-steelpan" => "Regular Drum Steelpan", 
        "far fa-drumstick" => "Regular Drumstick", 
        "far fa-drumstick-bite" => "Regular Drumstick Bite", 
        "far fa-duck" => "Regular Duck", 
        "far fa-dumbbell" => "Regular Dumbbell", 
        "far fa-dumpster" => "Regular Dumpster", 
        "far fa-dumpster-fire" => "Regular Dumpster Fire", 
        "far fa-dungeon" => "Regular Dungeon", 
        "far fa-ear" => "Regular Ear", 
        "far fa-ear-muffs" => "Regular Ear Muffs", 
        "far fa-eclipse" => "Regular Eclipse", 
        "far fa-eclipse-alt" => "Regular Eclipse Alt", 
        "far fa-edit" => "Regular Edit", 
        "far fa-egg" => "Regular Egg", 
        "far fa-egg-fried" => "Regular Egg Fried", 
        "far fa-eject" => "Regular Eject", 
        "far fa-elephant" => "Regular Elephant", 
        "far fa-ellipsis-h" => "Regular Ellipsis H", 
        "far fa-ellipsis-h-alt" => "Regular Ellipsis H Alt", 
        "far fa-ellipsis-v" => "Regular Ellipsis V", 
        "far fa-ellipsis-v-alt" => "Regular Ellipsis V Alt", 
        "far fa-empty-set" => "Regular Empty Set", 
        "far fa-engine-warning" => "Regular Engine Warning", 
        "far fa-envelope" => "Regular Envelope", 
        "far fa-envelope-open" => "Regular Envelope Open", 
        "far fa-envelope-open-dollar" => "Regular Envelope Open Dollar", 
        "far fa-envelope-open-text" => "Regular Envelope Open Text", 
        "far fa-envelope-square" => "Regular Envelope Square", 
        "far fa-equals" => "Regular Equals", 
        "far fa-eraser" => "Regular Eraser", 
        "far fa-ethernet" => "Regular Ethernet", 
        "far fa-euro-sign" => "Regular Euro Sign", 
        "far fa-exchange" => "Regular Exchange", 
        "far fa-exchange-alt" => "Regular Exchange Alt", 
        "far fa-exclamation" => "Regular Exclamation", 
        "far fa-exclamation-circle" => "Regular Exclamation Circle", 
        "far fa-exclamation-square" => "Regular Exclamation Square", 
        "far fa-exclamation-triangle" => "Regular Exclamation Triangle", 
        "far fa-expand" => "Regular Expand", 
        "far fa-expand-alt" => "Regular Expand Alt", 
        "far fa-expand-arrows" => "Regular Expand Arrows", 
        "far fa-expand-arrows-alt" => "Regular Expand Arrows Alt", 
        "far fa-expand-wide" => "Regular Expand Wide", 
        "far fa-external-link" => "Regular External Link", 
        "far fa-external-link-alt" => "Regular External Link Alt", 
        "far fa-external-link-square" => "Regular External Link Square", 
        "far fa-external-link-square-alt" => "Regular External Link Square Alt", 
        "far fa-eye" => "Regular Eye", 
        "far fa-eye-dropper" => "Regular Eye Dropper", 
        "far fa-eye-evil" => "Regular Eye Evil", 
        "far fa-eye-slash" => "Regular Eye Slash", 
        "far fa-fast-backward" => "Regular Fast Backward", 
        "far fa-fast-forward" => "Regular Fast Forward", 
        "far fa-fax" => "Regular Fax", 
        "far fa-feather" => "Regular Feather", 
        "far fa-feather-alt" => "Regular Feather Alt", 
        "far fa-female" => "Regular Female", 
        "far fa-field-hockey" => "Regular Field Hockey", 
        "far fa-fighter-jet" => "Regular Fighter Jet", 
        "far fa-file" => "Regular File", 
        "far fa-file-alt" => "Regular File Alt", 
        "far fa-file-archive" => "Regular File Archive", 
        "far fa-file-audio" => "Regular File Audio", 
        "far fa-file-certificate" => "Regular File Certificate", 
        "far fa-file-chart-line" => "Regular File Chart Line", 
        "far fa-file-chart-pie" => "Regular File Chart Pie", 
        "far fa-file-check" => "Regular File Check", 
        "far fa-file-code" => "Regular File Code", 
        "far fa-file-contract" => "Regular File Contract", 
        "far fa-file-csv" => "Regular File Csv", 
        "far fa-file-download" => "Regular File Download", 
        "far fa-file-edit" => "Regular File Edit", 
        "far fa-file-excel" => "Regular File Excel", 
        "far fa-file-exclamation" => "Regular File Exclamation", 
        "far fa-file-export" => "Regular File Export", 
        "far fa-file-image" => "Regular File Image", 
        "far fa-file-import" => "Regular File Import", 
        "far fa-file-invoice" => "Regular File Invoice", 
        "far fa-file-invoice-dollar" => "Regular File Invoice Dollar", 
        "far fa-file-medical" => "Regular File Medical", 
        "far fa-file-medical-alt" => "Regular File Medical Alt", 
        "far fa-file-minus" => "Regular File Minus", 
        "far fa-file-pdf" => "Regular File Pdf", 
        "far fa-file-plus" => "Regular File Plus", 
        "far fa-file-powerpoint" => "Regular File Powerpoint", 
        "far fa-file-prescription" => "Regular File Prescription", 
        "far fa-file-signature" => "Regular File Signature", 
        "far fa-file-spreadsheet" => "Regular File Spreadsheet", 
        "far fa-file-times" => "Regular File Times", 
        "far fa-file-upload" => "Regular File Upload", 
        "far fa-file-user" => "Regular File User", 
        "far fa-file-video" => "Regular File Video", 
        "far fa-file-word" => "Regular File Word", 
        "far fa-files-medical" => "Regular Files Medical", 
        "far fa-fill" => "Regular Fill", 
        "far fa-fill-drip" => "Regular Fill Drip", 
        "far fa-film" => "Regular Film", 
        "far fa-film-alt" => "Regular Film Alt", 
        "far fa-filter" => "Regular Filter", 
        "far fa-fingerprint" => "Regular Fingerprint", 
        "far fa-fire" => "Regular Fire", 
        "far fa-fire-alt" => "Regular Fire Alt", 
        "far fa-fire-extinguisher" => "Regular Fire Extinguisher", 
        "far fa-fire-smoke" => "Regular Fire Smoke", 
        "far fa-fireplace" => "Regular Fireplace", 
        "far fa-first-aid" => "Regular First Aid", 
        "far fa-fish" => "Regular Fish", 
        "far fa-fish-cooked" => "Regular Fish Cooked", 
        "far fa-fist-raised" => "Regular Fist Raised", 
        "far fa-flag" => "Regular Flag", 
        "far fa-flag-alt" => "Regular Flag Alt", 
        "far fa-flag-checkered" => "Regular Flag Checkered", 
        "far fa-flag-usa" => "Regular Flag Usa", 
        "far fa-flame" => "Regular Flame", 
        "far fa-flask" => "Regular Flask", 
        "far fa-flask-poison" => "Regular Flask Poison", 
        "far fa-flask-potion" => "Regular Flask Potion", 
        "far fa-flower" => "Regular Flower", 
        "far fa-flower-daffodil" => "Regular Flower Daffodil", 
        "far fa-flower-tulip" => "Regular Flower Tulip", 
        "far fa-flushed" => "Regular Flushed", 
        "far fa-fog" => "Regular Fog", 
        "far fa-folder" => "Regular Folder", 
        "far fa-folder-minus" => "Regular Folder Minus", 
        "far fa-folder-open" => "Regular Folder Open", 
        "far fa-folder-plus" => "Regular Folder Plus", 
        "far fa-folder-times" => "Regular Folder Times", 
        "far fa-folder-tree" => "Regular Folder Tree", 
        "far fa-folders" => "Regular Folders", 
        "far fa-font" => "Regular Font", 
        "far fa-football-ball" => "Regular Football Ball", 
        "far fa-football-helmet" => "Regular Football Helmet", 
        "far fa-forklift" => "Regular Forklift", 
        "far fa-forward" => "Regular Forward", 
        "far fa-fragile" => "Regular Fragile", 
        "far fa-french-fries" => "Regular French Fries", 
        "far fa-frog" => "Regular Frog", 
        "far fa-frosty-head" => "Regular Frosty Head", 
        "far fa-frown" => "Regular Frown", 
        "far fa-frown-open" => "Regular Frown Open", 
        "far fa-function" => "Regular Function", 
        "far fa-funnel-dollar" => "Regular Funnel Dollar", 
        "far fa-futbol" => "Regular Futbol", 
        "far fa-gamepad" => "Regular Gamepad", 
        "far fa-gas-pump" => "Regular Gas Pump", 
        "far fa-gas-pump-slash" => "Regular Gas Pump Slash", 
        "far fa-gavel" => "Regular Gavel", 
        "far fa-gem" => "Regular Gem", 
        "far fa-genderless" => "Regular Genderless", 
        "far fa-ghost" => "Regular Ghost", 
        "far fa-gift" => "Regular Gift", 
        "far fa-gift-card" => "Regular Gift Card", 
        "far fa-gifts" => "Regular Gifts", 
        "far fa-gingerbread-man" => "Regular Gingerbread Man", 
        "far fa-glass" => "Regular Glass", 
        "far fa-glass-champagne" => "Regular Glass Champagne", 
        "far fa-glass-cheers" => "Regular Glass Cheers", 
        "far fa-glass-martini" => "Regular Glass Martini", 
        "far fa-glass-martini-alt" => "Regular Glass Martini Alt", 
        "far fa-glass-whiskey" => "Regular Glass Whiskey", 
        "far fa-glass-whiskey-rocks" => "Regular Glass Whiskey Rocks", 
        "far fa-glasses" => "Regular Glasses", 
        "far fa-glasses-alt" => "Regular Glasses Alt", 
        "far fa-globe" => "Regular Globe", 
        "far fa-globe-africa" => "Regular Globe Africa", 
        "far fa-globe-americas" => "Regular Globe Americas", 
        "far fa-globe-asia" => "Regular Globe Asia", 
        "far fa-globe-europe" => "Regular Globe Europe", 
        "far fa-globe-snow" => "Regular Globe Snow", 
        "far fa-globe-stand" => "Regular Globe Stand", 
        "far fa-golf-ball" => "Regular Golf Ball", 
        "far fa-golf-club" => "Regular Golf Club", 
        "far fa-gopuram" => "Regular Gopuram", 
        "far fa-graduation-cap" => "Regular Graduation Cap", 
        "far fa-greater-than" => "Regular Greater Than", 
        "far fa-greater-than-equal" => "Regular Greater Than Equal", 
        "far fa-grimace" => "Regular Grimace", 
        "far fa-grin" => "Regular Grin", 
        "far fa-grin-alt" => "Regular Grin Alt", 
        "far fa-grin-beam" => "Regular Grin Beam", 
        "far fa-grin-beam-sweat" => "Regular Grin Beam Sweat", 
        "far fa-grin-hearts" => "Regular Grin Hearts", 
        "far fa-grin-squint" => "Regular Grin Squint", 
        "far fa-grin-squint-tears" => "Regular Grin Squint Tears", 
        "far fa-grin-stars" => "Regular Grin Stars", 
        "far fa-grin-tears" => "Regular Grin Tears", 
        "far fa-grin-tongue" => "Regular Grin Tongue", 
        "far fa-grin-tongue-squint" => "Regular Grin Tongue Squint", 
        "far fa-grin-tongue-wink" => "Regular Grin Tongue Wink", 
        "far fa-grin-wink" => "Regular Grin Wink", 
        "far fa-grip-horizontal" => "Regular Grip Horizontal", 
        "far fa-grip-lines" => "Regular Grip Lines", 
        "far fa-grip-lines-vertical" => "Regular Grip Lines Vertical", 
        "far fa-grip-vertical" => "Regular Grip Vertical", 
        "far fa-guitar" => "Regular Guitar", 
        "far fa-h-square" => "Regular H Square", 
        "far fa-h1" => "Regular H1", 
        "far fa-h2" => "Regular H2", 
        "far fa-h3" => "Regular H3", 
        "far fa-hamburger" => "Regular Hamburger", 
        "far fa-hammer" => "Regular Hammer", 
        "far fa-hammer-war" => "Regular Hammer War", 
        "far fa-hamsa" => "Regular Hamsa", 
        "far fa-hand-heart" => "Regular Hand Heart", 
        "far fa-hand-holding" => "Regular Hand Holding", 
        "far fa-hand-holding-box" => "Regular Hand Holding Box", 
        "far fa-hand-holding-heart" => "Regular Hand Holding Heart", 
        "far fa-hand-holding-magic" => "Regular Hand Holding Magic", 
        "far fa-hand-holding-seedling" => "Regular Hand Holding Seedling", 
        "far fa-hand-holding-usd" => "Regular Hand Holding Usd", 
        "far fa-hand-holding-water" => "Regular Hand Holding Water", 
        "far fa-hand-lizard" => "Regular Hand Lizard", 
        "far fa-hand-middle-finger" => "Regular Hand Middle Finger", 
        "far fa-hand-paper" => "Regular Hand Paper", 
        "far fa-hand-peace" => "Regular Hand Peace", 
        "far fa-hand-point-down" => "Regular Hand Point Down", 
        "far fa-hand-point-left" => "Regular Hand Point Left", 
        "far fa-hand-point-right" => "Regular Hand Point Right", 
        "far fa-hand-point-up" => "Regular Hand Point Up", 
        "far fa-hand-pointer" => "Regular Hand Pointer", 
        "far fa-hand-receiving" => "Regular Hand Receiving", 
        "far fa-hand-rock" => "Regular Hand Rock", 
        "far fa-hand-scissors" => "Regular Hand Scissors", 
        "far fa-hand-spock" => "Regular Hand Spock", 
        "far fa-hands" => "Regular Hands", 
        "far fa-hands-heart" => "Regular Hands Heart", 
        "far fa-hands-helping" => "Regular Hands Helping", 
        "far fa-hands-usd" => "Regular Hands Usd", 
        "far fa-handshake" => "Regular Handshake", 
        "far fa-handshake-alt" => "Regular Handshake Alt", 
        "far fa-hanukiah" => "Regular Hanukiah", 
        "far fa-hard-hat" => "Regular Hard Hat", 
        "far fa-hashtag" => "Regular Hashtag", 
        "far fa-hat-santa" => "Regular Hat Santa", 
        "far fa-hat-winter" => "Regular Hat Winter", 
        "far fa-hat-witch" => "Regular Hat Witch", 
        "far fa-hat-wizard" => "Regular Hat Wizard", 
        "far fa-haykal" => "Regular Haykal", 
        "far fa-hdd" => "Regular Hdd", 
        "far fa-head-side" => "Regular Head Side", 
        "far fa-head-side-brain" => "Regular Head Side Brain", 
        "far fa-head-side-medical" => "Regular Head Side Medical", 
        "far fa-head-vr" => "Regular Head Vr", 
        "far fa-heading" => "Regular Heading", 
        "far fa-headphones" => "Regular Headphones", 
        "far fa-headphones-alt" => "Regular Headphones Alt", 
        "far fa-headset" => "Regular Headset", 
        "far fa-heart" => "Regular Heart", 
        "far fa-heart-broken" => "Regular Heart Broken", 
        "far fa-heart-circle" => "Regular Heart Circle", 
        "far fa-heart-rate" => "Regular Heart Rate", 
        "far fa-heart-square" => "Regular Heart Square", 
        "far fa-heartbeat" => "Regular Heartbeat", 
        "far fa-helicopter" => "Regular Helicopter", 
        "far fa-helmet-battle" => "Regular Helmet Battle", 
        "far fa-hexagon" => "Regular Hexagon", 
        "far fa-highlighter" => "Regular Highlighter", 
        "far fa-hiking" => "Regular Hiking", 
        "far fa-hippo" => "Regular Hippo", 
        "far fa-history" => "Regular History", 
        "far fa-hockey-mask" => "Regular Hockey Mask", 
        "far fa-hockey-puck" => "Regular Hockey Puck", 
        "far fa-hockey-sticks" => "Regular Hockey Sticks", 
        "far fa-holly-berry" => "Regular Holly Berry", 
        "far fa-home" => "Regular Home", 
        "far fa-home-alt" => "Regular Home Alt", 
        "far fa-home-heart" => "Regular Home Heart", 
        "far fa-home-lg" => "Regular Home Lg", 
        "far fa-home-lg-alt" => "Regular Home Lg Alt", 
        "far fa-hood-cloak" => "Regular Hood Cloak", 
        "far fa-horse" => "Regular Horse", 
        "far fa-horse-head" => "Regular Horse Head", 
        "far fa-hospital" => "Regular Hospital", 
        "far fa-hospital-alt" => "Regular Hospital Alt", 
        "far fa-hospital-symbol" => "Regular Hospital Symbol", 
        "far fa-hospital-user" => "Regular Hospital User", 
        "far fa-hospitals" => "Regular Hospitals", 
        "far fa-hot-tub" => "Regular Hot Tub", 
        "far fa-hotdog" => "Regular Hotdog", 
        "far fa-hotel" => "Regular Hotel", 
        "far fa-hourglass" => "Regular Hourglass", 
        "far fa-hourglass-end" => "Regular Hourglass End", 
        "far fa-hourglass-half" => "Regular Hourglass Half", 
        "far fa-hourglass-start" => "Regular Hourglass Start", 
        "far fa-house-damage" => "Regular House Damage", 
        "far fa-house-flood" => "Regular House Flood", 
        "far fa-hryvnia" => "Regular Hryvnia", 
        "far fa-humidity" => "Regular Humidity", 
        "far fa-hurricane" => "Regular Hurricane", 
        "far fa-i-cursor" => "Regular I Cursor", 
        "far fa-ice-cream" => "Regular Ice Cream", 
        "far fa-ice-skate" => "Regular Ice Skate", 
        "far fa-icicles" => "Regular Icicles", 
        "far fa-id-badge" => "Regular Id Badge", 
        "far fa-id-card" => "Regular Id Card", 
        "far fa-id-card-alt" => "Regular Id Card Alt", 
        "far fa-igloo" => "Regular Igloo", 
        "far fa-image" => "Regular Image", 
        "far fa-images" => "Regular Images", 
        "far fa-inbox" => "Regular Inbox", 
        "far fa-inbox-in" => "Regular Inbox In", 
        "far fa-inbox-out" => "Regular Inbox Out", 
        "far fa-indent" => "Regular Indent", 
        "far fa-industry" => "Regular Industry", 
        "far fa-industry-alt" => "Regular Industry Alt", 
        "far fa-infinity" => "Regular Infinity", 
        "far fa-info" => "Regular Info", 
        "far fa-info-circle" => "Regular Info Circle", 
        "far fa-info-square" => "Regular Info Square", 
        "far fa-inhaler" => "Regular Inhaler", 
        "far fa-integral" => "Regular Integral", 
        "far fa-intersection" => "Regular Intersection", 
        "far fa-inventory" => "Regular Inventory", 
        "far fa-island-tropical" => "Regular Island Tropical", 
        "far fa-italic" => "Regular Italic", 
        "far fa-jack-o-lantern" => "Regular Jack O Lantern", 
        "far fa-jedi" => "Regular Jedi", 
        "far fa-joint" => "Regular Joint", 
        "far fa-journal-whills" => "Regular Journal Whills", 
        "far fa-kaaba" => "Regular Kaaba", 
        "far fa-key" => "Regular Key", 
        "far fa-key-skeleton" => "Regular Key Skeleton", 
        "far fa-keyboard" => "Regular Keyboard", 
        "far fa-keynote" => "Regular Keynote", 
        "far fa-khanda" => "Regular Khanda", 
        "far fa-kidneys" => "Regular Kidneys", 
        "far fa-kiss" => "Regular Kiss", 
        "far fa-kiss-beam" => "Regular Kiss Beam", 
        "far fa-kiss-wink-heart" => "Regular Kiss Wink Heart", 
        "far fa-kite" => "Regular Kite", 
        "far fa-kiwi-bird" => "Regular Kiwi Bird", 
        "far fa-knife-kitchen" => "Regular Knife Kitchen", 
        "far fa-lambda" => "Regular Lambda", 
        "far fa-lamp" => "Regular Lamp", 
        "far fa-landmark" => "Regular Landmark", 
        "far fa-landmark-alt" => "Regular Landmark Alt", 
        "far fa-language" => "Regular Language", 
        "far fa-laptop" => "Regular Laptop", 
        "far fa-laptop-code" => "Regular Laptop Code", 
        "far fa-laptop-medical" => "Regular Laptop Medical", 
        "far fa-laugh" => "Regular Laugh", 
        "far fa-laugh-beam" => "Regular Laugh Beam", 
        "far fa-laugh-squint" => "Regular Laugh Squint", 
        "far fa-laugh-wink" => "Regular Laugh Wink", 
        "far fa-layer-group" => "Regular Layer Group", 
        "far fa-layer-minus" => "Regular Layer Minus", 
        "far fa-layer-plus" => "Regular Layer Plus", 
        "far fa-leaf" => "Regular Leaf", 
        "far fa-leaf-heart" => "Regular Leaf Heart", 
        "far fa-leaf-maple" => "Regular Leaf Maple", 
        "far fa-leaf-oak" => "Regular Leaf Oak", 
        "far fa-lemon" => "Regular Lemon", 
        "far fa-less-than" => "Regular Less Than", 
        "far fa-less-than-equal" => "Regular Less Than Equal", 
        "far fa-level-down" => "Regular Level Down", 
        "far fa-level-down-alt" => "Regular Level Down Alt", 
        "far fa-level-up" => "Regular Level Up", 
        "far fa-level-up-alt" => "Regular Level Up Alt", 
        "far fa-life-ring" => "Regular Life Ring", 
        "far fa-lightbulb" => "Regular Lightbulb", 
        "far fa-lightbulb-dollar" => "Regular Lightbulb Dollar", 
        "far fa-lightbulb-exclamation" => "Regular Lightbulb Exclamation", 
        "far fa-lightbulb-on" => "Regular Lightbulb On", 
        "far fa-lightbulb-slash" => "Regular Lightbulb Slash", 
        "far fa-lights-holiday" => "Regular Lights Holiday", 
        "far fa-link" => "Regular Link", 
        "far fa-lips" => "Regular Lips", 
        "far fa-lira-sign" => "Regular Lira Sign", 
        "far fa-list" => "Regular List", 
        "far fa-list-alt" => "Regular List Alt", 
        "far fa-list-ol" => "Regular List Ol", 
        "far fa-list-ul" => "Regular List Ul", 
        "far fa-location" => "Regular Location", 
        "far fa-location-arrow" => "Regular Location Arrow", 
        "far fa-location-circle" => "Regular Location Circle", 
        "far fa-location-slash" => "Regular Location Slash", 
        "far fa-lock" => "Regular Lock", 
        "far fa-lock-alt" => "Regular Lock Alt", 
        "far fa-lock-open" => "Regular Lock Open", 
        "far fa-lock-open-alt" => "Regular Lock Open Alt", 
        "far fa-long-arrow-alt-down" => "Regular Long Arrow Alt Down", 
        "far fa-long-arrow-alt-left" => "Regular Long Arrow Alt Left", 
        "far fa-long-arrow-alt-right" => "Regular Long Arrow Alt Right", 
        "far fa-long-arrow-alt-up" => "Regular Long Arrow Alt Up", 
        "far fa-long-arrow-down" => "Regular Long Arrow Down", 
        "far fa-long-arrow-left" => "Regular Long Arrow Left", 
        "far fa-long-arrow-right" => "Regular Long Arrow Right", 
        "far fa-long-arrow-up" => "Regular Long Arrow Up", 
        "far fa-loveseat" => "Regular Loveseat", 
        "far fa-low-vision" => "Regular Low Vision", 
        "far fa-luchador" => "Regular Luchador", 
        "far fa-luggage-cart" => "Regular Luggage Cart", 
        "far fa-lungs" => "Regular Lungs", 
        "far fa-mace" => "Regular Mace", 
        "far fa-magic" => "Regular Magic", 
        "far fa-magnet" => "Regular Magnet", 
        "far fa-mail-bulk" => "Regular Mail Bulk", 
        "far fa-mailbox" => "Regular Mailbox", 
        "far fa-male" => "Regular Male", 
        "far fa-mandolin" => "Regular Mandolin", 
        "far fa-map" => "Regular Map", 
        "far fa-map-marked" => "Regular Map Marked", 
        "far fa-map-marked-alt" => "Regular Map Marked Alt", 
        "far fa-map-marker" => "Regular Map Marker", 
        "far fa-map-marker-alt" => "Regular Map Marker Alt", 
        "far fa-map-marker-alt-slash" => "Regular Map Marker Alt Slash", 
        "far fa-map-marker-check" => "Regular Map Marker Check", 
        "far fa-map-marker-edit" => "Regular Map Marker Edit", 
        "far fa-map-marker-exclamation" => "Regular Map Marker Exclamation", 
        "far fa-map-marker-minus" => "Regular Map Marker Minus", 
        "far fa-map-marker-plus" => "Regular Map Marker Plus", 
        "far fa-map-marker-question" => "Regular Map Marker Question", 
        "far fa-map-marker-slash" => "Regular Map Marker Slash", 
        "far fa-map-marker-smile" => "Regular Map Marker Smile", 
        "far fa-map-marker-times" => "Regular Map Marker Times", 
        "far fa-map-pin" => "Regular Map Pin", 
        "far fa-map-signs" => "Regular Map Signs", 
        "far fa-marker" => "Regular Marker", 
        "far fa-mars" => "Regular Mars", 
        "far fa-mars-double" => "Regular Mars Double", 
        "far fa-mars-stroke" => "Regular Mars Stroke", 
        "far fa-mars-stroke-h" => "Regular Mars Stroke H", 
        "far fa-mars-stroke-v" => "Regular Mars Stroke V", 
        "far fa-mask" => "Regular Mask", 
        "far fa-meat" => "Regular Meat", 
        "far fa-medal" => "Regular Medal", 
        "far fa-medkit" => "Regular Medkit", 
        "far fa-megaphone" => "Regular Megaphone", 
        "far fa-meh" => "Regular Meh", 
        "far fa-meh-blank" => "Regular Meh Blank", 
        "far fa-meh-rolling-eyes" => "Regular Meh Rolling Eyes", 
        "far fa-memory" => "Regular Memory", 
        "far fa-menorah" => "Regular Menorah", 
        "far fa-mercury" => "Regular Mercury", 
        "far fa-meteor" => "Regular Meteor", 
        "far fa-microchip" => "Regular Microchip", 
        "far fa-microphone" => "Regular Microphone", 
        "far fa-microphone-alt" => "Regular Microphone Alt", 
        "far fa-microphone-alt-slash" => "Regular Microphone Alt Slash", 
        "far fa-microphone-slash" => "Regular Microphone Slash", 
        "far fa-microscope" => "Regular Microscope", 
        "far fa-mind-share" => "Regular Mind Share", 
        "far fa-minus" => "Regular Minus", 
        "far fa-minus-circle" => "Regular Minus Circle", 
        "far fa-minus-hexagon" => "Regular Minus Hexagon", 
        "far fa-minus-octagon" => "Regular Minus Octagon", 
        "far fa-minus-square" => "Regular Minus Square", 
        "far fa-mistletoe" => "Regular Mistletoe", 
        "far fa-mitten" => "Regular Mitten", 
        "far fa-mobile" => "Regular Mobile", 
        "far fa-mobile-alt" => "Regular Mobile Alt", 
        "far fa-mobile-android" => "Regular Mobile Android", 
        "far fa-mobile-android-alt" => "Regular Mobile Android Alt", 
        "far fa-money-bill" => "Regular Money Bill", 
        "far fa-money-bill-alt" => "Regular Money Bill Alt", 
        "far fa-money-bill-wave" => "Regular Money Bill Wave", 
        "far fa-money-bill-wave-alt" => "Regular Money Bill Wave Alt", 
        "far fa-money-check" => "Regular Money Check", 
        "far fa-money-check-alt" => "Regular Money Check Alt", 
        "far fa-monitor-heart-rate" => "Regular Monitor Heart Rate", 
        "far fa-monkey" => "Regular Monkey", 
        "far fa-monument" => "Regular Monument", 
        "far fa-moon" => "Regular Moon", 
        "far fa-moon-cloud" => "Regular Moon Cloud", 
        "far fa-moon-stars" => "Regular Moon Stars", 
        "far fa-mortar-pestle" => "Regular Mortar Pestle", 
        "far fa-mosque" => "Regular Mosque", 
        "far fa-motorcycle" => "Regular Motorcycle", 
        "far fa-mountain" => "Regular Mountain", 
        "far fa-mountains" => "Regular Mountains", 
        "far fa-mouse-pointer" => "Regular Mouse Pointer", 
        "far fa-mug-hot" => "Regular Mug Hot", 
        "far fa-mug-marshmallows" => "Regular Mug Marshmallows", 
        "far fa-music" => "Regular Music", 
        "far fa-narwhal" => "Regular Narwhal", 
        "far fa-network-wired" => "Regular Network Wired", 
        "far fa-neuter" => "Regular Neuter", 
        "far fa-newspaper" => "Regular Newspaper", 
        "far fa-not-equal" => "Regular Not Equal", 
        "far fa-notes-medical" => "Regular Notes Medical", 
        "far fa-object-group" => "Regular Object Group", 
        "far fa-object-ungroup" => "Regular Object Ungroup", 
        "far fa-octagon" => "Regular Octagon", 
        "far fa-oil-can" => "Regular Oil Can", 
        "far fa-oil-temp" => "Regular Oil Temp", 
        "far fa-om" => "Regular Om", 
        "far fa-omega" => "Regular Omega", 
        "far fa-ornament" => "Regular Ornament", 
        "far fa-otter" => "Regular Otter", 
        "far fa-outdent" => "Regular Outdent", 
        "far fa-pager" => "Regular Pager", 
        "far fa-paint-brush" => "Regular Paint Brush", 
        "far fa-paint-brush-alt" => "Regular Paint Brush Alt", 
        "far fa-paint-roller" => "Regular Paint Roller", 
        "far fa-palette" => "Regular Palette", 
        "far fa-pallet" => "Regular Pallet", 
        "far fa-pallet-alt" => "Regular Pallet Alt", 
        "far fa-paper-plane" => "Regular Paper Plane", 
        "far fa-paperclip" => "Regular Paperclip", 
        "far fa-parachute-box" => "Regular Parachute Box", 
        "far fa-paragraph" => "Regular Paragraph", 
        "far fa-parking" => "Regular Parking", 
        "far fa-parking-circle" => "Regular Parking Circle", 
        "far fa-parking-circle-slash" => "Regular Parking Circle Slash", 
        "far fa-parking-slash" => "Regular Parking Slash", 
        "far fa-passport" => "Regular Passport", 
        "far fa-pastafarianism" => "Regular Pastafarianism", 
        "far fa-paste" => "Regular Paste", 
        "far fa-pause" => "Regular Pause", 
        "far fa-pause-circle" => "Regular Pause Circle", 
        "far fa-paw" => "Regular Paw", 
        "far fa-paw-alt" => "Regular Paw Alt", 
        "far fa-paw-claws" => "Regular Paw Claws", 
        "far fa-peace" => "Regular Peace", 
        "far fa-pegasus" => "Regular Pegasus", 
        "far fa-pen" => "Regular Pen", 
        "far fa-pen-alt" => "Regular Pen Alt", 
        "far fa-pen-fancy" => "Regular Pen Fancy", 
        "far fa-pen-nib" => "Regular Pen Nib", 
        "far fa-pen-square" => "Regular Pen Square", 
        "far fa-pencil" => "Regular Pencil", 
        "far fa-pencil-alt" => "Regular Pencil Alt", 
        "far fa-pencil-paintbrush" => "Regular Pencil Paintbrush", 
        "far fa-pencil-ruler" => "Regular Pencil Ruler", 
        "far fa-pennant" => "Regular Pennant", 
        "far fa-people-carry" => "Regular People Carry", 
        "far fa-pepper-hot" => "Regular Pepper Hot", 
        "far fa-percent" => "Regular Percent", 
        "far fa-percentage" => "Regular Percentage", 
        "far fa-person-booth" => "Regular Person Booth", 
        "far fa-person-carry" => "Regular Person Carry", 
        "far fa-person-dolly" => "Regular Person Dolly", 
        "far fa-person-dolly-empty" => "Regular Person Dolly Empty", 
        "far fa-person-sign" => "Regular Person Sign", 
        "far fa-phone" => "Regular Phone", 
        "far fa-phone-office" => "Regular Phone Office", 
        "far fa-phone-plus" => "Regular Phone Plus", 
        "far fa-phone-slash" => "Regular Phone Slash", 
        "far fa-phone-square" => "Regular Phone Square", 
        "far fa-phone-volume" => "Regular Phone Volume", 
        "far fa-pi" => "Regular Pi", 
        "far fa-pie" => "Regular Pie", 
        "far fa-pig" => "Regular Pig", 
        "far fa-piggy-bank" => "Regular Piggy Bank", 
        "far fa-pills" => "Regular Pills", 
        "far fa-pizza" => "Regular Pizza", 
        "far fa-pizza-slice" => "Regular Pizza Slice", 
        "far fa-place-of-worship" => "Regular Place Of Worship", 
        "far fa-plane" => "Regular Plane", 
        "far fa-plane-alt" => "Regular Plane Alt", 
        "far fa-plane-arrival" => "Regular Plane Arrival", 
        "far fa-plane-departure" => "Regular Plane Departure", 
        "far fa-play" => "Regular Play", 
        "far fa-play-circle" => "Regular Play Circle", 
        "far fa-plug" => "Regular Plug", 
        "far fa-plus" => "Regular Plus", 
        "far fa-plus-circle" => "Regular Plus Circle", 
        "far fa-plus-hexagon" => "Regular Plus Hexagon", 
        "far fa-plus-octagon" => "Regular Plus Octagon", 
        "far fa-plus-square" => "Regular Plus Square", 
        "far fa-podcast" => "Regular Podcast", 
        "far fa-podium" => "Regular Podium", 
        "far fa-podium-star" => "Regular Podium Star", 
        "far fa-poll" => "Regular Poll", 
        "far fa-poll-h" => "Regular Poll H", 
        "far fa-poll-people" => "Regular Poll People", 
        "far fa-poo" => "Regular Poo", 
        "far fa-poo-storm" => "Regular Poo Storm", 
        "far fa-poop" => "Regular Poop", 
        "far fa-popcorn" => "Regular Popcorn", 
        "far fa-portrait" => "Regular Portrait", 
        "far fa-pound-sign" => "Regular Pound Sign", 
        "far fa-power-off" => "Regular Power Off", 
        "far fa-pray" => "Regular Pray", 
        "far fa-praying-hands" => "Regular Praying Hands", 
        "far fa-prescription" => "Regular Prescription", 
        "far fa-prescription-bottle" => "Regular Prescription Bottle", 
        "far fa-prescription-bottle-alt" => "Regular Prescription Bottle Alt", 
        "far fa-presentation" => "Regular Presentation", 
        "far fa-print" => "Regular Print", 
        "far fa-print-search" => "Regular Print Search", 
        "far fa-print-slash" => "Regular Print Slash", 
        "far fa-procedures" => "Regular Procedures", 
        "far fa-project-diagram" => "Regular Project Diagram", 
        "far fa-pumpkin" => "Regular Pumpkin", 
        "far fa-puzzle-piece" => "Regular Puzzle Piece", 
        "far fa-qrcode" => "Regular Qrcode", 
        "far fa-question" => "Regular Question", 
        "far fa-question-circle" => "Regular Question Circle", 
        "far fa-question-square" => "Regular Question Square", 
        "far fa-quidditch" => "Regular Quidditch", 
        "far fa-quote-left" => "Regular Quote Left", 
        "far fa-quote-right" => "Regular Quote Right", 
        "far fa-quran" => "Regular Quran", 
        "far fa-rabbit" => "Regular Rabbit", 
        "far fa-rabbit-fast" => "Regular Rabbit Fast", 
        "far fa-racquet" => "Regular Racquet", 
        "far fa-radiation" => "Regular Radiation", 
        "far fa-radiation-alt" => "Regular Radiation Alt", 
        "far fa-rainbow" => "Regular Rainbow", 
        "far fa-raindrops" => "Regular Raindrops", 
        "far fa-ram" => "Regular Ram", 
        "far fa-ramp-loading" => "Regular Ramp Loading", 
        "far fa-random" => "Regular Random", 
        "far fa-receipt" => "Regular Receipt", 
        "far fa-rectangle-landscape" => "Regular Rectangle Landscape", 
        "far fa-rectangle-portrait" => "Regular Rectangle Portrait", 
        "far fa-rectangle-wide" => "Regular Rectangle Wide", 
        "far fa-recycle" => "Regular Recycle", 
        "far fa-redo" => "Regular Redo", 
        "far fa-redo-alt" => "Regular Redo Alt", 
        "far fa-registered" => "Regular Registered", 
        "far fa-repeat" => "Regular Repeat", 
        "far fa-repeat-1" => "Regular Repeat 1", 
        "far fa-repeat-1-alt" => "Regular Repeat 1 Alt", 
        "far fa-repeat-alt" => "Regular Repeat Alt", 
        "far fa-reply" => "Regular Reply", 
        "far fa-reply-all" => "Regular Reply All", 
        "far fa-republican" => "Regular Republican", 
        "far fa-restroom" => "Regular Restroom", 
        "far fa-retweet" => "Regular Retweet", 
        "far fa-retweet-alt" => "Regular Retweet Alt", 
        "far fa-ribbon" => "Regular Ribbon", 
        "far fa-ring" => "Regular Ring", 
        "far fa-rings-wedding" => "Regular Rings Wedding", 
        "far fa-road" => "Regular Road", 
        "far fa-robot" => "Regular Robot", 
        "far fa-rocket" => "Regular Rocket", 
        "far fa-route" => "Regular Route", 
        "far fa-route-highway" => "Regular Route Highway", 
        "far fa-route-interstate" => "Regular Route Interstate", 
        "far fa-rss" => "Regular Rss", 
        "far fa-rss-square" => "Regular Rss Square", 
        "far fa-ruble-sign" => "Regular Ruble Sign", 
        "far fa-ruler" => "Regular Ruler", 
        "far fa-ruler-combined" => "Regular Ruler Combined", 
        "far fa-ruler-horizontal" => "Regular Ruler Horizontal", 
        "far fa-ruler-triangle" => "Regular Ruler Triangle", 
        "far fa-ruler-vertical" => "Regular Ruler Vertical", 
        "far fa-running" => "Regular Running", 
        "far fa-rupee-sign" => "Regular Rupee Sign", 
        "far fa-rv" => "Regular Rv", 
        "far fa-sack" => "Regular Sack", 
        "far fa-sack-dollar" => "Regular Sack Dollar", 
        "far fa-sad-cry" => "Regular Sad Cry", 
        "far fa-sad-tear" => "Regular Sad Tear", 
        "far fa-salad" => "Regular Salad", 
        "far fa-sandwich" => "Regular Sandwich", 
        "far fa-satellite" => "Regular Satellite", 
        "far fa-satellite-dish" => "Regular Satellite Dish", 
        "far fa-sausage" => "Regular Sausage", 
        "far fa-save" => "Regular Save", 
        "far fa-scalpel" => "Regular Scalpel", 
        "far fa-scalpel-path" => "Regular Scalpel Path", 
        "far fa-scanner" => "Regular Scanner", 
        "far fa-scanner-keyboard" => "Regular Scanner Keyboard", 
        "far fa-scanner-touchscreen" => "Regular Scanner Touchscreen", 
        "far fa-scarecrow" => "Regular Scarecrow", 
        "far fa-scarf" => "Regular Scarf", 
        "far fa-school" => "Regular School", 
        "far fa-screwdriver" => "Regular Screwdriver", 
        "far fa-scroll" => "Regular Scroll", 
        "far fa-scroll-old" => "Regular Scroll Old", 
        "far fa-scrubber" => "Regular Scrubber", 
        "far fa-scythe" => "Regular Scythe", 
        "far fa-sd-card" => "Regular Sd Card", 
        "far fa-search" => "Regular Search", 
        "far fa-search-dollar" => "Regular Search Dollar", 
        "far fa-search-location" => "Regular Search Location", 
        "far fa-search-minus" => "Regular Search Minus", 
        "far fa-search-plus" => "Regular Search Plus", 
        "far fa-seedling" => "Regular Seedling", 
        "far fa-server" => "Regular Server", 
        "far fa-shapes" => "Regular Shapes", 
        "far fa-share" => "Regular Share", 
        "far fa-share-all" => "Regular Share All", 
        "far fa-share-alt" => "Regular Share Alt", 
        "far fa-share-alt-square" => "Regular Share Alt Square", 
        "far fa-share-square" => "Regular Share Square", 
        "far fa-sheep" => "Regular Sheep", 
        "far fa-shekel-sign" => "Regular Shekel Sign", 
        "far fa-shield" => "Regular Shield", 
        "far fa-shield-alt" => "Regular Shield Alt", 
        "far fa-shield-check" => "Regular Shield Check", 
        "far fa-shield-cross" => "Regular Shield Cross", 
        "far fa-ship" => "Regular Ship", 
        "far fa-shipping-fast" => "Regular Shipping Fast", 
        "far fa-shipping-timed" => "Regular Shipping Timed", 
        "far fa-shish-kebab" => "Regular Shish Kebab", 
        "far fa-shoe-prints" => "Regular Shoe Prints", 
        "far fa-shopping-bag" => "Regular Shopping Bag", 
        "far fa-shopping-basket" => "Regular Shopping Basket", 
        "far fa-shopping-cart" => "Regular Shopping Cart", 
        "far fa-shovel" => "Regular Shovel", 
        "far fa-shovel-snow" => "Regular Shovel Snow", 
        "far fa-shower" => "Regular Shower", 
        "far fa-shredder" => "Regular Shredder", 
        "far fa-shuttle-van" => "Regular Shuttle Van", 
        "far fa-shuttlecock" => "Regular Shuttlecock", 
        "far fa-sickle" => "Regular Sickle", 
        "far fa-sigma" => "Regular Sigma", 
        "far fa-sign" => "Regular Sign", 
        "far fa-sign-in" => "Regular Sign In", 
        "far fa-sign-in-alt" => "Regular Sign In Alt", 
        "far fa-sign-language" => "Regular Sign Language", 
        "far fa-sign-out" => "Regular Sign Out", 
        "far fa-sign-out-alt" => "Regular Sign Out Alt", 
        "far fa-signal" => "Regular Signal", 
        "far fa-signal-1" => "Regular Signal 1", 
        "far fa-signal-2" => "Regular Signal 2", 
        "far fa-signal-3" => "Regular Signal 3", 
        "far fa-signal-4" => "Regular Signal 4", 
        "far fa-signal-alt" => "Regular Signal Alt", 
        "far fa-signal-alt-1" => "Regular Signal Alt 1", 
        "far fa-signal-alt-2" => "Regular Signal Alt 2", 
        "far fa-signal-alt-3" => "Regular Signal Alt 3", 
        "far fa-signal-alt-slash" => "Regular Signal Alt Slash", 
        "far fa-signal-slash" => "Regular Signal Slash", 
        "far fa-signature" => "Regular Signature", 
        "far fa-sim-card" => "Regular Sim Card", 
        "far fa-sitemap" => "Regular Sitemap", 
        "far fa-skating" => "Regular Skating", 
        "far fa-skeleton" => "Regular Skeleton", 
        "far fa-ski-jump" => "Regular Ski Jump", 
        "far fa-ski-lift" => "Regular Ski Lift", 
        "far fa-skiing" => "Regular Skiing", 
        "far fa-skiing-nordic" => "Regular Skiing Nordic", 
        "far fa-skull" => "Regular Skull", 
        "far fa-skull-crossbones" => "Regular Skull Crossbones", 
        "far fa-slash" => "Regular Slash", 
        "far fa-sledding" => "Regular Sledding", 
        "far fa-sleigh" => "Regular Sleigh", 
        "far fa-sliders-h" => "Regular Sliders H", 
        "far fa-sliders-h-square" => "Regular Sliders H Square", 
        "far fa-sliders-v" => "Regular Sliders V", 
        "far fa-sliders-v-square" => "Regular Sliders V Square", 
        "far fa-smile" => "Regular Smile", 
        "far fa-smile-beam" => "Regular Smile Beam", 
        "far fa-smile-plus" => "Regular Smile Plus", 
        "far fa-smile-wink" => "Regular Smile Wink", 
        "far fa-smog" => "Regular Smog", 
        "far fa-smoke" => "Regular Smoke", 
        "far fa-smoking" => "Regular Smoking", 
        "far fa-smoking-ban" => "Regular Smoking Ban", 
        "far fa-sms" => "Regular Sms", 
        "far fa-snake" => "Regular Snake", 
        "far fa-snow-blowing" => "Regular Snow Blowing", 
        "far fa-snowboarding" => "Regular Snowboarding", 
        "far fa-snowflake" => "Regular Snowflake", 
        "far fa-snowflakes" => "Regular Snowflakes", 
        "far fa-snowman" => "Regular Snowman", 
        "far fa-snowmobile" => "Regular Snowmobile", 
        "far fa-snowplow" => "Regular Snowplow", 
        "far fa-socks" => "Regular Socks", 
        "far fa-solar-panel" => "Regular Solar Panel", 
        "far fa-sort" => "Regular Sort", 
        "far fa-sort-alpha-down" => "Regular Sort Alpha Down", 
        "far fa-sort-alpha-up" => "Regular Sort Alpha Up", 
        "far fa-sort-amount-down" => "Regular Sort Amount Down", 
        "far fa-sort-amount-up" => "Regular Sort Amount Up", 
        "far fa-sort-down" => "Regular Sort Down", 
        "far fa-sort-numeric-down" => "Regular Sort Numeric Down", 
        "far fa-sort-numeric-up" => "Regular Sort Numeric Up", 
        "far fa-sort-up" => "Regular Sort Up", 
        "far fa-soup" => "Regular Soup", 
        "far fa-spa" => "Regular Spa", 
        "far fa-space-shuttle" => "Regular Space Shuttle", 
        "far fa-spade" => "Regular Spade", 
        "far fa-spider" => "Regular Spider", 
        "far fa-spider-black-widow" => "Regular Spider Black Widow", 
        "far fa-spider-web" => "Regular Spider Web", 
        "far fa-spinner" => "Regular Spinner", 
        "far fa-spinner-third" => "Regular Spinner Third", 
        "far fa-splotch" => "Regular Splotch", 
        "far fa-spray-can" => "Regular Spray Can", 
        "far fa-square" => "Regular Square", 
        "far fa-square-full" => "Regular Square Full", 
        "far fa-square-root" => "Regular Square Root", 
        "far fa-square-root-alt" => "Regular Square Root Alt", 
        "far fa-squirrel" => "Regular Squirrel", 
        "far fa-staff" => "Regular Staff", 
        "far fa-stamp" => "Regular Stamp", 
        "far fa-star" => "Regular Star", 
        "far fa-star-and-crescent" => "Regular Star And Crescent", 
        "far fa-star-christmas" => "Regular Star Christmas", 
        "far fa-star-exclamation" => "Regular Star Exclamation", 
        "far fa-star-half" => "Regular Star Half", 
        "far fa-star-half-alt" => "Regular Star Half Alt", 
        "far fa-star-of-david" => "Regular Star Of David", 
        "far fa-star-of-life" => "Regular Star Of Life", 
        "far fa-stars" => "Regular Stars", 
        "far fa-steak" => "Regular Steak", 
        "far fa-steering-wheel" => "Regular Steering Wheel", 
        "far fa-step-backward" => "Regular Step Backward", 
        "far fa-step-forward" => "Regular Step Forward", 
        "far fa-stethoscope" => "Regular Stethoscope", 
        "far fa-sticky-note" => "Regular Sticky Note", 
        "far fa-stocking" => "Regular Stocking", 
        "far fa-stomach" => "Regular Stomach", 
        "far fa-stop" => "Regular Stop", 
        "far fa-stop-circle" => "Regular Stop Circle", 
        "far fa-stopwatch" => "Regular Stopwatch", 
        "far fa-store" => "Regular Store", 
        "far fa-store-alt" => "Regular Store Alt", 
        "far fa-stream" => "Regular Stream", 
        "far fa-street-view" => "Regular Street View", 
        "far fa-stretcher" => "Regular Stretcher", 
        "far fa-strikethrough" => "Regular Strikethrough", 
        "far fa-stroopwafel" => "Regular Stroopwafel", 
        "far fa-subscript" => "Regular Subscript", 
        "far fa-subway" => "Regular Subway", 
        "far fa-suitcase" => "Regular Suitcase", 
        "far fa-suitcase-rolling" => "Regular Suitcase Rolling", 
        "far fa-sun" => "Regular Sun", 
        "far fa-sun-cloud" => "Regular Sun Cloud", 
        "far fa-sun-dust" => "Regular Sun Dust", 
        "far fa-sun-haze" => "Regular Sun Haze", 
        "far fa-sunrise" => "Regular Sunrise", 
        "far fa-sunset" => "Regular Sunset", 
        "far fa-superscript" => "Regular Superscript", 
        "far fa-surprise" => "Regular Surprise", 
        "far fa-swatchbook" => "Regular Swatchbook", 
        "far fa-swimmer" => "Regular Swimmer", 
        "far fa-swimming-pool" => "Regular Swimming Pool", 
        "far fa-sword" => "Regular Sword", 
        "far fa-swords" => "Regular Swords", 
        "far fa-synagogue" => "Regular Synagogue", 
        "far fa-sync" => "Regular Sync", 
        "far fa-sync-alt" => "Regular Sync Alt", 
        "far fa-syringe" => "Regular Syringe", 
        "far fa-table" => "Regular Table", 
        "far fa-table-tennis" => "Regular Table Tennis", 
        "far fa-tablet" => "Regular Tablet", 
        "far fa-tablet-alt" => "Regular Tablet Alt", 
        "far fa-tablet-android" => "Regular Tablet Android", 
        "far fa-tablet-android-alt" => "Regular Tablet Android Alt", 
        "far fa-tablet-rugged" => "Regular Tablet Rugged", 
        "far fa-tablets" => "Regular Tablets", 
        "far fa-tachometer" => "Regular Tachometer", 
        "far fa-tachometer-alt" => "Regular Tachometer Alt", 
        "far fa-tachometer-alt-average" => "Regular Tachometer Alt Average", 
        "far fa-tachometer-alt-fast" => "Regular Tachometer Alt Fast", 
        "far fa-tachometer-alt-fastest" => "Regular Tachometer Alt Fastest", 
        "far fa-tachometer-alt-slow" => "Regular Tachometer Alt Slow", 
        "far fa-tachometer-alt-slowest" => "Regular Tachometer Alt Slowest", 
        "far fa-tachometer-average" => "Regular Tachometer Average", 
        "far fa-tachometer-fast" => "Regular Tachometer Fast", 
        "far fa-tachometer-fastest" => "Regular Tachometer Fastest", 
        "far fa-tachometer-slow" => "Regular Tachometer Slow", 
        "far fa-tachometer-slowest" => "Regular Tachometer Slowest", 
        "far fa-taco" => "Regular Taco", 
        "far fa-tag" => "Regular Tag", 
        "far fa-tags" => "Regular Tags", 
        "far fa-tally" => "Regular Tally", 
        "far fa-tanakh" => "Regular Tanakh", 
        "far fa-tape" => "Regular Tape", 
        "far fa-tasks" => "Regular Tasks", 
        "far fa-tasks-alt" => "Regular Tasks Alt", 
        "far fa-taxi" => "Regular Taxi", 
        "far fa-teeth" => "Regular Teeth", 
        "far fa-teeth-open" => "Regular Teeth Open", 
        "far fa-temperature-frigid" => "Regular Temperature Frigid", 
        "far fa-temperature-high" => "Regular Temperature High", 
        "far fa-temperature-hot" => "Regular Temperature Hot", 
        "far fa-temperature-low" => "Regular Temperature Low", 
        "far fa-tenge" => "Regular Tenge", 
        "far fa-tennis-ball" => "Regular Tennis Ball", 
        "far fa-terminal" => "Regular Terminal", 
        "far fa-text-height" => "Regular Text Height", 
        "far fa-text-width" => "Regular Text Width", 
        "far fa-th" => "Regular Th", 
        "far fa-th-large" => "Regular Th Large", 
        "far fa-th-list" => "Regular Th List", 
        "far fa-theater-masks" => "Regular Theater Masks", 
        "far fa-thermometer" => "Regular Thermometer", 
        "far fa-thermometer-empty" => "Regular Thermometer Empty", 
        "far fa-thermometer-full" => "Regular Thermometer Full", 
        "far fa-thermometer-half" => "Regular Thermometer Half", 
        "far fa-thermometer-quarter" => "Regular Thermometer Quarter", 
        "far fa-thermometer-three-quarters" => "Regular Thermometer Three Quarters", 
        "far fa-theta" => "Regular Theta", 
        "far fa-thumbs-down" => "Regular Thumbs Down", 
        "far fa-thumbs-up" => "Regular Thumbs Up", 
        "far fa-thumbtack" => "Regular Thumbtack", 
        "far fa-thunderstorm" => "Regular Thunderstorm", 
        "far fa-thunderstorm-moon" => "Regular Thunderstorm Moon", 
        "far fa-thunderstorm-sun" => "Regular Thunderstorm Sun", 
        "far fa-ticket" => "Regular Ticket", 
        "far fa-ticket-alt" => "Regular Ticket Alt", 
        "far fa-tilde" => "Regular Tilde", 
        "far fa-times" => "Regular Times", 
        "far fa-times-circle" => "Regular Times Circle", 
        "far fa-times-hexagon" => "Regular Times Hexagon", 
        "far fa-times-octagon" => "Regular Times Octagon", 
        "far fa-times-square" => "Regular Times Square", 
        "far fa-tint" => "Regular Tint", 
        "far fa-tint-slash" => "Regular Tint Slash", 
        "far fa-tire" => "Regular Tire", 
        "far fa-tire-flat" => "Regular Tire Flat", 
        "far fa-tire-pressure-warning" => "Regular Tire Pressure Warning", 
        "far fa-tire-rugged" => "Regular Tire Rugged", 
        "far fa-tired" => "Regular Tired", 
        "far fa-toggle-off" => "Regular Toggle Off", 
        "far fa-toggle-on" => "Regular Toggle On", 
        "far fa-toilet" => "Regular Toilet", 
        "far fa-toilet-paper" => "Regular Toilet Paper", 
        "far fa-toilet-paper-alt" => "Regular Toilet Paper Alt", 
        "far fa-tombstone" => "Regular Tombstone", 
        "far fa-tombstone-alt" => "Regular Tombstone Alt", 
        "far fa-toolbox" => "Regular Toolbox", 
        "far fa-tools" => "Regular Tools", 
        "far fa-tooth" => "Regular Tooth", 
        "far fa-toothbrush" => "Regular Toothbrush", 
        "far fa-torah" => "Regular Torah", 
        "far fa-torii-gate" => "Regular Torii Gate", 
        "far fa-tornado" => "Regular Tornado", 
        "far fa-tractor" => "Regular Tractor", 
        "far fa-trademark" => "Regular Trademark", 
        "far fa-traffic-cone" => "Regular Traffic Cone", 
        "far fa-traffic-light" => "Regular Traffic Light", 
        "far fa-traffic-light-go" => "Regular Traffic Light Go", 
        "far fa-traffic-light-slow" => "Regular Traffic Light Slow", 
        "far fa-traffic-light-stop" => "Regular Traffic Light Stop", 
        "far fa-train" => "Regular Train", 
        "far fa-tram" => "Regular Tram", 
        "far fa-transgender" => "Regular Transgender", 
        "far fa-transgender-alt" => "Regular Transgender Alt", 
        "far fa-trash" => "Regular Trash", 
        "far fa-trash-alt" => "Regular Trash Alt", 
        "far fa-trash-restore" => "Regular Trash Restore", 
        "far fa-trash-restore-alt" => "Regular Trash Restore Alt", 
        "far fa-treasure-chest" => "Regular Treasure Chest", 
        "far fa-tree" => "Regular Tree", 
        "far fa-tree-alt" => "Regular Tree Alt", 
        "far fa-tree-christmas" => "Regular Tree Christmas", 
        "far fa-tree-decorated" => "Regular Tree Decorated", 
        "far fa-tree-large" => "Regular Tree Large", 
        "far fa-tree-palm" => "Regular Tree Palm", 
        "far fa-trees" => "Regular Trees", 
        "far fa-triangle" => "Regular Triangle", 
        "far fa-trophy" => "Regular Trophy", 
        "far fa-trophy-alt" => "Regular Trophy Alt", 
        "far fa-truck" => "Regular Truck", 
        "far fa-truck-container" => "Regular Truck Container", 
        "far fa-truck-couch" => "Regular Truck Couch", 
        "far fa-truck-loading" => "Regular Truck Loading", 
        "far fa-truck-monster" => "Regular Truck Monster", 
        "far fa-truck-moving" => "Regular Truck Moving", 
        "far fa-truck-pickup" => "Regular Truck Pickup", 
        "far fa-truck-plow" => "Regular Truck Plow", 
        "far fa-truck-ramp" => "Regular Truck Ramp", 
        "far fa-tshirt" => "Regular Tshirt", 
        "far fa-tty" => "Regular Tty", 
        "far fa-turkey" => "Regular Turkey", 
        "far fa-turtle" => "Regular Turtle", 
        "far fa-tv" => "Regular Tv", 
        "far fa-tv-retro" => "Regular Tv Retro", 
        "far fa-umbrella" => "Regular Umbrella", 
        "far fa-umbrella-beach" => "Regular Umbrella Beach", 
        "far fa-underline" => "Regular Underline", 
        "far fa-undo" => "Regular Undo", 
        "far fa-undo-alt" => "Regular Undo Alt", 
        "far fa-unicorn" => "Regular Unicorn", 
        "far fa-union" => "Regular Union", 
        "far fa-universal-access" => "Regular Universal Access", 
        "far fa-university" => "Regular University", 
        "far fa-unlink" => "Regular Unlink", 
        "far fa-unlock" => "Regular Unlock", 
        "far fa-unlock-alt" => "Regular Unlock Alt", 
        "far fa-upload" => "Regular Upload", 
        "far fa-usd-circle" => "Regular Usd Circle", 
        "far fa-usd-square" => "Regular Usd Square", 
        "far fa-user" => "Regular User", 
        "far fa-user-alt" => "Regular User Alt", 
        "far fa-user-alt-slash" => "Regular User Alt Slash", 
        "far fa-user-astronaut" => "Regular User Astronaut", 
        "far fa-user-chart" => "Regular User Chart", 
        "far fa-user-check" => "Regular User Check", 
        "far fa-user-circle" => "Regular User Circle", 
        "far fa-user-clock" => "Regular User Clock", 
        "far fa-user-cog" => "Regular User Cog", 
        "far fa-user-crown" => "Regular User Crown", 
        "far fa-user-edit" => "Regular User Edit", 
        "far fa-user-friends" => "Regular User Friends", 
        "far fa-user-graduate" => "Regular User Graduate", 
        "far fa-user-hard-hat" => "Regular User Hard Hat", 
        "far fa-user-headset" => "Regular User Headset", 
        "far fa-user-injured" => "Regular User Injured", 
        "far fa-user-lock" => "Regular User Lock", 
        "far fa-user-md" => "Regular User Md", 
        "far fa-user-md-chat" => "Regular User Md Chat", 
        "far fa-user-minus" => "Regular User Minus", 
        "far fa-user-ninja" => "Regular User Ninja", 
        "far fa-user-nurse" => "Regular User Nurse", 
        "far fa-user-plus" => "Regular User Plus", 
        "far fa-user-secret" => "Regular User Secret", 
        "far fa-user-shield" => "Regular User Shield", 
        "far fa-user-slash" => "Regular User Slash", 
        "far fa-user-tag" => "Regular User Tag", 
        "far fa-user-tie" => "Regular User Tie", 
        "far fa-user-times" => "Regular User Times", 
        "far fa-users" => "Regular Users", 
        "far fa-users-class" => "Regular Users Class", 
        "far fa-users-cog" => "Regular Users Cog", 
        "far fa-users-crown" => "Regular Users Crown", 
        "far fa-users-medical" => "Regular Users Medical", 
        "far fa-utensil-fork" => "Regular Utensil Fork", 
        "far fa-utensil-knife" => "Regular Utensil Knife", 
        "far fa-utensil-spoon" => "Regular Utensil Spoon", 
        "far fa-utensils" => "Regular Utensils", 
        "far fa-utensils-alt" => "Regular Utensils Alt", 
        "far fa-value-absolute" => "Regular Value Absolute", 
        "far fa-vector-square" => "Regular Vector Square", 
        "far fa-venus" => "Regular Venus", 
        "far fa-venus-double" => "Regular Venus Double", 
        "far fa-venus-mars" => "Regular Venus Mars", 
        "far fa-vial" => "Regular Vial", 
        "far fa-vials" => "Regular Vials", 
        "far fa-video" => "Regular Video", 
        "far fa-video-plus" => "Regular Video Plus", 
        "far fa-video-slash" => "Regular Video Slash", 
        "far fa-vihara" => "Regular Vihara", 
        "far fa-volcano" => "Regular Volcano", 
        "far fa-volleyball-ball" => "Regular Volleyball Ball", 
        "far fa-volume" => "Regular Volume", 
        "far fa-volume-down" => "Regular Volume Down", 
        "far fa-volume-mute" => "Regular Volume Mute", 
        "far fa-volume-off" => "Regular Volume Off", 
        "far fa-volume-slash" => "Regular Volume Slash", 
        "far fa-volume-up" => "Regular Volume Up", 
        "far fa-vote-nay" => "Regular Vote Nay", 
        "far fa-vote-yea" => "Regular Vote Yea", 
        "far fa-vr-cardboard" => "Regular Vr Cardboard", 
        "far fa-walker" => "Regular Walker", 
        "far fa-walking" => "Regular Walking", 
        "far fa-wallet" => "Regular Wallet", 
        "far fa-wand" => "Regular Wand", 
        "far fa-wand-magic" => "Regular Wand Magic", 
        "far fa-warehouse" => "Regular Warehouse", 
        "far fa-warehouse-alt" => "Regular Warehouse Alt", 
        "far fa-watch" => "Regular Watch", 
        "far fa-watch-fitness" => "Regular Watch Fitness", 
        "far fa-water" => "Regular Water", 
        "far fa-water-lower" => "Regular Water Lower", 
        "far fa-water-rise" => "Regular Water Rise", 
        "far fa-wave-square" => "Regular Wave Square", 
        "far fa-webcam" => "Regular Webcam", 
        "far fa-webcam-slash" => "Regular Webcam Slash", 
        "far fa-weight" => "Regular Weight", 
        "far fa-weight-hanging" => "Regular Weight Hanging", 
        "far fa-whale" => "Regular Whale", 
        "far fa-wheat" => "Regular Wheat", 
        "far fa-wheelchair" => "Regular Wheelchair", 
        "far fa-whistle" => "Regular Whistle", 
        "far fa-wifi" => "Regular Wifi", 
        "far fa-wifi-1" => "Regular Wifi 1", 
        "far fa-wifi-2" => "Regular Wifi 2", 
        "far fa-wifi-slash" => "Regular Wifi Slash", 
        "far fa-wind" => "Regular Wind", 
        "far fa-wind-warning" => "Regular Wind Warning", 
        "far fa-window" => "Regular Window", 
        "far fa-window-alt" => "Regular Window Alt", 
        "far fa-window-close" => "Regular Window Close", 
        "far fa-window-maximize" => "Regular Window Maximize", 
        "far fa-window-minimize" => "Regular Window Minimize", 
        "far fa-window-restore" => "Regular Window Restore", 
        "far fa-windsock" => "Regular Windsock", 
        "far fa-wine-bottle" => "Regular Wine Bottle", 
        "far fa-wine-glass" => "Regular Wine Glass", 
        "far fa-wine-glass-alt" => "Regular Wine Glass Alt", 
        "far fa-won-sign" => "Regular Won Sign", 
        "far fa-wreath" => "Regular Wreath", 
        "far fa-wrench" => "Regular Wrench", 
        "far fa-x-ray" => "Regular X Ray", 
        "far fa-yen-sign" => "Regular Yen Sign", 
        "far fa-yin-yang" => "Regular Yin Yang", 
        "fal fa-abacus" => "Light Abacus", 
        "fal fa-acorn" => "Light Acorn", 
        "fal fa-ad" => "Light Ad", 
        "fal fa-address-book" => "Light Address Book", 
        "fal fa-address-card" => "Light Address Card", 
        "fal fa-adjust" => "Light Adjust", 
        "fal fa-air-freshener" => "Light Air Freshener", 
        "fal fa-alarm-clock" => "Light Alarm Clock", 
        "fal fa-alicorn" => "Light Alicorn", 
        "fal fa-align-center" => "Light Align Center", 
        "fal fa-align-justify" => "Light Align Justify", 
        "fal fa-align-left" => "Light Align Left", 
        "fal fa-align-right" => "Light Align Right", 
        "fal fa-allergies" => "Light Allergies", 
        "fal fa-ambulance" => "Light Ambulance", 
        "fal fa-american-sign-language-interpreting" => "Light American Sign Language Interpreting", 
        "fal fa-analytics" => "Light Analytics", 
        "fal fa-anchor" => "Light Anchor", 
        "fal fa-angel" => "Light Angel", 
        "fal fa-angle-double-down" => "Light Angle Double Down", 
        "fal fa-angle-double-left" => "Light Angle Double Left", 
        "fal fa-angle-double-right" => "Light Angle Double Right", 
        "fal fa-angle-double-up" => "Light Angle Double Up", 
        "fal fa-angle-down" => "Light Angle Down", 
        "fal fa-angle-left" => "Light Angle Left", 
        "fal fa-angle-right" => "Light Angle Right", 
        "fal fa-angle-up" => "Light Angle Up", 
        "fal fa-angry" => "Light Angry", 
        "fal fa-ankh" => "Light Ankh", 
        "fal fa-apple-alt" => "Light Apple Alt", 
        "fal fa-apple-crate" => "Light Apple Crate", 
        "fal fa-archive" => "Light Archive", 
        "fal fa-archway" => "Light Archway", 
        "fal fa-arrow-alt-circle-down" => "Light Arrow Alt Circle Down", 
        "fal fa-arrow-alt-circle-left" => "Light Arrow Alt Circle Left", 
        "fal fa-arrow-alt-circle-right" => "Light Arrow Alt Circle Right", 
        "fal fa-arrow-alt-circle-up" => "Light Arrow Alt Circle Up", 
        "fal fa-arrow-alt-down" => "Light Arrow Alt Down", 
        "fal fa-arrow-alt-from-bottom" => "Light Arrow Alt From Bottom", 
        "fal fa-arrow-alt-from-left" => "Light Arrow Alt From Left", 
        "fal fa-arrow-alt-from-right" => "Light Arrow Alt From Right", 
        "fal fa-arrow-alt-from-top" => "Light Arrow Alt From Top", 
        "fal fa-arrow-alt-left" => "Light Arrow Alt Left", 
        "fal fa-arrow-alt-right" => "Light Arrow Alt Right", 
        "fal fa-arrow-alt-square-down" => "Light Arrow Alt Square Down", 
        "fal fa-arrow-alt-square-left" => "Light Arrow Alt Square Left", 
        "fal fa-arrow-alt-square-right" => "Light Arrow Alt Square Right", 
        "fal fa-arrow-alt-square-up" => "Light Arrow Alt Square Up", 
        "fal fa-arrow-alt-to-bottom" => "Light Arrow Alt To Bottom", 
        "fal fa-arrow-alt-to-left" => "Light Arrow Alt To Left", 
        "fal fa-arrow-alt-to-right" => "Light Arrow Alt To Right", 
        "fal fa-arrow-alt-to-top" => "Light Arrow Alt To Top", 
        "fal fa-arrow-alt-up" => "Light Arrow Alt Up", 
        "fal fa-arrow-circle-down" => "Light Arrow Circle Down", 
        "fal fa-arrow-circle-left" => "Light Arrow Circle Left", 
        "fal fa-arrow-circle-right" => "Light Arrow Circle Right", 
        "fal fa-arrow-circle-up" => "Light Arrow Circle Up", 
        "fal fa-arrow-down" => "Light Arrow Down", 
        "fal fa-arrow-from-bottom" => "Light Arrow From Bottom", 
        "fal fa-arrow-from-left" => "Light Arrow From Left", 
        "fal fa-arrow-from-right" => "Light Arrow From Right", 
        "fal fa-arrow-from-top" => "Light Arrow From Top", 
        "fal fa-arrow-left" => "Light Arrow Left", 
        "fal fa-arrow-right" => "Light Arrow Right", 
        "fal fa-arrow-square-down" => "Light Arrow Square Down", 
        "fal fa-arrow-square-left" => "Light Arrow Square Left", 
        "fal fa-arrow-square-right" => "Light Arrow Square Right", 
        "fal fa-arrow-square-up" => "Light Arrow Square Up", 
        "fal fa-arrow-to-bottom" => "Light Arrow To Bottom", 
        "fal fa-arrow-to-left" => "Light Arrow To Left", 
        "fal fa-arrow-to-right" => "Light Arrow To Right", 
        "fal fa-arrow-to-top" => "Light Arrow To Top", 
        "fal fa-arrow-up" => "Light Arrow Up", 
        "fal fa-arrows" => "Light Arrows", 
        "fal fa-arrows-alt" => "Light Arrows Alt", 
        "fal fa-arrows-alt-h" => "Light Arrows Alt H", 
        "fal fa-arrows-alt-v" => "Light Arrows Alt V", 
        "fal fa-arrows-h" => "Light Arrows H", 
        "fal fa-arrows-v" => "Light Arrows V", 
        "fal fa-assistive-listening-systems" => "Light Assistive Listening Systems", 
        "fal fa-asterisk" => "Light Asterisk", 
        "fal fa-at" => "Light At", 
        "fal fa-atlas" => "Light Atlas", 
        "fal fa-atom" => "Light Atom", 
        "fal fa-atom-alt" => "Light Atom Alt", 
        "fal fa-audio-description" => "Light Audio Description", 
        "fal fa-award" => "Light Award", 
        "fal fa-axe" => "Light Axe", 
        "fal fa-axe-battle" => "Light Axe Battle", 
        "fal fa-baby" => "Light Baby", 
        "fal fa-baby-carriage" => "Light Baby Carriage", 
        "fal fa-backpack" => "Light Backpack", 
        "fal fa-backspace" => "Light Backspace", 
        "fal fa-backward" => "Light Backward", 
        "fal fa-bacon" => "Light Bacon", 
        "fal fa-badge" => "Light Badge", 
        "fal fa-badge-check" => "Light Badge Check", 
        "fal fa-badge-dollar" => "Light Badge Dollar", 
        "fal fa-badge-percent" => "Light Badge Percent", 
        "fal fa-badger-honey" => "Light Badger Honey", 
        "fal fa-balance-scale" => "Light Balance Scale", 
        "fal fa-balance-scale-left" => "Light Balance Scale Left", 
        "fal fa-balance-scale-right" => "Light Balance Scale Right", 
        "fal fa-ball-pile" => "Light Ball Pile", 
        "fal fa-ballot" => "Light Ballot", 
        "fal fa-ballot-check" => "Light Ballot Check", 
        "fal fa-ban" => "Light Ban", 
        "fal fa-band-aid" => "Light Band Aid", 
        "fal fa-barcode" => "Light Barcode", 
        "fal fa-barcode-alt" => "Light Barcode Alt", 
        "fal fa-barcode-read" => "Light Barcode Read", 
        "fal fa-barcode-scan" => "Light Barcode Scan", 
        "fal fa-bars" => "Light Bars", 
        "fal fa-baseball" => "Light Baseball", 
        "fal fa-baseball-ball" => "Light Baseball Ball", 
        "fal fa-basketball-ball" => "Light Basketball Ball", 
        "fal fa-basketball-hoop" => "Light Basketball Hoop", 
        "fal fa-bat" => "Light Bat", 
        "fal fa-bath" => "Light Bath", 
        "fal fa-battery-bolt" => "Light Battery Bolt", 
        "fal fa-battery-empty" => "Light Battery Empty", 
        "fal fa-battery-full" => "Light Battery Full", 
        "fal fa-battery-half" => "Light Battery Half", 
        "fal fa-battery-quarter" => "Light Battery Quarter", 
        "fal fa-battery-slash" => "Light Battery Slash", 
        "fal fa-battery-three-quarters" => "Light Battery Three Quarters", 
        "fal fa-bed" => "Light Bed", 
        "fal fa-beer" => "Light Beer", 
        "fal fa-bell" => "Light Bell", 
        "fal fa-bell-school" => "Light Bell School", 
        "fal fa-bell-school-slash" => "Light Bell School Slash", 
        "fal fa-bell-slash" => "Light Bell Slash", 
        "fal fa-bells" => "Light Bells", 
        "fal fa-bezier-curve" => "Light Bezier Curve", 
        "fal fa-bible" => "Light Bible", 
        "fal fa-bicycle" => "Light Bicycle", 
        "fal fa-binoculars" => "Light Binoculars", 
        "fal fa-biohazard" => "Light Biohazard", 
        "fal fa-birthday-cake" => "Light Birthday Cake", 
        "fal fa-blanket" => "Light Blanket", 
        "fal fa-blender" => "Light Blender", 
        "fal fa-blender-phone" => "Light Blender Phone", 
        "fal fa-blind" => "Light Blind", 
        "fal fa-blog" => "Light Blog", 
        "fal fa-bold" => "Light Bold", 
        "fal fa-bolt" => "Light Bolt", 
        "fal fa-bomb" => "Light Bomb", 
        "fal fa-bone" => "Light Bone", 
        "fal fa-bone-break" => "Light Bone Break", 
        "fal fa-bong" => "Light Bong", 
        "fal fa-book" => "Light Book", 
        "fal fa-book-alt" => "Light Book Alt", 
        "fal fa-book-dead" => "Light Book Dead", 
        "fal fa-book-heart" => "Light Book Heart", 
        "fal fa-book-medical" => "Light Book Medical", 
        "fal fa-book-open" => "Light Book Open", 
        "fal fa-book-reader" => "Light Book Reader", 
        "fal fa-book-spells" => "Light Book Spells", 
        "fal fa-book-user" => "Light Book User", 
        "fal fa-bookmark" => "Light Bookmark", 
        "fal fa-books" => "Light Books", 
        "fal fa-books-medical" => "Light Books Medical", 
        "fal fa-boot" => "Light Boot", 
        "fal fa-booth-curtain" => "Light Booth Curtain", 
        "fal fa-bow-arrow" => "Light Bow Arrow", 
        "fal fa-bowling-ball" => "Light Bowling Ball", 
        "fal fa-bowling-pins" => "Light Bowling Pins", 
        "fal fa-box" => "Light Box", 
        "fal fa-box-alt" => "Light Box Alt", 
        "fal fa-box-ballot" => "Light Box Ballot", 
        "fal fa-box-check" => "Light Box Check", 
        "fal fa-box-fragile" => "Light Box Fragile", 
        "fal fa-box-full" => "Light Box Full", 
        "fal fa-box-heart" => "Light Box Heart", 
        "fal fa-box-open" => "Light Box Open", 
        "fal fa-box-up" => "Light Box Up", 
        "fal fa-box-usd" => "Light Box Usd", 
        "fal fa-boxes" => "Light Boxes", 
        "fal fa-boxes-alt" => "Light Boxes Alt", 
        "fal fa-boxing-glove" => "Light Boxing Glove", 
        "fal fa-brackets" => "Light Brackets", 
        "fal fa-brackets-curly" => "Light Brackets Curly", 
        "fal fa-braille" => "Light Braille", 
        "fal fa-brain" => "Light Brain", 
        "fal fa-bread-loaf" => "Light Bread Loaf", 
        "fal fa-bread-slice" => "Light Bread Slice", 
        "fal fa-briefcase" => "Light Briefcase", 
        "fal fa-briefcase-medical" => "Light Briefcase Medical", 
        "fal fa-broadcast-tower" => "Light Broadcast Tower", 
        "fal fa-broom" => "Light Broom", 
        "fal fa-browser" => "Light Browser", 
        "fal fa-brush" => "Light Brush", 
        "fal fa-bug" => "Light Bug", 
        "fal fa-building" => "Light Building", 
        "fal fa-bullhorn" => "Light Bullhorn", 
        "fal fa-bullseye" => "Light Bullseye", 
        "fal fa-bullseye-arrow" => "Light Bullseye Arrow", 
        "fal fa-bullseye-pointer" => "Light Bullseye Pointer", 
        "fal fa-burn" => "Light Burn", 
        "fal fa-burrito" => "Light Burrito", 
        "fal fa-bus" => "Light Bus", 
        "fal fa-bus-alt" => "Light Bus Alt", 
        "fal fa-bus-school" => "Light Bus School", 
        "fal fa-business-time" => "Light Business Time", 
        "fal fa-cabinet-filing" => "Light Cabinet Filing", 
        "fal fa-calculator" => "Light Calculator", 
        "fal fa-calculator-alt" => "Light Calculator Alt", 
        "fal fa-calendar" => "Light Calendar", 
        "fal fa-calendar-alt" => "Light Calendar Alt", 
        "fal fa-calendar-check" => "Light Calendar Check", 
        "fal fa-calendar-day" => "Light Calendar Day", 
        "fal fa-calendar-edit" => "Light Calendar Edit", 
        "fal fa-calendar-exclamation" => "Light Calendar Exclamation", 
        "fal fa-calendar-minus" => "Light Calendar Minus", 
        "fal fa-calendar-plus" => "Light Calendar Plus", 
        "fal fa-calendar-star" => "Light Calendar Star", 
        "fal fa-calendar-times" => "Light Calendar Times", 
        "fal fa-calendar-week" => "Light Calendar Week", 
        "fal fa-camera" => "Light Camera", 
        "fal fa-camera-alt" => "Light Camera Alt", 
        "fal fa-camera-retro" => "Light Camera Retro", 
        "fal fa-campfire" => "Light Campfire", 
        "fal fa-campground" => "Light Campground", 
        "fal fa-candle-holder" => "Light Candle Holder", 
        "fal fa-candy-cane" => "Light Candy Cane", 
        "fal fa-candy-corn" => "Light Candy Corn", 
        "fal fa-cannabis" => "Light Cannabis", 
        "fal fa-capsules" => "Light Capsules", 
        "fal fa-car" => "Light Car", 
        "fal fa-car-alt" => "Light Car Alt", 
        "fal fa-car-battery" => "Light Car Battery", 
        "fal fa-car-bump" => "Light Car Bump", 
        "fal fa-car-crash" => "Light Car Crash", 
        "fal fa-car-garage" => "Light Car Garage", 
        "fal fa-car-mechanic" => "Light Car Mechanic", 
        "fal fa-car-side" => "Light Car Side", 
        "fal fa-car-tilt" => "Light Car Tilt", 
        "fal fa-car-wash" => "Light Car Wash", 
        "fal fa-caret-circle-down" => "Light Caret Circle Down", 
        "fal fa-caret-circle-left" => "Light Caret Circle Left", 
        "fal fa-caret-circle-right" => "Light Caret Circle Right", 
        "fal fa-caret-circle-up" => "Light Caret Circle Up", 
        "fal fa-caret-down" => "Light Caret Down", 
        "fal fa-caret-left" => "Light Caret Left", 
        "fal fa-caret-right" => "Light Caret Right", 
        "fal fa-caret-square-down" => "Light Caret Square Down", 
        "fal fa-caret-square-left" => "Light Caret Square Left", 
        "fal fa-caret-square-right" => "Light Caret Square Right", 
        "fal fa-caret-square-up" => "Light Caret Square Up", 
        "fal fa-caret-up" => "Light Caret Up", 
        "fal fa-carrot" => "Light Carrot", 
        "fal fa-cart-arrow-down" => "Light Cart Arrow Down", 
        "fal fa-cart-plus" => "Light Cart Plus", 
        "fal fa-cash-register" => "Light Cash Register", 
        "fal fa-cat" => "Light Cat", 
        "fal fa-cauldron" => "Light Cauldron", 
        "fal fa-certificate" => "Light Certificate", 
        "fal fa-chair" => "Light Chair", 
        "fal fa-chair-office" => "Light Chair Office", 
        "fal fa-chalkboard" => "Light Chalkboard", 
        "fal fa-chalkboard-teacher" => "Light Chalkboard Teacher", 
        "fal fa-charging-station" => "Light Charging Station", 
        "fal fa-chart-area" => "Light Chart Area", 
        "fal fa-chart-bar" => "Light Chart Bar", 
        "fal fa-chart-line" => "Light Chart Line", 
        "fal fa-chart-line-down" => "Light Chart Line Down", 
        "fal fa-chart-network" => "Light Chart Network", 
        "fal fa-chart-pie" => "Light Chart Pie", 
        "fal fa-chart-pie-alt" => "Light Chart Pie Alt", 
        "fal fa-chart-scatter" => "Light Chart Scatter", 
        "fal fa-check" => "Light Check", 
        "fal fa-check-circle" => "Light Check Circle", 
        "fal fa-check-double" => "Light Check Double", 
        "fal fa-check-square" => "Light Check Square", 
        "fal fa-cheese" => "Light Cheese", 
        "fal fa-cheese-swiss" => "Light Cheese Swiss", 
        "fal fa-cheeseburger" => "Light Cheeseburger", 
        "fal fa-chess" => "Light Chess", 
        "fal fa-chess-bishop" => "Light Chess Bishop", 
        "fal fa-chess-bishop-alt" => "Light Chess Bishop Alt", 
        "fal fa-chess-board" => "Light Chess Board", 
        "fal fa-chess-clock" => "Light Chess Clock", 
        "fal fa-chess-clock-alt" => "Light Chess Clock Alt", 
        "fal fa-chess-king" => "Light Chess King", 
        "fal fa-chess-king-alt" => "Light Chess King Alt", 
        "fal fa-chess-knight" => "Light Chess Knight", 
        "fal fa-chess-knight-alt" => "Light Chess Knight Alt", 
        "fal fa-chess-pawn" => "Light Chess Pawn", 
        "fal fa-chess-pawn-alt" => "Light Chess Pawn Alt", 
        "fal fa-chess-queen" => "Light Chess Queen", 
        "fal fa-chess-queen-alt" => "Light Chess Queen Alt", 
        "fal fa-chess-rook" => "Light Chess Rook", 
        "fal fa-chess-rook-alt" => "Light Chess Rook Alt", 
        "fal fa-chevron-circle-down" => "Light Chevron Circle Down", 
        "fal fa-chevron-circle-left" => "Light Chevron Circle Left", 
        "fal fa-chevron-circle-right" => "Light Chevron Circle Right", 
        "fal fa-chevron-circle-up" => "Light Chevron Circle Up", 
        "fal fa-chevron-double-down" => "Light Chevron Double Down", 
        "fal fa-chevron-double-left" => "Light Chevron Double Left", 
        "fal fa-chevron-double-right" => "Light Chevron Double Right", 
        "fal fa-chevron-double-up" => "Light Chevron Double Up", 
        "fal fa-chevron-down" => "Light Chevron Down", 
        "fal fa-chevron-left" => "Light Chevron Left", 
        "fal fa-chevron-right" => "Light Chevron Right", 
        "fal fa-chevron-square-down" => "Light Chevron Square Down", 
        "fal fa-chevron-square-left" => "Light Chevron Square Left", 
        "fal fa-chevron-square-right" => "Light Chevron Square Right", 
        "fal fa-chevron-square-up" => "Light Chevron Square Up", 
        "fal fa-chevron-up" => "Light Chevron Up", 
        "fal fa-child" => "Light Child", 
        "fal fa-chimney" => "Light Chimney", 
        "fal fa-church" => "Light Church", 
        "fal fa-circle" => "Light Circle", 
        "fal fa-circle-notch" => "Light Circle Notch", 
        "fal fa-city" => "Light City", 
        "fal fa-claw-marks" => "Light Claw Marks", 
        "fal fa-clinic-medical" => "Light Clinic Medical", 
        "fal fa-clipboard" => "Light Clipboard", 
        "fal fa-clipboard-check" => "Light Clipboard Check", 
        "fal fa-clipboard-list" => "Light Clipboard List", 
        "fal fa-clipboard-list-check" => "Light Clipboard List Check", 
        "fal fa-clipboard-prescription" => "Light Clipboard Prescription", 
        "fal fa-clipboard-user" => "Light Clipboard User", 
        "fal fa-clock" => "Light Clock", 
        "fal fa-clone" => "Light Clone", 
        "fal fa-closed-captioning" => "Light Closed Captioning", 
        "fal fa-cloud" => "Light Cloud", 
        "fal fa-cloud-download" => "Light Cloud Download", 
        "fal fa-cloud-download-alt" => "Light Cloud Download Alt", 
        "fal fa-cloud-drizzle" => "Light Cloud Drizzle", 
        "fal fa-cloud-hail" => "Light Cloud Hail", 
        "fal fa-cloud-hail-mixed" => "Light Cloud Hail Mixed", 
        "fal fa-cloud-meatball" => "Light Cloud Meatball", 
        "fal fa-cloud-moon" => "Light Cloud Moon", 
        "fal fa-cloud-moon-rain" => "Light Cloud Moon Rain", 
        "fal fa-cloud-rain" => "Light Cloud Rain", 
        "fal fa-cloud-rainbow" => "Light Cloud Rainbow", 
        "fal fa-cloud-showers" => "Light Cloud Showers", 
        "fal fa-cloud-showers-heavy" => "Light Cloud Showers Heavy", 
        "fal fa-cloud-sleet" => "Light Cloud Sleet", 
        "fal fa-cloud-snow" => "Light Cloud Snow", 
        "fal fa-cloud-sun" => "Light Cloud Sun", 
        "fal fa-cloud-sun-rain" => "Light Cloud Sun Rain", 
        "fal fa-cloud-upload" => "Light Cloud Upload", 
        "fal fa-cloud-upload-alt" => "Light Cloud Upload Alt", 
        "fal fa-clouds" => "Light Clouds", 
        "fal fa-clouds-moon" => "Light Clouds Moon", 
        "fal fa-clouds-sun" => "Light Clouds Sun", 
        "fal fa-club" => "Light Club", 
        "fal fa-cocktail" => "Light Cocktail", 
        "fal fa-code" => "Light Code", 
        "fal fa-code-branch" => "Light Code Branch", 
        "fal fa-code-commit" => "Light Code Commit", 
        "fal fa-code-merge" => "Light Code Merge", 
        "fal fa-coffee" => "Light Coffee", 
        "fal fa-coffee-togo" => "Light Coffee Togo", 
        "fal fa-coffin" => "Light Coffin", 
        "fal fa-cog" => "Light Cog", 
        "fal fa-cogs" => "Light Cogs", 
        "fal fa-coins" => "Light Coins", 
        "fal fa-columns" => "Light Columns", 
        "fal fa-comment" => "Light Comment", 
        "fal fa-comment-alt" => "Light Comment Alt", 
        "fal fa-comment-alt-check" => "Light Comment Alt Check", 
        "fal fa-comment-alt-dollar" => "Light Comment Alt Dollar", 
        "fal fa-comment-alt-dots" => "Light Comment Alt Dots", 
        "fal fa-comment-alt-edit" => "Light Comment Alt Edit", 
        "fal fa-comment-alt-exclamation" => "Light Comment Alt Exclamation", 
        "fal fa-comment-alt-lines" => "Light Comment Alt Lines", 
        "fal fa-comment-alt-medical" => "Light Comment Alt Medical", 
        "fal fa-comment-alt-minus" => "Light Comment Alt Minus", 
        "fal fa-comment-alt-plus" => "Light Comment Alt Plus", 
        "fal fa-comment-alt-slash" => "Light Comment Alt Slash", 
        "fal fa-comment-alt-smile" => "Light Comment Alt Smile", 
        "fal fa-comment-alt-times" => "Light Comment Alt Times", 
        "fal fa-comment-check" => "Light Comment Check", 
        "fal fa-comment-dollar" => "Light Comment Dollar", 
        "fal fa-comment-dots" => "Light Comment Dots", 
        "fal fa-comment-edit" => "Light Comment Edit", 
        "fal fa-comment-exclamation" => "Light Comment Exclamation", 
        "fal fa-comment-lines" => "Light Comment Lines", 
        "fal fa-comment-medical" => "Light Comment Medical", 
        "fal fa-comment-minus" => "Light Comment Minus", 
        "fal fa-comment-plus" => "Light Comment Plus", 
        "fal fa-comment-slash" => "Light Comment Slash", 
        "fal fa-comment-smile" => "Light Comment Smile", 
        "fal fa-comment-times" => "Light Comment Times", 
        "fal fa-comments" => "Light Comments", 
        "fal fa-comments-alt" => "Light Comments Alt", 
        "fal fa-comments-alt-dollar" => "Light Comments Alt Dollar", 
        "fal fa-comments-dollar" => "Light Comments Dollar", 
        "fal fa-compact-disc" => "Light Compact Disc", 
        "fal fa-compass" => "Light Compass", 
        "fal fa-compass-slash" => "Light Compass Slash", 
        "fal fa-compress" => "Light Compress", 
        "fal fa-compress-alt" => "Light Compress Alt", 
        "fal fa-compress-arrows-alt" => "Light Compress Arrows Alt", 
        "fal fa-compress-wide" => "Light Compress Wide", 
        "fal fa-concierge-bell" => "Light Concierge Bell", 
        "fal fa-container-storage" => "Light Container Storage", 
        "fal fa-conveyor-belt" => "Light Conveyor Belt", 
        "fal fa-conveyor-belt-alt" => "Light Conveyor Belt Alt", 
        "fal fa-cookie" => "Light Cookie", 
        "fal fa-cookie-bite" => "Light Cookie Bite", 
        "fal fa-copy" => "Light Copy", 
        "fal fa-copyright" => "Light Copyright", 
        "fal fa-corn" => "Light Corn", 
        "fal fa-couch" => "Light Couch", 
        "fal fa-cow" => "Light Cow", 
        "fal fa-credit-card" => "Light Credit Card", 
        "fal fa-credit-card-blank" => "Light Credit Card Blank", 
        "fal fa-credit-card-front" => "Light Credit Card Front", 
        "fal fa-cricket" => "Light Cricket", 
        "fal fa-croissant" => "Light Croissant", 
        "fal fa-crop" => "Light Crop", 
        "fal fa-crop-alt" => "Light Crop Alt", 
        "fal fa-cross" => "Light Cross", 
        "fal fa-crosshairs" => "Light Crosshairs", 
        "fal fa-crow" => "Light Crow", 
        "fal fa-crown" => "Light Crown", 
        "fal fa-crutch" => "Light Crutch", 
        "fal fa-crutches" => "Light Crutches", 
        "fal fa-cube" => "Light Cube", 
        "fal fa-cubes" => "Light Cubes", 
        "fal fa-curling" => "Light Curling", 
        "fal fa-cut" => "Light Cut", 
        "fal fa-dagger" => "Light Dagger", 
        "fal fa-database" => "Light Database", 
        "fal fa-deaf" => "Light Deaf", 
        "fal fa-debug" => "Light Debug", 
        "fal fa-deer" => "Light Deer", 
        "fal fa-deer-rudolph" => "Light Deer Rudolph", 
        "fal fa-democrat" => "Light Democrat", 
        "fal fa-desktop" => "Light Desktop", 
        "fal fa-desktop-alt" => "Light Desktop Alt", 
        "fal fa-dewpoint" => "Light Dewpoint", 
        "fal fa-dharmachakra" => "Light Dharmachakra", 
        "fal fa-diagnoses" => "Light Diagnoses", 
        "fal fa-diamond" => "Light Diamond", 
        "fal fa-dice" => "Light Dice", 
        "fal fa-dice-d10" => "Light Dice D10", 
        "fal fa-dice-d12" => "Light Dice D12", 
        "fal fa-dice-d20" => "Light Dice D20", 
        "fal fa-dice-d4" => "Light Dice D4", 
        "fal fa-dice-d6" => "Light Dice D6", 
        "fal fa-dice-d8" => "Light Dice D8", 
        "fal fa-dice-five" => "Light Dice Five", 
        "fal fa-dice-four" => "Light Dice Four", 
        "fal fa-dice-one" => "Light Dice One", 
        "fal fa-dice-six" => "Light Dice Six", 
        "fal fa-dice-three" => "Light Dice Three", 
        "fal fa-dice-two" => "Light Dice Two", 
        "fal fa-digital-tachograph" => "Light Digital Tachograph", 
        "fal fa-diploma" => "Light Diploma", 
        "fal fa-directions" => "Light Directions", 
        "fal fa-disease" => "Light Disease", 
        "fal fa-divide" => "Light Divide", 
        "fal fa-dizzy" => "Light Dizzy", 
        "fal fa-dna" => "Light Dna", 
        "fal fa-do-not-enter" => "Light Do Not Enter", 
        "fal fa-dog" => "Light Dog", 
        "fal fa-dog-leashed" => "Light Dog Leashed", 
        "fal fa-dollar-sign" => "Light Dollar Sign", 
        "fal fa-dolly" => "Light Dolly", 
        "fal fa-dolly-empty" => "Light Dolly Empty", 
        "fal fa-dolly-flatbed" => "Light Dolly Flatbed", 
        "fal fa-dolly-flatbed-alt" => "Light Dolly Flatbed Alt", 
        "fal fa-dolly-flatbed-empty" => "Light Dolly Flatbed Empty", 
        "fal fa-donate" => "Light Donate", 
        "fal fa-door-closed" => "Light Door Closed", 
        "fal fa-door-open" => "Light Door Open", 
        "fal fa-dot-circle" => "Light Dot Circle", 
        "fal fa-dove" => "Light Dove", 
        "fal fa-download" => "Light Download", 
        "fal fa-drafting-compass" => "Light Drafting Compass", 
        "fal fa-dragon" => "Light Dragon", 
        "fal fa-draw-circle" => "Light Draw Circle", 
        "fal fa-draw-polygon" => "Light Draw Polygon", 
        "fal fa-draw-square" => "Light Draw Square", 
        "fal fa-dreidel" => "Light Dreidel", 
        "fal fa-drum" => "Light Drum", 
        "fal fa-drum-steelpan" => "Light Drum Steelpan", 
        "fal fa-drumstick" => "Light Drumstick", 
        "fal fa-drumstick-bite" => "Light Drumstick Bite", 
        "fal fa-duck" => "Light Duck", 
        "fal fa-dumbbell" => "Light Dumbbell", 
        "fal fa-dumpster" => "Light Dumpster", 
        "fal fa-dumpster-fire" => "Light Dumpster Fire", 
        "fal fa-dungeon" => "Light Dungeon", 
        "fal fa-ear" => "Light Ear", 
        "fal fa-ear-muffs" => "Light Ear Muffs", 
        "fal fa-eclipse" => "Light Eclipse", 
        "fal fa-eclipse-alt" => "Light Eclipse Alt", 
        "fal fa-edit" => "Light Edit", 
        "fal fa-egg" => "Light Egg", 
        "fal fa-egg-fried" => "Light Egg Fried", 
        "fal fa-eject" => "Light Eject", 
        "fal fa-elephant" => "Light Elephant", 
        "fal fa-ellipsis-h" => "Light Ellipsis H", 
        "fal fa-ellipsis-h-alt" => "Light Ellipsis H Alt", 
        "fal fa-ellipsis-v" => "Light Ellipsis V", 
        "fal fa-ellipsis-v-alt" => "Light Ellipsis V Alt", 
        "fal fa-empty-set" => "Light Empty Set", 
        "fal fa-engine-warning" => "Light Engine Warning", 
        "fal fa-envelope" => "Light Envelope", 
        "fal fa-envelope-open" => "Light Envelope Open", 
        "fal fa-envelope-open-dollar" => "Light Envelope Open Dollar", 
        "fal fa-envelope-open-text" => "Light Envelope Open Text", 
        "fal fa-envelope-square" => "Light Envelope Square", 
        "fal fa-equals" => "Light Equals", 
        "fal fa-eraser" => "Light Eraser", 
        "fal fa-ethernet" => "Light Ethernet", 
        "fal fa-euro-sign" => "Light Euro Sign", 
        "fal fa-exchange" => "Light Exchange", 
        "fal fa-exchange-alt" => "Light Exchange Alt", 
        "fal fa-exclamation" => "Light Exclamation", 
        "fal fa-exclamation-circle" => "Light Exclamation Circle", 
        "fal fa-exclamation-square" => "Light Exclamation Square", 
        "fal fa-exclamation-triangle" => "Light Exclamation Triangle", 
        "fal fa-expand" => "Light Expand", 
        "fal fa-expand-alt" => "Light Expand Alt", 
        "fal fa-expand-arrows" => "Light Expand Arrows", 
        "fal fa-expand-arrows-alt" => "Light Expand Arrows Alt", 
        "fal fa-expand-wide" => "Light Expand Wide", 
        "fal fa-external-link" => "Light External Link", 
        "fal fa-external-link-alt" => "Light External Link Alt", 
        "fal fa-external-link-square" => "Light External Link Square", 
        "fal fa-external-link-square-alt" => "Light External Link Square Alt", 
        "fal fa-eye" => "Light Eye", 
        "fal fa-eye-dropper" => "Light Eye Dropper", 
        "fal fa-eye-evil" => "Light Eye Evil", 
        "fal fa-eye-slash" => "Light Eye Slash", 
        "fal fa-fast-backward" => "Light Fast Backward", 
        "fal fa-fast-forward" => "Light Fast Forward", 
        "fal fa-fax" => "Light Fax", 
        "fal fa-feather" => "Light Feather", 
        "fal fa-feather-alt" => "Light Feather Alt", 
        "fal fa-female" => "Light Female", 
        "fal fa-field-hockey" => "Light Field Hockey", 
        "fal fa-fighter-jet" => "Light Fighter Jet", 
        "fal fa-file" => "Light File", 
        "fal fa-file-alt" => "Light File Alt", 
        "fal fa-file-archive" => "Light File Archive", 
        "fal fa-file-audio" => "Light File Audio", 
        "fal fa-file-certificate" => "Light File Certificate", 
        "fal fa-file-chart-line" => "Light File Chart Line", 
        "fal fa-file-chart-pie" => "Light File Chart Pie", 
        "fal fa-file-check" => "Light File Check", 
        "fal fa-file-code" => "Light File Code", 
        "fal fa-file-contract" => "Light File Contract", 
        "fal fa-file-csv" => "Light File Csv", 
        "fal fa-file-download" => "Light File Download", 
        "fal fa-file-edit" => "Light File Edit", 
        "fal fa-file-excel" => "Light File Excel", 
        "fal fa-file-exclamation" => "Light File Exclamation", 
        "fal fa-file-export" => "Light File Export", 
        "fal fa-file-image" => "Light File Image", 
        "fal fa-file-import" => "Light File Import", 
        "fal fa-file-invoice" => "Light File Invoice", 
        "fal fa-file-invoice-dollar" => "Light File Invoice Dollar", 
        "fal fa-file-medical" => "Light File Medical", 
        "fal fa-file-medical-alt" => "Light File Medical Alt", 
        "fal fa-file-minus" => "Light File Minus", 
        "fal fa-file-pdf" => "Light File Pdf", 
        "fal fa-file-plus" => "Light File Plus", 
        "fal fa-file-powerpoint" => "Light File Powerpoint", 
        "fal fa-file-prescription" => "Light File Prescription", 
        "fal fa-file-signature" => "Light File Signature", 
        "fal fa-file-spreadsheet" => "Light File Spreadsheet", 
        "fal fa-file-times" => "Light File Times", 
        "fal fa-file-upload" => "Light File Upload", 
        "fal fa-file-user" => "Light File User", 
        "fal fa-file-video" => "Light File Video", 
        "fal fa-file-word" => "Light File Word", 
        "fal fa-files-medical" => "Light Files Medical", 
        "fal fa-fill" => "Light Fill", 
        "fal fa-fill-drip" => "Light Fill Drip", 
        "fal fa-film" => "Light Film", 
        "fal fa-film-alt" => "Light Film Alt", 
        "fal fa-filter" => "Light Filter", 
        "fal fa-fingerprint" => "Light Fingerprint", 
        "fal fa-fire" => "Light Fire", 
        "fal fa-fire-alt" => "Light Fire Alt", 
        "fal fa-fire-extinguisher" => "Light Fire Extinguisher", 
        "fal fa-fire-smoke" => "Light Fire Smoke", 
        "fal fa-fireplace" => "Light Fireplace", 
        "fal fa-first-aid" => "Light First Aid", 
        "fal fa-fish" => "Light Fish", 
        "fal fa-fish-cooked" => "Light Fish Cooked", 
        "fal fa-fist-raised" => "Light Fist Raised", 
        "fal fa-flag" => "Light Flag", 
        "fal fa-flag-alt" => "Light Flag Alt", 
        "fal fa-flag-checkered" => "Light Flag Checkered", 
        "fal fa-flag-usa" => "Light Flag Usa", 
        "fal fa-flame" => "Light Flame", 
        "fal fa-flask" => "Light Flask", 
        "fal fa-flask-poison" => "Light Flask Poison", 
        "fal fa-flask-potion" => "Light Flask Potion", 
        "fal fa-flower" => "Light Flower", 
        "fal fa-flower-daffodil" => "Light Flower Daffodil", 
        "fal fa-flower-tulip" => "Light Flower Tulip", 
        "fal fa-flushed" => "Light Flushed", 
        "fal fa-fog" => "Light Fog", 
        "fal fa-folder" => "Light Folder", 
        "fal fa-folder-minus" => "Light Folder Minus", 
        "fal fa-folder-open" => "Light Folder Open", 
        "fal fa-folder-plus" => "Light Folder Plus", 
        "fal fa-folder-times" => "Light Folder Times", 
        "fal fa-folder-tree" => "Light Folder Tree", 
        "fal fa-folders" => "Light Folders", 
        "fal fa-font" => "Light Font", 
        "fal fa-football-ball" => "Light Football Ball", 
        "fal fa-football-helmet" => "Light Football Helmet", 
        "fal fa-forklift" => "Light Forklift", 
        "fal fa-forward" => "Light Forward", 
        "fal fa-fragile" => "Light Fragile", 
        "fal fa-french-fries" => "Light French Fries", 
        "fal fa-frog" => "Light Frog", 
        "fal fa-frosty-head" => "Light Frosty Head", 
        "fal fa-frown" => "Light Frown", 
        "fal fa-frown-open" => "Light Frown Open", 
        "fal fa-function" => "Light Function", 
        "fal fa-funnel-dollar" => "Light Funnel Dollar", 
        "fal fa-futbol" => "Light Futbol", 
        "fal fa-gamepad" => "Light Gamepad", 
        "fal fa-gas-pump" => "Light Gas Pump", 
        "fal fa-gas-pump-slash" => "Light Gas Pump Slash", 
        "fal fa-gavel" => "Light Gavel", 
        "fal fa-gem" => "Light Gem", 
        "fal fa-genderless" => "Light Genderless", 
        "fal fa-ghost" => "Light Ghost", 
        "fal fa-gift" => "Light Gift", 
        "fal fa-gift-card" => "Light Gift Card", 
        "fal fa-gifts" => "Light Gifts", 
        "fal fa-gingerbread-man" => "Light Gingerbread Man", 
        "fal fa-glass" => "Light Glass", 
        "fal fa-glass-champagne" => "Light Glass Champagne", 
        "fal fa-glass-cheers" => "Light Glass Cheers", 
        "fal fa-glass-martini" => "Light Glass Martini", 
        "fal fa-glass-martini-alt" => "Light Glass Martini Alt", 
        "fal fa-glass-whiskey" => "Light Glass Whiskey", 
        "fal fa-glass-whiskey-rocks" => "Light Glass Whiskey Rocks", 
        "fal fa-glasses" => "Light Glasses", 
        "fal fa-glasses-alt" => "Light Glasses Alt", 
        "fal fa-globe" => "Light Globe", 
        "fal fa-globe-africa" => "Light Globe Africa", 
        "fal fa-globe-americas" => "Light Globe Americas", 
        "fal fa-globe-asia" => "Light Globe Asia", 
        "fal fa-globe-europe" => "Light Globe Europe", 
        "fal fa-globe-snow" => "Light Globe Snow", 
        "fal fa-globe-stand" => "Light Globe Stand", 
        "fal fa-golf-ball" => "Light Golf Ball", 
        "fal fa-golf-club" => "Light Golf Club", 
        "fal fa-gopuram" => "Light Gopuram", 
        "fal fa-graduation-cap" => "Light Graduation Cap", 
        "fal fa-greater-than" => "Light Greater Than", 
        "fal fa-greater-than-equal" => "Light Greater Than Equal", 
        "fal fa-grimace" => "Light Grimace", 
        "fal fa-grin" => "Light Grin", 
        "fal fa-grin-alt" => "Light Grin Alt", 
        "fal fa-grin-beam" => "Light Grin Beam", 
        "fal fa-grin-beam-sweat" => "Light Grin Beam Sweat", 
        "fal fa-grin-hearts" => "Light Grin Hearts", 
        "fal fa-grin-squint" => "Light Grin Squint", 
        "fal fa-grin-squint-tears" => "Light Grin Squint Tears", 
        "fal fa-grin-stars" => "Light Grin Stars", 
        "fal fa-grin-tears" => "Light Grin Tears", 
        "fal fa-grin-tongue" => "Light Grin Tongue", 
        "fal fa-grin-tongue-squint" => "Light Grin Tongue Squint", 
        "fal fa-grin-tongue-wink" => "Light Grin Tongue Wink", 
        "fal fa-grin-wink" => "Light Grin Wink", 
        "fal fa-grip-horizontal" => "Light Grip Horizontal", 
        "fal fa-grip-lines" => "Light Grip Lines", 
        "fal fa-grip-lines-vertical" => "Light Grip Lines Vertical", 
        "fal fa-grip-vertical" => "Light Grip Vertical", 
        "fal fa-guitar" => "Light Guitar", 
        "fal fa-h-square" => "Light H Square", 
        "fal fa-h1" => "Light H1", 
        "fal fa-h2" => "Light H2", 
        "fal fa-h3" => "Light H3", 
        "fal fa-hamburger" => "Light Hamburger", 
        "fal fa-hammer" => "Light Hammer", 
        "fal fa-hammer-war" => "Light Hammer War", 
        "fal fa-hamsa" => "Light Hamsa", 
        "fal fa-hand-heart" => "Light Hand Heart", 
        "fal fa-hand-holding" => "Light Hand Holding", 
        "fal fa-hand-holding-box" => "Light Hand Holding Box", 
        "fal fa-hand-holding-heart" => "Light Hand Holding Heart", 
        "fal fa-hand-holding-magic" => "Light Hand Holding Magic", 
        "fal fa-hand-holding-seedling" => "Light Hand Holding Seedling", 
        "fal fa-hand-holding-usd" => "Light Hand Holding Usd", 
        "fal fa-hand-holding-water" => "Light Hand Holding Water", 
        "fal fa-hand-lizard" => "Light Hand Lizard", 
        "fal fa-hand-middle-finger" => "Light Hand Middle Finger", 
        "fal fa-hand-paper" => "Light Hand Paper", 
        "fal fa-hand-peace" => "Light Hand Peace", 
        "fal fa-hand-point-down" => "Light Hand Point Down", 
        "fal fa-hand-point-left" => "Light Hand Point Left", 
        "fal fa-hand-point-right" => "Light Hand Point Right", 
        "fal fa-hand-point-up" => "Light Hand Point Up", 
        "fal fa-hand-pointer" => "Light Hand Pointer", 
        "fal fa-hand-receiving" => "Light Hand Receiving", 
        "fal fa-hand-rock" => "Light Hand Rock", 
        "fal fa-hand-scissors" => "Light Hand Scissors", 
        "fal fa-hand-spock" => "Light Hand Spock", 
        "fal fa-hands" => "Light Hands", 
        "fal fa-hands-heart" => "Light Hands Heart", 
        "fal fa-hands-helping" => "Light Hands Helping", 
        "fal fa-hands-usd" => "Light Hands Usd", 
        "fal fa-handshake" => "Light Handshake", 
        "fal fa-handshake-alt" => "Light Handshake Alt", 
        "fal fa-hanukiah" => "Light Hanukiah", 
        "fal fa-hard-hat" => "Light Hard Hat", 
        "fal fa-hashtag" => "Light Hashtag", 
        "fal fa-hat-santa" => "Light Hat Santa", 
        "fal fa-hat-winter" => "Light Hat Winter", 
        "fal fa-hat-witch" => "Light Hat Witch", 
        "fal fa-hat-wizard" => "Light Hat Wizard", 
        "fal fa-haykal" => "Light Haykal", 
        "fal fa-hdd" => "Light Hdd", 
        "fal fa-head-side" => "Light Head Side", 
        "fal fa-head-side-brain" => "Light Head Side Brain", 
        "fal fa-head-side-medical" => "Light Head Side Medical", 
        "fal fa-head-vr" => "Light Head Vr", 
        "fal fa-heading" => "Light Heading", 
        "fal fa-headphones" => "Light Headphones", 
        "fal fa-headphones-alt" => "Light Headphones Alt", 
        "fal fa-headset" => "Light Headset", 
        "fal fa-heart" => "Light Heart", 
        "fal fa-heart-broken" => "Light Heart Broken", 
        "fal fa-heart-circle" => "Light Heart Circle", 
        "fal fa-heart-rate" => "Light Heart Rate", 
        "fal fa-heart-square" => "Light Heart Square", 
        "fal fa-heartbeat" => "Light Heartbeat", 
        "fal fa-helicopter" => "Light Helicopter", 
        "fal fa-helmet-battle" => "Light Helmet Battle", 
        "fal fa-hexagon" => "Light Hexagon", 
        "fal fa-highlighter" => "Light Highlighter", 
        "fal fa-hiking" => "Light Hiking", 
        "fal fa-hippo" => "Light Hippo", 
        "fal fa-history" => "Light History", 
        "fal fa-hockey-mask" => "Light Hockey Mask", 
        "fal fa-hockey-puck" => "Light Hockey Puck", 
        "fal fa-hockey-sticks" => "Light Hockey Sticks", 
        "fal fa-holly-berry" => "Light Holly Berry", 
        "fal fa-home" => "Light Home", 
        "fal fa-home-alt" => "Light Home Alt", 
        "fal fa-home-heart" => "Light Home Heart", 
        "fal fa-home-lg" => "Light Home Lg", 
        "fal fa-home-lg-alt" => "Light Home Lg Alt", 
        "fal fa-hood-cloak" => "Light Hood Cloak", 
        "fal fa-horse" => "Light Horse", 
        "fal fa-horse-head" => "Light Horse Head", 
        "fal fa-hospital" => "Light Hospital", 
        "fal fa-hospital-alt" => "Light Hospital Alt", 
        "fal fa-hospital-symbol" => "Light Hospital Symbol", 
        "fal fa-hospital-user" => "Light Hospital User", 
        "fal fa-hospitals" => "Light Hospitals", 
        "fal fa-hot-tub" => "Light Hot Tub", 
        "fal fa-hotdog" => "Light Hotdog", 
        "fal fa-hotel" => "Light Hotel", 
        "fal fa-hourglass" => "Light Hourglass", 
        "fal fa-hourglass-end" => "Light Hourglass End", 
        "fal fa-hourglass-half" => "Light Hourglass Half", 
        "fal fa-hourglass-start" => "Light Hourglass Start", 
        "fal fa-house-damage" => "Light House Damage", 
        "fal fa-house-flood" => "Light House Flood", 
        "fal fa-hryvnia" => "Light Hryvnia", 
        "fal fa-humidity" => "Light Humidity", 
        "fal fa-hurricane" => "Light Hurricane", 
        "fal fa-i-cursor" => "Light I Cursor", 
        "fal fa-ice-cream" => "Light Ice Cream", 
        "fal fa-ice-skate" => "Light Ice Skate", 
        "fal fa-icicles" => "Light Icicles", 
        "fal fa-id-badge" => "Light Id Badge", 
        "fal fa-id-card" => "Light Id Card", 
        "fal fa-id-card-alt" => "Light Id Card Alt", 
        "fal fa-igloo" => "Light Igloo", 
        "fal fa-image" => "Light Image", 
        "fal fa-images" => "Light Images", 
        "fal fa-inbox" => "Light Inbox", 
        "fal fa-inbox-in" => "Light Inbox In", 
        "fal fa-inbox-out" => "Light Inbox Out", 
        "fal fa-indent" => "Light Indent", 
        "fal fa-industry" => "Light Industry", 
        "fal fa-industry-alt" => "Light Industry Alt", 
        "fal fa-infinity" => "Light Infinity", 
        "fal fa-info" => "Light Info", 
        "fal fa-info-circle" => "Light Info Circle", 
        "fal fa-info-square" => "Light Info Square", 
        "fal fa-inhaler" => "Light Inhaler", 
        "fal fa-integral" => "Light Integral", 
        "fal fa-intersection" => "Light Intersection", 
        "fal fa-inventory" => "Light Inventory", 
        "fal fa-island-tropical" => "Light Island Tropical", 
        "fal fa-italic" => "Light Italic", 
        "fal fa-jack-o-lantern" => "Light Jack O Lantern", 
        "fal fa-jedi" => "Light Jedi", 
        "fal fa-joint" => "Light Joint", 
        "fal fa-journal-whills" => "Light Journal Whills", 
        "fal fa-kaaba" => "Light Kaaba", 
        "fal fa-key" => "Light Key", 
        "fal fa-key-skeleton" => "Light Key Skeleton", 
        "fal fa-keyboard" => "Light Keyboard", 
        "fal fa-keynote" => "Light Keynote", 
        "fal fa-khanda" => "Light Khanda", 
        "fal fa-kidneys" => "Light Kidneys", 
        "fal fa-kiss" => "Light Kiss", 
        "fal fa-kiss-beam" => "Light Kiss Beam", 
        "fal fa-kiss-wink-heart" => "Light Kiss Wink Heart", 
        "fal fa-kite" => "Light Kite", 
        "fal fa-kiwi-bird" => "Light Kiwi Bird", 
        "fal fa-knife-kitchen" => "Light Knife Kitchen", 
        "fal fa-lambda" => "Light Lambda", 
        "fal fa-lamp" => "Light Lamp", 
        "fal fa-landmark" => "Light Landmark", 
        "fal fa-landmark-alt" => "Light Landmark Alt", 
        "fal fa-language" => "Light Language", 
        "fal fa-laptop" => "Light Laptop", 
        "fal fa-laptop-code" => "Light Laptop Code", 
        "fal fa-laptop-medical" => "Light Laptop Medical", 
        "fal fa-laugh" => "Light Laugh", 
        "fal fa-laugh-beam" => "Light Laugh Beam", 
        "fal fa-laugh-squint" => "Light Laugh Squint", 
        "fal fa-laugh-wink" => "Light Laugh Wink", 
        "fal fa-layer-group" => "Light Layer Group", 
        "fal fa-layer-minus" => "Light Layer Minus", 
        "fal fa-layer-plus" => "Light Layer Plus", 
        "fal fa-leaf" => "Light Leaf", 
        "fal fa-leaf-heart" => "Light Leaf Heart", 
        "fal fa-leaf-maple" => "Light Leaf Maple", 
        "fal fa-leaf-oak" => "Light Leaf Oak", 
        "fal fa-lemon" => "Light Lemon", 
        "fal fa-less-than" => "Light Less Than", 
        "fal fa-less-than-equal" => "Light Less Than Equal", 
        "fal fa-level-down" => "Light Level Down", 
        "fal fa-level-down-alt" => "Light Level Down Alt", 
        "fal fa-level-up" => "Light Level Up", 
        "fal fa-level-up-alt" => "Light Level Up Alt", 
        "fal fa-life-ring" => "Light Life Ring", 
        "fal fa-lightbulb" => "Light Lightbulb", 
        "fal fa-lightbulb-dollar" => "Light Lightbulb Dollar", 
        "fal fa-lightbulb-exclamation" => "Light Lightbulb Exclamation", 
        "fal fa-lightbulb-on" => "Light Lightbulb On", 
        "fal fa-lightbulb-slash" => "Light Lightbulb Slash", 
        "fal fa-lights-holiday" => "Light Lights Holiday", 
        "fal fa-link" => "Light Link", 
        "fal fa-lips" => "Light Lips", 
        "fal fa-lira-sign" => "Light Lira Sign", 
        "fal fa-list" => "Light List", 
        "fal fa-list-alt" => "Light List Alt", 
        "fal fa-list-ol" => "Light List Ol", 
        "fal fa-list-ul" => "Light List Ul", 
        "fal fa-location" => "Light Location", 
        "fal fa-location-arrow" => "Light Location Arrow", 
        "fal fa-location-circle" => "Light Location Circle", 
        "fal fa-location-slash" => "Light Location Slash", 
        "fal fa-lock" => "Light Lock", 
        "fal fa-lock-alt" => "Light Lock Alt", 
        "fal fa-lock-open" => "Light Lock Open", 
        "fal fa-lock-open-alt" => "Light Lock Open Alt", 
        "fal fa-long-arrow-alt-down" => "Light Long Arrow Alt Down", 
        "fal fa-long-arrow-alt-left" => "Light Long Arrow Alt Left", 
        "fal fa-long-arrow-alt-right" => "Light Long Arrow Alt Right", 
        "fal fa-long-arrow-alt-up" => "Light Long Arrow Alt Up", 
        "fal fa-long-arrow-down" => "Light Long Arrow Down", 
        "fal fa-long-arrow-left" => "Light Long Arrow Left", 
        "fal fa-long-arrow-right" => "Light Long Arrow Right", 
        "fal fa-long-arrow-up" => "Light Long Arrow Up", 
        "fal fa-loveseat" => "Light Loveseat", 
        "fal fa-low-vision" => "Light Low Vision", 
        "fal fa-luchador" => "Light Luchador", 
        "fal fa-luggage-cart" => "Light Luggage Cart", 
        "fal fa-lungs" => "Light Lungs", 
        "fal fa-mace" => "Light Mace", 
        "fal fa-magic" => "Light Magic", 
        "fal fa-magnet" => "Light Magnet", 
        "fal fa-mail-bulk" => "Light Mail Bulk", 
        "fal fa-mailbox" => "Light Mailbox", 
        "fal fa-male" => "Light Male", 
        "fal fa-mandolin" => "Light Mandolin", 
        "fal fa-map" => "Light Map", 
        "fal fa-map-marked" => "Light Map Marked", 
        "fal fa-map-marked-alt" => "Light Map Marked Alt", 
        "fal fa-map-marker" => "Light Map Marker", 
        "fal fa-map-marker-alt" => "Light Map Marker Alt", 
        "fal fa-map-marker-alt-slash" => "Light Map Marker Alt Slash", 
        "fal fa-map-marker-check" => "Light Map Marker Check", 
        "fal fa-map-marker-edit" => "Light Map Marker Edit", 
        "fal fa-map-marker-exclamation" => "Light Map Marker Exclamation", 
        "fal fa-map-marker-minus" => "Light Map Marker Minus", 
        "fal fa-map-marker-plus" => "Light Map Marker Plus", 
        "fal fa-map-marker-question" => "Light Map Marker Question", 
        "fal fa-map-marker-slash" => "Light Map Marker Slash", 
        "fal fa-map-marker-smile" => "Light Map Marker Smile", 
        "fal fa-map-marker-times" => "Light Map Marker Times", 
        "fal fa-map-pin" => "Light Map Pin", 
        "fal fa-map-signs" => "Light Map Signs", 
        "fal fa-marker" => "Light Marker", 
        "fal fa-mars" => "Light Mars", 
        "fal fa-mars-double" => "Light Mars Double", 
        "fal fa-mars-stroke" => "Light Mars Stroke", 
        "fal fa-mars-stroke-h" => "Light Mars Stroke H", 
        "fal fa-mars-stroke-v" => "Light Mars Stroke V", 
        "fal fa-mask" => "Light Mask", 
        "fal fa-meat" => "Light Meat", 
        "fal fa-medal" => "Light Medal", 
        "fal fa-medkit" => "Light Medkit", 
        "fal fa-megaphone" => "Light Megaphone", 
        "fal fa-meh" => "Light Meh", 
        "fal fa-meh-blank" => "Light Meh Blank", 
        "fal fa-meh-rolling-eyes" => "Light Meh Rolling Eyes", 
        "fal fa-memory" => "Light Memory", 
        "fal fa-menorah" => "Light Menorah", 
        "fal fa-mercury" => "Light Mercury", 
        "fal fa-meteor" => "Light Meteor", 
        "fal fa-microchip" => "Light Microchip", 
        "fal fa-microphone" => "Light Microphone", 
        "fal fa-microphone-alt" => "Light Microphone Alt", 
        "fal fa-microphone-alt-slash" => "Light Microphone Alt Slash", 
        "fal fa-microphone-slash" => "Light Microphone Slash", 
        "fal fa-microscope" => "Light Microscope", 
        "fal fa-mind-share" => "Light Mind Share", 
        "fal fa-minus" => "Light Minus", 
        "fal fa-minus-circle" => "Light Minus Circle", 
        "fal fa-minus-hexagon" => "Light Minus Hexagon", 
        "fal fa-minus-octagon" => "Light Minus Octagon", 
        "fal fa-minus-square" => "Light Minus Square", 
        "fal fa-mistletoe" => "Light Mistletoe", 
        "fal fa-mitten" => "Light Mitten", 
        "fal fa-mobile" => "Light Mobile", 
        "fal fa-mobile-alt" => "Light Mobile Alt", 
        "fal fa-mobile-android" => "Light Mobile Android", 
        "fal fa-mobile-android-alt" => "Light Mobile Android Alt", 
        "fal fa-money-bill" => "Light Money Bill", 
        "fal fa-money-bill-alt" => "Light Money Bill Alt", 
        "fal fa-money-bill-wave" => "Light Money Bill Wave", 
        "fal fa-money-bill-wave-alt" => "Light Money Bill Wave Alt", 
        "fal fa-money-check" => "Light Money Check", 
        "fal fa-money-check-alt" => "Light Money Check Alt", 
        "fal fa-monitor-heart-rate" => "Light Monitor Heart Rate", 
        "fal fa-monkey" => "Light Monkey", 
        "fal fa-monument" => "Light Monument", 
        "fal fa-moon" => "Light Moon", 
        "fal fa-moon-cloud" => "Light Moon Cloud", 
        "fal fa-moon-stars" => "Light Moon Stars", 
        "fal fa-mortar-pestle" => "Light Mortar Pestle", 
        "fal fa-mosque" => "Light Mosque", 
        "fal fa-motorcycle" => "Light Motorcycle", 
        "fal fa-mountain" => "Light Mountain", 
        "fal fa-mountains" => "Light Mountains", 
        "fal fa-mouse-pointer" => "Light Mouse Pointer", 
        "fal fa-mug-hot" => "Light Mug Hot", 
        "fal fa-mug-marshmallows" => "Light Mug Marshmallows", 
        "fal fa-music" => "Light Music", 
        "fal fa-narwhal" => "Light Narwhal", 
        "fal fa-network-wired" => "Light Network Wired", 
        "fal fa-neuter" => "Light Neuter", 
        "fal fa-newspaper" => "Light Newspaper", 
        "fal fa-not-equal" => "Light Not Equal", 
        "fal fa-notes-medical" => "Light Notes Medical", 
        "fal fa-object-group" => "Light Object Group", 
        "fal fa-object-ungroup" => "Light Object Ungroup", 
        "fal fa-octagon" => "Light Octagon", 
        "fal fa-oil-can" => "Light Oil Can", 
        "fal fa-oil-temp" => "Light Oil Temp", 
        "fal fa-om" => "Light Om", 
        "fal fa-omega" => "Light Omega", 
        "fal fa-ornament" => "Light Ornament", 
        "fal fa-otter" => "Light Otter", 
        "fal fa-outdent" => "Light Outdent", 
        "fal fa-pager" => "Light Pager", 
        "fal fa-paint-brush" => "Light Paint Brush", 
        "fal fa-paint-brush-alt" => "Light Paint Brush Alt", 
        "fal fa-paint-roller" => "Light Paint Roller", 
        "fal fa-palette" => "Light Palette", 
        "fal fa-pallet" => "Light Pallet", 
        "fal fa-pallet-alt" => "Light Pallet Alt", 
        "fal fa-paper-plane" => "Light Paper Plane", 
        "fal fa-paperclip" => "Light Paperclip", 
        "fal fa-parachute-box" => "Light Parachute Box", 
        "fal fa-paragraph" => "Light Paragraph", 
        "fal fa-parking" => "Light Parking", 
        "fal fa-parking-circle" => "Light Parking Circle", 
        "fal fa-parking-circle-slash" => "Light Parking Circle Slash", 
        "fal fa-parking-slash" => "Light Parking Slash", 
        "fal fa-passport" => "Light Passport", 
        "fal fa-pastafarianism" => "Light Pastafarianism", 
        "fal fa-paste" => "Light Paste", 
        "fal fa-pause" => "Light Pause", 
        "fal fa-pause-circle" => "Light Pause Circle", 
        "fal fa-paw" => "Light Paw", 
        "fal fa-paw-alt" => "Light Paw Alt", 
        "fal fa-paw-claws" => "Light Paw Claws", 
        "fal fa-peace" => "Light Peace", 
        "fal fa-pegasus" => "Light Pegasus", 
        "fal fa-pen" => "Light Pen", 
        "fal fa-pen-alt" => "Light Pen Alt", 
        "fal fa-pen-fancy" => "Light Pen Fancy", 
        "fal fa-pen-nib" => "Light Pen Nib", 
        "fal fa-pen-square" => "Light Pen Square", 
        "fal fa-pencil" => "Light Pencil", 
        "fal fa-pencil-alt" => "Light Pencil Alt", 
        "fal fa-pencil-paintbrush" => "Light Pencil Paintbrush", 
        "fal fa-pencil-ruler" => "Light Pencil Ruler", 
        "fal fa-pennant" => "Light Pennant", 
        "fal fa-people-carry" => "Light People Carry", 
        "fal fa-pepper-hot" => "Light Pepper Hot", 
        "fal fa-percent" => "Light Percent", 
        "fal fa-percentage" => "Light Percentage", 
        "fal fa-person-booth" => "Light Person Booth", 
        "fal fa-person-carry" => "Light Person Carry", 
        "fal fa-person-dolly" => "Light Person Dolly", 
        "fal fa-person-dolly-empty" => "Light Person Dolly Empty", 
        "fal fa-person-sign" => "Light Person Sign", 
        "fal fa-phone" => "Light Phone", 
        "fal fa-phone-office" => "Light Phone Office", 
        "fal fa-phone-plus" => "Light Phone Plus", 
        "fal fa-phone-slash" => "Light Phone Slash", 
        "fal fa-phone-square" => "Light Phone Square", 
        "fal fa-phone-volume" => "Light Phone Volume", 
        "fal fa-pi" => "Light Pi", 
        "fal fa-pie" => "Light Pie", 
        "fal fa-pig" => "Light Pig", 
        "fal fa-piggy-bank" => "Light Piggy Bank", 
        "fal fa-pills" => "Light Pills", 
        "fal fa-pizza" => "Light Pizza", 
        "fal fa-pizza-slice" => "Light Pizza Slice", 
        "fal fa-place-of-worship" => "Light Place Of Worship", 
        "fal fa-plane" => "Light Plane", 
        "fal fa-plane-alt" => "Light Plane Alt", 
        "fal fa-plane-arrival" => "Light Plane Arrival", 
        "fal fa-plane-departure" => "Light Plane Departure", 
        "fal fa-play" => "Light Play", 
        "fal fa-play-circle" => "Light Play Circle", 
        "fal fa-plug" => "Light Plug", 
        "fal fa-plus" => "Light Plus", 
        "fal fa-plus-circle" => "Light Plus Circle", 
        "fal fa-plus-hexagon" => "Light Plus Hexagon", 
        "fal fa-plus-octagon" => "Light Plus Octagon", 
        "fal fa-plus-square" => "Light Plus Square", 
        "fal fa-podcast" => "Light Podcast", 
        "fal fa-podium" => "Light Podium", 
        "fal fa-podium-star" => "Light Podium Star", 
        "fal fa-poll" => "Light Poll", 
        "fal fa-poll-h" => "Light Poll H", 
        "fal fa-poll-people" => "Light Poll People", 
        "fal fa-poo" => "Light Poo", 
        "fal fa-poo-storm" => "Light Poo Storm", 
        "fal fa-poop" => "Light Poop", 
        "fal fa-popcorn" => "Light Popcorn", 
        "fal fa-portrait" => "Light Portrait", 
        "fal fa-pound-sign" => "Light Pound Sign", 
        "fal fa-power-off" => "Light Power Off", 
        "fal fa-pray" => "Light Pray", 
        "fal fa-praying-hands" => "Light Praying Hands", 
        "fal fa-prescription" => "Light Prescription", 
        "fal fa-prescription-bottle" => "Light Prescription Bottle", 
        "fal fa-prescription-bottle-alt" => "Light Prescription Bottle Alt", 
        "fal fa-presentation" => "Light Presentation", 
        "fal fa-print" => "Light Print", 
        "fal fa-print-search" => "Light Print Search", 
        "fal fa-print-slash" => "Light Print Slash", 
        "fal fa-procedures" => "Light Procedures", 
        "fal fa-project-diagram" => "Light Project Diagram", 
        "fal fa-pumpkin" => "Light Pumpkin", 
        "fal fa-puzzle-piece" => "Light Puzzle Piece", 
        "fal fa-qrcode" => "Light Qrcode", 
        "fal fa-question" => "Light Question", 
        "fal fa-question-circle" => "Light Question Circle", 
        "fal fa-question-square" => "Light Question Square", 
        "fal fa-quidditch" => "Light Quidditch", 
        "fal fa-quote-left" => "Light Quote Left", 
        "fal fa-quote-right" => "Light Quote Right", 
        "fal fa-quran" => "Light Quran", 
        "fal fa-rabbit" => "Light Rabbit", 
        "fal fa-rabbit-fast" => "Light Rabbit Fast", 
        "fal fa-racquet" => "Light Racquet", 
        "fal fa-radiation" => "Light Radiation", 
        "fal fa-radiation-alt" => "Light Radiation Alt", 
        "fal fa-rainbow" => "Light Rainbow", 
        "fal fa-raindrops" => "Light Raindrops", 
        "fal fa-ram" => "Light Ram", 
        "fal fa-ramp-loading" => "Light Ramp Loading", 
        "fal fa-random" => "Light Random", 
        "fal fa-receipt" => "Light Receipt", 
        "fal fa-rectangle-landscape" => "Light Rectangle Landscape", 
        "fal fa-rectangle-portrait" => "Light Rectangle Portrait", 
        "fal fa-rectangle-wide" => "Light Rectangle Wide", 
        "fal fa-recycle" => "Light Recycle", 
        "fal fa-redo" => "Light Redo", 
        "fal fa-redo-alt" => "Light Redo Alt", 
        "fal fa-registered" => "Light Registered", 
        "fal fa-repeat" => "Light Repeat", 
        "fal fa-repeat-1" => "Light Repeat 1", 
        "fal fa-repeat-1-alt" => "Light Repeat 1 Alt", 
        "fal fa-repeat-alt" => "Light Repeat Alt", 
        "fal fa-reply" => "Light Reply", 
        "fal fa-reply-all" => "Light Reply All", 
        "fal fa-republican" => "Light Republican", 
        "fal fa-restroom" => "Light Restroom", 
        "fal fa-retweet" => "Light Retweet", 
        "fal fa-retweet-alt" => "Light Retweet Alt", 
        "fal fa-ribbon" => "Light Ribbon", 
        "fal fa-ring" => "Light Ring", 
        "fal fa-rings-wedding" => "Light Rings Wedding", 
        "fal fa-road" => "Light Road", 
        "fal fa-robot" => "Light Robot", 
        "fal fa-rocket" => "Light Rocket", 
        "fal fa-route" => "Light Route", 
        "fal fa-route-highway" => "Light Route Highway", 
        "fal fa-route-interstate" => "Light Route Interstate", 
        "fal fa-rss" => "Light Rss", 
        "fal fa-rss-square" => "Light Rss Square", 
        "fal fa-ruble-sign" => "Light Ruble Sign", 
        "fal fa-ruler" => "Light Ruler", 
        "fal fa-ruler-combined" => "Light Ruler Combined", 
        "fal fa-ruler-horizontal" => "Light Ruler Horizontal", 
        "fal fa-ruler-triangle" => "Light Ruler Triangle", 
        "fal fa-ruler-vertical" => "Light Ruler Vertical", 
        "fal fa-running" => "Light Running", 
        "fal fa-rupee-sign" => "Light Rupee Sign", 
        "fal fa-rv" => "Light Rv", 
        "fal fa-sack" => "Light Sack", 
        "fal fa-sack-dollar" => "Light Sack Dollar", 
        "fal fa-sad-cry" => "Light Sad Cry", 
        "fal fa-sad-tear" => "Light Sad Tear", 
        "fal fa-salad" => "Light Salad", 
        "fal fa-sandwich" => "Light Sandwich", 
        "fal fa-satellite" => "Light Satellite", 
        "fal fa-satellite-dish" => "Light Satellite Dish", 
        "fal fa-sausage" => "Light Sausage", 
        "fal fa-save" => "Light Save", 
        "fal fa-scalpel" => "Light Scalpel", 
        "fal fa-scalpel-path" => "Light Scalpel Path", 
        "fal fa-scanner" => "Light Scanner", 
        "fal fa-scanner-keyboard" => "Light Scanner Keyboard", 
        "fal fa-scanner-touchscreen" => "Light Scanner Touchscreen", 
        "fal fa-scarecrow" => "Light Scarecrow", 
        "fal fa-scarf" => "Light Scarf", 
        "fal fa-school" => "Light School", 
        "fal fa-screwdriver" => "Light Screwdriver", 
        "fal fa-scroll" => "Light Scroll", 
        "fal fa-scroll-old" => "Light Scroll Old", 
        "fal fa-scrubber" => "Light Scrubber", 
        "fal fa-scythe" => "Light Scythe", 
        "fal fa-sd-card" => "Light Sd Card", 
        "fal fa-search" => "Light Search", 
        "fal fa-search-dollar" => "Light Search Dollar", 
        "fal fa-search-location" => "Light Search Location", 
        "fal fa-search-minus" => "Light Search Minus", 
        "fal fa-search-plus" => "Light Search Plus", 
        "fal fa-seedling" => "Light Seedling", 
        "fal fa-server" => "Light Server", 
        "fal fa-shapes" => "Light Shapes", 
        "fal fa-share" => "Light Share", 
        "fal fa-share-all" => "Light Share All", 
        "fal fa-share-alt" => "Light Share Alt", 
        "fal fa-share-alt-square" => "Light Share Alt Square", 
        "fal fa-share-square" => "Light Share Square", 
        "fal fa-sheep" => "Light Sheep", 
        "fal fa-shekel-sign" => "Light Shekel Sign", 
        "fal fa-shield" => "Light Shield", 
        "fal fa-shield-alt" => "Light Shield Alt", 
        "fal fa-shield-check" => "Light Shield Check", 
        "fal fa-shield-cross" => "Light Shield Cross", 
        "fal fa-ship" => "Light Ship", 
        "fal fa-shipping-fast" => "Light Shipping Fast", 
        "fal fa-shipping-timed" => "Light Shipping Timed", 
        "fal fa-shish-kebab" => "Light Shish Kebab", 
        "fal fa-shoe-prints" => "Light Shoe Prints", 
        "fal fa-shopping-bag" => "Light Shopping Bag", 
        "fal fa-shopping-basket" => "Light Shopping Basket", 
        "fal fa-shopping-cart" => "Light Shopping Cart", 
        "fal fa-shovel" => "Light Shovel", 
        "fal fa-shovel-snow" => "Light Shovel Snow", 
        "fal fa-shower" => "Light Shower", 
        "fal fa-shredder" => "Light Shredder", 
        "fal fa-shuttle-van" => "Light Shuttle Van", 
        "fal fa-shuttlecock" => "Light Shuttlecock", 
        "fal fa-sickle" => "Light Sickle", 
        "fal fa-sigma" => "Light Sigma", 
        "fal fa-sign" => "Light Sign", 
        "fal fa-sign-in" => "Light Sign In", 
        "fal fa-sign-in-alt" => "Light Sign In Alt", 
        "fal fa-sign-language" => "Light Sign Language", 
        "fal fa-sign-out" => "Light Sign Out", 
        "fal fa-sign-out-alt" => "Light Sign Out Alt", 
        "fal fa-signal" => "Light Signal", 
        "fal fa-signal-1" => "Light Signal 1", 
        "fal fa-signal-2" => "Light Signal 2", 
        "fal fa-signal-3" => "Light Signal 3", 
        "fal fa-signal-4" => "Light Signal 4", 
        "fal fa-signal-alt" => "Light Signal Alt", 
        "fal fa-signal-alt-1" => "Light Signal Alt 1", 
        "fal fa-signal-alt-2" => "Light Signal Alt 2", 
        "fal fa-signal-alt-3" => "Light Signal Alt 3", 
        "fal fa-signal-alt-slash" => "Light Signal Alt Slash", 
        "fal fa-signal-slash" => "Light Signal Slash", 
        "fal fa-signature" => "Light Signature", 
        "fal fa-sim-card" => "Light Sim Card", 
        "fal fa-sitemap" => "Light Sitemap", 
        "fal fa-skating" => "Light Skating", 
        "fal fa-skeleton" => "Light Skeleton", 
        "fal fa-ski-jump" => "Light Ski Jump", 
        "fal fa-ski-lift" => "Light Ski Lift", 
        "fal fa-skiing" => "Light Skiing", 
        "fal fa-skiing-nordic" => "Light Skiing Nordic", 
        "fal fa-skull" => "Light Skull", 
        "fal fa-skull-crossbones" => "Light Skull Crossbones", 
        "fal fa-slash" => "Light Slash", 
        "fal fa-sledding" => "Light Sledding", 
        "fal fa-sleigh" => "Light Sleigh", 
        "fal fa-sliders-h" => "Light Sliders H", 
        "fal fa-sliders-h-square" => "Light Sliders H Square", 
        "fal fa-sliders-v" => "Light Sliders V", 
        "fal fa-sliders-v-square" => "Light Sliders V Square", 
        "fal fa-smile" => "Light Smile", 
        "fal fa-smile-beam" => "Light Smile Beam", 
        "fal fa-smile-plus" => "Light Smile Plus", 
        "fal fa-smile-wink" => "Light Smile Wink", 
        "fal fa-smog" => "Light Smog", 
        "fal fa-smoke" => "Light Smoke", 
        "fal fa-smoking" => "Light Smoking", 
        "fal fa-smoking-ban" => "Light Smoking Ban", 
        "fal fa-sms" => "Light Sms", 
        "fal fa-snake" => "Light Snake", 
        "fal fa-snow-blowing" => "Light Snow Blowing", 
        "fal fa-snowboarding" => "Light Snowboarding", 
        "fal fa-snowflake" => "Light Snowflake", 
        "fal fa-snowflakes" => "Light Snowflakes", 
        "fal fa-snowman" => "Light Snowman", 
        "fal fa-snowmobile" => "Light Snowmobile", 
        "fal fa-snowplow" => "Light Snowplow", 
        "fal fa-socks" => "Light Socks", 
        "fal fa-solar-panel" => "Light Solar Panel", 
        "fal fa-sort" => "Light Sort", 
        "fal fa-sort-alpha-down" => "Light Sort Alpha Down", 
        "fal fa-sort-alpha-up" => "Light Sort Alpha Up", 
        "fal fa-sort-amount-down" => "Light Sort Amount Down", 
        "fal fa-sort-amount-up" => "Light Sort Amount Up", 
        "fal fa-sort-down" => "Light Sort Down", 
        "fal fa-sort-numeric-down" => "Light Sort Numeric Down", 
        "fal fa-sort-numeric-up" => "Light Sort Numeric Up", 
        "fal fa-sort-up" => "Light Sort Up", 
        "fal fa-soup" => "Light Soup", 
        "fal fa-spa" => "Light Spa", 
        "fal fa-space-shuttle" => "Light Space Shuttle", 
        "fal fa-spade" => "Light Spade", 
        "fal fa-spider" => "Light Spider", 
        "fal fa-spider-black-widow" => "Light Spider Black Widow", 
        "fal fa-spider-web" => "Light Spider Web", 
        "fal fa-spinner" => "Light Spinner", 
        "fal fa-spinner-third" => "Light Spinner Third", 
        "fal fa-splotch" => "Light Splotch", 
        "fal fa-spray-can" => "Light Spray Can", 
        "fal fa-square" => "Light Square", 
        "fal fa-square-full" => "Light Square Full", 
        "fal fa-square-root" => "Light Square Root", 
        "fal fa-square-root-alt" => "Light Square Root Alt", 
        "fal fa-squirrel" => "Light Squirrel", 
        "fal fa-staff" => "Light Staff", 
        "fal fa-stamp" => "Light Stamp", 
        "fal fa-star" => "Light Star", 
        "fal fa-star-and-crescent" => "Light Star And Crescent", 
        "fal fa-star-christmas" => "Light Star Christmas", 
        "fal fa-star-exclamation" => "Light Star Exclamation", 
        "fal fa-star-half" => "Light Star Half", 
        "fal fa-star-half-alt" => "Light Star Half Alt", 
        "fal fa-star-of-david" => "Light Star Of David", 
        "fal fa-star-of-life" => "Light Star Of Life", 
        "fal fa-stars" => "Light Stars", 
        "fal fa-steak" => "Light Steak", 
        "fal fa-steering-wheel" => "Light Steering Wheel", 
        "fal fa-step-backward" => "Light Step Backward", 
        "fal fa-step-forward" => "Light Step Forward", 
        "fal fa-stethoscope" => "Light Stethoscope", 
        "fal fa-sticky-note" => "Light Sticky Note", 
        "fal fa-stocking" => "Light Stocking", 
        "fal fa-stomach" => "Light Stomach", 
        "fal fa-stop" => "Light Stop", 
        "fal fa-stop-circle" => "Light Stop Circle", 
        "fal fa-stopwatch" => "Light Stopwatch", 
        "fal fa-store" => "Light Store", 
        "fal fa-store-alt" => "Light Store Alt", 
        "fal fa-stream" => "Light Stream", 
        "fal fa-street-view" => "Light Street View", 
        "fal fa-stretcher" => "Light Stretcher", 
        "fal fa-strikethrough" => "Light Strikethrough", 
        "fal fa-stroopwafel" => "Light Stroopwafel", 
        "fal fa-subscript" => "Light Subscript", 
        "fal fa-subway" => "Light Subway", 
        "fal fa-suitcase" => "Light Suitcase", 
        "fal fa-suitcase-rolling" => "Light Suitcase Rolling", 
        "fal fa-sun" => "Light Sun", 
        "fal fa-sun-cloud" => "Light Sun Cloud", 
        "fal fa-sun-dust" => "Light Sun Dust", 
        "fal fa-sun-haze" => "Light Sun Haze", 
        "fal fa-sunrise" => "Light Sunrise", 
        "fal fa-sunset" => "Light Sunset", 
        "fal fa-superscript" => "Light Superscript", 
        "fal fa-surprise" => "Light Surprise", 
        "fal fa-swatchbook" => "Light Swatchbook", 
        "fal fa-swimmer" => "Light Swimmer", 
        "fal fa-swimming-pool" => "Light Swimming Pool", 
        "fal fa-sword" => "Light Sword", 
        "fal fa-swords" => "Light Swords", 
        "fal fa-synagogue" => "Light Synagogue", 
        "fal fa-sync" => "Light Sync", 
        "fal fa-sync-alt" => "Light Sync Alt", 
        "fal fa-syringe" => "Light Syringe", 
        "fal fa-table" => "Light Table", 
        "fal fa-table-tennis" => "Light Table Tennis", 
        "fal fa-tablet" => "Light Tablet", 
        "fal fa-tablet-alt" => "Light Tablet Alt", 
        "fal fa-tablet-android" => "Light Tablet Android", 
        "fal fa-tablet-android-alt" => "Light Tablet Android Alt", 
        "fal fa-tablet-rugged" => "Light Tablet Rugged", 
        "fal fa-tablets" => "Light Tablets", 
        "fal fa-tachometer" => "Light Tachometer", 
        "fal fa-tachometer-alt" => "Light Tachometer Alt", 
        "fal fa-tachometer-alt-average" => "Light Tachometer Alt Average", 
        "fal fa-tachometer-alt-fast" => "Light Tachometer Alt Fast", 
        "fal fa-tachometer-alt-fastest" => "Light Tachometer Alt Fastest", 
        "fal fa-tachometer-alt-slow" => "Light Tachometer Alt Slow", 
        "fal fa-tachometer-alt-slowest" => "Light Tachometer Alt Slowest", 
        "fal fa-tachometer-average" => "Light Tachometer Average", 
        "fal fa-tachometer-fast" => "Light Tachometer Fast", 
        "fal fa-tachometer-fastest" => "Light Tachometer Fastest", 
        "fal fa-tachometer-slow" => "Light Tachometer Slow", 
        "fal fa-tachometer-slowest" => "Light Tachometer Slowest", 
        "fal fa-taco" => "Light Taco", 
        "fal fa-tag" => "Light Tag", 
        "fal fa-tags" => "Light Tags", 
        "fal fa-tally" => "Light Tally", 
        "fal fa-tanakh" => "Light Tanakh", 
        "fal fa-tape" => "Light Tape", 
        "fal fa-tasks" => "Light Tasks", 
        "fal fa-tasks-alt" => "Light Tasks Alt", 
        "fal fa-taxi" => "Light Taxi", 
        "fal fa-teeth" => "Light Teeth", 
        "fal fa-teeth-open" => "Light Teeth Open", 
        "fal fa-temperature-frigid" => "Light Temperature Frigid", 
        "fal fa-temperature-high" => "Light Temperature High", 
        "fal fa-temperature-hot" => "Light Temperature Hot", 
        "fal fa-temperature-low" => "Light Temperature Low", 
        "fal fa-tenge" => "Light Tenge", 
        "fal fa-tennis-ball" => "Light Tennis Ball", 
        "fal fa-terminal" => "Light Terminal", 
        "fal fa-text-height" => "Light Text Height", 
        "fal fa-text-width" => "Light Text Width", 
        "fal fa-th" => "Light Th", 
        "fal fa-th-large" => "Light Th Large", 
        "fal fa-th-list" => "Light Th List", 
        "fal fa-theater-masks" => "Light Theater Masks", 
        "fal fa-thermometer" => "Light Thermometer", 
        "fal fa-thermometer-empty" => "Light Thermometer Empty", 
        "fal fa-thermometer-full" => "Light Thermometer Full", 
        "fal fa-thermometer-half" => "Light Thermometer Half", 
        "fal fa-thermometer-quarter" => "Light Thermometer Quarter", 
        "fal fa-thermometer-three-quarters" => "Light Thermometer Three Quarters", 
        "fal fa-theta" => "Light Theta", 
        "fal fa-thumbs-down" => "Light Thumbs Down", 
        "fal fa-thumbs-up" => "Light Thumbs Up", 
        "fal fa-thumbtack" => "Light Thumbtack", 
        "fal fa-thunderstorm" => "Light Thunderstorm", 
        "fal fa-thunderstorm-moon" => "Light Thunderstorm Moon", 
        "fal fa-thunderstorm-sun" => "Light Thunderstorm Sun", 
        "fal fa-ticket" => "Light Ticket", 
        "fal fa-ticket-alt" => "Light Ticket Alt", 
        "fal fa-tilde" => "Light Tilde", 
        "fal fa-times" => "Light Times", 
        "fal fa-times-circle" => "Light Times Circle", 
        "fal fa-times-hexagon" => "Light Times Hexagon", 
        "fal fa-times-octagon" => "Light Times Octagon", 
        "fal fa-times-square" => "Light Times Square", 
        "fal fa-tint" => "Light Tint", 
        "fal fa-tint-slash" => "Light Tint Slash", 
        "fal fa-tire" => "Light Tire", 
        "fal fa-tire-flat" => "Light Tire Flat", 
        "fal fa-tire-pressure-warning" => "Light Tire Pressure Warning", 
        "fal fa-tire-rugged" => "Light Tire Rugged", 
        "fal fa-tired" => "Light Tired", 
        "fal fa-toggle-off" => "Light Toggle Off", 
        "fal fa-toggle-on" => "Light Toggle On", 
        "fal fa-toilet" => "Light Toilet", 
        "fal fa-toilet-paper" => "Light Toilet Paper", 
        "fal fa-toilet-paper-alt" => "Light Toilet Paper Alt", 
        "fal fa-tombstone" => "Light Tombstone", 
        "fal fa-tombstone-alt" => "Light Tombstone Alt", 
        "fal fa-toolbox" => "Light Toolbox", 
        "fal fa-tools" => "Light Tools", 
        "fal fa-tooth" => "Light Tooth", 
        "fal fa-toothbrush" => "Light Toothbrush", 
        "fal fa-torah" => "Light Torah", 
        "fal fa-torii-gate" => "Light Torii Gate", 
        "fal fa-tornado" => "Light Tornado", 
        "fal fa-tractor" => "Light Tractor", 
        "fal fa-trademark" => "Light Trademark", 
        "fal fa-traffic-cone" => "Light Traffic Cone", 
        "fal fa-traffic-light" => "Light Traffic Light", 
        "fal fa-traffic-light-go" => "Light Traffic Light Go", 
        "fal fa-traffic-light-slow" => "Light Traffic Light Slow", 
        "fal fa-traffic-light-stop" => "Light Traffic Light Stop", 
        "fal fa-train" => "Light Train", 
        "fal fa-tram" => "Light Tram", 
        "fal fa-transgender" => "Light Transgender", 
        "fal fa-transgender-alt" => "Light Transgender Alt", 
        "fal fa-trash" => "Light Trash", 
        "fal fa-trash-alt" => "Light Trash Alt", 
        "fal fa-trash-restore" => "Light Trash Restore", 
        "fal fa-trash-restore-alt" => "Light Trash Restore Alt", 
        "fal fa-treasure-chest" => "Light Treasure Chest", 
        "fal fa-tree" => "Light Tree", 
        "fal fa-tree-alt" => "Light Tree Alt", 
        "fal fa-tree-christmas" => "Light Tree Christmas", 
        "fal fa-tree-decorated" => "Light Tree Decorated", 
        "fal fa-tree-large" => "Light Tree Large", 
        "fal fa-tree-palm" => "Light Tree Palm", 
        "fal fa-trees" => "Light Trees", 
        "fal fa-triangle" => "Light Triangle", 
        "fal fa-trophy" => "Light Trophy", 
        "fal fa-trophy-alt" => "Light Trophy Alt", 
        "fal fa-truck" => "Light Truck", 
        "fal fa-truck-container" => "Light Truck Container", 
        "fal fa-truck-couch" => "Light Truck Couch", 
        "fal fa-truck-loading" => "Light Truck Loading", 
        "fal fa-truck-monster" => "Light Truck Monster", 
        "fal fa-truck-moving" => "Light Truck Moving", 
        "fal fa-truck-pickup" => "Light Truck Pickup", 
        "fal fa-truck-plow" => "Light Truck Plow", 
        "fal fa-truck-ramp" => "Light Truck Ramp", 
        "fal fa-tshirt" => "Light Tshirt", 
        "fal fa-tty" => "Light Tty", 
        "fal fa-turkey" => "Light Turkey", 
        "fal fa-turtle" => "Light Turtle", 
        "fal fa-tv" => "Light Tv", 
        "fal fa-tv-retro" => "Light Tv Retro", 
        "fal fa-umbrella" => "Light Umbrella", 
        "fal fa-umbrella-beach" => "Light Umbrella Beach", 
        "fal fa-underline" => "Light Underline", 
        "fal fa-undo" => "Light Undo", 
        "fal fa-undo-alt" => "Light Undo Alt", 
        "fal fa-unicorn" => "Light Unicorn", 
        "fal fa-union" => "Light Union", 
        "fal fa-universal-access" => "Light Universal Access", 
        "fal fa-university" => "Light University", 
        "fal fa-unlink" => "Light Unlink", 
        "fal fa-unlock" => "Light Unlock", 
        "fal fa-unlock-alt" => "Light Unlock Alt", 
        "fal fa-upload" => "Light Upload", 
        "fal fa-usd-circle" => "Light Usd Circle", 
        "fal fa-usd-square" => "Light Usd Square", 
        "fal fa-user" => "Light User", 
        "fal fa-user-alt" => "Light User Alt", 
        "fal fa-user-alt-slash" => "Light User Alt Slash", 
        "fal fa-user-astronaut" => "Light User Astronaut", 
        "fal fa-user-chart" => "Light User Chart", 
        "fal fa-user-check" => "Light User Check", 
        "fal fa-user-circle" => "Light User Circle", 
        "fal fa-user-clock" => "Light User Clock", 
        "fal fa-user-cog" => "Light User Cog", 
        "fal fa-user-crown" => "Light User Crown", 
        "fal fa-user-edit" => "Light User Edit", 
        "fal fa-user-friends" => "Light User Friends", 
        "fal fa-user-graduate" => "Light User Graduate", 
        "fal fa-user-hard-hat" => "Light User Hard Hat", 
        "fal fa-user-headset" => "Light User Headset", 
        "fal fa-user-injured" => "Light User Injured", 
        "fal fa-user-lock" => "Light User Lock", 
        "fal fa-user-md" => "Light User Md", 
        "fal fa-user-md-chat" => "Light User Md Chat", 
        "fal fa-user-minus" => "Light User Minus", 
        "fal fa-user-ninja" => "Light User Ninja", 
        "fal fa-user-nurse" => "Light User Nurse", 
        "fal fa-user-plus" => "Light User Plus", 
        "fal fa-user-secret" => "Light User Secret", 
        "fal fa-user-shield" => "Light User Shield", 
        "fal fa-user-slash" => "Light User Slash", 
        "fal fa-user-tag" => "Light User Tag", 
        "fal fa-user-tie" => "Light User Tie", 
        "fal fa-user-times" => "Light User Times", 
        "fal fa-users" => "Light Users", 
        "fal fa-users-class" => "Light Users Class", 
        "fal fa-users-cog" => "Light Users Cog", 
        "fal fa-users-crown" => "Light Users Crown", 
        "fal fa-users-medical" => "Light Users Medical", 
        "fal fa-utensil-fork" => "Light Utensil Fork", 
        "fal fa-utensil-knife" => "Light Utensil Knife", 
        "fal fa-utensil-spoon" => "Light Utensil Spoon", 
        "fal fa-utensils" => "Light Utensils", 
        "fal fa-utensils-alt" => "Light Utensils Alt", 
        "fal fa-value-absolute" => "Light Value Absolute", 
        "fal fa-vector-square" => "Light Vector Square", 
        "fal fa-venus" => "Light Venus", 
        "fal fa-venus-double" => "Light Venus Double", 
        "fal fa-venus-mars" => "Light Venus Mars", 
        "fal fa-vial" => "Light Vial", 
        "fal fa-vials" => "Light Vials", 
        "fal fa-video" => "Light Video", 
        "fal fa-video-plus" => "Light Video Plus", 
        "fal fa-video-slash" => "Light Video Slash", 
        "fal fa-vihara" => "Light Vihara", 
        "fal fa-volcano" => "Light Volcano", 
        "fal fa-volleyball-ball" => "Light Volleyball Ball", 
        "fal fa-volume" => "Light Volume", 
        "fal fa-volume-down" => "Light Volume Down", 
        "fal fa-volume-mute" => "Light Volume Mute", 
        "fal fa-volume-off" => "Light Volume Off", 
        "fal fa-volume-slash" => "Light Volume Slash", 
        "fal fa-volume-up" => "Light Volume Up", 
        "fal fa-vote-nay" => "Light Vote Nay", 
        "fal fa-vote-yea" => "Light Vote Yea", 
        "fal fa-vr-cardboard" => "Light Vr Cardboard", 
        "fal fa-walker" => "Light Walker", 
        "fal fa-walking" => "Light Walking", 
        "fal fa-wallet" => "Light Wallet", 
        "fal fa-wand" => "Light Wand", 
        "fal fa-wand-magic" => "Light Wand Magic", 
        "fal fa-warehouse" => "Light Warehouse", 
        "fal fa-warehouse-alt" => "Light Warehouse Alt", 
        "fal fa-watch" => "Light Watch", 
        "fal fa-watch-fitness" => "Light Watch Fitness", 
        "fal fa-water" => "Light Water", 
        "fal fa-water-lower" => "Light Water Lower", 
        "fal fa-water-rise" => "Light Water Rise", 
        "fal fa-wave-square" => "Light Wave Square", 
        "fal fa-webcam" => "Light Webcam", 
        "fal fa-webcam-slash" => "Light Webcam Slash", 
        "fal fa-weight" => "Light Weight", 
        "fal fa-weight-hanging" => "Light Weight Hanging", 
        "fal fa-whale" => "Light Whale", 
        "fal fa-wheat" => "Light Wheat", 
        "fal fa-wheelchair" => "Light Wheelchair", 
        "fal fa-whistle" => "Light Whistle", 
        "fal fa-wifi" => "Light Wifi", 
        "fal fa-wifi-1" => "Light Wifi 1", 
        "fal fa-wifi-2" => "Light Wifi 2", 
        "fal fa-wifi-slash" => "Light Wifi Slash", 
        "fal fa-wind" => "Light Wind", 
        "fal fa-wind-warning" => "Light Wind Warning", 
        "fal fa-window" => "Light Window", 
        "fal fa-window-alt" => "Light Window Alt", 
        "fal fa-window-close" => "Light Window Close", 
        "fal fa-window-maximize" => "Light Window Maximize", 
        "fal fa-window-minimize" => "Light Window Minimize", 
        "fal fa-window-restore" => "Light Window Restore", 
        "fal fa-windsock" => "Light Windsock", 
        "fal fa-wine-bottle" => "Light Wine Bottle", 
        "fal fa-wine-glass" => "Light Wine Glass", 
        "fal fa-wine-glass-alt" => "Light Wine Glass Alt", 
        "fal fa-won-sign" => "Light Won Sign", 
        "fal fa-wreath" => "Light Wreath", 
        "fal fa-wrench" => "Light Wrench", 
        "fal fa-x-ray" => "Light X Ray", 
        "fal fa-yen-sign" => "Light Yen Sign", 
        "fal fa-yin-yang" => "Light Yin Yang", 
        "fab fa-500px" => "Brand 500px", 
        "fab fa-accessible-icon" => "Brand Accessible Icon", 
        "fab fa-accusoft" => "Brand Accusoft", 
        "fab fa-acquisitions-incorporated" => "Brand Acquisitions Incorporated", 
        "fab fa-adn" => "Brand Adn", 
        "fab fa-adobe" => "Brand Adobe", 
        "fab fa-adversal" => "Brand Adversal", 
        "fab fa-affiliatetheme" => "Brand Affiliatetheme", 
        "fab fa-airbnb" => "Brand Airbnb", 
        "fab fa-algolia" => "Brand Algolia", 
        "fab fa-alipay" => "Brand Alipay", 
        "fab fa-amazon" => "Brand Amazon", 
        "fab fa-amazon-pay" => "Brand Amazon Pay", 
        "fab fa-amilia" => "Brand Amilia", 
        "fab fa-android" => "Brand Android", 
        "fab fa-angellist" => "Brand Angellist", 
        "fab fa-angrycreative" => "Brand Angrycreative", 
        "fab fa-angular" => "Brand Angular", 
        "fab fa-app-store" => "Brand App Store", 
        "fab fa-app-store-ios" => "Brand App Store Ios", 
        "fab fa-apper" => "Brand Apper", 
        "fab fa-apple" => "Brand Apple", 
        "fab fa-apple-pay" => "Brand Apple Pay", 
        "fab fa-artstation" => "Brand Artstation", 
        "fab fa-asymmetrik" => "Brand Asymmetrik", 
        "fab fa-atlassian" => "Brand Atlassian", 
        "fab fa-audible" => "Brand Audible", 
        "fab fa-autoprefixer" => "Brand Autoprefixer", 
        "fab fa-avianex" => "Brand Avianex", 
        "fab fa-aviato" => "Brand Aviato", 
        "fab fa-aws" => "Brand Aws", 
        "fab fa-bandcamp" => "Brand Bandcamp", 
        "fab fa-battle-net" => "Brand Battle Net", 
        "fab fa-behance" => "Brand Behance", 
        "fab fa-behance-square" => "Brand Behance Square", 
        "fab fa-bimobject" => "Brand Bimobject", 
        "fab fa-bitbucket" => "Brand Bitbucket", 
        "fab fa-bitcoin" => "Brand Bitcoin", 
        "fab fa-bity" => "Brand Bity", 
        "fab fa-black-tie" => "Brand Black Tie", 
        "fab fa-blackberry" => "Brand Blackberry", 
        "fab fa-blogger" => "Brand Blogger", 
        "fab fa-blogger-b" => "Brand Blogger B", 
        "fab fa-bluetooth" => "Brand Bluetooth", 
        "fab fa-bluetooth-b" => "Brand Bluetooth B", 
        "fab fa-bootstrap" => "Brand Bootstrap", 
        "fab fa-btc" => "Brand Btc", 
        "fab fa-buffer" => "Brand Buffer", 
        "fab fa-buromobelexperte" => "Brand Buromobelexperte", 
        "fab fa-buysellads" => "Brand Buysellads", 
        "fab fa-canadian-maple-leaf" => "Brand Canadian Maple Leaf", 
        "fab fa-cc-amazon-pay" => "Brand Cc Amazon Pay", 
        "fab fa-cc-amex" => "Brand Cc Amex", 
        "fab fa-cc-apple-pay" => "Brand Cc Apple Pay", 
        "fab fa-cc-diners-club" => "Brand Cc Diners Club", 
        "fab fa-cc-discover" => "Brand Cc Discover", 
        "fab fa-cc-jcb" => "Brand Cc Jcb", 
        "fab fa-cc-mastercard" => "Brand Cc Mastercard", 
        "fab fa-cc-paypal" => "Brand Cc Paypal", 
        "fab fa-cc-stripe" => "Brand Cc Stripe", 
        "fab fa-cc-visa" => "Brand Cc Visa", 
        "fab fa-centercode" => "Brand Centercode", 
        "fab fa-centos" => "Brand Centos", 
        "fab fa-chrome" => "Brand Chrome", 
        "fab fa-chromecast" => "Brand Chromecast", 
        "fab fa-cloudscale" => "Brand Cloudscale", 
        "fab fa-cloudsmith" => "Brand Cloudsmith", 
        "fab fa-cloudversify" => "Brand Cloudversify", 
        "fab fa-codepen" => "Brand Codepen", 
        "fab fa-codiepie" => "Brand Codiepie", 
        "fab fa-confluence" => "Brand Confluence", 
        "fab fa-connectdevelop" => "Brand Connectdevelop", 
        "fab fa-contao" => "Brand Contao", 
        "fab fa-cpanel" => "Brand Cpanel", 
        "fab fa-creative-commons" => "Brand Creative Commons", 
        "fab fa-creative-commons-by" => "Brand Creative Commons By", 
        "fab fa-creative-commons-nc" => "Brand Creative Commons Nc", 
        "fab fa-creative-commons-nc-eu" => "Brand Creative Commons Nc Eu", 
        "fab fa-creative-commons-nc-jp" => "Brand Creative Commons Nc Jp", 
        "fab fa-creative-commons-nd" => "Brand Creative Commons Nd", 
        "fab fa-creative-commons-pd" => "Brand Creative Commons Pd", 
        "fab fa-creative-commons-pd-alt" => "Brand Creative Commons Pd Alt", 
        "fab fa-creative-commons-remix" => "Brand Creative Commons Remix", 
        "fab fa-creative-commons-sa" => "Brand Creative Commons Sa", 
        "fab fa-creative-commons-sampling" => "Brand Creative Commons Sampling", 
        "fab fa-creative-commons-sampling-plus" => "Brand Creative Commons Sampling Plus", 
        "fab fa-creative-commons-share" => "Brand Creative Commons Share", 
        "fab fa-creative-commons-zero" => "Brand Creative Commons Zero", 
        "fab fa-critical-role" => "Brand Critical Role", 
        "fab fa-css3" => "Brand Css3", 
        "fab fa-css3-alt" => "Brand Css3 Alt", 
        "fab fa-cuttlefish" => "Brand Cuttlefish", 
        "fab fa-d-and-d" => "Brand D And D", 
        "fab fa-d-and-d-beyond" => "Brand D And D Beyond", 
        "fab fa-dashcube" => "Brand Dashcube", 
        "fab fa-delicious" => "Brand Delicious", 
        "fab fa-deploydog" => "Brand Deploydog", 
        "fab fa-deskpro" => "Brand Deskpro", 
        "fab fa-dev" => "Brand Dev", 
        "fab fa-deviantart" => "Brand Deviantart", 
        "fab fa-dhl" => "Brand Dhl", 
        "fab fa-diaspora" => "Brand Diaspora", 
        "fab fa-digg" => "Brand Digg", 
        "fab fa-digital-ocean" => "Brand Digital Ocean", 
        "fab fa-discord" => "Brand Discord", 
        "fab fa-discourse" => "Brand Discourse", 
        "fab fa-dochub" => "Brand Dochub", 
        "fab fa-docker" => "Brand Docker", 
        "fab fa-draft2digital" => "Brand Draft2digital", 
        "fab fa-dribbble" => "Brand Dribbble", 
        "fab fa-dribbble-square" => "Brand Dribbble Square", 
        "fab fa-dropbox" => "Brand Dropbox", 
        "fab fa-drupal" => "Brand Drupal", 
        "fab fa-dyalog" => "Brand Dyalog", 
        "fab fa-earlybirds" => "Brand Earlybirds", 
        "fab fa-ebay" => "Brand Ebay", 
        "fab fa-edge" => "Brand Edge", 
        "fab fa-elementor" => "Brand Elementor", 
        "fab fa-ello" => "Brand Ello", 
        "fab fa-ember" => "Brand Ember", 
        "fab fa-empire" => "Brand Empire", 
        "fab fa-envira" => "Brand Envira", 
        "fab fa-erlang" => "Brand Erlang", 
        "fab fa-ethereum" => "Brand Ethereum", 
        "fab fa-etsy" => "Brand Etsy", 
        "fab fa-evernote" => "Brand Evernote", 
        "fab fa-expeditedssl" => "Brand Expeditedssl", 
        "fab fa-facebook" => "Brand Facebook", 
        "fab fa-facebook-f" => "Brand Facebook F", 
        "fab fa-facebook-messenger" => "Brand Facebook Messenger", 
        "fab fa-facebook-square" => "Brand Facebook Square", 
        "fab fa-fantasy-flight-games" => "Brand Fantasy Flight Games", 
        "fab fa-fedex" => "Brand Fedex", 
        "fab fa-fedora" => "Brand Fedora", 
        "fab fa-figma" => "Brand Figma", 
        "fab fa-firefox" => "Brand Firefox", 
        "fab fa-first-order" => "Brand First Order", 
        "fab fa-first-order-alt" => "Brand First Order Alt", 
        "fab fa-firstdraft" => "Brand Firstdraft", 
        "fab fa-flickr" => "Brand Flickr", 
        "fab fa-flipboard" => "Brand Flipboard", 
        "fab fa-fly" => "Brand Fly", 
        "fab fa-font-awesome" => "Brand Font Awesome", 
        "fab fa-font-awesome-alt" => "Brand Font Awesome Alt", 
        "fab fa-font-awesome-flag" => "Brand Font Awesome Flag", 
        "fab fa-fonticons" => "Brand Fonticons", 
        "fab fa-fonticons-fi" => "Brand Fonticons Fi", 
        "fab fa-fort-awesome" => "Brand Fort Awesome", 
        "fab fa-fort-awesome-alt" => "Brand Fort Awesome Alt", 
        "fab fa-forumbee" => "Brand Forumbee", 
        "fab fa-foursquare" => "Brand Foursquare", 
        "fab fa-free-code-camp" => "Brand Free Code Camp", 
        "fab fa-freebsd" => "Brand Freebsd", 
        "fab fa-fulcrum" => "Brand Fulcrum", 
        "fab fa-galactic-republic" => "Brand Galactic Republic", 
        "fab fa-galactic-senate" => "Brand Galactic Senate", 
        "fab fa-get-pocket" => "Brand Get Pocket", 
        "fab fa-gg" => "Brand Gg", 
        "fab fa-gg-circle" => "Brand Gg Circle", 
        "fab fa-git" => "Brand Git", 
        "fab fa-git-square" => "Brand Git Square", 
        "fab fa-github" => "Brand Github", 
        "fab fa-github-alt" => "Brand Github Alt", 
        "fab fa-github-square" => "Brand Github Square", 
        "fab fa-gitkraken" => "Brand Gitkraken", 
        "fab fa-gitlab" => "Brand Gitlab", 
        "fab fa-gitter" => "Brand Gitter", 
        "fab fa-glide" => "Brand Glide", 
        "fab fa-glide-g" => "Brand Glide G", 
        "fab fa-gofore" => "Brand Gofore", 
        "fab fa-goodreads" => "Brand Goodreads", 
        "fab fa-goodreads-g" => "Brand Goodreads G", 
        "fab fa-google" => "Brand Google", 
        "fab fa-google-drive" => "Brand Google Drive", 
        "fab fa-google-play" => "Brand Google Play", 
        "fab fa-google-plus" => "Brand Google Plus", 
        "fab fa-google-plus-g" => "Brand Google Plus G", 
        "fab fa-google-plus-square" => "Brand Google Plus Square", 
        "fab fa-google-wallet" => "Brand Google Wallet", 
        "fab fa-gratipay" => "Brand Gratipay", 
        "fab fa-grav" => "Brand Grav", 
        "fab fa-gripfire" => "Brand Gripfire", 
        "fab fa-grunt" => "Brand Grunt", 
        "fab fa-gulp" => "Brand Gulp", 
        "fab fa-hacker-news" => "Brand Hacker News", 
        "fab fa-hacker-news-square" => "Brand Hacker News Square", 
        "fab fa-hackerrank" => "Brand Hackerrank", 
        "fab fa-hips" => "Brand Hips", 
        "fab fa-hire-a-helper" => "Brand Hire A Helper", 
        "fab fa-hooli" => "Brand Hooli", 
        "fab fa-hornbill" => "Brand Hornbill", 
        "fab fa-hotjar" => "Brand Hotjar", 
        "fab fa-houzz" => "Brand Houzz", 
        "fab fa-html5" => "Brand Html5", 
        "fab fa-hubspot" => "Brand Hubspot", 
        "fab fa-imdb" => "Brand Imdb", 
        "fab fa-instagram" => "Brand Instagram", 
        "fab fa-intercom" => "Brand Intercom", 
        "fab fa-internet-explorer" => "Brand Internet Explorer", 
        "fab fa-invision" => "Brand Invision", 
        "fab fa-ioxhost" => "Brand Ioxhost", 
        "fab fa-itch-io" => "Brand Itch Io", 
        "fab fa-itunes" => "Brand Itunes", 
        "fab fa-itunes-note" => "Brand Itunes Note", 
        "fab fa-java" => "Brand Java", 
        "fab fa-jedi-order" => "Brand Jedi Order", 
        "fab fa-jenkins" => "Brand Jenkins", 
        "fab fa-jira" => "Brand Jira", 
        "fab fa-joget" => "Brand Joget", 
        "fab fa-joomla" => "Brand Joomla", 
        "fab fa-js" => "Brand Js", 
        "fab fa-js-square" => "Brand Js Square", 
        "fab fa-jsfiddle" => "Brand Jsfiddle", 
        "fab fa-kaggle" => "Brand Kaggle", 
        "fab fa-keybase" => "Brand Keybase", 
        "fab fa-keycdn" => "Brand Keycdn", 
        "fab fa-kickstarter" => "Brand Kickstarter", 
        "fab fa-kickstarter-k" => "Brand Kickstarter K", 
        "fab fa-korvue" => "Brand Korvue", 
        "fab fa-laravel" => "Brand Laravel", 
        "fab fa-lastfm" => "Brand Lastfm", 
        "fab fa-lastfm-square" => "Brand Lastfm Square", 
        "fab fa-leanpub" => "Brand Leanpub", 
        "fab fa-less" => "Brand Less", 
        "fab fa-line" => "Brand Line", 
        "fab fa-linkedin" => "Brand Linkedin", 
        "fab fa-linkedin-in" => "Brand Linkedin In", 
        "fab fa-linode" => "Brand Linode", 
        "fab fa-linux" => "Brand Linux", 
        "fab fa-lyft" => "Brand Lyft", 
        "fab fa-magento" => "Brand Magento", 
        "fab fa-mailchimp" => "Brand Mailchimp", 
        "fab fa-mandalorian" => "Brand Mandalorian", 
        "fab fa-markdown" => "Brand Markdown", 
        "fab fa-mastodon" => "Brand Mastodon", 
        "fab fa-maxcdn" => "Brand Maxcdn", 
        "fab fa-medapps" => "Brand Medapps", 
        "fab fa-medium" => "Brand Medium", 
        "fab fa-medium-m" => "Brand Medium M", 
        "fab fa-medrt" => "Brand Medrt", 
        "fab fa-meetup" => "Brand Meetup", 
        "fab fa-megaport" => "Brand Megaport", 
        "fab fa-mendeley" => "Brand Mendeley", 
        "fab fa-microsoft" => "Brand Microsoft", 
        "fab fa-mix" => "Brand Mix", 
        "fab fa-mixcloud" => "Brand Mixcloud", 
        "fab fa-mizuni" => "Brand Mizuni", 
        "fab fa-modx" => "Brand Modx", 
        "fab fa-monero" => "Brand Monero", 
        "fab fa-napster" => "Brand Napster", 
        "fab fa-neos" => "Brand Neos", 
        "fab fa-nimblr" => "Brand Nimblr", 
        "fab fa-nintendo-switch" => "Brand Nintendo Switch", 
        "fab fa-node" => "Brand Node", 
        "fab fa-node-js" => "Brand Node Js", 
        "fab fa-npm" => "Brand Npm", 
        "fab fa-ns8" => "Brand Ns8", 
        "fab fa-nutritionix" => "Brand Nutritionix", 
        "fab fa-odnoklassniki" => "Brand Odnoklassniki", 
        "fab fa-odnoklassniki-square" => "Brand Odnoklassniki Square", 
        "fab fa-old-republic" => "Brand Old Republic", 
        "fab fa-opencart" => "Brand Opencart", 
        "fab fa-openid" => "Brand Openid", 
        "fab fa-opera" => "Brand Opera", 
        "fab fa-optin-monster" => "Brand Optin Monster", 
        "fab fa-osi" => "Brand Osi", 
        "fab fa-page4" => "Brand Page4", 
        "fab fa-pagelines" => "Brand Pagelines", 
        "fab fa-palfed" => "Brand Palfed", 
        "fab fa-patreon" => "Brand Patreon", 
        "fab fa-paypal" => "Brand Paypal", 
        "fab fa-penny-arcade" => "Brand Penny Arcade", 
        "fab fa-periscope" => "Brand Periscope", 
        "fab fa-phabricator" => "Brand Phabricator", 
        "fab fa-phoenix-framework" => "Brand Phoenix Framework", 
        "fab fa-phoenix-squadron" => "Brand Phoenix Squadron", 
        "fab fa-php" => "Brand Php", 
        "fab fa-pied-piper" => "Brand Pied Piper", 
        "fab fa-pied-piper-alt" => "Brand Pied Piper Alt", 
        "fab fa-pied-piper-hat" => "Brand Pied Piper Hat", 
        "fab fa-pied-piper-pp" => "Brand Pied Piper Pp", 
        "fab fa-pinterest" => "Brand Pinterest", 
        "fab fa-pinterest-p" => "Brand Pinterest P", 
        "fab fa-pinterest-square" => "Brand Pinterest Square", 
        "fab fa-playstation" => "Brand Playstation", 
        "fab fa-product-hunt" => "Brand Product Hunt", 
        "fab fa-pushed" => "Brand Pushed", 
        "fab fa-python" => "Brand Python", 
        "fab fa-qq" => "Brand Qq", 
        "fab fa-quinscape" => "Brand Quinscape", 
        "fab fa-quora" => "Brand Quora", 
        "fab fa-r-project" => "Brand R Project", 
        "fab fa-raspberry-pi" => "Brand Raspberry Pi", 
        "fab fa-ravelry" => "Brand Ravelry", 
        "fab fa-react" => "Brand React", 
        "fab fa-reacteurope" => "Brand Reacteurope", 
        "fab fa-readme" => "Brand Readme", 
        "fab fa-rebel" => "Brand Rebel", 
        "fab fa-red-river" => "Brand Red River", 
        "fab fa-reddit" => "Brand Reddit", 
        "fab fa-reddit-alien" => "Brand Reddit Alien", 
        "fab fa-reddit-square" => "Brand Reddit Square", 
        "fab fa-redhat" => "Brand Redhat", 
        "fab fa-renren" => "Brand Renren", 
        "fab fa-replyd" => "Brand Replyd", 
        "fab fa-researchgate" => "Brand Researchgate", 
        "fab fa-resolving" => "Brand Resolving", 
        "fab fa-rev" => "Brand Rev", 
        "fab fa-rocketchat" => "Brand Rocketchat", 
        "fab fa-rockrms" => "Brand Rockrms", 
        "fab fa-safari" => "Brand Safari", 
        "fab fa-salesforce" => "Brand Salesforce", 
        "fab fa-sass" => "Brand Sass", 
        "fab fa-schlix" => "Brand Schlix", 
        "fab fa-scribd" => "Brand Scribd", 
        "fab fa-searchengin" => "Brand Searchengin", 
        "fab fa-sellcast" => "Brand Sellcast", 
        "fab fa-sellsy" => "Brand Sellsy", 
        "fab fa-servicestack" => "Brand Servicestack", 
        "fab fa-shirtsinbulk" => "Brand Shirtsinbulk", 
        "fab fa-shopware" => "Brand Shopware", 
        "fab fa-simplybuilt" => "Brand Simplybuilt", 
        "fab fa-sistrix" => "Brand Sistrix", 
        "fab fa-sith" => "Brand Sith", 
        "fab fa-sketch" => "Brand Sketch", 
        "fab fa-skyatlas" => "Brand Skyatlas", 
        "fab fa-skype" => "Brand Skype", 
        "fab fa-slack" => "Brand Slack", 
        "fab fa-slack-hash" => "Brand Slack Hash", 
        "fab fa-slideshare" => "Brand Slideshare", 
        "fab fa-snapchat" => "Brand Snapchat", 
        "fab fa-snapchat-ghost" => "Brand Snapchat Ghost", 
        "fab fa-snapchat-square" => "Brand Snapchat Square", 
        "fab fa-soundcloud" => "Brand Soundcloud", 
        "fab fa-sourcetree" => "Brand Sourcetree", 
        "fab fa-speakap" => "Brand Speakap", 
        "fab fa-speaker-deck" => "Brand Speaker Deck", 
        "fab fa-spotify" => "Brand Spotify", 
        "fab fa-squarespace" => "Brand Squarespace", 
        "fab fa-stack-exchange" => "Brand Stack Exchange", 
        "fab fa-stack-overflow" => "Brand Stack Overflow", 
        "fab fa-staylinked" => "Brand Staylinked", 
        "fab fa-steam" => "Brand Steam", 
        "fab fa-steam-square" => "Brand Steam Square", 
        "fab fa-steam-symbol" => "Brand Steam Symbol", 
        "fab fa-sticker-mule" => "Brand Sticker Mule", 
        "fab fa-strava" => "Brand Strava", 
        "fab fa-stripe" => "Brand Stripe", 
        "fab fa-stripe-s" => "Brand Stripe S", 
        "fab fa-studiovinari" => "Brand Studiovinari", 
        "fab fa-stumbleupon" => "Brand Stumbleupon", 
        "fab fa-stumbleupon-circle" => "Brand Stumbleupon Circle", 
        "fab fa-superpowers" => "Brand Superpowers", 
        "fab fa-supple" => "Brand Supple", 
        "fab fa-suse" => "Brand Suse", 
        "fab fa-symfony" => "Brand Symfony", 
        "fab fa-teamspeak" => "Brand Teamspeak", 
        "fab fa-telegram" => "Brand Telegram", 
        "fab fa-telegram-plane" => "Brand Telegram Plane", 
        "fab fa-tencent-weibo" => "Brand Tencent Weibo", 
        "fab fa-the-red-yeti" => "Brand The Red Yeti", 
        "fab fa-themeco" => "Brand Themeco", 
        "fab fa-themeisle" => "Brand Themeisle", 
        "fab fa-think-peaks" => "Brand Think Peaks", 
        "fab fa-trade-federation" => "Brand Trade Federation", 
        "fab fa-trello" => "Brand Trello", 
        "fab fa-tripadvisor" => "Brand Tripadvisor", 
        "fab fa-tumblr" => "Brand Tumblr", 
        "fab fa-tumblr-square" => "Brand Tumblr Square", 
        "fab fa-twitch" => "Brand Twitch", 
        "fab fa-twitter" => "Brand Twitter", 
        "fab fa-twitter-square" => "Brand Twitter Square", 
        "fab fa-typo3" => "Brand Typo3", 
        "fab fa-uber" => "Brand Uber", 
        "fab fa-ubuntu" => "Brand Ubuntu", 
        "fab fa-uikit" => "Brand Uikit", 
        "fab fa-uniregistry" => "Brand Uniregistry", 
        "fab fa-untappd" => "Brand Untappd", 
        "fab fa-ups" => "Brand Ups", 
        "fab fa-usb" => "Brand Usb", 
        "fab fa-usps" => "Brand Usps", 
        "fab fa-ussunnah" => "Brand Ussunnah", 
        "fab fa-vaadin" => "Brand Vaadin", 
        "fab fa-viacoin" => "Brand Viacoin", 
        "fab fa-viadeo" => "Brand Viadeo", 
        "fab fa-viadeo-square" => "Brand Viadeo Square", 
        "fab fa-viber" => "Brand Viber", 
        "fab fa-vimeo" => "Brand Vimeo", 
        "fab fa-vimeo-square" => "Brand Vimeo Square", 
        "fab fa-vimeo-v" => "Brand Vimeo V", 
        "fab fa-vine" => "Brand Vine", 
        "fab fa-vk" => "Brand Vk", 
        "fab fa-vnv" => "Brand Vnv", 
        "fab fa-vuejs" => "Brand Vuejs", 
        "fab fa-waze" => "Brand Waze", 
        "fab fa-weebly" => "Brand Weebly", 
        "fab fa-weibo" => "Brand Weibo", 
        "fab fa-weixin" => "Brand Weixin", 
        "fab fa-whatsapp" => "Brand Whatsapp", 
        "fab fa-whatsapp-square" => "Brand Whatsapp Square", 
        "fab fa-whmcs" => "Brand Whmcs", 
        "fab fa-wikipedia-w" => "Brand Wikipedia W", 
        "fab fa-windows" => "Brand Windows", 
        "fab fa-wix" => "Brand Wix", 
        "fab fa-wizards-of-the-coast" => "Brand Wizards Of The Coast", 
        "fab fa-wolf-pack-battalion" => "Brand Wolf Pack Battalion", 
        "fab fa-wordpress" => "Brand Wordpress", 
        "fab fa-wordpress-simple" => "Brand Wordpress Simple", 
        "fab fa-wpbeginner" => "Brand Wpbeginner", 
        "fab fa-wpexplorer" => "Brand Wpexplorer", 
        "fab fa-wpforms" => "Brand Wpforms", 
        "fab fa-wpressr" => "Brand Wpressr", 
        "fab fa-xbox" => "Brand Xbox", 
        "fab fa-xing" => "Brand Xing", 
        "fab fa-xing-square" => "Brand Xing Square", 
        "fab fa-y-combinator" => "Brand Y Combinator", 
        "fab fa-yahoo" => "Brand Yahoo", 
        "fab fa-yammer" => "Brand Yammer", 
        "fab fa-yandex" => "Brand Yandex", 
        "fab fa-yandex-international" => "Brand Yandex International", 
        "fab fa-yarn" => "Brand Yarn", 
        "fab fa-yelp" => "Brand Yelp", 
        "fab fa-yoast" => "Brand Yoast", 
        "fab fa-youtube" => "Brand Youtube", 
        "fab fa-youtube-square" => "Brand Youtube Square", 
        "fab fa-zhihu" => "Brand Zhihu"
    );
    return $new_add;
}




/*
 * Elementor Templates List
 * return array
 */
function epress_elementor_template() {
    $templates = \Elementor\Plugin::instance()->templates_manager->get_source( 'local' )->get_items();
    $types = array();
    if ( empty( $templates ) ) {
        $template_lists = [ '0' => __( 'Do not Saved Templates.', 'epresscore' ) ];
    } else {
        $template_lists = [ '0' => __( 'Select Template', 'epresscore' ) ];
        foreach ( $templates as $template ) {
            $template_lists[ $template['template_id'] ] = $template['title'] . ' (' . $template['type'] . ')';
        }
    }
    return $template_lists;
}